(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17160,        487]*)
(*NotebookOutlinePosition[     81717,       2806]*)
(*  CellTagsIndexPosition[     81673,       2802]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Introduction"
}], "Title",
  CounterAssignments->{{"Title", -1}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[TextData[{
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "stores information in a kind of document called a ",
  StyleBox[ButtonBox["Notebook",
    ButtonData:>"Notebooks and Cells",
    ButtonStyle->"GettingStartedLink"],
    FontSlant->"Italic"],
  " which can contain text and graphics. The document you are now reading is \
itself a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebook. Notebooks are usually divided into sections consisting of \
groups of cells. When a group is closed, only the first cell in the group is \
displayed, and the group bracket is shown with a triangular flag at the \
bottom:"
}], "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, 30}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004m0000CA000`40O003h00Oogoo?Woo0002Oooo
000k0001Ool00003Ool000000?l003X0005oo`0000=oo`00Ool0odic>4ic0P000Goo00000goo001o
o`3oIcTgIcT00dic00000001Ool00003Ool007oo0?mW>CMW>@03CW<00000005oo`0000=oo`00Ool0
0VLi00=>LgooOol0ogoo<7oo0VLi00=>L`0000000Goo00000goo001oo`02IcT00dic0000003o000_
000017ooIcUW>Dic0P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<0
0P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo
001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic
001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool0
1@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<0
0P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo
001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic
001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool0
1@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<0
0P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo
001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic
001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool0
1@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<0
0P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo
001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic
001oo`3oOol^Ool01@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool0
1@00OomW>FLiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOol^Ool01@00OomW>FLiCW<0
0P000Goo00000goo001oo`02IcT00dic001oo`3oOolOOol5000:Ool01@00OomW>FLiCW<00P000Goo
00000goo001oo`02IcT00dic001oo`3oOolNOol70009Ool01@00OomS66LiCW<00P000Goo00000goo
001oo`02IcT00dic001oo`3oOolHOol501l00goo0000000300000goP001oo`08Ool01@00OomS66Li
CW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOolLOol00`0OOol000030002On000`00Oomo
o`07Ool01@00OomS66LiCW<00P000Goo00000goo001oo`02IcT00dic001oo`3oOolLOol00`0OOol0
00020003On000`00Oomoo`07Ool01@00OomS66LiCW<00P000Goo00000goo001oo`02IcT00dic001o
o`3oOolLOol0100OOol0000017oP00<007ooOol01goo00D007ooHaQW>Dic0080005oo`0000=oo`00
Ool00VLi00=>L`00Ool05goo0`000Woo2@0000Aoo`00000000=oo`@00003Ool0000000800004Ool0
00000002Ool70004Ool30004Ool2000017oo000000000Woo0P0000Aoo`000000009oo`<000=oo`L0
009oo`<0009oo`@00004Ool00000002ROol00`0OOol00005On000`00Oomoo`07Ool01@00OomS66Li
CW<00P000Goo00000goo001oo`02IcT00dic001oo`0<Ool60006Ool00`00Oomoo`03Ool20002Ool2
0002Ool20005Ool20003Ool20002Ool20002Ool20003Ool20004Ool200000goo00000002Ool20000
17oo000000000Woo0P0000Aoo`000000009oo`80009oo`04001oo`000003Ool20002Ool200000goo
00000002Ool20002Ool2002SOol00`0OOol0000400000goP001oo`08Ool01@00OomS66LiCW<00P00
0Goo00000goo001oo`02IcT00dic001oo`0<Ool60007Ool01000Oomoogoo0P000goo0P000Woo0P00
1Goo0P000goo0P000Woo0P000Woo0P000goo0P000goo0P000goo10000goo0P000Woo0P000Woo0P00
00=oo`0000001Goo0P000goo0P0000=oo`0000000goo0P0000=oo`0000000Woo0P00Xgoo00<07goo
0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0
37oo1P001goo1P000goo0P000Woo0P001Goo0P000goo0P000Woo0P000Woo0P000goo0P000goo0P00
0goo10000goo0P000Woo0P000Woo0P0000=oo`0000001Goo0P000goo0P0000=oo`0000000goo0P00
00=oo`0000000Woo0P00Xgoo00<07goo0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005o
o`0000=oo`00Ool00VLi00=>L`00Ool037oo1P001goo00<007ooOol00P0017oo0P000Woo0P001Goo
0P000goo0P000Woo0P000Woo0P000goo0P000goo0P000goo10000goo0P000Woo0P000Woo0P0000=o
o`0000000Woo0P0000=oo`0000000goo0P0000=oo`0000000goo0P0000=oo`0000000Woo0P00Xgoo
00<07goo0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>
L`00Ool037oo1P0027oo00@007oo000000Aoo`<00003Ool0000000Eoo`8000=oo`<00003Ool00000
009oo`8000=oo`D00004Ool00000Ool20002Ool2000017oo000000000Woo0P000Woo0P000Woo0P00
00Aoo`00001oo`8000=oo`80009oo`800003Ool00000009oo`<00003Ool000000:=oo`0301moo`00
00@00003On0007oo00Qoo`05001oof<HIcU>L`020001Ool00003Ool007oo009W>@03CW<007oo00ao
o`H000Qoo`@000=oo`<00003Ool0000000Ioo`80009oo`<00003Ool00000009oo`@00005Ool00000
001oo`020002Ool30004Ool2000017oo000007oo0`0000Aoo`00000000=oo`<00003Ool000000080
0004Ool000000003Ool30002Ool300000goo0000002TOol00`0OOol0000400000goP001oo`08Ool0
1@00OomS66LiCW<00P000Goo00000goo001oo`02IcT00dic001oo`0JOol3000@Ool2000;Ool2000D
Ool2000@Ool2002gOol00`0OOol0000400000goP001oo`08Ool01@00OomS66LiCW<00P000Goo0000
0goo001oo`02IcT00dic001oo`0KOol2000@Ool2000<Ool00`00Oomoo`0BOol2000AOol01000Oomo
ogoo0P00/Woo00<07goo0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=oo`00
Ool00VLi00=>L`00Ool06goo00<007ooOol03Woo10007goo0`005Goo0P00/Woo00<07goo00001000
00=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo77oo
00<07goo0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>
L`00Ool0ogoo77oo00<07goo0000100000=oh000Ool027oo00D007ooHaQW>Dic0080005oo`0000=o
o`00Ool00VLi00=>L`00Ool0ogoo6Goo100O00=oo`0000000`0000=oh000Ool027oo00D007ooHaQW
>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo77oo00<07goo0000100000=oh000Ool0
27oo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo67oo1@0O00=oo`00
On0017oP00<007ooOol01goo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0
ogoo7Woo1`002Goo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo7goo
1@002Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007oo
HaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005o
o`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool0
0VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0
ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007oo
HaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005o
o`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool0
0VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0
ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007oo
HaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005o
o`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool0
0VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0
ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007oo
HaQW>Dic0080005oo`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005o
o`0000=oo`00Ool00VLi00=>L`00Ool0ogoo;Woo00D007ooHaQW>Dic0080005oo`0000=oo`00Ool0
0VLi00=>L`000000o`00;`0000Aoof<HIcU>L`80005oo`0000=oo`00Ool00VLi00=oodicCW<0odic
;Tic00E:DVLiIcUS64ic0080005oo`0000=oo`00Ool0ofLi=fLi00=>L`0000000Goo00000goo001o
o`3oIcTgIcT00dic00000001Ool00003Ool007oo0?moocMoo`03IcT00000005oo`0000=oo`000000
o`00>@000Woo003oOolnOol00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{317, 77},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "To open a group of cells, double-click on a closed \
group\[CloseCurlyQuote]s cell bracket. For more information on the structure \
of Notebooks have a look at ",
  ButtonBox["Notebooks and Cells",
    ButtonStyle->"GettingStartedLink"],
  "."
}], "Text",
  GridBoxOptions->{RowLines->False}],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Course Overview"
}], "SectionFirst"],

Cell[TextData[{
  "\t",
  StyleBox["The purpose of computing is insight not numbers",
    FontSlant->"Italic"],
  "\[LongDash]Richard Hamming"
}], "Quote"],

Cell[TextData[{
  "The broad categories of computational physics are simulation, \
visualization and modelling. At a finer scale, computational physics embraces \
a wide range of areas\nincluding numerical methods, algorithms, and data \
analysis. Simulation and modelling are usually taught by stressing numerical \
techniques \[LongDash] this course focuses on\nusing symbolic or computer \
algebra \[LongDash] in particular, using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The objectives of this course are:"
}], "Text"],

Cell["\<\
1.to use computers as an aid to understanding real physical \
systems; \
\>", "BeginNumberedList"],

Cell["\<\
2.learn efficient methods for the analysis of these systems. \
\>", \
"NumberedList"],

Cell["\<\
This course is a \[OpenCurlyDoubleQuote]hands-on\
\[CloseCurlyDoubleQuote] laboratory course consisting of a number of \
computational experiments worth a total of 60%. Assessment is continuous and \
the final (take-home)
exam makes up the remaining 40%. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " References"
}], "Section"],

Cell[TextData[{
  "To learn more about ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["The Help Browser",
    ButtonData:>{"The Help Browser"},
    ButtonStyle->"GettingStartedLink"],
  " is the primary reference. Choosing ",
  StyleBox["Help. . .", "Menu"],
  " from the ",
  StyleBox["Help", "Menu"],
  " menu at any time gives you access to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s on-line documentation. ",
  "An overview of the capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is presented in the ",
  ButtonBox["Tour of ",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
    FontSlant->"Italic"],
  " section, and it is also suggested that you browse through the ",
  ButtonBox["Practical Introduction",
    ButtonData:>{"I1", None},
    ButtonStyle->"MainBookLink"],
  " section."
}], "Text"],

Cell[TextData[{
  "An up to date list of books about ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "is available at ",
  ButtonBox["http://www.wolfram.com/bookstore",
    ButtonData:>{
      URL[ "http://www.wolfram.com/bookstore"], None},
    ButtonStyle->"Hyperlink"],
  ". A number of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-related books can be borrowed from the FIZ library. The following \
resources are particularly useful:"
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  "Book: ",
  ButtonBox["on-line",
    ButtonData:>{"5.0.1"},
    ButtonStyle->"AddOnsLink"]
}], "BulletedList"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  "Standard Add-on Packages: ",
  ButtonBox["on-line",
    ButtonData:>{"5.0.1"},
    ButtonStyle->"AddOnsLink"]
}], "BulletedList"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Journal: ",
  ButtonBox["http://www.mathematica-journal.com",
    ButtonData:>{
      URL[ "http://www.mathematica-journal.com"], None},
    ButtonStyle->"Hyperlink"]
}], "BulletedList"],

Cell[TextData[{
  "Eric Weisstein's ",
  StyleBox["World of Mathematics",
    FontSlant->"Italic"],
  ": ",
  ButtonBox["http://mathworld.wolfram.com",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com"], None},
    ButtonStyle->"Hyperlink"]
}], "BulletedList"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Book-keeping"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Naming your Assignments"
}], "Subsection"],

Cell["\<\
It is important that you name your solution Notebooks in the \
correct format.\
\>", "Text"],

Cell[TextData[{
  "Do a ",
  StyleBox["Save As...", "Menu"],
  " renaming the first assignment Notebook using the format "
}], "Warning"],

Cell[TextData[{
  "\t",
  StyleBox["1.your_initials.nb", "InlineInputTraditionalForm"]
}], "Text"],

Cell[TextData[{
  "As an example, ",
  StyleBox["1.PCA.nb", "InlineInputTraditionalForm"],
  " is the correct name for my work."
}], "Text"],

Cell[TextData[{
  "It is important that you work with a ",
  StyleBox["local copy",
    FontSlant->"Italic"],
  " of your Notebook, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the Notebook is saved on the machine you are working on rather than on \
another machine somewhere else on the internet."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Exercises"
}], "Subsection"],

Cell["All exercises look like", "Text"],

Cell["What is your name?", "BeginEndQuestion"],

Cell[TextData[{
  "There are two ways in which you will asked to supply answers to questions. \
 Sometimes I will leave an answer field for you to write your solutions \
directly into the Notebook, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ",  "
}], "Text"],

Cell["", "Answer"],

Cell[TextData[{
  "You just need to position your cursor after the ",
  StyleBox[":", "Answer"],
  " and start typing. Much of the time though you will just enter a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command in the appropriate place and the output will be automatically \
recorded in the Notebook."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Submitting your Solutions"
}], "Subsection"],

Cell[TextData[{
  "Please submit your assignment solutions to the appropriate numbered folder \
at ",
  ButtonBox["ftp://ftp.physics.uwa.edu.au/incoming/",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/incoming/"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "You ",
  StyleBox["must",
    FontWeight->"Bold"],
  " also keep a copy of your edited Notebook on a local machine (and perhaps \
keep a floppy back-up too)."
}], "Warning"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 112, 5, 74, "Title",
  CounterAssignments->{{"Title", -1}}],
Cell[1902, 60, 29, 0, 26, "Author"],
Cell[1934, 62, 414, 12, 88, "Address"],
Cell[2351, 76, 711, 17, 84, "Text"],
Cell[3065, 95, 6998, 90, 87, 6884, 86, "GraphicsData", "Bitmap", "Graphics",
  Evaluatable->False],
Cell[10066, 187, 311, 8, 24, "Text"],

Cell[CellGroupData[{
Cell[10402, 199, 117, 7, 67, "SectionFirst"],
Cell[10522, 208, 155, 5, 26, "Quote"],
Cell[10680, 215, 541, 10, 58, "Text"],
Cell[11224, 227, 108, 3, 22, "BeginNumberedList"],
Cell[11335, 232, 95, 3, 22, "NumberedList"],
Cell[11433, 237, 279, 6, 40, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11749, 248, 107, 7, 39, "Section"],
Cell[11859, 257, 1103, 34, 61, "Text"],
Cell[12965, 293, 474, 14, 42, "Text"],
Cell[13442, 309, 197, 9, 24, "BulletedList"],
Cell[13642, 320, 207, 8, 24, "BulletedList"],
Cell[13852, 330, 268, 9, 24, "BulletedList"],
Cell[14123, 341, 270, 9, 24, "BulletedList"]
}, Closed]],

Cell[CellGroupData[{
Cell[14430, 355, 109, 7, 39, "Section"],

Cell[CellGroupData[{
Cell[14564, 366, 161, 10, 54, "Subsection"],
Cell[14728, 378, 102, 3, 24, "Text"],
Cell[14833, 383, 137, 4, 27, "Warning"],
Cell[14973, 389, 98, 3, 26, "Text"],
Cell[15074, 394, 140, 4, 26, "Text"],
Cell[15217, 400, 321, 9, 42, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[15575, 414, 147, 10, 32, "Subsection"],
Cell[15725, 426, 39, 0, 24, "Text"],
Cell[15767, 428, 46, 0, 48, "BeginEndQuestion"],
Cell[15816, 430, 265, 7, 44, "Text"],
Cell[16084, 439, 18, 0, 24, "Answer"],
Cell[16105, 441, 334, 8, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16476, 454, 163, 10, 32, "Subsection"],
Cell[16642, 466, 283, 8, 24, "Text"],
Cell[16928, 476, 192, 6, 26, "Warning"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

