(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     55825,       2010]*)
(*NotebookOutlinePosition[    121085,       4349]*)
(*  CellTagsIndexPosition[    120886,       4340]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Basics"
}], "Title",
  CounterAssignments->{{"Title", 0}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Getting Help"
}], "SectionFirst"],

Cell[TextData[{
  "To learn more about ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["The Help Browser",
    ButtonData:>{"The Help Browser"},
    ButtonStyle->"GettingStartedLink"],
  " is the primary reference. Choosing ",
  StyleBox["Help. . .", "Menu"],
  " from the ",
  StyleBox["Help", "Menu"],
  " menu at any time gives you access to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s on-line documentation. ",
  "An overview of the capabilities of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is presented in the ",
  ButtonBox["Tour of ",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
    FontSlant->"Italic"],
  " section, and it is also suggested that you browse through the ",
  ButtonBox["Practical Introduction",
    ButtonData:>{"I1", None},
    ButtonStyle->"MainBookLink"],
  " section."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " On-line Help"
}], "Subsection"],

Cell[TextData[{
  "To find out what a particular command does, you can use the on-line help \
system. Choosing ",
  StyleBox["Help. . .", "Menu"],
  " from the ",
  StyleBox["Help", "Menu"],
  " menu at any time accesses ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s on-line documentation. "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["Help\[Ellipsis]", "Menu"],
  " to find out what ",
  Cell[BoxData[
      FormBox[
        StyleBox["FactorInteger",
          "Input"], TraditionalForm]]],
  " does. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Alternatively, enter ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(?FactorInteger\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Also try ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(?Factor\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(?*Factor*\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Command Completion"
}], "Subsection"],

Cell["\<\
The long names can be difficult to enter, especially if you are a \
slow typist. Command completion increases the speed, correctness, and \
convenience of Notebooks.\
\>", "Text"],

Cell[TextData[{
  "Enter ",
  Cell[BoxData[
      FormBox[
        StyleBox["Bess",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", then select ",
  StyleBox["Complete Selection", "Menu"],
  " under the ",
  StyleBox["Input", "Menu"],
  " menu. The completions window,"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000`0000>b000`400?l00000o`00003o<0000000
00030000003oool0oooo02`0oooo0@00000000030000003oool0oooo02`0oooo0@00000000030000
003oool0oooo02`0oooo0@00000000030000003oool0oooo02`0oooo0@00000000030000003oool0
000000H000000P3oool3000000030?ooo`00000000000080000000<0oooo0000000000000P000002
0?ooo`<0000000<0oooo0000000000000P0000020?ooo`<00000203oool10000000000<000000?oo
o`3oool00P0000030?ooo`@000000P3oool200000080oooo0`0000020?ooo`@000000P3oool01000
0000oooo0000000000040?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo
008000000`3oool4000000D0oooo0`0000020?ooo`D00000103oool2000000@0oooo00<000000?oo
o`3oool01`3oool10000000000<000000?ooo`3oool00P0000030?ooo`X000000P3oool300000080
oooo1@0000000`3oool00000000000040?ooo`030000003oool0oooo00L0oooo0@00000000030000
003oool0oooo00D000000P3oool2000000030?ooo`0000000000008000000P3oool300000080oooo
0`000000103oool000000000003oool2000000<0oooo00<000000?ooo`000000203oool100000000
00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00<000000P3oool4000000030?oo
o`00000000000080000000@0oooo00000000000000000P3oool2000000<0oooo00<000000?ooo`00
0000203oool10000000000<000000?ooo`3oool00P0000030?ooo`8000005@3oool200000080oooo
00D000000?ooo`3oool0oooo000000070?ooo`40000000000`000000oooo00000006000001D0oooo
0`0000001@3oool00000000000000000oooo00<000001P3oool10000000000<000000?ooo`3oool0
;03oool10000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0;03oool1
0000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0;03oool100000000
00<000000?ooo`3oool0;03oool10000000000<000000?ooo`0000001P0000020?ooo`<0000000<0
oooo0000000000000P0000000`3oool000000000000200000080oooo0`0000000`3oool000000000
000500000080oooo0`0000050?ooo`40000000000`000000oooo0?ooo`02000000<0oooo10000002
0?ooo`8000000P3oool300000080oooo100000020?ooo`040000003oool0000000000080oooo00D0
00000?ooo`3oool0oooo000000070?ooo`40000000000`000000oooo0?ooo`02000000<0oooo1000
00050?ooo`<000000P3oool5000000@0oooo0P0000020?ooo`040000003oool0oooo000000P0oooo
0@00000000030000003oool0oooo008000000`3oool:00000080oooo0`0000020?ooo`D0000000<0
oooo0000000000000P3oool00`000000oooo000000090?ooo`40000000000`000000oooo0?ooo`05
00000080oooo0P0000000`3oool000000000000200000080oooo0`0000020?ooo`<0000000@0oooo
000000000000oooo0P0000020?ooo`8000002P3oool10000000000<000000?ooo`3oool00P000003
0?ooo`030000003oool0oooo00<000000P3oool4000000030?ooo`00000000000080000000@0oooo
00000000000000000P3oool200000080oooo00<000000?ooo`0000002@3oool10000000000<00000
0?ooo`3oool00P0000030?ooo`8000005@3oool200000080oooo00@000000?ooo`3oool00000203o
ool10000000000<000000?ooo`0000001P00000E0?ooo`<0000000D0oooo00000000000000000?oo
o`03000000H0oooo0@00000000030000003oool0oooo02`0oooo0@00000000030000003oool0oooo
02`0oooo0@00000000030000003oool0oooo02`0oooo0@00000000030000003oool0000002/00000
0@3oool10000000000<000000?ooo`000000:`0000010?ooo`40000000000`000000oooo0000000[
00000040oooo0@00000000030000003oool0oooo00H0oooo0P0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0900000040oooo0@00000000030000003oool000000080oooo0`0000040?ooo`80
00000P3oool2000000<0oooo0P0000040?ooo`80000000H0oooo0000003oool0oooo0000003oool2
000000030?ooo`000000000000H000000@3oool10000000000<000000?ooo`0000000P3oool30000
00@0oooo1@0000030?ooo`8000001@3oool400000080oooo100000000`3oool00000000000060000
0040oooo0@00000000030000003oool000000080oooo0`00000:0?ooo`8000000`3oool2000000D0
oooo00<000000?ooo`3oool0100000000`3oool000000000000600000040oooo0@00000000030000
003oool0000000D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000
0`3oool010000000oooo0?ooo`0000020?ooo`@0000000<0oooo0000000000001P0000010?ooo`40
000000000`000000oooo000000020?ooo`<0000000<0oooo0000000000000`3oool2000000@0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool200000080oooo100000000`3oool0
00000000000600000040oooo0@00000000030000003oool000000080oooo0`0000020?oooaD00000
0P3oool4000000030?ooo`000000000000H000000@3oool10000000000<000000?ooo`3oool01P3o
oolE000000<0oooo0`0000030?ooo`L000000@3oool10000000000<000000?ooo`000000:`000001
0?ooo`40000000000`000000oooo0000000[00000040oooo0@00000000030000003oool0oooo02`0
oooo0@00000000030000003oool0oooo02`0oooo0@00000000030000003oool0oooo02`0oooo0@00
000000030000003oool0oooo02`0oooo0@00000000030000003oool0000000H000000P3oool30000
00030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<0000000<0oooo0000
000000001@00000:0?ooo`40000000000`000000oooo0?ooo`02000000<0oooo100000020?ooo`80
00000P3oool300000080oooo100000020?ooo`040000003oool0000000000080oooo00<000000?oo
o`3oool02@3oool10000000000<000000?ooo`3oool00P0000030?ooo`@000001@3oool300000080
oooo1@0000040?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`40000000000`000000oooo
0?ooo`02000000<0oooo2P0000020?ooo`<000000P3oool5000000030?ooo`00000000000080oooo
00<000000?ooo`3oool02@3oool10000000000<000000?ooo`3oool01@0000020?ooo`80000000<0
oooo0000000000000P0000020?ooo`<000000P3oool3000000040?ooo`00000000000?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooo`40000000000`000000oooo0?ooo`02000000<0oooo00<0
00000?ooo`3oool00`0000020?ooo`@0000000<0oooo0000000000000P000000103oool000000000
000000020?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`40000000000`000000oooo0?oo
o`02000000<0oooo0P00000E0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`4000000000
0`000000oooo00000006000001D0oooo0`000000103oool0000000000000000:0?ooo`4000000000
0`000000oooo0?ooo`0/0?ooo`40000000000`000000oooo0?ooo`0/0?ooo`400000000`00000000
<03oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{48, 59},
  ImageMargins->{{99, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "will pop up and you can select which command you desire using the mouse, \
here ",
  StyleBox["BesselJ", "InlineInputTraditionalForm"],
  ". This is advantageous for long commands."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". In a new cell, enter your own name with no spaces, e.g. ",
  Cell[BoxData[
      FormBox[
        StyleBox["PaulAbbott",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and evaluate the input. In a blank cell, enter the first two letters of \
your name and use command completion. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "See, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows a bit about you already."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Templates"
}], "Subsection"],

Cell[TextData[{
  "Templates work much like command completion. The ",
  StyleBox["Make Template", "Menu"],
  " command is also found under the ",
  StyleBox["Input", "Menu"],
  " menu. "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["Make Template", "Menu"],
  " on ",
  Cell[BoxData[
      FormBox[
        StyleBox["Plot3D",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and produce a 3D plot of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x\ y)\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \[Pi]]\)\[Times]\([0, \[Pi]]\)\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Remember to create an ",
  StyleBox["insertion point",
    FontSlant->"Italic"],
  " in your Notebook ",
  StyleBox["before",
    FontSlant->"Italic"],
  " you enter an expression or use a palette."
}], "Warning"],

Cell[TextData[{
  "Alternatively, you can use the ",
  ButtonBox["Basic Calculations palette",
    ButtonData:>{"BasicCalculations.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " to find out more about how to use a function."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Basic Calculations"
}], "Section"],

Cell[TextData[{
  "Read the ",
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{"Mathematica as a Calculator"},
    ButtonStyle->"GettingStartedLink"],
    FontSlant->"Italic"],
  ButtonBox[" as a Calculator",
    ButtonData:>{"Mathematica as a Calculator"},
    ButtonStyle->"GettingStartedLink"],
  " section of the",
  " ",
  ButtonBox["Tour of ",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
  StyleBox[ButtonBox["Mathematica",
    ButtonData:>{"Mathematica as a Calculator", None},
    Active->True,
    ButtonStyle->"GettingStartedLink"],
    FontSlant->"Italic"],
  " ",
  "and then attempt the following exercises. If it is not already open, you \
may find the ",
  ButtonBox["Basic Input palette",
    ButtonData:>{"BasicInput.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " helpful. For more information on palettes see ",
  ButtonBox["Using Palettes",
    ButtonData:>{"Using Palettes (Macintosh)"},
    ButtonStyle->"GettingStartedLink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Getting Started"
}], "Subsection"],

Cell[TextData[{
  "You can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as an enhanced scientific calculator.  Let's start with a simple example. \
"
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use the ",
  ButtonBox["Basic Input palette",
    ButtonData:>{"BasicInput.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " to type in the expression ",
  Cell[BoxData[
      \(TraditionalForm\`3\^100\)]],
  " ",
  StyleBox["below",
    FontSlant->"Italic"],
  " this cell.  Hit \[ShiftKey]\[KeyBar]\[ReturnKey] together to evaluate \
this expression. Note that you should get the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " answer. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "You can in fact have the cursor positioned ",
  StyleBox["anywhere",
    FontSlant->"Italic"],
  " on the line for expression evaluation to work.  Alternatively you can \
select the cell-bracket (or a range of cell brackets) that contains an \
expression (s) and select ",
  StyleBox["Evaluate Cells", "Menu"],
  " under the ",
  StyleBox["Kernel/Evaluation", "Menu"],
  " menu."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Select your input line above (either by selecting its cell bracket or by \
scrolling over the expression with the mouse clicked) and make a copy using \
",
  StyleBox["Copy", "Menu"],
  " under the ",
  StyleBox["Edit", "Menu"],
  " menu. ",
  StyleBox["Paste", "Menu"],
  " your expression below this box. Change the ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`1000\)]],
  " and evaluate the result.",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "You should have just evaluated ",
  Cell[BoxData[
      \(TraditionalForm\`3\^1000\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". To get the result in the form you might get on a calculator, try ",
  Cell[BoxData[
      \(TraditionalForm\`N[%]\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`%\)]],
  " indicates the last expression.  Similarly ",
  Cell[BoxData[
      \(TraditionalForm\`%%\)]],
  " indicates the second-last expression. Alternatively, expressions can be \
named using assignment (denoted using ",
  Cell[BoxData[
      \(TraditionalForm\` = \)]],
  ")."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter ",
  Cell[BoxData[
      \(TraditionalForm\`pi = N[\[Pi], 200]\)]],
  " below this cell and evaluate it. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[
"You should get the value of \[Pi] to two hundred decimal places."], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\@163\ pi\)\/3\)\)]],
  " below this cell and evaluate it. What is special about this number? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". \[Pi] has a run of six consecutive 9's in the first 1000 digits. Where \
are they located? ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": One way to find the location is to convert the number to a string (using \
",
  StyleBox["ToString", "InlineInputTraditionalForm"],
  "), drop the leading ",
  Cell[BoxData[
      FormBox[
        StyleBox["3.",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " (using ",
  StyleBox["StringDrop", "InlineInputTraditionalForm"],
  ") and locating the position of the string ",
  StyleBox["\"999999\"", "InlineInputTraditionalForm"],
  " (using ",
  StyleBox["StringPosition", "InlineInputTraditionalForm"],
  "). ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " More Functions"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knows about a big collection of mathematical functions \[LongDash] nearly \
all those you will find in any book of mathematical tables."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`BesselJ[5, 34.6]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Log[4.5 + 2  I]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`ChebyshevT[3, 0.1]\)]],
  " by copying these expressions below this cell and entering them.",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"BesselJ"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      FormBox[
        StyleBox["I",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " denotes ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)]],
  ". You can also enter ",
  Cell[BoxData[
      FormBox[
        StyleBox["I",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " off the ",
  ButtonBox["Basic Input palette",
    ButtonData:>{"BasicInput.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\)]],
  "."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Lookup ",
  Cell[BoxData[
      \(TraditionalForm\`BesselJ\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`ChebyshevT\)]],
  " in the on-line help and determine closed-form expressions for ",
  Cell[BoxData[
      \(TraditionalForm\`BesselJ[1/2, x]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`ChebyshevT[n, cos(\[Theta])]\)]],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"BesselJ"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_5\)(34.6)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`log(4.5 + 2  \[ImaginaryI])\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_3\)(0.1)\)]],
  Cell[BoxData[
      FormBox[
        TagBox["",
          InterpretTemplate[ Zeta[ #]&]], TraditionalForm]]],
  ". Compare your results with your answer to question ",
  
  CounterBox["Exercise", "BesselJ"],
  ". What do you conclude? ",
  StyleBox["[3 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "An easy way to copy an expression is to click on it as many times as is \
necessary to select the entire expression (this is a type of ",
  StyleBox["scoping",
    FontSlant->"Italic"],
  ")."
}], "BrightIdea"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can do many kinds of exact computations with integers."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`FactorInteger[70612139395722186]\)]],
  ".  What is the meaning of this output? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox["FactorInteger",
          "Input"], TraditionalForm]]],
  " produces a set of pairs of numbers which are \[Ellipsis]"
}], "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Recombine the numbers in the above output to show how they form ",
  Cell[BoxData[
      \(TraditionalForm\`70612139395722186. \)]],
  " ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Simple Expressions"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can deal with mathematical formulas in algebraic form."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter the expression ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\^2 + 2\ x + 1)\)\^20\)]],
  ". Expand this expression using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Expand[%]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  ",
  Cell[BoxData[
      FormBox[
        StyleBox["Factor",
          "Text"], TraditionalForm]]],
  " the expanded result.",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox["%",
          "Text"], TraditionalForm]]],
  StyleBox[" indicates the previous expression. ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(%  n\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " ",
  StyleBox["refers to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(Out[n]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  StyleBox[".",
    FontSlant->"Plain"]
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Re-do the steps in the above computation using the ",
  ButtonBox["Basic Calculations palette",
    ButtonData:>{"BasicCalculations.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Try ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(TrigReduce[Cos[x]\^5\ \(Sin[x]\^3\) Cos[3  x]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". What is the name for the resulting expansion? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Basic Plots"
}], "Subsection"],

Cell[TextData[{
  "The above sections have guided you through each calculation.  Now you are \
expected to use palettes such as the ",
  ButtonBox["Basic Calculations palette",
    ButtonData:>{"BasicCalculations.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " or on-line help to work out how to achieve each of the following tasks."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Produce a plot of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x\^2)\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[Element] \([0, 5]\)\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Produce a phase-space plot of ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x)\)]],
  " versus ",
  Cell[BoxData[
      \(TraditionalForm\`sin(3\ x)\)]],
  " for over ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[Element] \ \([0, 2  \[Pi]]\)\)]],
  ".  ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": lookup ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ". Do you recognise this figure? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Produce a contour plot and density plot of ",
  Cell[BoxData[
      \(TraditionalForm\`x\ \[ExponentialE]\^\(\(-x\^2\) - y\^2\)\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\[Times]\([\(-1\), 1]\)\)]],
  ".  ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Calculus"
}], "Subsection"],

Cell["You can do calculus.  Try a simple integral:", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(x\/\(x\^3 - 
                1\)\) \[DifferentialD]x\)]],
  ". Check by differentiating the resulting expression with respect to ",
  Cell[BoxData[
      FormBox[
        StyleBox["x",
          "Text"], TraditionalForm]]],
  " and then using ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["You can also get exact solutions to many definite integrals.", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\(\(\(\( sin\^2\)(
                  x)\)\ \(\(cos\^3\)(x)\)\)\/x\) \[DifferentialD]x\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Many integrals do not have a simple closed form.  If you try such a \
definite integral it will be returned unevaluated.  You can still use ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " to get a numerical answer."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Try ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%1\( sin(
            sin(x))\) \[DifferentialD]x\)]],
  ". Compute the numerical value of this expression using ",
  Cell[BoxData[
      \(TraditionalForm\`N[%]\)]],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can find a closed form for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi]\( sin(
            sin(x))\) \[DifferentialD]x\)]],
  "."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Solving Equations"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the general quadratic equation, ",
  Cell[BoxData[
      \(TraditionalForm\`a\ x\^2 + b\ x + c \[Equal] 0\)]],
  " and call the solution set ",
  Cell[BoxData[
      FormBox[
        StyleBox["s",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Check the solutions by back-substitution using the syntax ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\ x\^2 + b\ x + c /. s\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". You will need to ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " the result. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      FormBox[
        StyleBox["==",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " denotes ",
  StyleBox["equality",
    FontSlant->"Italic"],
  ", not assignment (which is ",
  Cell[BoxData[
      FormBox[
        StyleBox["=",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ")."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the quintic equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5 - x + \[Rho] \[Equal] 0\)]],
  " and call the solution set ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(s(\[Rho]_)\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". The output may appear puzzling but it is actually a useful ",
  StyleBox["representation of the roots",
    FontSlant->"Italic"],
  " of the quintic. For example, plot the first root (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(x /. First[s(\[Rho])]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ") as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Element] \([\(-5\), 5]\)\)]],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"quintic equation"],

Cell[TextData[{
  "In this case, it can be proved that no solution involving radicals exists. \
However, each root can be expressed in terms of generalized hypergeometric \
functions. For example, the \[OpenCurlyDoubleQuote]simplest\
\[CloseCurlyDoubleQuote] root of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^5 - x + \[Rho] \[Equal] 0\)]],
  " can be expressed as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", " ", 
          TagBox[
            TagBox[
              RowBox[{
                RowBox[{
                  SubscriptBox["\[InvisiblePrefixScriptBase]", 
                    FormBox["4",
                      "TraditionalForm"]], 
                  SubscriptBox["F", 
                    FormBox["3",
                      "TraditionalForm"]]}], "\[InvisibleApplication]", 
                RowBox[{"(", 
                  RowBox[{
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[\(1\/5\),
                            HypergeometricPFQ,
                            Editable->True], ",", 
                          TagBox[\(2\/5\),
                            HypergeometricPFQ,
                            Editable->True], ",", 
                          TagBox[\(3\/5\),
                            HypergeometricPFQ,
                            Editable->True], ",", 
                          TagBox[\(4\/5\),
                            HypergeometricPFQ,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox[
                      TagBox[
                        RowBox[{
                          TagBox[\(1\/2\),
                            HypergeometricPFQ,
                            Editable->True], ",", 
                          TagBox[\(3\/4\),
                            HypergeometricPFQ,
                            Editable->True], ",", 
                          TagBox[\(5\/4\),
                            HypergeometricPFQ,
                            Editable->True]}],
                        InterpretTemplate[ {
                          SlotSequence[ 1]}&]],
                      HypergeometricPFQ,
                      Editable->False], ";", 
                    TagBox[\(\(3125\ \[Rho]\^4\)\/256\),
                      HypergeometricPFQ,
                      Editable->True]}], ")"}]}],
              InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
              Editable->False],
            HypergeometricPFQ]}], TraditionalForm]]],
  ". See ",
  ButtonBox["http://library.wolfram.com/examples/quintic/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/examples/quintic/"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["http://mathworld.wolfram.com/QuinticEquation.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/QuinticEquation.html"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Evaluate ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(s(1)\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " numerically using 30-digit precision (using ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  ") and call the result ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(s(1)\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Does your answer satisfy the requirement that roots of equations with \
real coefficients must come in conjugate pairs? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use the syntax ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(r = x /. s(1)\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to obtain the numerical values of the roots as a list ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute the product of all the roots. Why is this result expected? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox[Cell[BoxData[
      FormBox[
        StyleBox[\(ListPlot[Transpose[{Re[r], Im[r]}]]\),
          "Input^"], TraditionalForm]], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  " to obtain an ",
  StyleBox["Argand plot",
    FontSlant->"Italic"],
  " of the roots. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Matrices"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Entering matrices", "Subsubsection"],

Cell[TextData[{
  "Matrices can be entered using List brackets (",
  StyleBox["{}", "InlineInputTraditionalForm"],
  "). Alternatively, they can be entered using the ",
  ButtonBox["Basic Input palette",
    ButtonData:>{"BasicInput.nb", None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  " or from the ",
  StyleBox["Create Table/Matrix/Palette\[Ellipsis]", "Menu"],
  " entry under the ",
  StyleBox["Input", "Menu"],
  " menu."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". In a new cell, enter the ",
  Cell[BoxData[
      \(TraditionalForm\`3\[Times]3\)]],
  " matrix, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"mat", "=", 
            RowBox[{"(", GridBox[{
                  {"3.5", "7.2", "1.2"},
                  {\(-2.4\), "6.4", "2.3"},
                  {"1.1", "2.2", \(-3.7\)}
                  },
                ColumnAlignments->{Decimal}], ")"}]}],
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute the inverse and eigenvalues of ",
  Cell[BoxData[
      FormBox[
        StyleBox["mat",
          "Input"], TraditionalForm]]],
  " \[LongDash] you should be able to guess the names of the appropriate ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands. ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear algebra", "Subsubsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " also does linear algebra on symbolic matrices."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"mat", "=", 
            TagBox[
              RowBox[{"(", GridBox[{
                    {"a", "b", "c"},
                    {"d", "e", "f"},
                    {"g", "h", "i"}
                    }], ")"}],
              (MatrixForm[ #]&)]}],
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  This overwrites your previous value for the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["mat",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute the inverse of ",
  Cell[BoxData[
      FormBox[
        StyleBox["mat",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and assign (using ",
  Cell[BoxData[
      FormBox[
        StyleBox["=",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ") the result to ",
  Cell[BoxData[
      FormBox[
        StyleBox["minv",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(minv . mat\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and simplify the result. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      FormBox[
        StyleBox[".",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " (",
  StyleBox["i.e., ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        StyleBox["Dot",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ") in ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a . b\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " indicates that the usual dot product and is used both for vectors ",
  StyleBox["and",
    FontSlant->"Italic"],
  " matrices. This makes sense because each element in the resulting matrix \
is formed by dot product multiplication of rows of ",
  Cell[BoxData[
      FormBox[
        StyleBox["a",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " with columns of ",
  Cell[BoxData[
      FormBox[
        StyleBox["b",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Without the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Dot",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " one gets the direct (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", element-by-element) product. The direct product is useful for general \
matrix operations such as ",
  StyleBox["masking",
    FontSlant->"Italic"],
  " and ",
  StyleBox["convolution",
    FontSlant->"Italic"],
  "."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Generate a random real ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Times]4\)]],
  " matrix and call it ",
  StyleBox["rand", "InlineInputTraditionalForm"],
  " (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": use ",
  StyleBox["Random", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["Table", "InlineInputTraditionalForm"],
  "). Replace the ",
  Cell[BoxData[
      \(TraditionalForm\`{2, 3}\)]],
  " entry of ",
  StyleBox["rand", "InlineInputTraditionalForm"],
  " with the symbolic parameter ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": look-up ",
  StyleBox["Part", "InlineInputTraditionalForm"],
  "). Compute the (symbolic) inverse of ",
  StyleBox["rand", "InlineInputTraditionalForm"],
  " and determine the numerical value of the inverse when ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 1\)]],
  ". ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pauli spin matrices", "Subsubsection"],

Cell["\<\
Enter the following three (Pauli spin) matrices. \
\>", "Text",
  CellTags->"Pauli spin matrices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_1\), "=", 
          RowBox[{"(", GridBox[{
                {"0", \(-\[ImaginaryI]\)},
                {"\[ImaginaryI]", "0"}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_2\), "=", 
          RowBox[{"(", GridBox[{
                {"1", "0"},
                {"0", \(-1\)}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_3\), "=", 
          TagBox[
            RowBox[{"(", GridBox[{
                  {"0", "1"},
                  {"1", "0"}
                  }], ")"}],
            (MatrixForm[ #]&)]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "The syntax ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] /: \[Sigma]\_1 = \[Ellipsis]\)]],
  " attaches the definition to the symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  ". You can clear all such definitions using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Clear[\[Sigma]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "BrightIdea"],

Cell[TextData[{
  "In general matrices do ",
  StyleBox["not",
    FontSlant->"Italic"],
  " commute.  "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define the commutator, ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  ", as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[LeftAngleBracket]a_, b_\[RightAngleBracket] := 
            a\  . b - b\  . a\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute the commutators of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_3\)]],
  " and of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_3\)]],
  ".",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "The angle bracket ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]\)]\
],
  " is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(<\)\(\[Ellipsis]\)\(>\)\)\)]],
  ".  You can enter an angle-bracket as \
\[EscapeKey]<\[EscapeKey]\[EscapeKey]>\[EscapeKey]"
}], "Warning"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      FormBox[
        StyleBox["a_",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["b_",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " that appear on the left-hand side represent ",
  StyleBox["any",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", generic) values.  When you supply particular values the expression will \
be evaluated. "
}], "Warning"],

Cell[TextData[{
  "In general, it is possible to express the commutator of two of the Pauli \
matrices as a ",
  StyleBox["linear combination",
    FontSlant->"Italic"],
  " of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " matrices. For example"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]\[Sigma]\_1, \[Sigma]\_2\
\[RightAngleBracket] \[Equal] 2  \[ImaginaryI]\ \[Sigma]\_3\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Find the appropriate linear combination for the commutator ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\[Sigma]\_2, \[Sigma]\_3\
\[RightAngleBracket]\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  Cell[BoxData[
      FormBox[
        StyleBox["Solve",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to obtain a method for reducing any given commutator to a linear \
expansion by determining the coefficients of the linear combination. Give \
some examples.  (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": A general linear combination is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\ \[Sigma]\_1 + \[Beta]\ \[Sigma]\_2 + \
\[Gamma]\ \[Sigma]\_3\)]],
  ". Try equating this (using ",
  Cell[BoxData[
      \(TraditionalForm\` == \)]],
  ") to, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\[Sigma]\_2, \[Sigma]\_3\
\[RightAngleBracket]\)]],
  " and solving for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  ".) ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "These coefficients are called the ",
  StyleBox["structure coefficients",
    FontSlant->"Italic"],
  " of the Lie algebra."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Curve Fitting"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use the command ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Table[\(i!\), {i, 1, 10}]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to compute the first 10 values of the factorial function and assign the \
answer to the variable called ",
  StyleBox["is", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["\<\
We could plot this table but the dynamic range is so large that it \
would be difficult to produce a meaningful plot. Let us take the logarithm of \
these values.\
\>", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Take the ",
  Cell[BoxData[
      \(TraditionalForm\`log\)]],
  " of values using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(log(is)\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and numerically evaluate the result. Save this result as a named variable \
called ",
  StyleBox["data", "InlineInputTraditionalForm"],
  ".",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Now that we have a table of values we can plot it using the ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " command."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " to plot ",
  Cell[BoxData[
      FormBox[
        StyleBox["data",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and save your graphic as a named variable called, e.g., ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the best (least-squares) third-order polynomial fit to this data \
using ",
  StyleBox["Fit", "InlineInputTraditionalForm"],
  ". Obtain a plot of this fit and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_2\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". You need to choose and appropriate range for the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Plot",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " command (see ",
  Cell[BoxData[
      FormBox[
        StyleBox["PlotRange",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "). Show ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_2\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " superimposed using ",
  StyleBox["Show", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "You can, in fact, do fits using any linear combination of functions but ",
  StyleBox["Fit", "InlineInputTraditionalForm"],
  " presently does not allow exponent optimization \[LongDash] you need to \
use the ",
  Cell[BoxData[
      ButtonBox["Statistics`NonlinearFit`",
        ButtonData:>{"Statistics`NonlinearFit`", "1.1"},
        ButtonStyle->"AddOnsLink"]]],
  " package for this.  "
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Series"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Manipulation of Series", "Subsubsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the Taylor (Maclaurin) series of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x)\)]],
  " up to tenth order using the command ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x) + \(O(x)\)\^10\)]],
  ". Square this output. Integrate this result. What happens to the order \
term. ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the reciprocal (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(1/%\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ") of the last expression. What is the name for the type of series has \
resulted? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": this type of series arises in complex function theory.) ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Higher orders", "Subsubsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`sin(tan(x)) - tan(sin(x))\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \[Pi]]\)\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"sin(tan(x))-tan(sin(x))"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the series of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(tan(x)) - tan(sin(x))\)]],
  " up to fifteenth order. What is special about the series produced? What \
does the series tell you about the behaviour of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(tan(x)) - tan(sin(x))\)]],
  " near the origin? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Take the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Normal",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " of this expression (this removes the order term and turns the series into \
a \"normal\" function) and plot a graph of the result. What is the apparent \
about this graph near the origin. Compare your result to the plot of question \
",
  
  CounterBox["Exercise", "sin(tan(x))-tan(sin(x))"],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the series expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(tan(x)) - tan(sin(x))\)]],
  " about ",
  Cell[BoxData[
      \(TraditionalForm\`x = \[Pi]\)]],
  " up to 5-th order. What is the leading term in this series? Relate this \
result to the plot of question ",
  
  CounterBox["Exercise", "sin(tan(x))-tan(sin(x))"],
  ".  ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the series expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(tan(x)) - tan(sin(x))\)]],
  " about ",
  Cell[BoxData[
      \(TraditionalForm\`x = \[Pi]/2\)]],
  " up to 3-rd order. Relate this result to the plot of question ",
  
  CounterBox["Exercise", "sin(tan(x))-tan(sin(x))"],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Complex Series", "Subsubsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(e = \[ExponentialE]\^\(\[ImaginaryI]\ x\) + \(O(x)\)\^8\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Apply ",
  Cell[BoxData[
      \(TraditionalForm\`Normal\)]],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["e",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and re-assign the output to be ",
  Cell[BoxData[
      FormBox[
        StyleBox["e",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Apply ",
  StyleBox["ComplexExpand", "InlineInputTraditionalForm"],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Re[e]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Im[\[ScriptE]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and compare these series expansions to the expansions of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x)\)]],
  ". What does this result tell you? ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the same as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\)]],
  ".  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses double-struck notation to indicate letters which have special \
meaning including \[ExponentialE], \[ImaginaryI], and \[DifferentialD]."
}], "Warning"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "BesselJ"->{
    Cell[19900, 643, 429, 15, 50, "BeginEndQuestion",
      CellTags->"BesselJ"],
    Cell[20926, 685, 495, 18, 50, "BeginEndQuestion",
      CellTags->"BesselJ"]},
  "quintic equation"->{
    Cell[30172, 1070, 968, 31, 67, "BeginEndQuestion",
      CellTags->"quintic equation"]},
  "Pauli spin matrices"->{
    Cell[41477, 1451, 108, 3, 24, "Text",
      CellTags->"Pauli spin matrices"]},
  "sin(tan(x))-tan(sin(x))"->{
    Cell[51566, 1844, 314, 12, 50, "BeginEndQuestion",
      CellTags->"sin(tan(x))-tan(sin(x))"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"BesselJ", 120338, 4322},
  {"quintic equation", 120527, 4327},
  {"Pauli spin matrices", 120647, 4330},
  {"sin(tan(x))-tan(sin(x))", 120761, 4333}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 164, 8, 74, "Title",
  CounterAssignments->{{"Title", 0}}],
Cell[1954, 63, 29, 0, 26, "Author"],
Cell[1986, 65, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2425, 81, 39, 0, 42, "Subsubsection"],
Cell[2467, 83, 215, 5, 26, "Text"],
Cell[2685, 90, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2800, 94, 87, 3, 24, "Text"],
Cell[2890, 99, 117, 2, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3044, 106, 114, 7, 41, "SectionFirst"],
Cell[3161, 115, 1103, 34, 61, "Text"],

Cell[CellGroupData[{
Cell[4289, 153, 150, 10, 54, "Subsection"],
Cell[4442, 165, 335, 10, 43, "Text"],
Cell[4780, 177, 302, 12, 53, "BeginEndQuestion"],
Cell[5085, 191, 549, 20, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[5671, 216, 156, 10, 32, "Subsection"],
Cell[5830, 228, 189, 4, 24, "Text"],
Cell[6022, 234, 299, 11, 27, "Text"],
Cell[6324, 247, 5685, 74, 69, 5572, 70, "GraphicsData", "Bitmap", "Graphics",
  Evaluatable->False],
Cell[12012, 323, 212, 5, 26, "Text"],
Cell[12227, 330, 415, 11, 65, "BeginEndQuestion"],
Cell[12645, 343, 126, 5, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12808, 353, 153, 11, 32, "Subsection"],
Cell[12964, 366, 199, 6, 27, "Text"],
Cell[13166, 374, 478, 18, 53, "BeginEndQuestion"],
Cell[13647, 394, 232, 8, 26, "Warning"],
Cell[13882, 404, 258, 7, 24, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14189, 417, 115, 7, 39, "Section"],
Cell[14307, 426, 1062, 32, 42, "Text"],

Cell[CellGroupData[{
Cell[15394, 462, 153, 10, 54, "Subsection"],
Cell[15550, 474, 179, 6, 26, "Text"],
Cell[15732, 482, 579, 20, 67, "BeginEndQuestion"],
Cell[16314, 504, 413, 11, 45, "Warning"],
Cell[16730, 517, 577, 19, 72, "BeginEndQuestion"],
Cell[17310, 538, 124, 5, 24, "Text"],
Cell[17437, 545, 241, 8, 50, "BeginEndQuestion"],
Cell[17681, 555, 359, 12, 24, "Text"],
Cell[18043, 569, 228, 8, 50, "BeginEndQuestion"],
Cell[18274, 579, 91, 1, 24, "Text"],
Cell[18368, 582, 283, 8, 66, "BeginEndQuestion"],
Cell[18654, 592, 18, 0, 32, "Answer"],
Cell[18675, 594, 789, 23, 70, "BeginEndQuestion"],
Cell[19467, 619, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[19522, 624, 152, 10, 32, "Subsection"],
Cell[19677, 636, 220, 5, 26, "Text"],
Cell[19900, 643, 429, 15, 50, "BeginEndQuestion",
  CellTags->"BesselJ"],
Cell[20332, 660, 591, 23, 27, "Warning"],
Cell[20926, 685, 495, 18, 50, "BeginEndQuestion",
  CellTags->"BesselJ"],
Cell[21424, 705, 580, 21, 50, "BeginEndQuestion"],
Cell[22007, 728, 18, 0, 32, "Answer"],
Cell[22028, 730, 229, 6, 24, "BrightIdea"],
Cell[22260, 738, 139, 4, 26, "Text"],
Cell[22402, 744, 251, 8, 50, "BeginEndQuestion"],
Cell[22656, 754, 196, 6, 32, "Answer"],
Cell[22855, 762, 255, 8, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[23147, 775, 156, 10, 32, "Subsection"],
Cell[23306, 787, 139, 4, 26, "Text"],
Cell[23448, 793, 505, 18, 51, "BeginEndQuestion"],
Cell[23956, 813, 535, 20, 24, "Warning"],
Cell[24494, 835, 320, 10, 50, "BeginEndQuestion"],
Cell[24817, 847, 337, 10, 50, "BeginEndQuestion"],
Cell[25157, 859, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[25212, 864, 149, 10, 32, "Subsection"],
Cell[25364, 876, 366, 8, 40, "Text"],
Cell[25733, 886, 283, 11, 50, "BeginEndQuestion"],
Cell[26019, 899, 535, 19, 52, "BeginEndQuestion"],
Cell[26557, 920, 18, 0, 32, "Answer"],
Cell[26578, 922, 354, 11, 53, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[26969, 938, 146, 10, 32, "Subsection"],
Cell[27118, 950, 60, 0, 24, "Text"],
Cell[27181, 952, 488, 16, 54, "BeginEndQuestion"],
Cell[27672, 970, 76, 0, 24, "Text"],
Cell[27751, 972, 292, 9, 57, "BeginEndQuestion"],
Cell[28046, 983, 253, 6, 24, "Text"],
Cell[28302, 991, 353, 12, 53, "BeginEndQuestion"],
Cell[28658, 1005, 253, 9, 27, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[28948, 1019, 155, 10, 32, "Subsection"],
Cell[29106, 1031, 681, 20, 67, "BeginEndQuestion"],
Cell[29790, 1053, 379, 15, 26, "Warning"],
Cell[30172, 1070, 968, 31, 67, "BeginEndQuestion",
  CellTags->"quintic equation"],
Cell[31143, 1103, 3088, 75, 64, "Warning"],
Cell[34234, 1180, 695, 20, 65, "BeginEndQuestion"],
Cell[34932, 1202, 18, 0, 32, "Answer"],
Cell[34953, 1204, 511, 15, 50, "BeginEndQuestion"],
Cell[35467, 1221, 18, 0, 32, "Answer"],
Cell[35488, 1223, 419, 14, 51, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[35944, 1242, 146, 10, 32, "Subsection"],

Cell[CellGroupData[{
Cell[36115, 1256, 42, 0, 42, "Subsubsection"],
Cell[36160, 1258, 453, 13, 46, "Text"],
Cell[36616, 1273, 882, 28, 96, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[37535, 1306, 39, 0, 26, "Subsubsection"],
Cell[37577, 1308, 131, 4, 26, "Text"],
Cell[37711, 1314, 1273, 43, 95, "BeginEndQuestion"],
Cell[38987, 1359, 1388, 48, 62, "Warning"],
Cell[40378, 1409, 1015, 35, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[41430, 1449, 44, 0, 26, "Subsubsection"],
Cell[41477, 1451, 108, 3, 24, "Text",
  CellTags->"Pauli spin matrices"],
Cell[41588, 1456, 327, 9, 39, "Input"],
Cell[41918, 1467, 303, 9, 39, "Input"],
Cell[42224, 1478, 308, 9, 39, "Input"],
Cell[42535, 1489, 419, 13, 23, "BrightIdea"],
Cell[42957, 1504, 116, 5, 26, "Text"],
Cell[43076, 1511, 713, 26, 50, "BeginEndQuestion"],
Cell[43792, 1539, 396, 13, 26, "Warning"],
Cell[44191, 1554, 524, 19, 26, "Warning"],
Cell[44718, 1575, 280, 9, 26, "Text"],

Cell[CellGroupData[{
Cell[45023, 1588, 154, 2, 24, "Input"],
Cell[45180, 1592, 55, 1, 22, "Output"]
}, Open  ]],
Cell[45250, 1596, 296, 9, 50, "BeginEndQuestion"],
Cell[45549, 1607, 1086, 38, 66, "BeginEndQuestion"],
Cell[46638, 1647, 155, 5, 26, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46842, 1658, 151, 10, 32, "Subsection"],
Cell[46996, 1670, 441, 13, 52, "BeginEndQuestion"],
Cell[47440, 1685, 186, 4, 24, "Text"],
Cell[47629, 1691, 468, 16, 52, "BeginEndQuestion"],
Cell[48100, 1709, 161, 4, 26, "Text"],
Cell[48264, 1715, 497, 17, 52, "BeginEndQuestion"],
Cell[48764, 1734, 1076, 35, 70, "BeginEndQuestion"],
Cell[49843, 1771, 425, 10, 42, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[50305, 1786, 144, 10, 32, "Subsection"],

Cell[CellGroupData[{
Cell[50474, 1800, 47, 0, 42, "Subsubsection"],
Cell[50524, 1802, 408, 12, 65, "BeginEndQuestion"],
Cell[50935, 1816, 18, 0, 32, "Answer"],
Cell[50956, 1818, 511, 17, 66, "BeginEndQuestion"],
Cell[51470, 1837, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[51525, 1842, 38, 0, 26, "Subsubsection"],
Cell[51566, 1844, 314, 12, 50, "BeginEndQuestion",
  CellTags->"sin(tan(x))-tan(sin(x))"],
Cell[51883, 1858, 436, 12, 64, "BeginEndQuestion"],
Cell[52322, 1872, 18, 0, 32, "Answer"],
Cell[52343, 1874, 551, 16, 65, "BeginEndQuestion"],
Cell[52897, 1892, 18, 0, 32, "Answer"],
Cell[52918, 1894, 467, 15, 64, "BeginEndQuestion"],
Cell[53388, 1911, 18, 0, 32, "Answer"],
Cell[53409, 1913, 425, 14, 50, "BeginEndQuestion"],
Cell[53837, 1929, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[53892, 1934, 39, 0, 26, "Subsubsection"],
Cell[53934, 1936, 1203, 41, 68, "BeginEndQuestion"],
Cell[55140, 1979, 18, 0, 32, "Answer"],
Cell[55161, 1981, 612, 23, 26, "Warning"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

