(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     81147,       2620]*)
(*NotebookOutlinePosition[    148988,       5041]*)
(*  CellTagsIndexPosition[    148559,       5026]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Precision, Interpolation, and Numerical Differentiation"
}], "Title",
  CounterAssignments->{{"Title", 2}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following code is used to display two approaches to numerical \
differentiation.\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(ln[\[Delta]_]\)[x_, y_, m_] = 
        Line[{{x - \[Delta]\/\@\(m\^2 + 1\), 
              y - \(\[Delta]\ m\)\/\@\(m\^2 + 1\)}, {x + \[Delta]\/\@\(m\^2 + \
1\), y + \(\[Delta]\ m\)\/\@\(m\^2 + 1\)}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`NDPlot[f_, {x_, a_, b_}, n_:  5] := 
      Module[{\[Delta] = \(b - a\)\/n, dat, i1, xs, ys, pts}, 
        dat = Table[{x, f}, {x, a, b, \[Delta]}]; 
        i1 = Interpolation[dat, InterpolationOrder \[Rule] 1]; {xs, ys} = 
          Transpose[dat]; 
        pts = Drop[
            Rest[{xs, 
                  ys, \(RotateLeft[ys] - RotateRight[ys]\)\/\(2\ \[Delta]\)} // 
                Transpose], \(-1\)]; 
        Plot[{f, i1(x)}, {x, a, b}, PlotStyle \[Rule] {Hue[2\/3], Hue[1\/3]}, 
          Epilog \[Rule] {AbsolutePointSize[3], Hue[1], Point /@ dat, 
              GrayLevel[0], Apply[ln[\[Delta]], pts, 1]}]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Finite and Infinite Precision"
}], "SectionFirst"],

Cell[TextData[{
  "In this section, some examples of finite or machine arithmetic (see \
\[Section]\[Section]",
  ButtonBox["3.1.4",
    ButtonData:>{"3.1.4", "4.11"},
    ButtonStyle->"MainBookLink"],
  ", ",
  ButtonBox["3.1.6",
    ButtonData:>{"3.1.6", "6.2"},
    ButtonStyle->"MainBookLink"],
  " of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book) and infinite or arbitrary\[Hyphen]precision numbers (see \[Section]\
\[Section]",
  ButtonBox["1.1.4",
    ButtonData:>{"1.1.4", "4.2"},
    ButtonStyle->"MainBookLink"],
  ", ",
  ButtonBox["3.1.5",
    ButtonData:>{"3.1.5", "5.2"},
    ButtonStyle->"MainBookLink"],
  ") are presented."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Exact Inverse of a Hilbert Matrix"
}], "Subsection",
  CellTags->"Exact inverse"],

Cell[TextData[{
  "A ",
  StyleBox["Hilbert matrix",
    FontSlant->"Italic"],
  " (see ",
  ButtonBox["http://mathworld.wolfram.com/HilbertMatrix.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HilbertMatrix.html"], None},
    ButtonStyle->"Hyperlink"],
  ") is a popular example for testing numerical matrix methods because they \
are difficult to invert numerically."
}], "Text"],

Cell[TextData[{
  "Complete the following ",
  StyleBox["Table", "InlineInputTraditionalForm"],
  " command"
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalH]\_n_ := 
      Table[1\/\(i + j + 1\),  ... ]\)], "Input"],

Cell[TextData[{
  "to produce an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  " Hilbert matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_n\)]],
  ", whose ",
  Cell[BoxData[
      \(TraditionalForm\`i, j\)]],
  " entry is ",
  Cell[BoxData[
      \(TraditionalForm\`1/\((i + j + 1)\)\)]],
  "."
}], "EndQuestion"],

Cell[TextData[{
  "Compute the determinant of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalH]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". What is striking about this value?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Compute the (exact) inverse of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalH]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalI]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalI]\_20\  . \ \[ScriptCapitalH]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  Is the result as expected?"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Matrix Norm"
}], "Subsection"],

Cell[TextData[{
  "Defining the ",
  StyleBox["matrix norm",
    FontSlant->"Italic"],
  " as the sum of the squares of all the elements of a matrix, what answer \
will you get for (i) a zero matrix and (ii) an Identity matrix of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  "?"
}], "BeginEndQuestion"],

Cell["\<\
(i)
(ii)\
\>", "Answer"],

Cell["\<\
What can you say in general about the matrix norm of a non-zero \
matrix?\
\>", "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Produce a random integer matrix of size 5\[Times]5 using ",
  StyleBox["Table", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["Random", "InlineInputTraditionalForm"],
  ". Square your matrix (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  "squares each element in the matrix).  Apply ",
  StyleBox["Plus", "InlineInputTraditionalForm"],
  " to the result twice.  "
}], "BeginEndQuestion"],

Cell["\<\
Congratulations, you have just computed the matrix norm of your \
matrix! Can you see how this worked? \
\>", "Text"],

Cell[TextData[{
  "The above operations do ",
  StyleBox["not",
    FontSlant->"Italic"],
  " depend on the size of the matrix! You could use ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\_\(i = 1\)\%n\(\[Sum]\_\(j = 1\)\%n \
\[ScriptCapitalA]\_\(i, j\)\)\)]],
  " but then you need to compute ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and sum over the dummy indices ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "."
}], "Warning"],

Cell[TextData[{
  "Combine the above steps to create a new function for computing the matrix \
norm, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[LeftDoubleBracketingBar]\[ScriptCapitalM]\
\[RightDoubleBracketingBar]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", by completing the following definition."
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      StyleBox[\(\[LeftDoubleBracketingBar]\[ScriptCapitalM]_\
\[RightDoubleBracketingBar] := Apply[Plus, \[Ellipsis]]\),
        "Input"], TraditionalForm]], "Input"],

Cell["\<\
This function takes a single matrix as its argument. Check your \
definition on a zero matrix and a unit matrix.\
\>", "EndQuestion"],

Cell[TextData[{
  "The ",
  ButtonBox["LinearAlgebra`MatrixManipulation`",
    ButtonData:>{"LinearAlgebra`MatrixManipulation`", "1.35"},
    ButtonStyle->"AddOnsLink"],
  "  package includes a number of different matrix norms. See also ",
  ButtonBox["http://mathworld.wolfram.com/MatrixNorm.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MatrixNorm.html"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "BrightIdea"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Numerical Inverse of a Hilbert Matrix"
}], "Subsection"],

Cell[TextData[{
  "Now we repeat the analysis of \[Section]",
  
  CounterBox["Title", "Exact inverse"],
  ".",
  
  CounterBox["Section", "Exact inverse"],
  ".",
  
  CounterBox["Subsection", "Exact inverse"],
  " numerically."
}], "Text"],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"N", "[", 
            FormBox[\(\[ScriptCapitalH]\_20\),
              "TraditionalForm"], "]"}],
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". What is the ",
  StyleBox["Precision", "InlineInputTraditionalForm"],
  " of each element in ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": lookup ",
  StyleBox["Map", "InlineInputTraditionalForm"],
  " to see how to apply ",
  StyleBox["Precision", "InlineInputTraditionalForm"],
  " at the appropriate level of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ")."
}], "BeginEndQuestion",
  CellTags->"Precision"],

Cell["", "Answer"],

Cell[TextData[{
  "Compute the (matrix) inverse of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalI]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalI]\_20\  . \ \[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Is this result expected?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Realizing what ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalI]\_20\  . \ \[ScriptCapitalN]\_20\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " ",
  StyleBox["should",
    FontSlant->"Italic"],
  " be, subtract the exact result from your answer and apply ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[LeftDoubleBracketingBar]_\[RightDoubleBracketingBar]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to the difference. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": ",
  "Use ",
  StyleBox["Length", "InlineInputTraditionalForm"],
  " or ",
  StyleBox["Dimensions", "InlineInputTraditionalForm"],
  " to determine the appropriately sized ",
  StyleBox["IdentityMatrix", "InlineInputTraditionalForm"],
  ".) ",
  "What does your answer tell you?"
}], "BeginEndQuestion",
  CellTags->"difference"],

Cell["", "Answer"],

Cell[TextData[{
  "Repeat steps (",
  
  CounterBox["Exercise", "Precision"],
  ")\[Dash](",
  
  CounterBox["Exercise", "difference"],
  ") this time computing the numerical values to 30 and then 60 decimal \
places (look up ",
  Cell[BoxData[
      FormBox[
        StyleBox["N",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to see how to do this).  Explain the results."
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Interpolation"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Reading in data from an external file"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Getting the Data", "Subsubsection"],

Cell[TextData[{
  "Get a copy of the file ",
  ButtonBox["rt.data",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/pub/Computational/rt.data"], None},
    ButtonStyle->"Hyperlink"],
  " from the URL ",
  ButtonBox["ftp://ftp.physics.uwa.edu.au/pub/Computational/rt.data",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/pub/Computational/rt.data"], None},
    ButtonStyle->"Hyperlink"],
  ". Save the resulting file as ",
  StyleBox["rt.data", "InlineInputTraditionalForm"],
  ". You can then use ",
  StyleBox["Get File Path...", "Menu"],
  " under the ",
  StyleBox["Input", "Menu"],
  " menu to access this file. You can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["!!",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " (show file command, \[Section]",
  ButtonBox["A.2.11",
    ButtonData:>{"A.2.11", "11.3"},
    ButtonStyle->"MainBookLink"],
  ") to view this file."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Structure", "Subsubsection"],

Cell[TextData[{
  "You should be able to see the structure of the data file. (",
  StyleBox["Hint:",
    FontSlant->"Italic"],
  " the data was taken by mounting an object on a turn-table and measuring \
the radius (",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ") every 5 degrees (",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  "))."
}], "Text"],

Cell[TextData[{
  "Look up ",
  StyleBox["ReadList", "InlineInputTraditionalForm"],
  " and use it to read in ",
  StyleBox["rt.data", "InlineInputTraditionalForm"],
  " in an appropriate format.  Save the result as ",
  Cell[BoxData[
      FormBox[
        StyleBox["r\[Theta]",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you will want to read in the data as ",
  StyleBox["pairs ",
    FontSlant->"Italic"],
  "of numbers. You might want to look at the on-line documentation for ",
  StyleBox["ReadList", "InlineInputTraditionalForm"],
  ".)"
}], "BeginEndQuestion"],

Cell[TextData[{
  "Note that the valid format specifications are ",
  Cell[BoxData[
      FormBox[
        StyleBox["Byte",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Character",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Expression",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Number",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Real",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Record",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["String",
          "Input"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["Word",
          "Input"], TraditionalForm]]],
  "."
}], "Warning"],

Cell[TextData[{
  "Enter ",
  Cell[BoxData[
      FormBox[
      Cell[TextData[StyleBox["", "InlineInputTraditionalForm"]]], 
        TraditionalForm]]]
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`{rs, \[Theta]s} = r\[Theta]\^T\)], "Input"],

Cell[TextData[{
  "What does ",
  StyleBox["Transpose", "InlineInputTraditionalForm"],
  " do here?"
}], "EndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "In many applications it is more natural to work in radians.  Use ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Theta]s\  = \ \[Theta]s\ \[Degree]\  // N\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to convert from degrees to radians."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Define ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Theta]r = {\[Theta]s, rs}\^T\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". "
}], "BeginEndQuestion"],

Cell[BoxData[
    FormBox["", TraditionalForm]], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Interpolation"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Interpolation", "InlineInputTraditionalForm"],
  " can be used to give the radius, ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", for any value of \[Theta]:"
}], "Text"],

Cell[TextData[{
  "Enter ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptR] = Interpolation[\[Theta]r]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". The output shows the range of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " values over which the interpolation has been defined. Use ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptR][0.2]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to compute the (interpolated) radius at an angle of 0.2 radians.  By \
having a look at the raw data, is your answer is reasonable?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Visualize the shape of the object using ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ". (",
  StyleBox["Hint:",
    FontSlant->"Italic"],
  " The ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " lengths are ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[ScriptR](\[Theta])\) \(cos(\[Theta])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(\[ScriptR](\[Theta])\) \(sin(\[Theta])\)\)]],
  " respectively, and \[Theta] ranges from 0 to 2\[Pi]. To get the picture \
scaled properly you might want to set the ",
  Cell[BoxData[
      FormBox[
        StyleBox["ParametricPlot",
          "Input"], TraditionalForm]]],
  " option ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(AspectRatio \[Rule] Automatic\),
          "Input"], TraditionalForm]]],
  ".)"
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Area of a parametrically defined region"
}], "Subsection",
  CellTags->"parametrically defined region"],

Cell[TextData[{
  "The area of an object whose radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is expressed as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Theta])\)]],
  ", is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] = \[Integral]\_0\%\(2  \[Pi]\)\(\
\[Integral]\_0\%\(f(\[Theta])\)r\ \[DifferentialD]r\ \[DifferentialD]\[Theta]\
\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The integral over ",
  StyleBox["r",
    FontSlant->"Italic"],
  " is trivial. Compute the inner integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(f(\[Theta])\)r \
\[DifferentialD]r\)]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "From this result, the definition of the (numerical) area of a shape \
parametrized by ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is"
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalA][f_] := 
      1\/2\ NIntegrate[\(f(\[Theta])\)\^2, {\[Theta], 0, 
            2\ \[Pi]}]\)], "Input"],

Cell[TextData[{
  "Compute the area of the shape above by entering ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalA][\[ScriptR]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". By looking at the graphical output above, explain whether your answer is \
reasonable?"
}], "EndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Of course, this is only an ",
  StyleBox["approximation",
    FontSlant->"Italic"],
  " to the area of the object as the dataset was incomplete and interpolation \
has been used."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Centre of mass"
}], "Subsection"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-coordinate of the ",
  StyleBox["centre of mass",
    FontSlant->"Italic"],
  " of an object whose radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is expressed as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", is given by the following integral average:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`x\_CM = \(\(\[Integral]\_0\%\(2  \
\[Pi]\)\(\[Integral]\_0\%\(f(\[Theta])\)x\ r\ \[DifferentialD]r\ \
\[DifferentialD]\[Theta]\)\)\/\(\[Integral]\_0\%\(2  \
\[Pi]\)\(\[Integral]\_0\%\(f(\[Theta])\)\ r\ \[DifferentialD]r\ \
\[DifferentialD]\[Theta]\)\) = \(\(\(\[Integral]\_0\%\(2  \
\[Pi]\)\(\[Integral]\_0\%\(f(\[Theta])\)x\ r\ \[DifferentialD]r\ \
\[DifferentialD]\[Theta]\)\)\/\[ScriptCapitalA]\)\(.\)\)\)\)], \
"NumberedEquation"],

Cell[TextData[{
  "What is the expression for the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-coordinate of the centre of mass?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Noting that ",
  Cell[BoxData[
      \(TraditionalForm\`x = r\ \(cos(\[Theta])\)\)]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = r\ \(sin(\[Theta])\)\)]],
  ", modify the steps in \[Section]",
  
  CounterBox["Title", "parametrically defined region"],
  ".",
  
  CounterBox["Section", "parametrically defined region"],
  ".",
  
  CounterBox["Subsection", "parametrically defined region"],
  " to define functions ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptX]\_CM[f_]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptY]\_CM[f_]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Compute the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " coordinates of the centre of mass. By looking at the graphical output \
above, is your answer reasonable? (Approximately where should the centre of \
mass of the shape be located?)"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Numerical Differentiation"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Numerical derivatives"
}], "Subsection",
  CellTags->"numerical derivatives"],

Cell[TextData[{
  "To solve differential equations ",
  StyleBox["numerically",
    FontSlant->"Italic"],
  ", a method for computing derivatives numerically is required. How can the \
derivative of a function be computed numerically? "
}], "Text"],

Cell[TextData[{
  "Compute the Taylor series of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h)\  - \ f(x)\)\/h\)]],
  " using ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h)\  - \ f(x)\)\/h + \(O(h)\)\^3\)]],
  ". What happens to this expression when ",
  Cell[BoxData[
      \(TraditionalForm\`h \[Rule] 0\)]],
  "?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "This result, with modification is the basis of techniques for integrating \
differential equations. For computing the derivative of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " numerically, relying on this definition of differentiation is not \
optimal. As ",
  Cell[BoxData[
      \(TraditionalForm\`h \[Rule] 0\)]],
  ", the error term in the Taylor series is ",
  StyleBox["first order",
    FontSlant->"Italic"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Compute the Taylor series of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h) - \ f(x - h)\)\/\(2\ h\)\)]],
  " and explain why it is preferable for numerical computation of the \
derivative."
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Here is a plot of ",
  Cell[BoxData[
      \(TraditionalForm\`x\ \((1 - x)\) \((1 + 2  x)\)\)]],
  " (",
  StyleBox["\[LongDash]",
    FontColor->RGBColor[0, 0, 1]],
  ") sampled at a set of points (",
  StyleBox["\[Bullet]",
    FontColor->RGBColor[1, 0, 0]],
  ") showing the numerical derivatives computed using ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h)\  - \ f(x)\)\/h\)]],
  " (",
  StyleBox["\[LongDash]",
    FontColor->RGBColor[0, 1, 0]],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h) - \ f(x - h)\)\/\(2\ h\)\)]],
  " (",
  StyleBox["\[LongDash]",
    FontColor->GrayLevel[0]],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(NDPlot[
        x\ \((1 - x)\) \((1 + 2  x)\), {x, \(-0.6\), 1.1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.359944 0.560224 0.250116 0.668752 [
[.07983 .23762 -11.7188 -12 ]
[.07983 .23762 11.7188 0 ]
[.21989 .23762 -14.2188 -12 ]
[.21989 .23762 14.2188 0 ]
[.5 .23762 -10.75 -12 ]
[.5 .23762 10.75 0 ]
[.64006 .23762 -8.25 -12 ]
[.64006 .23762 8.25 0 ]
[.78011 .23762 -10.75 -12 ]
[.78011 .23762 10.75 0 ]
[.92017 .23762 -4.5 -12 ]
[.92017 .23762 4.5 0 ]
[.34744 .11637 -23.4375 -6 ]
[.34744 .11637 0 6 ]
[.34744 .38387 -16.5 -6 ]
[.34744 .38387 0 6 ]
[.34744 .51762 -16.5 -6 ]
[.34744 .51762 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07983 .25012 m
.07983 .25637 L
s
gsave
.07983 .23762 -72.7188 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.21989 .25012 m
.21989 .25637 L
s
gsave
.21989 .23762 -75.2188 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.5 .25012 m
.5 .25637 L
s
gsave
.5 .23762 -71.75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.64006 .25012 m
.64006 .25637 L
s
gsave
.64006 .23762 -69.25 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.78011 .25012 m
.78011 .25637 L
s
gsave
.78011 .23762 -71.75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.92017 .25012 m
.92017 .25637 L
s
gsave
.92017 .23762 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.10784 .25012 m
.10784 .25387 L
s
.13585 .25012 m
.13585 .25387 L
s
.16387 .25012 m
.16387 .25387 L
s
.19188 .25012 m
.19188 .25387 L
s
.2479 .25012 m
.2479 .25387 L
s
.27591 .25012 m
.27591 .25387 L
s
.30392 .25012 m
.30392 .25387 L
s
.33193 .25012 m
.33193 .25387 L
s
.38796 .25012 m
.38796 .25387 L
s
.41597 .25012 m
.41597 .25387 L
s
.44398 .25012 m
.44398 .25387 L
s
.47199 .25012 m
.47199 .25387 L
s
.52801 .25012 m
.52801 .25387 L
s
.55602 .25012 m
.55602 .25387 L
s
.58403 .25012 m
.58403 .25387 L
s
.61204 .25012 m
.61204 .25387 L
s
.66807 .25012 m
.66807 .25387 L
s
.69608 .25012 m
.69608 .25387 L
s
.72409 .25012 m
.72409 .25387 L
s
.7521 .25012 m
.7521 .25387 L
s
.80812 .25012 m
.80812 .25387 L
s
.83613 .25012 m
.83613 .25387 L
s
.86415 .25012 m
.86415 .25387 L
s
.89216 .25012 m
.89216 .25387 L
s
.05182 .25012 m
.05182 .25387 L
s
.02381 .25012 m
.02381 .25387 L
s
.94818 .25012 m
.94818 .25387 L
s
.97619 .25012 m
.97619 .25387 L
s
.25 Mabswid
0 .25012 m
1 .25012 L
s
.35994 .11637 m
.36619 .11637 L
s
gsave
.34744 .11637 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.35994 .38387 m
.36619 .38387 L
s
gsave
.34744 .38387 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.35994 .51762 m
.36619 .51762 L
s
gsave
.34744 .51762 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.35994 .1498 m
.36369 .1498 L
s
.35994 .18324 m
.36369 .18324 L
s
.35994 .21668 m
.36369 .21668 L
s
.35994 .28355 m
.36369 .28355 L
s
.35994 .31699 m
.36369 .31699 L
s
.35994 .35043 m
.36369 .35043 L
s
.35994 .4173 m
.36369 .4173 L
s
.35994 .45074 m
.36369 .45074 L
s
.35994 .48418 m
.36369 .48418 L
s
.35994 .08293 m
.36369 .08293 L
s
.35994 .04949 m
.36369 .04949 L
s
.35994 .01605 m
.36369 .01605 L
s
.35994 .55105 m
.36369 .55105 L
s
.35994 .58449 m
.36369 .58449 L
s
.35994 .61793 m
.36369 .61793 L
s
.25 Mabswid
.35994 0 m
.35994 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .37852 m
.06244 .28387 L
.08255 .2453 L
.10458 .21091 L
.12507 .18586 L
.14415 .16818 L
.15465 .16067 L
.16457 .15496 L
.17348 .15093 L
.17847 .14912 L
.18314 .14771 L
.18807 .14651 L
.19258 .14568 L
.19515 .14531 L
.19759 .14503 L
.20017 .14481 L
.20163 .14472 L
.20233 .14469 L
.20298 .14466 L
.2043 .14462 L
.205 .14461 L
.20573 .1446 L
.20697 .1446 L
.20767 .14461 L
.20832 .14462 L
.20954 .14466 L
.21066 .14471 L
.21194 .14478 L
.21316 .14486 L
.21586 .14511 L
.21836 .14541 L
.22401 .14633 L
.22864 .14733 L
.23364 .14866 L
.24268 .1517 L
.26328 .16151 L
.28332 .17458 L
.30442 .1917 L
.34253 .23001 L
.38309 .27879 L
.42213 .33076 L
.46363 .38832 L
.50361 .44304 L
.54208 .49226 L
.583 .53797 L
.60335 .55722 L
.6224 .57267 L
.64184 .58554 L
.66029 .59476 L
.66999 .59834 L
Mistroke
.67512 .59985 L
.68057 .60117 L
.68562 .60212 L
.69019 .60275 L
.6924 .60297 L
.69356 .60306 L
.69479 .60315 L
.69586 .60321 L
.69704 .60326 L
.69811 .60329 L
.69911 .60331 L
.70038 .60332 L
.70102 .60332 L
.70172 .60331 L
.70297 .60328 L
.70413 .60324 L
.70551 .60317 L
.70676 .60309 L
.70959 .60283 L
.7119 .60256 L
.71442 .60218 L
.7195 .6012 L
.72416 .60002 L
.72913 .59847 L
.73807 .59489 L
.74834 .58949 L
.75946 .58205 L
.77962 .5641 L
.79954 .54043 L
.82059 .50858 L
.85853 .43215 L
.89892 .32146 L
.9378 .18362 L
.97619 .01472 L
Mfstroke
0 1 0 r
.02381 .37852 m
.06244 .33114 L
.10458 .27948 L
.14415 .23095 L
.18221 .18429 L
.20178 .16029 L
.20742 .15338 L
.21019 .14998 L
.2114 .14849 L
.21274 .14685 L
.21394 .14538 L
.21506 .14562 L
.21625 .14663 L
.21753 .14772 L
.22272 .15214 L
.26394 .18725 L
.30365 .22108 L
.34184 .25361 L
.38249 .28824 L
.42162 .32868 L
.4632 .38166 L
.50327 .4327 L
.54182 .48181 L
.56136 .50671 L
.57172 .51991 L
.58282 .53405 L
.58831 .54104 L
.59101 .54447 L
.5935 .54766 L
.59467 .54914 L
.59576 .54989 L
.59691 .54993 L
.59817 .54998 L
.60324 .55019 L
.62231 .55095 L
.661 .5525 L
.70214 .55415 L
.74176 .55574 L
.76173 .55654 L
.77043 .55689 L
.77987 .55727 L
.78242 .55737 L
.78381 .55743 L
.78512 .55748 L
.78623 .55604 L
.78742 .55264 L
.78996 .54542 L
.79948 .51828 L
.82043 .45858 L
.86171 .34096 L
Mistroke
.90147 .22765 L
.93971 .11867 L
.97619 .01472 L
Mfstroke
1 0 0 r
3 Mabswid
.02381 .37852 Mdot
.21429 .14496 Mdot
.40476 .30721 Mdot
.59524 .54987 Mdot
.78571 .55751 Mdot
.97619 .01471 Mdot
0 g
.5 Mabswid
.02611 .18018 m
.40246 .10973 L
s
.2625 .15601 m
.54702 .45841 L
s
.42837 .44023 m
0 0 rlineto s
.42837 .44023 m
.69899 .61803 L
s
.74263 .61803 m
.90906 .38424 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oI`3oool0
0`000000oooo0?ooo`2f0?ooo`00I`3oool00`000000oooo0?ooo`2f0?ooo`00I`3oool00`000000
oooo0?ooo`2f0?ooo`00I`3oool00`000000oooo0?ooo`2/0?ooo`<0o`001`3oool006L0oooo0P00
002]0?ooo`<0o`001`3oool006L0oooo00<000000?ooo`3oool0[03oool30?l000L0oooo001W0?oo
o`030000003oool0oooo0:`0oooo00<00?l00000o`3oool01`3oool006L0oooo00<000000?ooo`3o
ool0[03oool00`00o`00oooo0?ooo`070?ooo`00I`3oool00`000000oooo0?ooo`2/0?ooo`03003o
003oool0oooo00L0oooo001W0?ooo`030000003oool0oooo0:/0oooo00<00?l00000o`3oool0203o
ool006L0oooo00<000000?ooo`3oool0Z`3oool00`00o`00003o0?ooo`080?ooo`00I`3oool00`00
0000oooo0?ooo`2[0?ooo`03003o00000?l0oooo00P0oooo001W0?ooo`030000003oool0oooo0:X0
oooo00<00?l00000o`3oool02@3oool006L0oooo00<000000?ooo`3oool0ZP3oool00`00o`00003o
0?ooo`090?ooo`00I`3oool200000:/0oooo00<00?l00000o`3oool02@3oool006L0oooo00<00000
0?ooo`3oool0Z@3oool00`00o`00oooo0000o`0:0?ooo`00I`3oool00`000000oooo0?ooo`2Y0?oo
o`03003o00000?l0oooo00X0oooo001W0?ooo`030000003oool0oooo0:T0oooo00<00?l00000o`3o
ool02P3oool006L0oooo00<000000?ooo`3oool0Z03oool00`00o`00oooo0000o`0;0?ooo`00I`3o
ool00`000000oooo0?ooo`2X0?ooo`03003o003oool0003o00/0oooo001W0?ooo`030000003oool0
oooo0:P0oooo00<00?l00000o`3oool02`3oool006L0oooo00<000000?ooo`3oool0Y`3oool00`00
o`00oooo0000o`0<0?ooo`00I`3oool00`000000oooo0?ooo`2W0?ooo`03003o003oool0003o00`0
oooo001W0?ooo`800000Z03oool00`00o`00oooo0000o`0<0?ooo`00I`3oool00`000000oooo0?oo
o`2V0?ooo`04003o003oool0oooo0000o``0oooo001W0?ooo`030000003oool0oooo0:H0oooo00<0
0?l00?ooo`000?l03@3oool006L0oooo00<000000?ooo`3oool0YP3oool00`00o`00oooo0000o`0=
0?ooo`00I`3oool00`000000oooo0?ooo`2U0?ooo`04003o003oool0oooo0000o`d0oooo001W0?oo
o`030000003oool0oooo0:D0oooo00@00?l00?ooo`3oool0003o3@3oool006L0oooo00<000000?oo
o`3oool0Y@3oool00`00o`00oooo0000o`0>0?ooo`00I`3oool00`000000oooo0?ooo`2T0?ooo`04
003o003oool0oooo0000o`h0oooo001F0?ooo`8000000`3oool00`000000oooo00000003000000H0
oooo00<000000?ooo`3oool01P3oool4000009X0oooo00@00?l00?ooo`3oool0003o3P3oool005D0
oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000060?ooo`040000003oool0
oooo0?ooo`D00000WP3oool01000o`00oooo0?ooo`000?l>0?ooo`00C`3oool400000080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`H00000XP3oool01000o`00oooo
0?ooo`000?l?0?ooo`00E@3oool010000000oooo0?ooo`0000060?ooo`H000000P3oool00`000000
oooo0?ooo`2S0?ooo`04003o003oool0oooo0000o`l0oooo001E0?ooo`040000003oool0oooo0000
0080oooo1P0000060?ooo`030000003oool0oooo0:<0oooo00@00?l00?ooo`3oool0003o3`3oool0
05D0oooo1P0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0XP3oool0
1@00o`00oooo0?ooo`3oool0003o00l0oooo001@0?ooo`D0000000<0oooo0000000000001P3oool2
000000L0oooo00<000000?ooo`3oool0XP3oool01@00o`00oooo0?ooo`3oool0003o00l0oooo001:
0?ooo`H000005`3oool00`000000oooo0?ooo`2R0?ooo`04003o003oool0oooo0000oa00oooo0015
0?ooo`D000007@3oool00`000000oooo0?ooo`2Q0?ooo`05003o003oool0oooo0?ooo`000?l0403o
ool003`0oooo0`3o00000`3oool000000000000300000280oooo00<000000?ooo`3oool0X@3oool0
1@00o`00oooo0?ooo`3oool0003o0100oooo000g0?ooo`<0003o1P0000000`000?l0oooo0?ooo`0T
0?ooo`030000003oool0oooo0:40oooo00D00?l00?ooo`3oool0oooo0000o`0@0?ooo`00<`3oool2
0000o`D000000P3oool30?l00003003o003oool0003o00<0003o8P3oool200000:40oooo00D00?l0
0?ooo`3oool0oooo0000o`0A0?ooo`00;`3oool6000000H0oooo00<00?l00?ooo`3oool00P3oool2
003o00<0oooo0P000?lP0?ooo`030000003oool0oooo0:00oooo00D00?l00?ooo`3oool0oooo0000
o`0A0?ooo`00:P3oool500000080003o2P3oool00`00o`00oooo0?ooo`040?ooo`03003o003oool0
oooo0080oooo0P000?l20?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0X03oool0
1@00o`00oooo0?ooo`3oool0003o0140oooo000U0?ooo`D000000`3oool00`000?l0oooo0?ooo`0:
0?ooo`03003o003oool0oooo00H0oooo00<00?l00?ooo`3oool00`3oool20000o`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0W`3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0
oooo00l0oooo000O0?ooo`H000001P3oool20000o`d0oooo00<00?l00?ooo`3oool01`3oool00`00
o`00oooo0?ooo`040?ooo`030000o`000000oooo01T0oooo00<000000?ooo`3oool0W`3oool01@00
o`00oooo0?ooo`3oool0003o0180oooo000J0?ooo`D000002`3oool00`000?l0oooo0?ooo`0<0?oo
o`03003o003oool0oooo00T0oooo00<00?l00?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo09l0oooo00D00?l00?ooo`3oool0oooo0000o`0B0?ooo`00503oool60000
00l0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0;0?ooo`03003o003oool0oooo
00D0oooo00<000000000o`3oool05P3oool00`000000oooo0?ooo`2N0?ooo`03003o003oool0oooo
0080oooo00<0003o0?ooo`3oool0403oool000l0oooo1@00000D0?ooo`030000o`3oool0oooo00`0
oooo00<00?l00?ooo`3oool03@3oool00`00o`00oooo0?ooo`050?ooo`03000000000?l0oooo01D0
oooo00<000000?ooo`3oool0WP3oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0100
oooo000:0?ooo`D00000603oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0oooo00l0oooo
00<00?l00?ooo`3oool01@3oool00`000000003o0000o`0D0?ooo`030000003oool0oooo09d0oooo
00<00?l00?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`001`3oool3000001`0oooo00<0
003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0A0?ooo`03003o003oool0oooo00D0oooo00<0
00000?ooo`000?l04`3oool00`000000oooo0?ooo`2M0?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool04@3oool002D0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0C
0?ooo`03003o003oool0oooo00D0oooo00@000000?ooo`000?l0003o4@3oool2000009h0oooo00<0
0?l00?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`00903oool00`000?l0oooo0?ooo`0=
0?ooo`03003o003oool0oooo01@0oooo0P00o`060?ooo`040000003oool0oooo0000oa00oooo00<0
00000?ooo`3oool0W03oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo000T
0?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`3oool05`3oool00`00o`00oooo0?ooo`04
0?ooo`040000003oool0oooo0000o`l0oooo00<000000?ooo`3oool0W03oool00`00o`00oooo0?oo
o`030?ooo`030000o`3oool0oooo0140oooo000S0?ooo`030000o`3oool0oooo00`0oooo00<00?l0
0?ooo`3oool06@3oool00`00o`00oooo0?ooo`040?ooo`040000003oool0oooo0000o`h0oooo00<0
00000?ooo`3oool0W03oool00`00o`00oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo000R
0?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`3oool06`3oool00`00o`00oooo0?ooo`04
0?ooo`040000003oool0oooo0000o`d0oooo00<000000?ooo`3oool0V`3oool00`00o`00oooo0?oo
o`030?ooo`030000o`3oool0oooo0180oooo000Q0?ooo`030000o`3oool0oooo00`0oooo00<00?l0
0?ooo`3oool07@3oool00`00o`00oooo0?ooo`040?ooo`040000003oool0oooo0000o``0oooo00<0
00000?ooo`3oool0V`3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0oooo0180oooo000P
0?ooo`030000o`3oool0oooo00d0oooo00<00?l00?ooo`3oool07P3oool2003o00D0oooo00@00000
0?ooo`3oool0003o2`3oool00`000000oooo0?ooo`2K0?ooo`03003o003oool0oooo0080oooo00<0
003o0?ooo`3oool04`3oool001l0oooo00<0003o0?ooo`3oool03@3oool00`00o`00oooo0?ooo`0Q
0?ooo`03003o003oool0oooo00<0oooo00@000000?ooo`3oool0003o2P3oool00`000000oooo0?oo
o`2J0?ooo`03003o003oool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool001D0oooo0P000003
0?ooo`050000003oool0oooo000000000?l03`3oool00`00o`00oooo0?ooo`0:0?ooo`8000000`3o
ool00`000000oooo0000000300000080oooo0P00000:0?ooo`03003o003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000o`090?ooo`030000003oool0oooo01d0oooo0P0000030?ooo`030000
003oool0000000<000000P3oool2000001`0oooo0P0000030?ooo`030000003oool0oooo00800000
6`3oool2000000<0oooo00@000000?ooo`3oool00000103oool2000001h0oooo00<00?l00?ooo`00
00000P0000000`3oool0003o0?ooo`0D0?ooo`00503oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0003o000000d0oooo00<00?l00?ooo`3oool02P3oool010000000oooo0?ooo`000004
0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`080?ooo`03003o
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000o`080?ooo`030000003oool0oooo01`0
oooo00@000000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool0603oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000001T0
oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool06`3oool01000o`00oooo0?ooo`0000020?ooo`030000o`3oool0oooo01<0oooo000>
0?ooo`@000000P3oool010000000oooo0?ooo`0000050?ooo`030000o`3oool0000000d0oooo00<0
0?l00?ooo`3oool0103oool400000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00?l00?ooo`3oool00P3oool01@000000oooo
0?ooo`3oool0003o00L0oooo0P00000M0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06P3oool01`00o`00oooo0?ooo`3oool000000?ooo`000?l05P3oool001@0oooo
00@000000?ooo`3oool00000103oool010000?l0oooo0?ooo`00000<0?ooo`03003o003oool0oooo
00/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo0P00o`030?ooo`050000003oool0oooo0?ooo`000?l01P3oool00`000000oooo0?oo
o`0L0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0H0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool05`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool01`00
o`00oooo0?ooo`3oool000000?ooo`000?l05P3oool001@0oooo00@000000?ooo`3oool00000103o
ool00`000?l000000000000<0?ooo`03003o003oool0oooo00`0oooo00@000000?ooo`3oool00000
1`3oool00`000000oooo00000002000000l0oooo00D00?l00?ooo`3oool0oooo000000030?ooo`03
0000o`3oool0oooo00<0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`0000070?oo
o`030000003oool00000008000006`3oool010000000oooo0?ooo`0000040?ooo`<000006P3oool0
10000000oooo0?ooo`0000070?ooo`030000003oool00000008000007@3oool01`00o`00oooo0?oo
o`3oool000000?ooo`000?l05P3oool001@0oooo00@000000?ooo`3oool000000`3oool00`000?l0
00000?ooo`0<0?ooo`03003o003oool0oooo00d0oooo00@000000?ooo`3oool00000103oool01P00
0000oooo0?ooo`000000oooo00000180oooo00D00?l00?ooo`3oool0oooo000000030?ooo`030000
o`3oool0oooo0080oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`0000040?ooo`06
0000003oool0oooo0000003oool000007@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo01X0oooo00@000000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo0000
01h0oooo00@00?l00?ooo`3oool0oooo0P0000000`3oool0003o0?ooo`0E0?ooo`005@3oool20000
00<0oooo00<0003o0?ooo`0000000`0000090?ooo`03003o003oool0oooo00l0oooo0P0000060?oo
o`8000000P3oool400000100oooo00D00?l00?ooo`3oool0oooo000000020?ooo`030000o`3oool0
oooo0080oooo00<000000?ooo`3oool07@3oool2000000H0oooo0P0000020?ooo`@000006`3oool2
000000D0oooo1000000J0?ooo`8000001@3oool4000000030?ooo`0000000000008000006`3oool0
0`00o`00oooo0?ooo`020?ooo`03000000000?l0oooo01H0oooo000I0?ooo`030000o`3oool0oooo
00d0oooo00<00?l00?ooo`3oool0<03oool2003o0080oooo00@000000?ooo`3oool0003o0`3oool0
0`000000oooo0?ooo`2G0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool05@3oool0
01T0oooo00<0003o0?ooo`3oool0303oool00`00o`00oooo0?ooo`0c0?ooo`04003o003oool0oooo
00000080oooo00@0003o0?ooo`3oool00000V@3oool00`00o`00oooo0?ooo`040?ooo`030000o`3o
ool0oooo01D0oooo000H0?ooo`030000o`3oool0oooo00`0oooo00<00?l00?ooo`3oool0=@3oool0
1000o`00oooo0?ooo`0000020?ooo`030000o`3oool0000009T0oooo00<00?l00?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0F0?ooo`005`3oool00`000?l0oooo0?ooo`0<0?ooo`03003o003oool0
oooo03L0oooo00@00?l00?ooo`3oool000000P3oool00`000?l000000?ooo`2G0?ooo`03003o003o
ool0oooo00@0oooo00<0003o0?ooo`3oool05P3oool001L0000000<0003o0000000000002`000000
0`00o`0000000000000i00000003003o00000000000000<0000000<0003o000000000000UP000000
0`00o`00000000000004000000030000o`000000000001D000000@3oool000L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000o`000000oooo00H0oooo00<000000?oo
o`3oool00`3oool00`00o`00oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800?l000D0oooo0000
003oool000000000o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`0300000000o`00oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo000F0?ooo`030000o`000000oooo
00/0oooo00<00?l00?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`05003o003oool00000
000000000?l09P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool07@3oool00`00o`00oooo0?ooo`040?ooo`030000o`000000oooo01L0oooo000E0?oo
o`030000o`3oool0oooo00/0oooo00<00?l00?ooo`3oool0?`3oool01@00o`0000000000003oool0
003o09D0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`005@3oool00`00
0?l0oooo0?ooo`0:0?ooo`03003o003oool0oooo0440oooo00D00?l00000003oool0oooo0000o`2D
0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool001@0oooo00<0003o0?oo
o`3oool02`3oool00`00o`00oooo0?ooo`120?ooo`05003o00000000oooo0?ooo`000?l0TP3oool0
0`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo01L0oooo000D0?ooo`030000o`3oool0oooo
00X0oooo00<00?l00?ooo`3oool0@`3oool00`0000000?l0000000020?ooo`030000o`3oool0oooo
08l0oooo00<00?l00?ooo`3oool0103oool00`000?l0oooo0?ooo`0H0?ooo`00503oool00`000?l0
oooo0?ooo`090?ooo`03003o003oool0oooo04@0oooo00@000000?ooo`00o`0000000P3oool00`00
0?l0oooo0?ooo`2>0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool0603oool001<0
oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`150?ooo`050000003oool0oooo003o
000000000P3oool00`000?l0oooo0?ooo`2<0?ooo`03003o003oool0oooo00D0oooo00<0003o0?oo
o`3oool0603oool001<0oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`160?ooo`08
0000003oool0oooo0?ooo`00o`0000000?ooo`000?n>0?ooo`03003o003oool0oooo00@0oooo00<0
003o0?ooo`3oool06@3oool00180oooo00<0003o0?ooo`3oool02@3oool00`00o`00oooo0?ooo`16
0?ooo`8000000`3oool01000o`0000000?ooo`000?n=0?ooo`03003o003oool0oooo00@0oooo00<0
003o0?ooo`3oool06@3oool00180oooo00<0003o0?ooo`3oool0203oool00`00o`00oooo0?ooo`17
0?ooo`030000003oool0oooo00<0oooo00@00?l00000003oool0003oR`3oool00`00o`00oooo0?oo
o`050?ooo`030000o`3oool0oooo01T0oooo000A0?ooo`030000o`3oool0oooo00P0oooo00<00?l0
0?ooo`3oool0B03oool00`000000oooo0?ooo`040?ooo`04003o00000000oooo0000ohX0oooo00<0
0?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0I0?ooo`004@3oool00`000?l0oooo0?ooo`07
0?ooo`03003o003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool00`00o`0000000000o`2:
0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`3oool06P3oool00140oooo00<0003o0?oo
o`3oool01P3oool00`00o`00oooo0?ooo`1:0?ooo`030000003oool0oooo00H0oooo00<00?l00000
00000?l0R03oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo01X0oooo000@0?ooo`03
0000o`3oool0oooo00H0oooo00<00?l00?ooo`3oool0B`3oool00`000000oooo0?ooo`070?ooo`03
003o00000000003o08L0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0J0?ooo`00
403oool00`000?l0oooo0?ooo`050?ooo`03003o003oool0oooo04`0oooo00<000000?ooo`3oool0
203oool01000o`0000000?l0003o00250?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3o
ool06P3oool000l0oooo00<0003o0?ooo`3oool01P3oool00`00o`00oooo0?ooo`1<0?ooo`030000
003oool0oooo00T0oooo00<0o`000000003o0000Q03oool00`00o`00oooo0?ooo`050?ooo`030000
o`3oool0oooo01/0oooo000?0?ooo`030000o`3oool0oooo00D0oooo00<00?l00?ooo`3oool0C@3o
ool00`000000oooo0?ooo`090?ooo`030?l000000000o`0008@0oooo00<00?l00?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0K0?ooo`003`3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0
oooo04h0oooo0P00000<0?ooo`03000000000?l0oooo0880oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0K0?ooo`003P3oool00`000?l0oooo0?ooo`040?ooo`03003o003oool0oooo
04l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`200?ooo`03003o003oool0oooo
00D0oooo00<0003o0?ooo`3oool0703oool000h0oooo00<0003o0?ooo`3oool00`3oool00`00o`00
oooo0?ooo`1@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O`3oool00`00o`00
oooo0?ooo`050?ooo`030000o`3oool0oooo01`0oooo000=0?ooo`030000o`3oool0oooo00<0oooo
00<00?l00?ooo`3oool0D@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07h0oooo
00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0L0?ooo`003@3oool00`000?l0oooo0?oo
o`020?ooo`03003o003oool0oooo0580oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`1l0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool07@3oool000`0oooo00<0003o
0?ooo`3oool00`3oool00`00o`00oooo0?ooo`1B0?ooo`030000003oool0oooo00l0oooo00<00?l0
0000003oool0O03oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo000<0?oo
o`030000o`3oool0oooo0080oooo00<00?l00?ooo`3oool0D`3oool00`000000oooo0?ooo`0@0?oo
o`03003o00000000oooo07/0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0M0?oo
o`00303oool01@000?l0oooo0?ooo`3oool00?l005H0oooo00<000000?ooo`3oool04@3oool00`00
o`0000000?ooo`1i0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool07P3oool000/0
oooo00D0003o0?ooo`3oool0oooo003o001G0?ooo`030000003oool0oooo0140oooo00<0003o003o
00000000N@3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo01h0oooo000;0?ooo`04
0000o`3oool0oooo003o05P0oooo00<000000?ooo`3oool04P3oool00`00o`00oooo0000001g0?oo
o`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool07P3oool000X0oooo00D0003o0?ooo`3o
ool0oooo003o001H0?ooo`800000503oool00`00o`00oooo0000001f0?ooo`03003o003oool0oooo
00D0oooo00<0003o0?ooo`3oool07`3oool000X0oooo00@0003o0?ooo`3oool00?l0F@3oool00`00
0000oooo0?ooo`0D0?ooo`03003o003oool0000007D0oooo00<00?l00?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0O0?ooo`002P3oool00`000?l0oooo003o001J0?ooo`030000003oool0oooo01@0
oooo00@0003o003o003oool00000L`3oool00`00o`00oooo0?ooo`060?ooo`030000o`3oool0oooo
01l0oooo00090?ooo`030000o`3oool00?l005/0oooo00<000000?ooo`3oool05@3oool00`00o`00
oooo0000001c0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool000T0oooo
00<0003o0?ooo`00o`00F`3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool000000780oooo
00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0P0?ooo`00203oool00`000?l0oooo003o
001L0?ooo`030000003oool0oooo01H0oooo00@0003o003o003oool00000L03oool00`00o`00oooo
0?ooo`060?ooo`030000o`3oool0oooo0200oooo00080?ooo`030000o`00o`00oooo05`0oooo00<0
00000?ooo`3oool05`3oool01000o`00oooo0?ooo`00001_0?ooo`03003o003oool0oooo00D0oooo
00<0003o0?ooo`3oool08@3oool000H0oooo0`3o001=0?ooo`8000000`3oool00`000000oooo0000
0003000000H0oooo00<000000?ooo`3oool0603oool01000o`00oooo0?ooo`00001^0?ooo`03003o
003oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool000H0oooo0`3o001<0?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0I0?ooo`04
003o003oool0oooo000006`0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`0R0?oo
o`001P3oool30?l004`0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`060?oo
o`<000006@3oool01@000?l00?l00?ooo`3oool0000006/0oooo00<00?l00?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0R0?ooo`00E@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06P3oool01@00o`00oooo0?ooo`3oool0000006X0oooo00<0
0?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo001E
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0K0?ooo`05003o003oool0oooo0?ooo`000000J03oool00`00o`00oooo0?ooo`050?ooo`030000
o`3oool0oooo00L0oooo00<000000?ooo`3oool06@3oool005D0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo01/0oooo00<0003o003o003o
ool00P3oool00`000000oooo0?ooo`1U0?ooo`03003o003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`000000oooo0?ooo`0J0?ooo`00EP3oool2000000H0oooo0P0000070?ooo`030000
003oool0oooo01`0oooo00<0003o003o003oool00P3oool00`000000oooo0?ooo`1T0?ooo`03003o
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`00I`3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`00o`00oooo0080oooo00<000000?ooo`3oool0HP3o
ool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0703o
ool006L0oooo00<000000?ooo`3oool07P3oool00`000?l00?l00?ooo`020?ooo`030000003oool0
oooo0640oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0
oooo01`0oooo001W0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`00o`000`3oool00`00
0000oooo0?ooo`1O0?ooo`03003o003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`00
0000oooo0?ooo`0M0?ooo`00I`3oool00`000000oooo0?ooo`0O0?ooo`030000o`00o`00oooo00<0
oooo00<000000?ooo`3oool0GP3oool00`00o`00oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<000000?ooo`3oool07P3oool006L0oooo00<000000?ooo`3oool0803oool00`000?l00?l0
0?ooo`020?ooo`030000003oool0oooo05h0oooo00<00?l00?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030000003oool0oooo01h0oooo001W0?ooo`8000008P3oool00`000?l00?l00?oo
o`020?ooo`030000003oool0oooo05`0oooo00<00?l00?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`030000003oool0oooo01l0oooo001W0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`00o`000`3oool00`000000oooo0?ooo`1K0?ooo`03003o003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`00I`3oool00`000000oooo0?ooo`0R0?oo
o`030000o`3oool00?l000<0oooo00<000000?ooo`3oool0FP3oool00`00o`00oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo00<000000?ooo`3oool08@3oool006L0oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo003o00030?ooo`030000003oool0oooo05P0oooo00<00?l00?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0240oooo001W0?ooo`030000
003oool0oooo02<0oooo00@0003o0?ooo`3oool00?l00`3oool00`000000oooo0?ooo`1G0?ooo`03
003o003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`00
I`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool00?l000@0oooo00<000000?ooo`3oool0
EP3oool00`00o`00oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`0000009@3oool006L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool00?l000@0oooo
00<000000?ooo`3oool0E03oool00`00o`00oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00
00009P3oool006L0oooo00<000000?ooo`3oool0403oool2000001@0oooo00<0003o0?ooo`00o`00
103oool00`000000oooo0?ooo`1C0?ooo`03003o003oool0oooo00D0oooo00D0003o0?ooo`3oool0
oooo0000000V0?ooo`00I`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
00@0003o0?ooo`3oool00?l0103oool00`000000oooo0?ooo`1B0?ooo`03003o003oool0oooo00@0
oooo00D0003o0?ooo`3oool0oooo0000000W0?ooo`00I`3oool00`000000oooo0?ooo`0C0?ooo`80
00004P3oool010000?l0oooo0?ooo`00o`040?ooo`030000003oool0oooo0500oooo00<00?l00?oo
o`3oool01@3oool010000?l0oooo0?ooo`00000X0?ooo`00I`3oool2000001H0oooo00<000000?oo
o`3oool0403oool00`000?l0oooo003o00050?ooo`030000003oool0oooo04l0oooo00<00?l00?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool0000002P0oooo001W0?ooo`030000003oool0oooo
01H0oooo0P00000A0?ooo`030000o`3oool00?l000D0oooo00<000000?ooo`3oool0CP3oool00`00
o`00oooo0?ooo`040?ooo`040000o`3oool0oooo000002T0oooo001W0?ooo`030000003oool0oooo
01P0oooo0P00000@0?ooo`030000o`3oool00?l000D0oooo00<000000?ooo`3oool0C03oool00`00
o`00oooo0?ooo`040?ooo`040000o`3oool0oooo000002X0oooo001W0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool03@3oool010000?l0oooo0?ooo`00o`1C0?ooo`03003o003oool0
oooo00@0oooo00<0003o0?ooo`000000:`3oool006L0oooo00<000000?ooo`3oool06`3oool20000
00h0oooo00<0003o0?ooo`00o`00DP3oool00`00o`00oooo0?ooo`040?ooo`040000o`3oool0oooo
000002/0oooo001W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`00
0?l0oooo003o001A0?ooo`03003o003oool0oooo00@0oooo00<0003o0?ooo`000000;03oool006L0
oooo00<000000?ooo`3oool07P3oool2000000d0oooo00<0003o0?ooo`00o`00D03oool00`00o`00
oooo0?ooo`030?ooo`030000o`3oool0000002d0oooo001W0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool02P3oool010000?l0oooo0?ooo`00o`1>0?ooo`03003o003oool0oooo00@0
oooo00<0003o0000003oool0;@3oool006L0oooo00<000000?ooo`3oool08@3oool2000000/0oooo
00@0003o0?ooo`3oool00?l0C@3oool00`00o`00oooo0?ooo`030?ooo`030000o`3oool0000002h0
oooo001W0?ooo`800000903oool2000000X0oooo00<0003o0?ooo`00o`00C@3oool00`00o`00oooo
0?ooo`030?ooo`030000o`000000oooo02h0oooo001W0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0203oool00`000?l0oooo003o001;0?ooo`03003o003oool0oooo00<0oooo00<0
003o0000003oool0;`3oool006L0oooo00<000000?ooo`3oool09P3oool2000000T0oooo00<0003o
0?ooo`00o`00BP3oool00`00o`00oooo0?ooo`030?ooo`030000o`000000oooo02l0oooo001W0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool010000?l0oooo0?ooo`00o`19
0?ooo`03003o003oool0oooo0080oooo00<0003o0000003oool0<03oool006L0oooo00<000000?oo
o`3oool0:@3oool2000000L0oooo00<0003o0?ooo`00o`00B03oool00`00o`00oooo0?ooo`030?oo
o`030000003oool0oooo0300oooo001W0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo003o00170?ooo`03003o003oool0oooo0080oooo00<000000?ooo`3o
ool0<@3oool006L0oooo00<000000?ooo`3oool0;03oool2000000H0oooo00<0003o0?ooo`00o`00
AP3oool00`00o`00oooo0?ooo`020?ooo`030000003oool0oooo0340oooo001W0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0103oool00`000?l0oooo003o00140?ooo`03003o003o
ool0oooo0080oooo00<000000?ooo`3oool0<P3oool005H0oooo0P0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`8000001@3oool0
0`000?l0oooo003o00130?ooo`06003o003oool0oooo0?ooo`000000003o=03oool005D0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0340oooo
0P0000040?ooo`030000o`3oool00?l00480oooo00D00?l00?ooo`3oool000000000o`0e0?ooo`00
E@3oool010000000oooo0?ooo`0000040?ooo`@000001P3oool3000003<0oooo00D000000?ooo`3o
ool0oooo0000o`020?ooo`03003o003oool0oooo03h0oooo00D00?l00?ooo`3oool0oooo0000000f
0?ooo`00E@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0=03oool200000080oooo00<0003o0?ooo`00o`00@03oool01@00o`00oooo0?oo
o`000000003o03H0oooo001E0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`0f0?ooo`060000003oool0oooo0000o`3oool00?l0?P3oool01@00
o`00oooo0?ooo`000000003o03L0oooo001E0?ooo`040000003oool0oooo000000H0oooo0P000006
0?ooo`030000003oool0oooo03L0oooo0P000000103oool0003o0?ooo`00o`0m0?ooo`04003o003o
ool0oooo000003P0oooo001F0?ooo`800000203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo03T0oooo00D000000?ooo`000?l0oooo003o000l0?ooo`04003o003oool000000000ocP0
oooo001W0?ooo`030000003oool0oooo03X0oooo0P0000000`000?l00?l00?ooo`0j0?ooo`04003o
003oool000000000ocT0oooo001W0?ooo`030000003oool0oooo03`0oooo00<000000000o`00o`00
>P3oool00`00o`0000000000o`0j0?ooo`00I`3oool00`000000oooo0?ooo`0m0?ooo`80000000<0
0?l00?ooo`3oool0=`3oool00`00o`0000000000o`0j0?ooo`00I`3oool00`000000oooo0?ooo`0o
0?ooo`80000000<0o`000?ooo`3oool0=03oool00`00o`0000000000o`0k0?ooo`00I`3oool20000
0400oooo0P3o00000`0000000?l0003o000;003o02T0oooo00<000000000o`3oool0>`3oool006L0
oooo00<000000?ooo`3oool0?`3oool30?l0008000002`3ooolG003o0100oooo00<0o`000000003o
0000?@3oool006L0oooo00<000000?ooo`3oool0@`3oool00`000?l000000?ooo`0P0?oooa000?l0
00<0o`000000003o0000?@3oool006L0oooo00<000000?ooo`3oool0A03oool00`000?l000000000
000_0?ooo`030000003o0000o`0003d0oooo001W0?ooo`030000003oool0oooo04D0oooo00<0003o
0?ooo`000000;03oool00`000?l000000?ooo`0o0?ooo`00I`3oool00`000000oooo0?ooo`160?oo
o`040000o`3oool00000000002T0oooo00<0003o0?ooo`000000@03oool006L0oooo00<000000?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`02000002H0oooo00<0003o0?ooo`000000@@3oool006L0
oooo00<000000?ooo`3oool0B03oool20000o`80oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo000000120?ooo`00I`3oool00`000000oooo0?ooo`1:0?ooo`80003o00<0oooo000000000000
8@3oool00`000?l0oooo000000130?ooo`00I`3oool00`000000oooo0?ooo`1<0?ooo`80003o00<0
oooo0000003oool07@3oool20000o`80oooo00<000000?ooo`3oool0@@3oool006L0oooo0P00001?
0?ooo`80003o0P00000K0?ooo`050000o`3oool0oooo0?ooo`000000A03oool006L0oooo00<00000
0?ooo`3oool0D03oool20000o`030000003oool0oooo01H0oooo0P000?l30?ooo`030000003oool0
oooo04<0oooo001W0?ooo`030000003oool0oooo0580oooo00<0003o0000000000005@3oool00`00
0?l0oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo001W0?ooo`030000003oool0oooo05<0
oooo0P000?l00`000000oooo0?ooo`0@0?ooo`80003o1@3oool00`000000oooo0?ooo`140?ooo`00
I`3oool00`000000oooo0?ooo`1F0?ooo`80000000<0003o0?ooo`3oool02P3oool30000o`H0oooo
00<000000?ooo`3oool0A@3oool006L0oooo00<000000?ooo`3oool0F03oool2000000/0003o203o
ool00`000000oooo0?ooo`160?ooo`00I`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0AP3oool006L0oooo00<000000?ooo`3oool0F`3oool20000
00l0oooo00<000000?ooo`3oool0A`3oool006L0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo001W0?ooo`800000G`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.644714, -0.374009, \
0.00623494, 0.00522311}}]
}, Open  ]],

Cell[TextData[{
  "Suppose that you can easily compute (or know) the values ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + h)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - h)\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the values of the function at three points, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[PlusMinus] h\)]],
  "."
}], "Text"],

Cell["Form an arbitrary linear combination of these terms, say", \
"BeginQuestion",
  CellTags->"arbitrary linear combination"],

Cell[BoxData[
    \(TraditionalForm\`lc = \(\[Alpha]\ \(f(x)\) + \[Beta]\ \(f(h + x)\)\  + \
\(\(\[Gamma]\)\(\ \)\(f(x - h)\)\(\ \)\)\)\/h\)], "Input"],

Cell[TextData[{
  "Expand ",
  StyleBox["lc", "InlineInputTraditionalForm"],
  " in a Taylor series about ",
  Cell[BoxData[
      \(TraditionalForm\`h = 0\)]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  " up to second order by adding ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(h)\)\^2\)]],
  " to ",
  StyleBox["lc", "InlineInputTraditionalForm"],
  ". Equate this (using ",
  Cell[BoxData[
      \(TraditionalForm\` == \)]],
  ") with ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(x)\)]],
  ". Use ",
  Cell[BoxData[
      FormBox[
        StyleBox["LogicalExpand",
          "Input"], TraditionalForm]]],
  " on this equation (this step is not necessary but is used to show that you \
obtain 3 equations, one for each order of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  "). Use ",
  StyleBox["Solve", "InlineInputTraditionalForm"],
  " to find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " and thus determine the best numerical expression for computing ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(x)\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + h)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - h)\)]],
  ". Substitute your values back into ",
  Cell[BoxData[
      FormBox[
        StyleBox["lc",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "EndQuestion"],

Cell[TextData[{
  "You should have found the best \[OpenCurlyDoubleQuote]two-point\
\[CloseCurlyDoubleQuote] approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(x)\)]],
  " which is ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h) - \ f(x - h)\)\/\(2\ h\)\)]],
  ". Because ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] 0\)]],
  " this expression does not depend upon ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`sin(x)\)]],
  " compute and compare: ",
  Cell[BoxData[
      \(TraditionalForm\`\(sin\^\[Prime]\)(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((sin(x + h) - sin(x))\)/h\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x + h) - \ f(x - h)\)\/\(2\ h\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 0.2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h \[Rule] 0.1\)]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Suitably modify the steps of question ",
  
  CounterBox["Exercise", "arbitrary linear combination"],
  " to obtain the best expression for computing ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(x)\)]],
  " numerically in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + 2  h)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + h)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - h)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - 2  h)\)]],
  ".  Also determine the error term."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Suitably modify the steps of question ",
  
  CounterBox["Exercise", "arbitrary linear combination"],
  " to obtain the best expression for computing ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[DoublePrime]\)(x)\)]],
  " numerically in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + h)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - h)\)]],
  ". Also determine the error term."
}], "BeginEndQuestion",
  CellTags->"second derivative"],

Cell[TextData[{
  "Compute a table of values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^3\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " ranging from 0 to 3 in steps of 0.1. Use the result of question ",
  
  CounterBox["Exercise", "second derivative"],
  " to compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[DoublePrime]\)(x)\)]],
  " numerically. You may find the (list) operations ",
  StyleBox["RotateLeft", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["RotateRight", "InlineInputTraditionalForm"],
  " useful. Compare your result with a table of exactly computed second \
derivatives. Explain why the results agree ",
  StyleBox["exactly",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", there is no error term). Why you do you need to discard the values at \
each end of the resulting list?"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Euler's method"
}], "Subsection"],

Cell[TextData[{
  "Consider the completely general first-order differential equation, ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime] = f(x, y)\)]],
  ". If you know ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " at some initial point, say ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_0) = y\_0\)]],
  ", then you can compute ",
  Cell[BoxData[
      \(TraditionalForm\`f(x\_0, y\_0)\)]],
  " and the value of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\_0 + h) = y\_1\)]],
  " can be obtained approximately from Taylor's theorem, ",
  StyleBox["i.e",
    FontSlant->"Italic"],
  ".,  ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1 = y\_1 + h\ \(f(x\_0, y\_0)\)\)]],
  ".  In general, ",
  Cell[BoxData[
      \(TraditionalForm\`y\_n = 
        y\_\(n - 1\) + h\ \(f(x\_\(n - 1\), y\_\(n - 1\))\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n = n\ h\)]],
  ". This method is known as ",
  StyleBox["Euler's method",
    FontSlant->"Italic"],
  ".",
  " The error in each step is of ",
  Cell[BoxData[
      \(TraditionalForm\`\(O(h)\)\^2\)]],
  "."
}], "Text"],

Cell["Define Euler's method by entering", "BeginQuestion",
  CellTags->"Euler's method"],

Cell[BoxData[
    \(TraditionalForm\`\(x /: x\_n_ = n\ h;\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`y /: 
      y\_\(n_ /; n > 0\) := \(y /: y\_n = 
        y\_\(n - 1\) + h\ \(f(x\_n, y\_\(n - 1\))\)\)\)], "Input"],

Cell[TextData[{
  "We use dynamic programming (see \[Section]",
  ButtonBox["2.4.9",
    ButtonData:>{"2.4.9", "9.2"},
    ButtonStyle->"MainBookLink"],
  ") to remember intermediate values."
}], "EndQuestion"],

Cell[TextData[{
  "Consider the differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime] = \(f(x, y) = x\ y\^2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Enter the differential equation as ",
  Cell[BoxData[
      \(TraditionalForm\`f(x_, y_) = x\ y\^2\)]],
  ". In what follows fix the step size to be ",
  Cell[BoxData[
      \(TraditionalForm\`h = 0.05\)]],
  " and choose the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0 = 1\)]],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_n, y\_n}\)]],
  " pairs for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ranging from 1 to 30 using ",
  Cell[BoxData[
      \(TraditionalForm\`Table\)]],
  ". Use ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " with ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PlotJoined \[Rule] True\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to visualize the result and call this ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "BeginEndQuestion",
  CellTags->"tabular solution"],

Cell[TextData[{
  "Use ",
  StyleBox["DSolve", "InlineInputTraditionalForm"],
  " to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^\[Prime]\)(x) \[Equal] x\ \(y(x)\)\^2\)]],
  " ",
  StyleBox["exactly",
    FontSlant->"Italic"],
  " for the initial condition ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(y(0) == 1\),
          "Input"], TraditionalForm]]],
  ". Get the result as a concrete expression (not a replacement rule) using \
",
  Cell[BoxData[
      FormBox[
        StyleBox[\(y(x) /. First[%]\),
          "Input"], TraditionalForm]]],
  ". Use ",
  StyleBox["Plot", "InlineInputTraditionalForm"],
  " to visualize the solution over the range 0 to 1.4 and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_2\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  Cell[BoxData[Cell[TextData[StyleBox["", "Input"]]]]],
  ". Display ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_2\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " together using ",
  StyleBox["Show", "InlineInputTraditionalForm"],
  ". What can you say about the two curves?"
}], "BeginEndQuestion",
  CellTags->"DSolve"],

Cell["", "Answer"],

Cell[TextData[{
  "Conclude this section by clearing the values assigned to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", Cell[""]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  "."
}], "Text",
  CellTags->"DSolve"],

Cell[BoxData[
    \(TraditionalForm\`Clear[h, x, y]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Taylor series expansion"
}], "Subsection"],

Cell[TextData[{
  "Euler's method only uses the ",
  StyleBox["first order",
    FontSlant->"Italic"],
  " term of the Taylor series.  The expansion to next order is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalT] = 
      Normal[y(h + x) + \(O(h)\)\^3]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(1\/2\), " ", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "x", ")"}], " ", \(h\^2\)}], "+",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "(", "x", ")"}], " ", "h"}], 
        "+", \(y(x)\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "From the differential equation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "(", "x", ")"}], 
          "=", \(f(x, y(x))\)}], TraditionalForm]]],
  ", we can also obtain ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " expressions for higher derivatives, ",
  StyleBox["e.g., ",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[DoublePrime]",
              MultilineFunction->None], "(", "x", ")"}], "=", 
          FractionBox[\(\[PartialD]\(f(x, y(x))\)\), \(\[PartialD]x\),
            MultilineFunction->None]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "(", "x", ")"}], "=", 
          FractionBox[\(\[PartialD]\^2\( f(x, y(x))\)\), \(\[PartialD]x\^2\),
            MultilineFunction->None]}], TraditionalForm]]],
  ", ",
  StyleBox["etc.",
    FontSlant->"Italic"],
  ", and so, for specific ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", we can express \[ScriptCapitalT] in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Use exact expressions for the derivatives of the differential equation ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime] = \(f(x, y) = x\ y\^2\)\)]],
  " to express \[ScriptCapitalT] in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "To solve the equation numerically, use the replacements ",
  Cell[BoxData[
      \(TraditionalForm\`y(x) \[Rule] y\_\(n - 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] x\_\(n - 1\)\)]],
  ", and suitably modify the definitions of question ",
  
  CounterBox["Exercise", "Euler's method"],
  ", to extend Euler's method to second order. Again fix the step size to be \
",
  Cell[BoxData[
      \(TraditionalForm\`h = 0.05\)]],
  " and choose the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0 = 1\)]],
  ". As in question ",
  
  CounterBox["Exercise", "tabular solution"],
  ", compute ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_n, y\_n}\)]],
  " pairs for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ranging from 1 to 30, visualize the result, and call it ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_3\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Display ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_2\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\_3\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " together using ",
  StyleBox["Show", "InlineInputTraditionalForm"],
  ". What can you say about the three curves?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell["\<\
The method of this section is an example of a numeric-symbolic \
hybrid. We used exact symbolic differentiation applied to the right hand side \
of our differential equation so that we could substitute this into the Taylor \
series of the solution to obtain a numerical method whose error depended on \
the order of the Taylor series expansion. Note that we could easily extend \
the method to higher orders.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Use of Caption style by itself should be discouraged. See cell \
styles for NumberedFigureCaption, NumberedTableCaption, \
NumberedProgramCaption and the palette TMJAuthorPalette.nb.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {Inherited, 5}},
    PageBreakAbove->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Caption", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Caption", "Printout"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {10, 10}},
    FontSize->8],
  
  Cell[StyleData["Caption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{20, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    ZeroWidthTimes->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Exercise"], ". "}]], None}, {None, None}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{72, 35}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Exercise"], ". "}]], None}, {None, None}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellMargins->{{54, 35}, {Inherited, Inherited}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Exercise"], ".   Answer:"}]], None}, {None, None}},
    
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[RawData["\<\
Cell[StyleData[\"NumberedEquation\", \"Presentation\"],
  FontSize->14]\
\>"],
    FontSize->14],
  
  Cell[RawData["\<\
Cell[StyleData[\"NumberedEquation\", \"Printout\"],
  CellMargins->{{Inherited, Inherited}, {10, Inherited}},
  FontSize->10]\
\>"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[RawData["\<\
Cell[StyleData[\"NumberedEquation\", \"Production\"],
  CellMargins->{{72, 72}, {2, 4}},
  PrivateEvaluationOptions->{\"OutputFormPageWidth\"->342},
  FontFamily->\"Janson Text\",
  FontSize->10,
  FontProperties->{\"FontSerifed\"->True,
  \"FontMonospaced\"->False}]\
\>"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorialComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["EditorialComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["EditorialComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    ZeroWidthTimes->True,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`_n3ohL==`Tf0fL5N`?P0080004/0B`000000`d26P01
0000I00000400@410?l00BL?00400@j;Zk0000000000060801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Exact inverse"->{
    Cell[4971, 166, 200, 11, 54, "Subsection",
      CellTags->"Exact inverse"]},
  "Precision"->{
    Cell[10463, 394, 1086, 35, 67, "BeginEndQuestion",
      CellTags->"Precision"]},
  "difference"->{
    Cell[12176, 454, 894, 27, 70, "BeginEndQuestion",
      CellTags->"difference"]},
  "parametrically defined region"->{
    Cell[19912, 766, 222, 11, 32, "Subsection",
      CellTags->"parametrically defined region"]},
  "numerical derivatives"->{
    Cell[24371, 947, 196, 11, 54, "Subsection",
      CellTags->"numerical derivatives"]},
  "arbitrary linear combination"->{
    Cell[66676, 2088, 127, 2, 35, "BeginQuestion",
      CellTags->"arbitrary linear combination"]},
  "second derivative"->{
    Cell[70205, 2219, 547, 18, 62, "BeginEndQuestion",
      CellTags->"second derivative"]},
  "Euler's method"->{
    Cell[72982, 2323, 88, 1, 35, "BeginQuestion",
      CellTags->"Euler's method"]},
  "tabular solution"->{
    Cell[73676, 2349, 988, 33, 67, "BeginEndQuestion",
      CellTags->"tabular solution"]},
  "DSolve"->{
    Cell[74667, 2384, 1298, 42, 70, "BeginEndQuestion",
      CellTags->"DSolve"],
    Cell[75989, 2430, 318, 13, 24, "Text",
      CellTags->"DSolve"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Exact inverse", 147340, 4990},
  {"Precision", 147439, 4993},
  {"difference", 147543, 4996},
  {"parametrically defined region", 147666, 4999},
  {"numerical derivatives", 147794, 5002},
  {"arbitrary linear combination", 147921, 5005},
  {"second derivative", 148047, 5008},
  {"Euler's method", 148163, 5011},
  {"tabular solution", 148273, 5014},
  {"DSolve", 148380, 5017}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 154, 5, 74, "Title",
  CounterAssignments->{{"Title", 2}}],
Cell[1944, 60, 29, 0, 26, "Author"],
Cell[1976, 62, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2415, 78, 39, 0, 42, "Subsubsection"],
Cell[2457, 80, 215, 5, 26, "Text"],
Cell[2675, 87, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2790, 91, 87, 3, 24, "Text"],
Cell[2880, 96, 117, 2, 24, "Input",
  InitializationCell->True],
Cell[3000, 100, 108, 3, 24, "Text"],
Cell[3111, 105, 285, 5, 50, "Input",
  InitializationCell->True],
Cell[3399, 112, 701, 13, 109, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4137, 130, 131, 7, 41, "SectionFirst"],
Cell[4271, 139, 675, 23, 42, "Text"],

Cell[CellGroupData[{
Cell[4971, 166, 200, 11, 54, "Subsection",
  CellTags->"Exact inverse"],
Cell[5174, 179, 400, 11, 42, "Text"],
Cell[5577, 192, 129, 4, 39, "BeginQuestion"],
Cell[5709, 198, 112, 2, 42, "Input"],
Cell[5824, 202, 352, 14, 39, "EndQuestion"],
Cell[6179, 218, 249, 7, 49, "BeginEndQuestion"],
Cell[6431, 227, 18, 0, 24, "Answer"],
Cell[6452, 229, 373, 12, 49, "BeginEndQuestion"],
Cell[6828, 243, 251, 7, 49, "BeginEndQuestion"],
Cell[7082, 252, 18, 0, 24, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[7137, 257, 149, 10, 32, "Subsection"],
Cell[7289, 269, 324, 9, 50, "BeginEndQuestion"],
Cell[7616, 280, 34, 3, 40, "Answer"],
Cell[7653, 285, 109, 3, 48, "BeginEndQuestion"],
Cell[7765, 290, 18, 0, 24, "Answer"],
Cell[7786, 292, 425, 12, 52, "BeginEndQuestion"],
Cell[8214, 306, 127, 3, 24, "Text"],
Cell[8344, 311, 515, 18, 27, "Warning"],
Cell[8862, 331, 357, 9, 36, "BeginQuestion"],
Cell[9222, 342, 194, 4, 24, "Input"],
Cell[9419, 348, 143, 3, 39, "EndQuestion"],
Cell[9565, 353, 439, 11, 22, "BrightIdea"]
}, Closed]],

Cell[CellGroupData[{
Cell[10041, 369, 175, 10, 32, "Subsection"],
Cell[10219, 381, 241, 11, 24, "Text"],
Cell[10463, 394, 1086, 35, 67, "BeginEndQuestion",
  CellTags->"Precision"],
Cell[11552, 431, 18, 0, 24, "Answer"],
Cell[11573, 433, 579, 17, 49, "BeginEndQuestion"],
Cell[12155, 452, 18, 0, 24, "Answer"],
Cell[12176, 454, 894, 27, 70, "BeginEndQuestion",
  CellTags->"difference"],
Cell[13073, 483, 18, 0, 24, "Answer"],
Cell[13094, 485, 417, 14, 49, "BeginEndQuestion"],
Cell[13514, 501, 18, 0, 24, "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13581, 507, 110, 7, 39, "Section"],

Cell[CellGroupData[{
Cell[13716, 518, 175, 10, 54, "Subsection"],

Cell[CellGroupData[{
Cell[13916, 532, 41, 0, 42, "Subsubsection"],
Cell[13960, 534, 934, 27, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14931, 566, 39, 0, 42, "Subsubsection"],
Cell[14973, 568, 366, 12, 26, "Text"],
Cell[15342, 582, 646, 19, 70, "BeginEndQuestion"],
Cell[15991, 603, 933, 42, 24, "Warning"],
Cell[16927, 647, 173, 6, 39, "BeginQuestion"],
Cell[17103, 655, 80, 1, 25, "Input"],
Cell[17186, 658, 119, 4, 43, "EndQuestion"],
Cell[17308, 664, 18, 0, 24, "Answer"],
Cell[17329, 666, 309, 7, 49, "BeginEndQuestion"],
Cell[17641, 675, 204, 7, 49, "BeginEndQuestion"],
Cell[17848, 684, 57, 1, 24, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17954, 691, 151, 10, 32, "Subsection"],
Cell[18108, 703, 206, 6, 26, "Text"],
Cell[18317, 711, 628, 16, 63, "BeginEndQuestion"],
Cell[18948, 729, 18, 0, 24, "Answer"],
Cell[18969, 731, 906, 30, 67, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[19912, 766, 222, 11, 32, "Subsection",
  CellTags->"parametrically defined region"],
Cell[20137, 779, 480, 16, 27, "Text"],
Cell[20620, 797, 256, 9, 53, "BeginEndQuestion"],
Cell[20879, 808, 184, 6, 35, "BeginQuestion"],
Cell[21066, 816, 156, 3, 39, "Input"],
Cell[21225, 821, 325, 8, 40, "EndQuestion"],
Cell[21553, 831, 18, 0, 24, "Answer"],
Cell[21574, 833, 213, 6, 26, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[21824, 844, 152, 10, 32, "Subsection"],
Cell[21979, 856, 388, 14, 26, "Text"],
Cell[22370, 872, 471, 8, 53, "NumberedEquation"],
Cell[22844, 882, 163, 5, 48, "BeginEndQuestion"],
Cell[23010, 889, 18, 0, 24, "Answer"],
Cell[23031, 891, 1123, 37, 64, "BeginEndQuestion"],
Cell[24157, 930, 18, 0, 24, "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24224, 936, 122, 7, 39, "Section"],

Cell[CellGroupData[{
Cell[24371, 947, 196, 11, 54, "Subsection",
  CellTags->"numerical derivatives"],
Cell[24570, 960, 248, 6, 26, "Text"],
Cell[24821, 968, 356, 11, 54, "BeginEndQuestion"],
Cell[25180, 981, 18, 0, 24, "Answer"],
Cell[25201, 983, 533, 16, 42, "Text"],
Cell[25737, 1001, 241, 6, 54, "BeginEndQuestion"],
Cell[25981, 1009, 18, 0, 24, "Answer"],
Cell[26002, 1011, 655, 23, 28, "Text"],

Cell[CellGroupData[{
Cell[26682, 1038, 121, 2, 24, "Input"],
Cell[26806, 1042, 39349, 1021, 186, 11519, 673, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[66170, 2066, 503, 20, 26, "Text"],
Cell[66676, 2088, 127, 2, 35, "BeginQuestion",
  CellTags->"arbitrary linear combination"],
Cell[66806, 2092, 151, 2, 39, "Input"],
Cell[66960, 2096, 1589, 57, 76, "EndQuestion"],
Cell[68552, 2155, 485, 15, 28, "Text"],
Cell[69040, 2172, 517, 20, 54, "BeginEndQuestion"],
Cell[69560, 2194, 642, 23, 62, "BeginEndQuestion"],
Cell[70205, 2219, 547, 18, 62, "BeginEndQuestion",
  CellTags->"second derivative"],
Cell[70755, 2239, 904, 26, 81, "BeginEndQuestion"],
Cell[71662, 2267, 18, 0, 24, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[71717, 2272, 152, 10, 32, "Subsection"],
Cell[71872, 2284, 1107, 37, 60, "Text"],
Cell[72982, 2323, 88, 1, 35, "BeginQuestion",
  CellTags->"Euler's method"],
Cell[73073, 2326, 72, 1, 25, "Input"],
Cell[73148, 2329, 152, 3, 25, "Input"],
Cell[73303, 2334, 210, 6, 39, "EndQuestion"],
Cell[73516, 2342, 157, 5, 24, "Text"],
Cell[73676, 2349, 988, 33, 67, "BeginEndQuestion",
  CellTags->"tabular solution"],
Cell[74667, 2384, 1298, 42, 70, "BeginEndQuestion",
  CellTags->"DSolve"],
Cell[75968, 2428, 18, 0, 24, "Answer"],
Cell[75989, 2430, 318, 13, 24, "Text",
  CellTags->"DSolve"],
Cell[76310, 2445, 64, 1, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[76411, 2451, 161, 10, 32, "Subsection"],
Cell[76575, 2463, 178, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[76778, 2472, 107, 2, 25, "Input"],
Cell[76888, 2476, 437, 12, 38, "Output"]
}, Open  ]],
Cell[77340, 2491, 1428, 47, 48, "Text"],
Cell[78771, 2540, 362, 11, 49, "BeginEndQuestion"],
Cell[79136, 2553, 18, 0, 24, "Answer"],
Cell[79157, 2555, 1494, 49, 80, "BeginEndQuestion"],
Cell[80654, 2606, 18, 0, 24, "Answer"],
Cell[80675, 2608, 432, 7, 56, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

