(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    926930,      19575]*)
(*NotebookOutlinePosition[    997530,      22064]*)
(*  CellTagsIndexPosition[    996219,      22024]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Fourier Methods"
}], "Title",
  CounterAssignments->{{"Title", 3}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "A consistent set of options for ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["ListPlot3D", "InlineInputTraditionalForm"],
  " is desirable."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ListDensityPlot, Mesh \[Rule] False, 
        Frame \[Rule] False, PlotRange \[Rule] All];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ListPlot3D, Mesh \[Rule] False, 
        PlotRange \[Rule] All];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Fourier Series"
}], "SectionFirst"],

Cell[TextData[{
  "You should have already met Fourier series (see ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  ButtonBox["http://mathworld.wolfram.com/FourierSeries.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FourierSeries.html"], None},
    ButtonStyle->"Hyperlink"],
  ") on a number of occasions. Fourier series are expansions of any periodic \
function, ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", in terms of an infinite of the form"
}], "Text",
  CellTags->{"Fourier series", "orthogonality integrals"}],

Cell[BoxData[
    \(TraditionalForm\`f(x) = 
      a\_0\/2 + \ \[Sum]\+\(n = 1\)\%m\(\((a\_n\ \(cos(
                    n\ x)\) + \(b\_n\) \(sin(
                    n\ x)\))\)\(.\)\)\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Orthogonality"
}], "Subsection"],

Cell["\<\
In this section the the basic orthogonality integrals will be \
examined.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%\(2  \[Pi]\)\(sin(n\ x)\)\ \(sin(
          m\ x)\) \[DifferentialD]x\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["In this section you will prove that", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%\(2  \[Pi]\)\(sin(n\ x)\)\ \(sin(
            m\ x)\) \[DifferentialD]x = \[Pi]\ \[Delta]\_\(n, m\)\)], \
"NumberedEquation"]
}, Closed]],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2  \[Pi]\)\(sin(n\ x)\)\ \(sin(
            m\ x)\) \[DifferentialD]x\)]],
  ". Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does ",
  StyleBox["not",
    FontWeight->"Bold"],
  " assume that ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " are integers.   "
}], "BeginEndQuestion"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] m\)]],
  ": Use ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " with appropriate conditions to show that this integral vanishes."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  ": In this case take the ",
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(n \[Rule] m\)\)]],
  " (you may have to look up ",
  StyleBox["Limit", "InlineInputTraditionalForm"],
  ") and ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " the result."
}], "BeginEndQuestion"],

Cell["You should now have the desired result.", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_0\%\(2  \[Pi]\)\(sin(n\ x)\)\ \(cos(m\ x)\) 
        \[DifferentialD]x\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Prove that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2  \[Pi]\)\(sin(n\ x)\)\ \(cos(
              m\ x)\) \[DifferentialD]x = 0\)]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_0\%\(2  \[Pi]\)\(cos(n\ x)\)\ \(cos(m\ x)\) 
        \[DifferentialD]x\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\(2  \[Pi]\)\(cos(n\ x)\)\ \(cos(
            m\ x)\) \[DifferentialD]x\)]],
  " for general ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/L\) \(\[Integral]\_\(-L\)\%L\( 
            cos(\(m\ \[Pi]\ x\)\/L)\)\ \(cos(\(n\ \[Pi]\ x\)\/L)\) \
\[DifferentialD]x\)\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/L\) \(\[Integral]\_\(-L\)\%L\( 
              cos(\(m\ \[Pi]\ x\)\/L)\)\ \(cos(\(n\ \[Pi]\ x\)\/L)\) \
\[DifferentialD]x\)\)]],
  " for general ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Square wave"
}], "Subsection"],

Cell["\<\
The Fourier series of a function assumes that the function is \
periodic outside its specified domain. Consider the function defined by\
\>", \
"Text",
  CellTags->"periodic"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(x)\), "=", 
        RowBox[{
          StyleBox["{",
            SpanMaxSize->Infinity], 
          RowBox[{GridBox[{
                {\(1, \ 0 \[LessEqual] x \[LessEqual] \[Pi]\)},
                {\(\(-1\), \[Pi] \[LessEqual] x \[LessEqual] 2  \[Pi]\)}
                }], ","}], "\[AutoRightMatch]"}]}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"square wave"],

Cell[TextData[{
  "with the additional (",
  StyleBox["periodicity",
    FontSlant->"Italic"],
  ") condition"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(f(x)\), "=", 
          RowBox[{"f", "(", 
            InterpretationBox[\(x\ mod\ \((2\ \[Pi])\)\),
              Mod[ x, 
                Times[ 2, Pi]]], ")"}]}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"periodicity condition"],

Cell[TextData[{
  "which causes the function to repeat itself outside the domain ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 2  \[Pi]]\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Complete the following", "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`f(
        x_ /; \ 0 \[LessEqual] x \[LessEqual] \[Pi]) :=  ... \)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`f(x_ /; \  ... ) :=  ... \)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(f(x_)\), ":=", 
        RowBox[{"f", "(", 
          InterpretationBox[\(Mod[\(...\)\(,\)\(\ \)\(...\)]\),
            Mod[ x, 
              Times[ 2, Pi]]], ")"}]}], TraditionalForm]], "Input"]
}, Open  ]],

Cell[TextData[{
  "to define the square wave of equations (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "square wave"],
  ") and (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "periodicity condition"],
  ") above. "
}], "EndQuestion"],

Cell["\<\
To verify your definition visualize the function.  \
\>", \
"BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Fourier coefficients"
}], "Subsection",
  CellTags->"Fourier coefficients"],

Cell["\<\
From the orthogonality integrals computed above it can be shown \
that the Fourier coefficients are:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`a\_0 = \(1\/\[Pi]\) \(\[Integral]\_0\%\(2  \[Pi]\)\(f(
              x)\)\ \[DifferentialD]x\), \[IndentingNewLine]a\_n = \(1\/\[Pi]\
\) \(\[Integral]\_0\%\(2  \[Pi]\)\(f(x)\)\ \(cos(
              n\ x)\) \[DifferentialD]x\), \ \ n \[GreaterEqual] 1, \n
    b\_n = \(1\/\[Pi]\) \(\[Integral]\_0\%\(2  \[Pi]\)\(f(x)\)\ \(sin(
              n\ x)\) \[DifferentialD]x\), \ \ n \[GreaterEqual] 
      1. \)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  "For the square wave ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x)\), "=", 
          RowBox[{
            StyleBox["{",
              SpanMaxSize->Infinity], GridBox[{
                {\(1, \ 0 \[LessEqual] x \[LessEqual] \[Pi]\)},
                {\(\(-1\), \[Pi] \[LessEqual] x \[LessEqual] 2  \[Pi]\)}
                }], "\[AutoRightMatch]"}]}], TraditionalForm]]],
  ", compute ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  " by splitting the integration into two parts and compute the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " integral for each domain. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": the first integral to be computed is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi] 1 \[DifferentialD]x\)]],
  "). Save the result as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_0 = \[CenterEllipsis]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Is your answer reasonable? (What value do you expect for the ",
  StyleBox["DC-term",
    FontSlant->"Italic"],
  " or average of a square wave)?"
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Similarly compute ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and simplify your result using the methods of the orthogonality section \
above and save the result as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_n_ = \[CenterEllipsis]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Why is your answer expected?"
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Open  ]],

Cell[TextData[{
  "Compute and simplify ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  ". Save the result as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(b\_n_ = \[CenterEllipsis]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Partial sum of the Fourier series to ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " terms"
}], "Subsection",
  CellTags->"partial sum"],

Cell[TextData[{
  StyleBox["Using ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " computed in \[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "Fourier coefficients"],
  " ",
  StyleBox["the sum to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  StyleBox[" terms found in the previous section can be written as ",
    FontSlant->"Plain"]
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`FourierSeries[m_] := 
      a\_0\/2 + \ \[Sum]\+\(n = 1\)\%m\((a\_n\ \(cos(n\ x)\) + \(b\_n\) \(sin(
                  n\ x)\))\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "Produce a ",
  StyleBox["Table", "InlineInputTraditionalForm"],
  " of ",
  StyleBox["Plot", "InlineInputTraditionalForm"],
  "s of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(FourierSeries[m]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to see the partial sums for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2, \[Ellipsis], 10\)]],
  ". Set ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PlotRange \[Rule] {\(-1.5\), 1.5}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " in each of the plots. Select all the graphical output of the previous \
section and use ",
  StyleBox["Animate Selected Graphics", "Menu"],
  " (under the ",
  StyleBox["Cell", "Menu"],
  " menu) on your result to visualize the partial sums. "
}], "BeginEndQuestion"],

Cell[TextData[{
  "It is a good idea to wrap ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(FourierSeries[m]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " with ",
  StyleBox["Evaluate", "InlineInputTraditionalForm"],
  " so that the sum is not re-computed for each value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Warning"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Lanczos \[Sigma]-factors"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Gibbs phenomenon",
    FontSlant->"Italic"],
  " (see ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  " ",
  ButtonBox["http://mathworld.wolfram.com/GibbsPhenomenon.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/GibbsPhenomenon.html"], None},
    ButtonStyle->"Hyperlink"],
  ") is the overshoot that occurs at each discontinuity in Fourier Series \
\[LongDash] you should be able to see this in the graphics of \[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "partial sum"],
  ".  Note also that, in general, Fourier series are slowly convergent. The \
",
  StyleBox["Lanczsos ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  "-",
  StyleBox["factor",
    FontSlant->"Italic"],
  " (see ",
  ButtonBox["Lanczsos 1956",
    ButtonData:>"Lanczsos (1956)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Hamming 1973",
    ButtonData:>"Hamming (1973)",
    ButtonStyle->"Hyperlink"],
  "),"
}], "Text",
  CellTags->{"Lanczos \[Sigma] factors", "Gibbs phenomenon"}],

Cell[BoxData[
    \(TraditionalForm\`\(\[Sigma]\_\(m_, n_\) = \(sin(\(n\ \
\[Pi]\)\/m)\)\/\(\(n\ \[Pi]\)\/m\);\)\)], "Input"],

Cell[TextData[{
  "improves the convergence of Fourier series. Including ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(m, n\)\)]],
  ", the modified partial sum ",
  StyleBox["to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  StyleBox[" terms",
    FontSlant->"Plain"],
  " is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Sigma]Series[m_] := 
      a\_0\/2 + \ \[Sum]\+\(n = 1\)\%m \[Sigma]\_\(m, n\)\ \((a\_n\ \(cos(
                    n\ x)\) + \(b\_n\) \(sin(n\ x)\))\)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(FourierSeries[10]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Sigma]Series[10]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and compare the output. Select both your graphics and animate them. You \
should do each ",
  StyleBox["Plot", "InlineInputTraditionalForm"],
  " over an identical (vertical and horizontal) ",
  StyleBox["PlotRange", "InlineInputTraditionalForm"],
  " to facilitate the comparison. Describe the differences between the two \
graphs."
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Can you explain why ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(m, n\)\)]],
  " improves the behaviour of the partial sums? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(m, n\)\)]],
  " themselves are the Fourier transform of a simple function. What is it?  \
Try relating the inclusion of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_\(m, n\)\)]],
  " in the partial sums to a ",
  StyleBox["convolution",
    FontSlant->"Italic"],
  ")"
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell[TextData[{
  "R W Hamming ",
  StyleBox["Numerical Methods for Scientists and Engineers",
    FontSlant->"Italic"],
  ", 2nd ed., McGraw-Hill, New York, 1973."
}], "Text",
  CellTags->"Hamming (1973)"],

Cell[TextData[{
  "C Lanczsos, ",
  StyleBox["Applied Analysis",
    FontSlant->"Italic"],
  ", Prentice-Hall, Chapter 4, 1956."
}], "Text",
  CellTags->"Lanczsos (1956)"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Triangular wave"
}], "Subsection"],

Cell[TextData[{
  "Repeat the analysis of \[Section]\[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "Fourier coefficients"],
  "-",
  
  CounterBox["Subsection", "Lanczos \[Sigma] factors"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(x) = x\)\(\[AutoRightMatch]\)\)\)], 
    "NumberedEquation",
    CellTags->"square wave"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([\(-\[Pi]\), \[Pi]]\)\)]],
  "."
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " DFT and FFT"
}], "Section"],

Cell["\<\
In this section you will be introduced to the basics of the \
discrete Fourier transform (DFT) and fast Fourier transform (FFT). \
\>", \
"Text",
  CellTags->{"FFT", "DFT", "DCT", "JPEG"}],

Cell[TextData[{
  "Use of the FFT is important in practice because experimentally you can \
only measure a quantity finitely often at a discrete set of times. Hence you \
always have a ",
  StyleBox["discrete dataset",
    FontSlant->"Italic"],
  " which you can analyse using the FFT. It is important to understand the \
relationship between the results returned by the FFT and the amplitudes and \
frequencies present in the data you are analysing."
}], "Warning",
  CellTags->"discrete dataset"],

Cell[TextData[{
  "As an aside, there are a number of other transform functions relevant \
including the discrete cosine transform (DCT), used in JPEG image \
compression, the Hartley transform, and the discrete wavelet transform (DWT). \
Wavelets are finitely restricted waves (wave-packets) which permit orthogonal \
expansion of functions which are both spatially and temporally restricted. \
Recently, wavelets have been adopted by the FBI as their image compression \
standard for ",
  ButtonBox["fingerprints",
    ButtonData:>{
      URL[ "http://www.c3.lanl.gov/~brislawn/FBI/FBI.html"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->{
  "Hartley transform", "DWT", "discrete wavelet transform", "fingerprints"}],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " DFT and FFT"
}], "Subsection"],

Cell[TextData[{
  "Read the discussion on ",
  ButtonBox["fast transform algorithms",
    ButtonData:>"5.0.6",
    ButtonStyle->"AddOnsLink"],
  " to see why the FFT is faster than the DFT. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " One-dimensional Example"
}], "Subsection",
  CellTags->"1D FFT"],

Cell["Analysis of a Periodic Signal", "Subsubsection"],

Cell[TextData[{
  "Evaluate the linear superposition of 3 harmomic waves, ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\(\[Pi]\ t\)\/128)\)],
    AspectRatioFixed->True],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\(3\ \[Pi]\ t\)\/128)\)],
    AspectRatioFixed->True],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\(5\ \[Pi]\ t\)\/128)\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1, 2, \[Ellipsis], 256\)]],
  " and call the result ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Visualise ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  ". Join up the data values using the ",
  StyleBox["PlotJoined", "InlineInputTraditionalForm"],
  " option and use ",
  StyleBox["PlotStyle", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["RGBColor", "InlineInputTraditionalForm"],
  " to show signal in red. Call your plot ",
  StyleBox["\[ScriptCapitalS]", "InlineInputTraditionalForm"],
  "."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute the DFT (using ",
  StyleBox["Fourier", "InlineInputTraditionalForm"],
  ") of ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  " and call the result ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  ". Display ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  "s of the real (",
  StyleBox["Re", "InlineInputTraditionalForm"],
  ") and imaginary (",
  StyleBox["Im", "InlineInputTraditionalForm"],
  ") values of ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  " over a suitably chosen ",
  StyleBox["PlotRange", "InlineInputTraditionalForm"],
  ". (Hint: it might be useful to divide ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  " by ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\@Length[\[ScriptF]]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ").  Interpret this (graphical) result in light of the data. What do the \
largest values in each graph correspond to?  Where is the \
\[OpenCurlyDoubleQuote]DC-term\[CloseCurlyDoubleQuote] (i.e., the average) \
located and what is its value? "
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the Fourier transform, displayed as of the function of (angular) \
frequency, is \[OpenCurlyDoubleQuote]wrapped\[CloseCurlyDoubleQuote], ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the low frequency terms appear at ",
  StyleBox["both",
    FontSlant->"Italic"],
  " ends of the plot. The high frequency terms are in the ",
  StyleBox["middle",
    FontSlant->"Italic"],
  " of these plots. Think of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ n\ \
t\)\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " goes from 0 to 1 as indicated in the following figure. The \
\[OpenCurlyDoubleQuote]DC-term\[CloseCurlyDoubleQuote] is indicated by the \
red line."
}], "Warning"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.4329 0.5 0.4329 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 1 0 r
.5 Mabswid
[ ] 0 setdash
newpath
.5 .5 .4329 0 365.73 arc
s
.2 0 1 r
.5 .5 m
.97619 .5 L
s
.5 .5 m
.96704 .5929 L
s
.5 .5 m
.93994 .68223 L
s
.5 .5 m
.89594 .76456 L
s
.5 .5 m
.83672 .83672 L
s
.5 .5 m
.76456 .89594 L
s
.5 .5 m
.68223 .93994 L
s
.5 .5 m
.5929 .96704 L
s
.5 .5 m
.5 .97619 L
s
.5 .5 m
.4071 .96704 L
s
.5 .5 m
.31777 .93994 L
s
.5 .5 m
.23544 .89594 L
s
.5 .5 m
.16328 .83672 L
s
.5 .5 m
.10406 .76456 L
s
.5 .5 m
.06006 .68223 L
s
.5 .5 m
.03296 .5929 L
s
.5 .5 m
.02381 .5 L
s
.5 .5 m
.03296 .4071 L
s
.5 .5 m
.06006 .31777 L
s
.5 .5 m
.10406 .23544 L
s
.5 .5 m
.16328 .16328 L
s
.5 .5 m
.23544 .10406 L
s
.5 .5 m
.31777 .06006 L
s
.5 .5 m
.4071 .03296 L
s
.5 .5 m
.5 .02381 L
s
.5 .5 m
.5929 .03296 L
s
.5 .5 m
.68223 .06006 L
s
.5 .5 m
.76456 .10406 L
s
.5 .5 m
.83672 .16328 L
s
.5 .5 m
.89594 .23544 L
s
.5 .5 m
.93994 .31777 L
s
.5 .5 m
.96704 .4071 L
s
.5 .5 m
.97619 .5 L
s
1 0 0 r
.005 w
.5 .5 m
.97619 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00S`3oool00`0c0?l0oooo0?ooo`2>0?ooo`00S`3oool00`0c0?l0oooo
0?ooo`2>0?ooo`00S`3oool00`0c0?l0oooo0?ooo`2>0?ooo`00M03oool00`0c0?l0oooo0?ooo`0H
0?ooo`0303<0o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool0L`3oool007@0oooo00<0<`3o0?oo
o`3oool0603oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo07<0oooo001d0?ooo`03
03<0o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`1c0?ooo`00
M@3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool0
M03oool007D0oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3o
ool0oooo07@0oooo001e0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool05`3oool0
0`0c0?l0oooo0?ooo`1d0?ooo`00M@3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo
01L0oooo00<0<`3o0?ooo`3oool0M03oool007D0oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0
oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo07@0oooo001K0?ooo`0303<0o`3oool0oooo01P0oooo
00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo01P0oooo
00<0<`3o0?ooo`3oool0FP3oool005/0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?oo
o`0F0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?oo
o`1J0?ooo`00G03oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo00T0oooo3@0co`00
0`0c0?l0<ol003?o000;03?o00/0oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`1K
0?ooo`00G03oool00`0c0?l0oooo0?ooo`0G0?ooo`0403<0o`3oool0oooo0?ooo`P0<ol03@3oool0
0`0c0?l0oooo0?ooo`0;0?ooo`P0<ol00`3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0
oooo05/0oooo001L0?ooo`0303<0o`3oool0oooo01H0oooo00<0<ol003<0o`0co`000P0co`0E0?oo
o`0303<0o`3oool0oooo01<0oooo0`0co`000`0c0?l0<ol003?o000G0?ooo`0303<0o`3oool0oooo
05/0oooo001M0?ooo`0303<0o`3oool0oooo0140oooo100co`020?ooo`0303<0o`3oool0oooo01D0
oooo00<0<`3o0?ooo`3oool05@3oool0100c0?l0oooo0?ooo`3oool303?o01<0oooo00<0<`3o0?oo
o`3oool0G03oool005d0oooo00<0<`3o0?ooo`3oool0303oool503?o00H0oooo00<0<`3o0?ooo`3o
ool05@3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00@0oooo1P0co`0=0?ooo`03
03<0o`3oool0oooo05`0oooo001N0?ooo`0303<0o`3oool0oooo00P0oooo0`0co`0;0?ooo`0303<0
o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0:0?ooo`<0<ol0
2@3oool00`0c0?l0oooo0?ooo`1M0?ooo`00GP3oool00`0c0?l0oooo0?ooo`050?ooo`<0<ol03P3o
ool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool03@3o
ool303?o00H0oooo00<0<`3o0?ooo`3oool0G@3oool005l0oooo00<0<`3o0?ooo`3oool00P3oool2
03?o0140oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0
oooo0100oooo0P0co`030?ooo`0303<0o`3oool0oooo05h0oooo001O0?ooo`0303<0o`3oool0<ol0
0080<ol0503oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?oo
o`3oool04`3oool203?o00030?ooo`0c0?l0oooo05l0oooo001O0?ooo`0303<0o`0co`00oooo01H0
oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01D0
oooo00<0<ol003<0o`3oool0G`3oool004<0oooo00<0<`3o0?ooo`3oool0603oool203?o000303<0
o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0
o`3oool0oooo01D0oooo00@0<`3o03?o000co`00<ol06@3oool00`0c0?l0oooo0?ooo`120?ooo`00
@`3oool00`0c0?l0oooo0?ooo`0E0?ooo`<0<ol00P3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0
o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0E0?ooo`0403<0
o`3oool0oooo0?ooo`<0<ol05P3oool00`0c0?l0oooo0?ooo`120?ooo`00A03oool00`0c0?l0oooo
0?ooo`0A0?ooo`<0<ol01P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01@0oooo
00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo00D0oooo
0`0co`0B0?ooo`0303<0o`3oool0oooo04<0oooo00150?ooo`0303<0o`3oool0oooo00h0oooo0P0c
o`090?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?oo
o`0C0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool0203oool00`0co`00oooo0?oo
o`0>0?ooo`0303<0o`3oool0oooo04@0oooo00150?ooo`0303<0o`3oool0oooo00d0oooo00<0<ol0
0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o
0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00T0oooo00<0<ol0
0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`140?ooo`00AP3oool00`0c0?l0oooo0?ooo`0:0?oo
o`80<ol03@3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?oo
o`3oool04`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo00/0oooo0`0co`0;0?oo
o`0303<0o`3oool0oooo04D0oooo00170?ooo`0303<0o`3oool0oooo00H0oooo0`0co`0?0?ooo`03
03<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0C0?ooo`03
03<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool03P3oool203?o00P0oooo00<0<`3o0?ooo`3o
ool0AP3oool004L0oooo00<0<`3o0?ooo`3oool01@3oool00`0co`00oooo0?ooo`0A0?ooo`0303<0
o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool04@3oool00`0co`00oooo0?ooo`050?ooo`0303<0
o`3oool0oooo04H0oooo00180?ooo`0303<0o`3oool0oooo00<0oooo00<0<ol00?ooo`3oool04P3o
ool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04P3o
ool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0180oooo00<0<ol00?ooo`3oool00`3o
ool00`0c0?l0oooo0?ooo`170?ooo`00B@3oool01@0c0?l0oooo0?ooo`3oool0<ol001D0oooo00<0
<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo0180oooo00<0
<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0C0?ooo`0503?o003oool0oooo0?ooo`0c0?l0
BP3oool004T0oooo00@0<`3o0?ooo`0co`00<ol05`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo01D0oooo0`0co`000`0c0?l0oooo0?ooo`180?ooo`00B03oool203?o000303<0o`3o
ool0oooo01L0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3o
ool0oooo0180oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`0c
o`00<ol004T0oooo00170?ooo`0503?o003oool0oooo0?ooo`0c0?l06@3oool00`0c0?l0oooo0?oo
o`0B0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?oo
o`0B0?ooo`0303<0o`3oool0oooo01L0oooo00D0<`3o0?ooo`3oool0oooo03?o00180?ooo`00AP3o
ool00`0co`00oooo0?ooo`020?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool04`3o
ool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool04`3o
ool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo0080oooo00<0<ol00?ooo`3oool0A@3o
ool004D0oooo00<0<ol00?ooo`3oool0103oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0
oooo0180oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0
oooo0180oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`040?ooo`0303?o003oool0
oooo04@0oooo00140?ooo`0303?o003oool0oooo00H0oooo00<0<`3o0?ooo`3oool05P3oool00`0c
0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool04@3oool00`0c
0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool01P3oool00`0c
o`00oooo0?ooo`130?ooo`00@`3oool00`0co`00oooo0?ooo`070?ooo`0303<0o`3oool0oooo01H0
oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0140
oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo00L0
oooo00<0<ol00?ooo`3oool0@P3oool002h0oooo00<0<`3o0?ooo`3oool0403oool203?o00/0oooo
00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0140oooo
00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01H0oooo
00<0<`3o0?ooo`3oool02@3oool203?o0180oooo00<0<`3o0?ooo`3oool0;@3oool002l0oooo00<0
<`3o0?ooo`3oool03P3oool00`0co`00oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo01D0oooo00<0
<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo0100oooo00<0
<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00`0oooo00<0
<ol00?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0^0?ooo`00<03oool00`0c0?l0oooo0?ooo`0<
0?ooo`0303?o003oool0oooo00d0oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0A
0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0A
0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool03@3oool00`0co`00oooo0?ooo`0<
0?ooo`0303<0o`3oool0oooo02l0oooo000a0?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol00?oo
o`3oool03`3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?oo
o`3oool0403oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?oo
o`3oool05@3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303?o003oool0oooo00X0oooo00<0<`3o0?oo
o`3oool0<03oool00380oooo00<0<`3o0?ooo`3oool0203oool00`0co`00oooo0?ooo`0A0?ooo`03
03<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0@0?ooo`03
03<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0D0?ooo`03
03<0o`3oool0oooo0140oooo0P0co`090?ooo`0303<0o`3oool0oooo0340oooo000c0?ooo`0303<0
o`3oool0oooo00H0oooo00<0<ol00?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0
o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0
o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303?o
003oool0oooo00D0oooo00<0<`3o0?ooo`3oool0<P3oool003@0oooo00<0<`3o0?ooo`3oool00`3o
ool203?o01H0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3o
ool0oooo00l0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3o
ool0oooo01@0oooo00<0<`3o0?ooo`3oool05@3oool00`0co`00oooo0?ooo`030?ooo`0303<0o`3o
ool0oooo03<0oooo000e0?ooo`0503<0o`3oool0oooo0?ooo`0co`006@3oool00`0c0?l0oooo0?oo
o`0D0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?oo
o`0?0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?oo
o`0G0?ooo`0503?o003oool0oooo0?ooo`0c0?l0=P3oool003H0oooo00<0<`3o0?ooo`0co`006P3o
ool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool03`3o
ool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0503o
ool00`0c0?l0oooo0?ooo`0H0?ooo`0303?o003oool0<`3o03L0oooo000g0?ooo`0303<0o`3oool0
oooo01X0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0
oooo00l0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0
oooo01<0oooo00<0<`3o0?ooo`3oool06P3oool00`0c0?l0oooo0?ooo`0f0?ooo`00=P3oool00`0c
o`00oooo03<0o`0L0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool03`3oool00`0c
0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool03`3oool00`0c
0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01X0oooo00<0<`3o0?ooo`0co`00=`3oool003D0
oooo00D0<ol00?ooo`3oool0oooo03<0o`0K0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?oo
o`3oool0403oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?oo
o`3oool0403oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01T0oooo00@0<`3o0?oo
o`3oool0<ol0=`3oool003@0oooo00<0<ol00?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`0I0?oo
o`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0>0?oo
o`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0C0?oo
o`0303<0o`3oool0oooo01T0oooo00<0<`3o0?ooo`3oool00P3oool00`0co`00oooo0?ooo`0d0?oo
o`00=03oool00`0co`00oooo0?ooo`040?ooo`0303<0o`3oool0oooo01T0oooo00<0<`3o0?ooo`3o
ool04P3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3o
ool03P3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3o
ool06@3oool00`0c0?l0oooo0?ooo`040?ooo`0303?o003oool0oooo03<0oooo000c0?ooo`0303?o
003oool0oooo00H0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0
o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0
o`3oool0oooo00H0oooo00<0<ol00?ooo`3oool0<P3oool00380oooo00<0<ol00?ooo`3oool0203o
ool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool03P3o
ool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03P3o
ool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool0203o
ool00`0co`00oooo0?ooo`0a0?ooo`00<@3oool00`0co`00oooo0?ooo`0:0?ooo`0303<0o`3oool0
oooo01P0oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0
oooo00d0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0
oooo0140oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`0:0?ooo`0303?o003oool0
oooo0300oooo000`0?ooo`0303?o003oool0oooo00`0oooo00<0<`3o0?ooo`3oool05`3oool00`0c
0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03@3oool00`0c
0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool04P3oool00`0c
0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo00`0oooo00<0<ol00?ooo`3oool0;`3oool00300
oooo00<0<ol00?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo0140
oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00d0
oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01L0
oooo00<0<`3o0?ooo`3oool03@3oool00`0co`00oooo0?ooo`0_0?ooo`00;`3oool00`0co`00oooo
0?ooo`0?0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo
0?ooo`0=0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo
0?ooo`0=0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo
0?ooo`0?0?ooo`0303?o003oool0oooo02h0oooo000^0?ooo`0303?o003oool0oooo0140oooo00<0
<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo00d0oooo00<0
<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00d0oooo00<0
<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo0140oooo00<0
<ol00?ooo`3oool0;@3oool001d0oooo0P0c0?l>0?ooo`0303?o003oool0oooo01<0oooo00<0<`3o
0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo01<0oooo00<0<ol0
0?ooo`3oool0303oool203<0oah0oooo000O0?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol00?oo
o`3oool05@3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?oo
o`3oool03@3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?oo
o`3oool03@3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?oo
o`3oool05@3oool00`0co`00oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo01h0oooo000P0?ooo`80
<`3o2@3oool00`0co`00oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3o
ool0403oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3o
ool0303oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3o
ool05@3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303?o003oool0oooo00L0oooo0P0c0?lQ0?ooo`00
8P3oool00`0c0?l0oooo0?ooo`050?ooo`0303?o003oool0oooo01T0oooo00<0<`3o0?ooo`3oool0
5@3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0
303oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0
403oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo01T0oooo00<0<ol00?ooo`3oool0
1@3oool00`0c0?l0oooo0?ooo`0Q0?ooo`008`3oool203<0o`D0oooo00<0<ol00?ooo`3oool06P3o
ool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool0303o
ool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0303o
ool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool06P3o
ool00`0co`00oooo0?ooo`030?ooo`80<`3o903oool002D0oooo00D0<`3o0?ooo`3oool0oooo03?o
000N0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?oo
o`0=0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?oo
o`0=0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?oo
o`0L0?ooo`0503?o003oool0oooo0?ooo`0c0?l09P3oool002H0oooo0P0c0?l00`0co`00oooo0?oo
o`0N0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?oo
o`0<0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?oo
o`0<0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?oo
o`0N0?ooo`0303?o000c0?l0<`3o02L0oooo000X0?ooo`0303<0o`3oool0oooo01l0oooo00<0<`3o
0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o
0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o
0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01l0oooo00<0<`3o
0?ooo`3oool09`3oool002L0oooo00@0<ol00?ooo`0c0?l0<`3o803oool00`0c0?l0oooo0?ooo`0C
0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;
0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0?
0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool07P3oool203<0o`030?ooo`0co`00
oooo02L0oooo000W0?ooo`0503?o003oool0oooo0?ooo`0c0?l0803oool00`0c0?l0oooo0?ooo`0C
0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;
0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0>
0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool07P3oool01@0c0?l0oooo0?ooo`3o
ool0<ol002P0oooo000V0?ooo`0303?o003oool0oooo00<0oooo0P0c0?lO0?ooo`0303<0o`3oool0
oooo01<0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0
oooo00X0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0
oooo00h0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0M0?ooo`80<`3o1@3oool0
0`0co`00oooo0?ooo`0U0?ooo`009@3oool00`0co`00oooo0?ooo`060?ooo`0303<0o`3oool0oooo
01d0oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo
00/0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo
00/0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo
01d0oooo00<0<`3o0?ooo`3oool01P3oool00`0co`00oooo0?ooo`0T0?ooo`009@3oool00`0co`00
oooo0?ooo`070?ooo`80<`3o7P3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo00d0
oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00X0
oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0180
oooo00<0<`3o0?ooo`3oool0703oool203<0o`T0oooo00<0<ol00?ooo`3oool0903oool002@0oooo
00<0<ol00?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo0180oooo
00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00X0oooo
00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00d0oooo
00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo00X0oooo
00<0<ol00?ooo`3oool08`3oool002<0oooo00<0<ol00?ooo`3oool0303oool203<0oad0oooo00<0
<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00X0oooo00<0
<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00X0oooo00<0
<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01/0oooo0P0c
0?l>0?ooo`0303?o003oool0oooo0280oooo000S0?ooo`0303?o003oool0oooo00h0oooo00<0<`3o
0?ooo`3oool06`3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o
0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o
0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o
0?ooo`3oool06`3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303?o003oool0oooo0280oooo000R0?oo
o`0303?o003oool0oooo0100oooo0P0c0?lL0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?oo
o`3oool0303oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?oo
o`3oool02@3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?oo
o`3oool04@3oool00`0c0?l0oooo0?ooo`0J0?ooo`80<`3o4P3oool00`0co`00oooo0?ooo`0Q0?oo
o`008P3oool00`0co`00oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo01X0oooo00<0<`3o0?ooo`3o
ool0403oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3o
ool02@3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3o
ool0303oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo01X0oooo00<0<`3o0?ooo`3o
ool04P3oool00`0co`00oooo0?ooo`0Q0?ooo`008@3oool00`0co`00oooo0?ooo`0D0?ooo`80<`3o
6`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0
2@3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0
2@3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0
6@3oool203<0oaH0oooo00<0<ol00?ooo`3oool0803oool00200oooo00<0<ol00?ooo`3oool05`3o
ool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool02`3o
ool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool02@3o
ool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool0403o
ool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo01L0oooo00<0<ol00?ooo`3oool07`3o
ool00200oooo00<0<ol00?ooo`3oool0603oool203<0oaX0oooo00<0<`3o0?ooo`3oool03`3oool0
0`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0203oool0
0`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0303oool0
0`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo01P0oooo0P0c0?lJ0?ooo`0303?o003oool0
oooo01l0oooo000O0?ooo`0303?o003oool0oooo01/0oooo00<0<`3o0?ooo`3oool0603oool00`0c
0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02@3oool00`0c
0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool02@3oool00`0c
0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool0603oool00`0c
0?l0oooo0?ooo`0K0?ooo`0303?o003oool0oooo01h0oooo000O0?ooo`0303?o003oool0oooo01`0
oooo0P0c0?lI0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0
oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0
oooo0?ooo`080?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0
oooo0?ooo`0G0?ooo`80<`3o7P3oool00`0co`00oooo0?ooo`0N0?ooo`007`3oool00`0co`00oooo
0?ooo`0N0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo
0?ooo`0;0?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo
0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo
0?ooo`0>0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool07P3oool00`0co`00oooo
0?ooo`0N0?ooo`004@3oool203<0o`/0oooo00<0<ol00?ooo`3oool0803oool203<0oaP0oooo00<0
<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00P0oooo00<0
<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0
<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo01H0oooo0P0c
0?lR0?ooo`0303?o003oool0oooo00T0oooo0P0c0?lB0?ooo`004`3oool303<0o`P0oooo00<0<ol0
0?ooo`3oool08P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o
0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o
0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo0280oooo00<0<ol0
0?ooo`3oool01P3oool303<0oa@0oooo000F0?ooo`80<`3o1P3oool00`0co`00oooo0?ooo`0S0?oo
o`80<`3o5`3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?oo
o`3oool0203oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?oo
o`3oool0203oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?oo
o`3oool05@3oool203<0obD0oooo00<0<ol00?ooo`3oool0103oool203<0oaL0oooo000H0?ooo`80
<`3o0`3oool00`0co`00oooo0?ooo`0V0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3o
ool03@3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3o
ool01`3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3o
ool02P3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3o
ool09P3oool0100co`00oooo0?ooo`3oool203<0oaT0oooo000J0?ooo`<0<`3o00<0<ol00?ooo`3o
ool09`3oool203<0oaH0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`090?ooo`03
03<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`070?ooo`03
03<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`0=0?ooo`03
03<0o`3oool0oooo01@0oooo0P0c0?lY0?ooo`0403?o000c0?l0<`3o03<0oa/0oooo000M0?ooo`80
<`3o:P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3o
ool02@3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3o
ool01`3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3o
ool0303oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo02P0oooo0P0c0?lN0?ooo`00
703oool00`0co`00oooo0?ooo`0303<0obP0oooo0P0c0?lE0?ooo`0303<0o`3oool0oooo00`0oooo
00<0<`3o0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00H0oooo
00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00T0oooo
00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0C0?ooo`80<`3o:03oool303<0o`80oooo
00<0<ol00?ooo`3oool06`3oool001/0oooo00<0<ol00?ooo`3oool0103oool203<0obP0oooo00<0
<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00P0oooo00<0
<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<0
<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00`0oooo00<0
<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0V0?ooo`80<`3o1P3oool00`0co`00oooo0?oo
o`0J0?ooo`006`3oool00`0co`00oooo0?ooo`060?ooo`<0<`3o9P3oool203<0oa@0oooo00<0<`3o
0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o
0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o
0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo0180oooo0P0c0?lV
0?ooo`<0<`3o203oool00`0co`00oooo0?ooo`0J0?ooo`006P3oool00`0co`00oooo0?ooo`0:0?oo
o`80<`3o9P3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?oo
o`3oool0203oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?oo
o`3oool01P3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?oo
o`3oool02`3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo02@0oooo0P0c0?l<0?oo
o`0303?o003oool0oooo01T0oooo000J0?ooo`0303?o003oool0oooo00`0oooo0P0c0?lU0?ooo`80
<`3o4`3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3o
ool01P3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3o
ool01P3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3o
ool04@3oool203<0obD0oooo0P0c0?l>0?ooo`0303?o003oool0oooo01T0oooo000I0?ooo`0303?o
003oool0oooo00l0oooo0`0c0?lT0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool0
2P3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool0
1@3oool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool0
203oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool0
8P3oool303<0oa00oooo00<0<ol00?ooo`3oool06@3oool001T0oooo00<0<ol00?ooo`3oool04P3o
ool203<0ob<0oooo0P0c0?lB0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool01`3o
ool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3o
ool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool02P3o
ool00`0c0?l0oooo0?ooo`0@0?ooo`80<`3o8`3oool203<0oa@0oooo00<0<ol00?ooo`3oool0603o
ool001T0oooo00<0<ol00?ooo`3oool0503oool303<0ob80oooo00<0<`3o0?ooo`3oool0403oool0
0`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01@3oool0
0`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool0
0`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool0403oool0
0`0c0?l0oooo0?ooo`0P0?ooo`<0<`3o5P3oool00`0co`00oooo0?ooo`0H0?ooo`00603oool00`0c
o`00oooo0?ooo`0H0?ooo`80<`3o8@3oool203<0oa40oooo00<0<`3o0?ooo`3oool02@3oool00`0c
0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c
0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01`3oool00`0c
0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00l0oooo0P0c0?lQ0?ooo`80<`3o6P3oool00`0c
o`00oooo0?ooo`0G0?ooo`00603oool00`0co`00oooo0?ooo`0J0?ooo`<0<`3o803oool00`0c0?l0
oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0
oooo0?ooo`040?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0
oooo0?ooo`040?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool02@3oool00`0c0?l0
oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo01h0oooo0`0c0?lL0?ooo`0303?o003oool0oooo01L0
oooo000H0?ooo`0303?o003oool0oooo01d0oooo0P0c0?lO0?ooo`80<`3o403oool00`0c0?l0oooo
0?ooo`090?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo
0?ooo`040?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo
0?ooo`060?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool03P3oool203<0oal0oooo
0P0c0?lO0?ooo`0303?o003oool0oooo01L0oooo000G0?ooo`0303?o003oool0oooo0200oooo0P0c
0?lO0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?oo
o`060?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?oo
o`040?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?oo
o`080?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool07@3oool203<0ob80oooo00<0
<ol00?ooo`3oool05P3oool001L0oooo00<0<ol00?ooo`3oool08P3oool303<0oad0oooo0P0c0?l?
0?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`04
0?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`04
0?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0=
0?ooo`80<`3o7@3oool303<0ob@0oooo00<0<ol00?ooo`3oool05P3oool001L0oooo00<0<ol00?oo
o`3oool09@3oool203<0oad0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`080?oo
o`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`040?oo
o`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`050?oo
o`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0K0?oo
o`80<`3o9`3oool00`0co`00oooo0?ooo`0F0?ooo`005`3oool00`0co`00oooo0?ooo`0W0?ooo`<0
<`3o6`3oool203<0o`h0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`060?ooo`03
03<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`040?ooo`03
03<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`070?ooo`03
03<0o`3oool0oooo00`0oooo0P0c0?lK0?ooo`<0<`3o:@3oool00`0co`00oooo0?ooo`0F0?ooo`00
5`3oool00`0co`00oooo0?ooo`0Z0?ooo`80<`3o6`3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0
o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`040?ooo`0303<0
o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`040?ooo`0303<0
o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0
o`3oool0oooo01T0oooo0P0c0?l/0?ooo`0303?o003oool0oooo01H0oooo000G0?ooo`0303?o003o
ool0oooo02`0oooo0`0c0?lI0?ooo`80<`3o3@3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3o
ool0oooo00@0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3o
ool0oooo00<0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3o
ool0oooo00L0oooo00<0<`3o0?ooo`3oool02`3oool203<0oaT0oooo0`0c0?l^0?ooo`0303?o003o
ool0oooo01H0oooo000F0?ooo`0303?o003oool0oooo0300oooo0P0c0?lI0?ooo`0303<0o`3oool0
oooo00/0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0
oooo00<0oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0
oooo00<0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0
oooo00/0oooo00<0<`3o0?ooo`3oool05`3oool203<0oc80oooo00<0<ol00?ooo`3oool05@3oool0
01H0oooo00<0<ol00?ooo`3oool0<P3oool203<0oaP0oooo0P0c0?l<0?ooo`0303<0o`3oool0oooo
00H0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo
00<0oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo
00@0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`0:0?ooo`80<`3o603oool203<0
oc@0oooo00<0<ol00?ooo`3oool05@3oool000T0oooo0`0c0?l:0?ooo`0303?o003oool0oooo03@0
oooo0`0c0?lG0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0
oooo0?ooo`040?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0
oooo0?ooo`030?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0
oooo0?ooo`060?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool05@3oool303<0ocH0
oooo00<0<ol00?ooo`3oool0203oool303<0o`X0oooo000<0?ooo`D0<`3o103oool00`0co`00oooo
0?ooo`0h0?ooo`80<`3o5P3oool203<0o`/0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo
0?ooo`040?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo
0?ooo`020?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo
0?ooo`050?ooo`0303<0o`3oool0oooo00T0oooo0P0c0?lF0?ooo`80<`3o>P3oool00`0co`00oooo
0?ooo`020?ooo`D0<`3o3@3oool00140oooo1@0c0?ll0?ooo`<0<`3o5@3oool00`0c0?l0oooo0?oo
o`090?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?oo
o`030?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?oo
o`030?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?oo
o`090?ooo`0303<0o`3oool0oooo01<0oooo0`0c0?ll0?ooo`D0<`3o4P3oool001D0oooo00<0<ol0
03<0o`0c0?l00`0c0?lj0?ooo`80<`3o503oool203<0o`X0oooo00<0<`3o0?ooo`3oool01@3oool0
0`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00P3oool0
0`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00`3oool0
0`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00P0oooo0P0c0?lD0?ooo`80<`3o>P3oool5
03<0o`0303?o003oool0oooo01@0oooo000E0?ooo`0303?o003oool0oooo00<0oooo1@0c0?lg0?oo
o`80<`3o503oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?oo
o`3oool00`3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?oo
o`3oool00P3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?oo
o`3oool0103oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo0180oooo0P0c0?lg0?oo
o`D0<`3o1@3oool00`0co`00oooo0?ooo`0D0?ooo`005@3oool00`0co`00oooo0?ooo`080?ooo`D0
<`3o=03oool303<0oa80oooo0P0c0?l90?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3o
ool00`3oool01@0c0?l0oooo0?ooo`3oool0<`3o00@0oooo00<0<`3o0?ooo`3oool00P3oool01@0c
0?l0oooo0?ooo`3oool0<`3o00D0oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`07
0?ooo`80<`3o4P3oool303<0oc@0oooo1@0c0?l:0?ooo`0303?o003oool0oooo01@0oooo000E0?oo
o`0303?o003oool0oooo00d0oooo1@0c0?lb0?ooo`80<`3o4P3oool00`0c0?l0oooo0?ooo`070?oo
o`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`020?oo
o`0503<0o`3oool0oooo0?ooo`0c0?l00`3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0
oooo0080oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0
oooo0100oooo0P0c0?lb0?ooo`D0<`3o3`3oool00`0co`00oooo0?ooo`0D0?ooo`00503oool00`0c
o`00oooo0?ooo`0C0?ooo`D0<`3o;`3oool303<0oa00oooo0P0c0?l80?ooo`0303<0o`3oool0oooo
00<0oooo00<0<`3o0?ooo`3oool00`3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00D0<`3o
0?ooo`3oool0oooo03<0o`030?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00`3o
ool00`0c0?l0oooo0?ooo`060?ooo`80<`3o403oool303<0obl0oooo1@0c0?lE0?ooo`0303?o003o
ool0oooo01<0oooo000D0?ooo`0303?o003oool0oooo01P0oooo1@0c0?l]0?ooo`80<`3o403oool0
0`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3oool0
1@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`030?ooo`0303<0
o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0
o`3oool0oooo00h0oooo0P0c0?l]0?ooo`D0<`3o6P3oool00`0co`00oooo0?ooo`0C0?ooo`00503o
ool00`0co`00oooo0?ooo`0M0?ooo`D0<`3o:P3oool303<0o`h0oooo0P0c0?l70?ooo`0303<0o`3o
ool0oooo00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`030?ooo`0503<0o`3oool0oooo0?ooo`0c
0?l00`3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00<0<`3o0?ooo`3oool00`3oool00`0c
0?l0oooo0?ooo`050?ooo`80<`3o3P3oool303<0obX0oooo1@0c0?lO0?ooo`0303?o003oool0oooo
01<0oooo000D0?ooo`0303?o003oool0oooo0280oooo1@0c0?lX0?ooo`80<`3o3P3oool00`0c0?l0
oooo0?ooo`050?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00P3oool0100c0?l0
oooo0?ooo`0c0?l30?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00P3oool00`0c0?l0oooo0?ooo`02
0?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`0<
0?ooo`80<`3o:03oool503<0ob@0oooo00<0<ol00?ooo`3oool04`3oool001@0oooo00<0<ol00?oo
o`3oool09`3oool503<0obD0oooo0P0c0?l=0?ooo`80<`3o1P3oool00`0c0?l0oooo0?ooo`020?oo
o`0503<0o`3oool0oooo0?ooo`0c0?l00`3oool0100c0?l0oooo0?ooo`0c0?l20?ooo`0503<0o`3o
ool0oooo0?ooo`0c0?l00`3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo00@0oooo
0P0c0?l=0?ooo`80<`3o9@3oool503<0obT0oooo00<0<ol00?ooo`3oool04`3oool001@0oooo00<0
<ol00?ooo`3oool0;03oool503<0ob80oooo0`0c0?l<0?ooo`0303<0o`3oool0oooo00@0oooo00<0
<`3o0?ooo`3oool00P3oool01@0c0?l0oooo0?ooo`3oool0<`3o0080oooo00@0<`3o0?ooo`3oool0
<`3o0P3oool0100c0?l0oooo0?ooo`0c0?l30?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?oo
o`3oool0103oool00`0c0?l0oooo0?ooo`0:0?ooo`<0<`3o8P3oool503<0obh0oooo00<0<ol00?oo
o`3oool04`3oool001@0oooo00<0<ol00?ooo`3oool0<@3oool503<0ob00oooo0P0c0?l;0?ooo`80
<`3o1@3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00@0<`3o0?ooo`3oool0<`3o0P3oool0
100c0?l0oooo0?ooo`0c0?l20?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00`3oool00`0c0?l0oooo
0?ooo`030?ooo`80<`3o2`3oool203<0ob00oooo1@0c0?lc0?ooo`0303?o003oool0oooo01<0oooo
000D0?ooo`0303?o003oool0oooo03H0oooo1@0c0?lM0?ooo`<0<`3o2P3oool00`0c0?l0oooo0?oo
o`030?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00P3oool0100c0?l0oooo0?ooo`0c0?l20?ooo`04
03<0o`3oool0oooo03<0o`80oooo00@0<`3o0?ooo`3oool0<`3o0`3oool00`0c0?l0oooo0?ooo`03
0?ooo`0303<0o`3oool0oooo00P0oooo0`0c0?lM0?ooo`D0<`3o>03oool00`0co`00oooo0?ooo`0C
0?ooo`004`3oool00`0co`00oooo0?ooo`0l0?ooo`D0<`3o6`3oool203<0o`T0oooo0P0c0?l40?oo
o`0503<0o`3oool0oooo0?ooo`0c0?l00P3oool00`0c0?l0oooo03<0o`020?ooo`0603<0o`3oool0
oooo03<0o`3oool0<`3o0P3oool01@0c0?l0oooo0?ooo`3oool0<`3o00@0oooo0P0c0?l90?ooo`80
<`3o6`3oool503<0och0oooo00<0<ol00?ooo`3oool04P3oool001<0oooo00<0<ol00?ooo`3oool0
@@3oool503<0oaP0oooo0`0c0?l80?ooo`0303<0o`3oool0oooo0080oooo00@0<`3o0?ooo`3oool0
<`3o0P3oool0200c0?l0oooo0?ooo`0c0?l0oooo03<0o`3oool0<`3o0P3oool0100c0?l0oooo0?oo
o`0c0?l20?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool01P3oool303<0oaP0oooo
1@0c0?m30?ooo`0303?o003oool0oooo0180oooo000C0?ooo`0303?o003oool0oooo04H0oooo1@0c
0?lF0?ooo`80<`3o1`3oool203<0o`<0oooo00@0<`3o0?ooo`3oool0<`3o0P3oool02@0c0?l0oooo
03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0o`020?ooo`0403<0o`3oool0oooo03<0o`<0oooo0P0c
0?l70?ooo`80<`3o5P3oool503<0odP0oooo00<0<ol00?ooo`3oool04P3oool001<0oooo00<0<ol0
0?ooo`3oool0B`3oool503<0oa<0oooo0P0c0?l70?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00P3o
ool03@0c0?l0oooo03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0o`3oool0<`3o0?ooo`0c0?l00P3o
ool01@0c0?l0oooo0?ooo`3oool0<`3o00L0oooo0P0c0?lC0?ooo`D0<`3oC@3oool00`0co`00oooo
0?ooo`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1@0?ooo`D0<`3o403oool303<0o`D0oooo0P0c
0?l20?ooo`0A03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0
o`3oool0<`3o0?ooo`0c0?l00P3oool203<0o`D0oooo0`0c0?l@0?ooo`D0<`3oDP3oool00`0co`00
oooo0?ooo`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1E0?ooo`D0<`3o3P3oool203<0o`D0oooo
00L0<`3o0?ooo`3oool0<`3o0?ooo`0c0?l0oooo0080<`3o00<0oooo03<0o`3oool00P0c0?l0103o
ool0<`3o0?ooo`0c0?l20?ooo`0303<0o`3oool0oooo00<0oooo0P0c0?l>0?ooo`D0<`3oE`3oool0
0`0co`00oooo0?ooo`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1J0?ooo`D0<`3o2`3oool303<0
o`<0oooo0P0c0?l00`3oool0<`3o0?ooo`0203<0o`050?ooo`0c0?l0<`3o03<0o`3oool00P0c0?l0
0`3oool0<`3o0?ooo`0203<0o`<0oooo0`0c0?l;0?ooo`D0<`3oG03oool00`0co`00oooo0?ooo`0B
0?ooo`004`3oool00`0co`00oooo0?ooo`1O0?ooo`D0<`3o2@3oool203<0o`<0oooo00D0<`3o0?oo
o`0c0?l0<`3o0?ooo`0503<0o`050?ooo`0c0?l0<`3o0?ooo`0c0?l00`3oool203<0o`T0oooo1@0c
0?mQ0?ooo`0303?o003oool0oooo0180oooo000C0?ooo`0303?o003oool0oooo06@0oooo1@0c0?l6
0?ooo`<0<`3o00<0oooo03<0o`0c0?l02`0c0?l0103oool0<`3o03<0o`0c0?l60?ooo`D0<`3oIP3o
ool00`0co`00oooo0?ooo`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1Y0?ooo`D0<`3o103oool2
03<0o`030?ooo`0c0?l0<`3o00L0<`3o00<0oooo03<0o`0c0?l0103oool503<0of/0oooo00<0<ol0
0?ooo`3oool04P3oool001<0oooo00<0<ol00?ooo`3oool0KP3oool503<0o`030?ooo`0c0?l0<`3o
00T0<`3o00<0oooo03<0o`0c0?l00`0c0?m`0?ooo`0303?o003oool0oooo0180oooo000C0?ooo`03
03?o003oool0oooo07<0oooo3@0c0?me0?ooo`0303?o003oool0oooo0180oooo00060?ooohT0<`3o
RP3o00070?ooo`004`3oool00`0co`00oooo0?ooo`1b0?ooo`l0<`3oM03oool00`0co`00oooo0?oo
o`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1]0?ooo`D0<`3o00<0oooo03<0o`0c0?l02`0c0?l0
0`3oool0<`3o03<0o`0303<0ofl0oooo00<0<ol00?ooo`3oool04P3oool001<0oooo00<0<ol00?oo
o`3oool0J03oool503<0o`@0oooo0P0c0?l00`3oool0<`3o0?ooo`0703<0o`030?ooo`0c0?l0oooo
0080<`3o103oool503<0ofX0oooo00<0<ol00?ooo`3oool04P3oool001<0oooo00<0<ol00?ooo`3o
ool0H`3oool503<0o`H0oooo0`0c0?l01P3oool0<`3o03<0o`3oool0<`3o0?ooo`D0<`3o00<0oooo
03<0o`3oool00P0c0?l0103oool0<`3o03<0o`0c0?l60?ooo`D0<`3oI@3oool00`0co`00oooo0?oo
o`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1N0?ooo`D0<`3o2@3oool203<0o`<0oooo00D0<`3o
0?ooo`3oool0<`3o0?ooo`0703<0o`050?ooo`0c0?l0oooo0?ooo`0c0?l00`3oool203<0o`T0oooo
1@0c0?mP0?ooo`0303?o003oool0oooo0180oooo000C0?ooo`0303?o003oool0oooo05T0oooo1@0c
0?l;0?ooo`<0<`3o0`3oool203<0o`80oooo00@0<`3o0?ooo`0c0?l0oooo1@0c0?l0103oool0<`3o
0?ooo`0c0?l20?ooo`80<`3o0`3oool303<0o`/0oooo1@0c0?mK0?ooo`0303?o003oool0oooo0180
oooo000C0?ooo`0303?o003oool0oooo05@0oooo1@0c0?l>0?ooo`80<`3o1@3oool01@0c0?l0oooo
0?ooo`3oool0<`3o0080oooo0P0c0?l01@3oool0<`3o03<0o`0c0?l0oooo0080<`3o0P3oool01@0c
0?l0oooo0?ooo`3oool0<`3o00D0oooo0P0c0?l>0?ooo`D0<`3oEP3oool00`0co`00oooo0?ooo`0B
0?ooo`004`3oool00`0co`00oooo0?ooo`1?0?ooo`D0<`3o403oool303<0o`D0oooo0P0c0?l30?oo
o`0503<0o`3oool0oooo03<0o`3oool00P0c0?l00`3oool0<`3o0?ooo`0203<0o`050?ooo`0c0?l0
oooo0?ooo`0c0?l00`3oool203<0o`D0oooo0`0c0?l@0?ooo`D0<`3oD@3oool00`0co`00oooo0?oo
o`0B0?ooo`004`3oool00`0co`00oooo0?ooo`1:0?ooo`D0<`3o4`3oool203<0o`L0oooo00<0<`3o
0?ooo`3oool00P3oool0400c0?l0oooo0?ooo`0c0?l0oooo03<0o`3oool0<`3o0?ooo`0c0?l0oooo
03<0o`3oool0<`3o0?ooo`0c0?l20?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool0
1@3oool203<0oa<0oooo1@0c0?m<0?ooo`0303?o003oool0oooo0180oooo000C0?ooo`0303?o003o
ool0oooo04D0oooo1@0c0?lF0?ooo`80<`3o1`3oool203<0o`@0oooo0140<`3o0?ooo`3oool0oooo
03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0o`3oool0<`3o0?ooo`0c0?l0oooo03<0o`030?ooo`03
03<0o`3oool0oooo0080oooo0P0c0?l70?ooo`80<`3o5P3oool503<0odL0oooo00<0<ol00?ooo`3o
ool04P3oool001<0oooo00<0<ol00?ooo`3oool0@03oool503<0oaP0oooo0`0c0?l80?ooo`0303<0
o`3oool0oooo00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`020?ooo`0903<0o`3oool0<`3o0?oo
o`0c0?l0oooo03<0o`3oool0<`3o0080oooo00D0<`3o0?ooo`3oool0oooo03<0o`050?ooo`0303<0
o`3oool0oooo00H0oooo0`0c0?lH0?ooo`D0<`3o@P3oool00`0co`00oooo0?ooo`0B0?ooo`004`3o
ool00`0co`00oooo0?ooo`0k0?ooo`D0<`3o6`3oool203<0o`T0oooo0P0c0?l50?ooo`0503<0o`3o
ool0oooo0?ooo`0c0?l00P3oool0200c0?l0oooo0?ooo`0c0?l0oooo03<0o`3oool0<`3o0P3oool0
100c0?l0oooo0?ooo`0c0?l30?ooo`0303<0o`3oool0oooo00<0oooo0P0c0?l90?ooo`80<`3o6`3o
ool503<0ocd0oooo00<0<ol00?ooo`3oool04P3oool001<0oooo00<0<ol00?ooo`3oool0=P3oool5
03<0oad0oooo0`0c0?l:0?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool00P3oool0
1P0c0?l0oooo0?ooo`0c0?l0oooo03<0o`80oooo00H0<`3o0?ooo`3oool0<`3o0?ooo`0c0?l20?oo
o`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`080?oo
o`<0<`3o7@3oool503<0ocP0oooo00<0<ol00?ooo`3oool04P3oool001@0oooo00<0<ol00?ooo`3o
ool0<03oool503<0ob00oooo0P0c0?l;0?ooo`80<`3o1P3oool00`0c0?l0oooo0?ooo`020?ooo`04
03<0o`3oool0oooo03<0o`80oooo00@0<`3o0?ooo`3oool0<`3o0P3oool0100c0?l0oooo0?ooo`0c
0?l20?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool0103oool203<0o`/0oooo0P0c
0?lP0?ooo`D0<`3o<P3oool00`0co`00oooo0?ooo`0C0?ooo`00503oool00`0co`00oooo0?ooo`0[
0?ooo`D0<`3o8P3oool303<0o``0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`02
0?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00P3oool0100c0?l0oooo0?ooo`0c0?l20?ooo`0403<0
o`3oool0oooo03<0o`<0oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`050?ooo`03
03<0o`3oool0oooo00X0oooo0`0c0?lR0?ooo`D0<`3o;@3oool00`0co`00oooo0?ooo`0C0?ooo`00
503oool00`0co`00oooo0?ooo`0V0?ooo`D0<`3o9@3oool203<0o`d0oooo0P0c0?l70?ooo`0303<0
o`3oool0oooo00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`020?ooo`0403<0o`3oool0oooo03<0
o`80oooo00@0<`3o0?ooo`3oool0<`3o0`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0
oooo00D0oooo0P0c0?l=0?ooo`80<`3o9@3oool503<0obP0oooo00<0<ol00?ooo`3oool04`3oool0
01@0oooo00<0<ol00?ooo`3oool08@3oool503<0obP0oooo0P0c0?l>0?ooo`0303<0o`3oool0oooo
00H0oooo00<0<`3o0?ooo`3oool00`3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00@0<`3o
0?ooo`3oool0<`3o0P3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00<0<`3o0?ooo`3oool0
0`3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00`0oooo0P0c0?lX0?ooo`D0<`3o
8`3oool00`0co`00oooo0?ooo`0C0?ooo`00503oool00`0co`00oooo0?ooo`0L0?ooo`D0<`3o:P3o
ool303<0o`h0oooo0P0c0?l80?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3o
ool0100c0?l0oooo0?ooo`0c0?l30?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00P3oool00`0c0?l0
oooo0?ooo`020?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool01P3oool203<0o`h0
oooo0`0c0?lZ0?ooo`D0<`3o7P3oool00`0co`00oooo0?ooo`0C0?ooo`00503oool00`0co`00oooo
0?ooo`0G0?ooo`D0<`3o;@3oool203<0oa00oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo
0?ooo`040?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00`3oool01@0c0?l0oooo0?ooo`3oool0<`3o
00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`030?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o
0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`0>0?ooo`80<`3o;@3oool503<0oaT0oooo00<0<ol0
0?ooo`3oool04`3oool001@0oooo00<0<ol00?ooo`3oool04P3oool503<0obl0oooo0`0c0?l@0?oo
o`80<`3o2@3oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo0080oooo00D0<`3o0?oo
o`3oool0oooo03<0o`030?ooo`0503<0o`3oool0oooo0?ooo`0c0?l00`3oool00`0c0?l0oooo0?oo
o`020?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01`3oool203<0oa00oooo0`0c
0?l_0?ooo`D0<`3o503oool00`0co`00oooo0?ooo`0C0?ooo`005@3oool00`0co`00oooo0?ooo`0<
0?ooo`D0<`3o<P3oool203<0oa80oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`04
0?ooo`0303<0o`3oool0oooo00<0oooo00D0<`3o0?ooo`3oool0oooo03<0o`030?ooo`0503<0o`3o
ool0oooo0?ooo`0c0?l00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00@0oooo
00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0@0?ooo`80<`3o<P3oool503<0o`l0oooo
00<0<ol00?ooo`3oool04`3oool001D0oooo00<0<ol00?ooo`3oool01`3oool503<0oc@0oooo0`0c
0?lB0?ooo`80<`3o2P3oool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo0080oooo00<0
<`3o0?ooo`3oool00P3oool01@0c0?l0oooo0?ooo`3oool0<`3o00<0oooo00<0<`3o0?ooo`3oool0
0P3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool0
203oool203<0oa80oooo0`0c0?ld0?ooo`D0<`3o2@3oool00`0co`00oooo0?ooo`0D0?ooo`005@3o
ool00`0co`00oooo0?ooo`020?ooo`D0<`3o=`3oool203<0oa@0oooo00<0<`3o0?ooo`3oool02@3o
ool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00<0oooo00D0<`3o0?ooo`3oool0oooo
03<0o`040?ooo`0303<0o`3oool0oooo0080oooo00D0<`3o0?ooo`3oool0oooo03<0o`050?ooo`03
03<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`0B0?ooo`80
<`3o=`3oool503<0o`@0oooo00<0<ol00?ooo`3oool0503oool001D0oooo1@0c0?lj0?ooo`80<`3o
503oool203<0o`/0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0
o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`020?ooo`0303<0
o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`050?ooo`0303<0
o`3oool0oooo00T0oooo0P0c0?lD0?ooo`80<`3o>P3oool503<0oaH0oooo000@0?ooo`D0<`3o00<0
<ol00?ooo`3oool0>@3oool303<0oaD0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?oo
o`060?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?oo
o`020?ooo`0303<0o`3oool0oooo0080oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?oo
o`030?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?oo
o`0C0?ooo`<0<`3o>`3oool00`0co`00<`3o03<0o`0303<0oa40oooo000;0?ooo`D0<`3o1P3oool0
0`0co`00oooo0?ooo`0f0?ooo`80<`3o5P3oool203<0o``0oooo00<0<`3o0?ooo`3oool01P3oool0
0`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3oool0
0`0c0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00`3oool0
0`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00X0oooo0P0c0?lF0?ooo`80<`3o>03oool0
0`0co`00oooo0?ooo`040?ooo`D0<`3o303oool000T0oooo0P0c0?l;0?ooo`0303?o003oool0oooo
03<0oooo0`0c0?lG0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool01P3oool00`0c
0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool00P3oool00`0c
0?l0oooo0?ooo`020?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o0?ooo`3oool0103oool00`0c
0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool05@3oool303<0
ocD0oooo00<0<ol00?ooo`3oool02@3oool203<0o`X0oooo000F0?ooo`0303?o003oool0oooo0340
oooo0P0c0?lH0?ooo`80<`3o3@3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00@0
oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00<0
oooo00<0<`3o0?ooo`3oool00P3oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00L0
oooo00<0<`3o0?ooo`3oool02`3oool203<0oaP0oooo0P0c0?lc0?ooo`0303?o003oool0oooo01D0
oooo000F0?ooo`0303?o003oool0oooo02l0oooo0P0c0?lI0?ooo`0303<0o`3oool0oooo00`0oooo
00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00<0oooo
00<0<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00<0oooo
00<0<`3o0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00`0oooo
00<0<`3o0?ooo`3oool05`3oool203<0oc40oooo00<0<ol00?ooo`3oool05@3oool001L0oooo00<0
<ol00?ooo`3oool0:`3oool303<0oaT0oooo0P0c0?l>0?ooo`0303<0o`3oool0oooo00L0oooo00<0
<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00<0oooo00<0
<`3o0?ooo`3oool00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00D0oooo00<0
<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`0<0?ooo`80<`3o6@3oool303<0obd0oooo00<0
<ol00?ooo`3oool05P3oool001L0oooo00<0<ol00?ooo`3oool0:@3oool203<0oa/0oooo00<0<`3o
0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o
0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00<0oooo00<0<`3o
0?ooo`3oool0103oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o
0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0I0?ooo`80<`3o:`3oool00`0co`00oooo0?ooo`0F
0?ooo`005`3oool00`0co`00oooo0?ooo`0V0?ooo`<0<`3o6`3oool203<0o`l0oooo00<0<`3o0?oo
o`3oool0203oool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?oo
o`3oool00`3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?oo
o`3oool01@3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00d0oooo0P0c0?lK0?oo
o`<0<`3o:03oool00`0co`00oooo0?ooo`0F0?ooo`005`3oool00`0co`00oooo0?ooo`0T0?ooo`80
<`3o7@3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3o
ool01P3oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3o
ool0103oool00`0c0?l0oooo0?ooo`030?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3o
ool0203oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo01/0oooo0P0c0?lV0?ooo`03
03?o003oool0oooo01H0oooo000G0?ooo`0303?o003oool0oooo0240oooo0`0c0?lM0?ooo`80<`3o
403oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool0
103oool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool0
103oool00`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0
3P3oool203<0oad0oooo0`0c0?lS0?ooo`0303?o003oool0oooo01H0oooo000G0?ooo`0303?o003o
ool0oooo01l0oooo0P0c0?lO0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool02@3o
ool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool0103o
ool00`0c0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01P3o
ool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool07@3o
ool203<0ob40oooo00<0<ol00?ooo`3oool05P3oool001P0oooo00<0<ol00?ooo`3oool0703oool2
03<0oal0oooo0P0c0?lA0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool01P3oool0
0`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool0103oool0
0`0c0?l0oooo0?ooo`050?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool02@3oool0
0`0c0?l0oooo0?ooo`0?0?ooo`80<`3o7`3oool203<0oah0oooo00<0<ol00?ooo`3oool05`3oool0
01P0oooo00<0<ol00?ooo`3oool06@3oool303<0ob00oooo00<0<`3o0?ooo`3oool0403oool00`0c
0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01@3oool00`0c
0?l0oooo0?ooo`040?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01@3oool00`0c
0?l0oooo0?ooo`060?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool0403oool00`0c
0?l0oooo0?ooo`0N0?ooo`<0<`3o6`3oool00`0co`00oooo0?ooo`0G0?ooo`00603oool00`0co`00
oooo0?ooo`0G0?ooo`80<`3o8@3oool203<0oa80oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0
oooo0?ooo`070?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0
oooo0?ooo`050?ooo`0303<0o`3oool0oooo00@0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0
oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo0100oooo0P0c0?lQ0?ooo`80<`3o6@3oool00`0co`00
oooo0?ooo`0G0?ooo`006@3oool00`0co`00oooo0?ooo`0C0?ooo`<0<`3o8P3oool00`0c0?l0oooo
0?ooo`0A0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo
0?ooo`050?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo
0?ooo`050?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo
0?ooo`0A0?ooo`0303<0o`3oool0oooo0200oooo0`0c0?lE0?ooo`0303?o003oool0oooo01P0oooo
000I0?ooo`0303?o003oool0oooo0140oooo0P0c0?lS0?ooo`80<`3o4`3oool00`0c0?l0oooo0?oo
o`0;0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?oo
o`050?ooo`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?oo
o`070?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool04@3oool203<0ob<0oooo0P0c
0?lC0?ooo`0303?o003oool0oooo01P0oooo000I0?ooo`0303?o003oool0oooo00h0oooo0`0c0?lT
0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`07
0?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`05
0?ooo`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`0;
0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool08P3oool303<0oa00oooo00<0<ol0
0?ooo`3oool0603oool001X0oooo00<0<ol00?ooo`3oool02`3oool203<0obD0oooo0P0c0?lD0?oo
o`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`060?oo
o`0303<0o`3oool0oooo00D0oooo00<0<`3o0?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`060?oo
o`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0B0?oo
o`80<`3o9@3oool203<0o`d0oooo00<0<ol00?ooo`3oool06@3oool001X0oooo00<0<ol00?ooo`3o
ool02@3oool203<0obH0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0<0?ooo`03
03<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`060?ooo`03
03<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`070?ooo`03
03<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0T0?ooo`80
<`3o2`3oool00`0co`00oooo0?ooo`0I0?ooo`006`3oool00`0co`00oooo0?ooo`050?ooo`<0<`3o
9P3oool203<0oaD0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`080?ooo`0303<0
o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0
o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0
o`3oool0oooo01<0oooo0P0c0?lV0?ooo`<0<`3o1`3oool00`0co`00oooo0?ooo`0J0?ooo`006`3o
ool00`0co`00oooo0?ooo`030?ooo`80<`3o:03oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3o
ool0oooo00`0oooo00<0<`3o0?ooo`3oool02@3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3o
ool0oooo00H0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`060?ooo`0303<0o`3o
ool0oooo00T0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3o
ool0oooo02H0oooo0P0c0?l50?ooo`0303?o003oool0oooo01X0oooo000K0?ooo`0303?o003oool0
oooo00<0<`3o:03oool203<0oaH0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`08
0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`06
0?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0=
0?ooo`0303<0o`3oool0oooo01@0oooo0P0c0?lX0?ooo`<0<`3o0P3oool00`0co`00oooo0?ooo`0J
0?ooo`00703oool203<0obX0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0=0?oo
o`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`060?oo
o`0303<0o`3oool0oooo00H0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0oooo0?ooo`090?oo
o`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0X0?oo
o`80<`3o7@3oool001T0oooo0`0c0?l00`3oool0<ol00?ooo`0W0?ooo`80<`3o5`3oool00`0c0?l0
oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0
oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01`3oool00`0c0?l0
oooo0?ooo`090?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool05@3oool203<0obP0
oooo00<0<ol00?ooo`0c0?l00P0c0?lJ0?ooo`005`3oool203<0o`@0oooo00<0<ol00?ooo`3oool0
9@3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool0
2@3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool0
1`3oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0
3P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo02D0oooo00<0<ol00?ooo`3oool0
0P3oool203<0oaP0oooo000E0?ooo`80<`3o1`3oool00`0co`00oooo0?ooo`0R0?ooo`80<`3o603o
ool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool01`3o
ool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00L0oooo00<0<`3o0?ooo`3oool01`3o
ool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool05P3o
ool203<0ob@0oooo00<0<ol00?ooo`3oool01@3oool203<0oaH0oooo000B0?ooo`<0<`3o2@3oool0
0`0co`00oooo0?ooo`0Q0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool03P3oool0
0`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool01`3oool0
0`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?ooo`3oool02P3oool0
0`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool08@3oool0
0`0co`00oooo0?ooo`070?ooo`<0<`3o4`3oool00140oooo00<0<`3o0?ooo`3oool02P3oool00`0c
o`00oooo0?ooo`0O0?ooo`80<`3o6@3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo
00X0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`070?ooo`0303<0o`3oool0oooo
00L0oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo
00l0oooo00<0<`3o0?ooo`3oool05`3oool203<0ob40oooo00<0<ol00?ooo`3oool02P3oool00`0c
0?l0oooo0?ooo`0@0?ooo`007`3oool00`0co`00oooo0?ooo`0M0?ooo`0303<0o`3oool0oooo01P0
oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00P0
oooo00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0
oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo01P0
oooo00<0<`3o0?ooo`3oool07@3oool00`0co`00oooo0?ooo`0N0?ooo`007`3oool00`0co`00oooo
0?ooo`0K0?ooo`80<`3o6P3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00/0oooo
00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo
00<0<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00l0oooo
00<0<`3o0?ooo`3oool0603oool203<0oad0oooo00<0<ol00?ooo`3oool07P3oool001l0oooo00<0
<ol00?ooo`3oool06P3oool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo0100oooo00<0
<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0
<`3o0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00/0oooo00<0
<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0o`3oool0oooo01X0oooo00<0
<ol00?ooo`3oool07P3oool00200oooo00<0<ol00?ooo`3oool05`3oool203<0oa/0oooo00<0<`3o
0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o
0?ooo`3oool0203oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o
0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo01T0oooo0P0c0?lI
0?ooo`0303?o003oool0oooo01l0oooo000P0?ooo`0303?o003oool0oooo01H0oooo00<0<`3o0?oo
o`3oool06P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?oo
o`3oool02@3oool00`0c0?l0oooo0?ooo`080?ooo`0303<0o`3oool0oooo00P0oooo00<0<`3o0?oo
o`3oool02@3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?oo
o`3oool06P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303?o003oool0oooo01l0oooo000Q0?ooo`03
03?o003oool0oooo01<0oooo0P0c0?lL0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3o
ool02`3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3o
ool02@3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3o
ool04@3oool00`0c0?l0oooo0?ooo`0J0?ooo`80<`3o5@3oool00`0co`00oooo0?ooo`0P0?ooo`00
8P3oool00`0co`00oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01/0oooo00<0<`3o0?ooo`3oool0
4@3oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0
2@3oool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool0
303oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01/0oooo00<0<`3o0?ooo`3oool0
4@3oool00`0co`00oooo0?ooo`0Q0?ooo`008P3oool00`0co`00oooo0?ooo`0?0?ooo`80<`3o7@3o
ool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool02P3o
ool00`0c0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool02P3o
ool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool06`3o
ool203<0oa40oooo00<0<ol00?ooo`3oool08@3oool002<0oooo00<0<ol00?ooo`3oool03@3oool0
0`0c0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool0303oool0
0`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00T0oooo00<0<`3o0?ooo`3oool02@3oool0
0`0c0?l0oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool04P3oool0
0`0c0?l0oooo0?ooo`0L0?ooo`0303<0o`3oool0oooo00d0oooo00<0<ol00?ooo`3oool08P3oool0
02<0oooo00<0<ol00?ooo`3oool02`3oool203<0oah0oooo00<0<`3o0?ooo`3oool04P3oool00`0c
0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool02@3oool00`0c
0?l0oooo0?ooo`090?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool03@3oool00`0c
0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo01`0oooo0P0c0?l=0?ooo`0303?o003oool0oooo
0280oooo000S0?ooo`0303?o003oool0oooo00X0oooo00<0<`3o0?ooo`3oool07@3oool00`0c0?l0
oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0
oooo0?ooo`0:0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0
oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool07@3oool00`0c0?l0
oooo0?ooo`0:0?ooo`0303?o003oool0oooo0280oooo000T0?ooo`0303?o003oool0oooo00L0oooo
0P0c0?lO0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo
0?ooo`0:0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo
0?ooo`0:0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo
0?ooo`0M0?ooo`80<`3o2@3oool00`0co`00oooo0?ooo`0S0?ooo`009@3oool00`0co`00oooo0?oo
o`050?ooo`0303<0o`3oool0oooo01h0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?oo
o`0=0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02P3oool00`0c0?l0oooo0?oo
o`0:0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?oo
o`0C0?ooo`0303<0o`3oool0oooo01h0oooo00<0<`3o0?ooo`3oool01@3oool00`0co`00oooo0?oo
o`0T0?ooo`009P3oool00`0co`00oooo0?ooo`020?ooo`80<`3o803oool00`0c0?l0oooo0?ooo`0C
0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0:
0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0>
0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool07P3oool203<0o`@0oooo00<0<ol0
0?ooo`3oool09@3oool002L0oooo00@0<ol00?ooo`3oool0<`3o8@3oool00`0c0?l0oooo0?ooo`0D
0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0:
0?ooo`0303<0o`3oool0oooo00X0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0>
0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool07`3oool0100c0?l0oooo0?ooo`0c
o`0X0?ooo`009`3oool00`0co`00<`3o03<0o`0Q0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o
0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o
0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0O0?ooo`80<`3o00<0<ol00?ooo`3oool09P3oool0
02L0oooo00<0<`3o03?o003oool0803oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo
00l0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo
00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo
01@0oooo00<0<`3o0?ooo`3oool07`3oool00`0co`00<`3o0?ooo`0W0?ooo`009@3oool203<0o`03
0?ooo`0co`00oooo01l0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0>0?ooo`03
03<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?ooo`03
03<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0E0?ooo`03
03<0o`3oool0oooo01h0oooo00@0<ol00?ooo`0c0?l0<`3o9P3oool002@0oooo00D0<`3o0?ooo`3o
ool0oooo03?o000O0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool03`3oool00`0c
0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00/0oooo00<0<`3o0?ooo`3oool02`3oool00`0c
0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool05@3oool00`0c
0?l0oooo0?ooo`0M0?ooo`0503?o003oool0oooo0?ooo`0c0?l09@3oool00280oooo0P0c0?l50?oo
o`0303?o003oool0oooo01/0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0?0?oo
o`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0;0?oo
o`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0E0?oo
o`0303<0o`3oool0oooo01/0oooo00<0<ol00?ooo`3oool00`3oool203<0ob<0oooo000Q0?ooo`03
03<0o`3oool0oooo00H0oooo00<0<ol00?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`0F0?ooo`03
03<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0<0?ooo`03
03<0o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0?0?ooo`03
03<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool06@3oool00`0co`00oooo0?ooo`060?ooo`03
03<0o`3oool0oooo0200oooo000O0?ooo`80<`3o2P3oool00`0co`00oooo0?ooo`0G0?ooo`0303<0
o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0
o`3oool0oooo00`0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0
o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303?o
003oool0oooo00P0oooo0P0c0?lP0?ooo`007P3oool00`0c0?l0oooo0?ooo`0;0?ooo`0303?o003o
ool0oooo01D0oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3o
ool0oooo00d0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3o
ool0oooo00d0oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3o
ool0oooo01D0oooo00<0<ol00?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0M0?ooo`007@3oool0
0`0c0?l0oooo0?ooo`0=0?ooo`0303?o003oool0oooo01<0oooo00<0<`3o0?ooo`3oool05`3oool0
0`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool0303oool0
0`0c0?l0oooo0?ooo`0<0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool0403oool0
0`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo01<0oooo00<0<ol00?ooo`3oool03@3oool0
0`0c0?l0oooo0?ooo`0L0?ooo`00;P3oool00`0co`00oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo
01L0oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo
00`0oooo00<0<`3o0?ooo`3oool0303oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo
0100oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303?o003oool0oooo
02d0oooo000^0?ooo`0303?o003oool0oooo0100oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0
oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0
oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0
oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo0100oooo00<0<ol00?ooo`3oool0;@3oool002l0oooo
00<0<ol00?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo0140oooo
00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00d0oooo
00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01P0oooo
00<0<`3o0?ooo`3oool03P3oool00`0co`00oooo0?ooo`0^0?ooo`00<03oool00`0co`00oooo0?oo
o`0<0?ooo`0303<0o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?oo
o`0>0?ooo`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool03@3oool00`0c0?l0oooo0?oo
o`0>0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?oo
o`0<0?ooo`0303?o003oool0oooo02l0oooo000a0?ooo`0303?o003oool0oooo00X0oooo00<0<`3o
0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool03@3oool00`0c0?l0oooo0?ooo`0=0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o
0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol0
0?ooo`3oool0<03oool00380oooo00<0<ol00?ooo`3oool0203oool00`0c0?l0oooo0?ooo`0I0?oo
o`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0=0?oo
o`0303<0o`3oool0oooo00d0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0A0?oo
o`0303<0o`3oool0oooo01T0oooo00<0<`3o0?ooo`3oool0203oool00`0co`00oooo0?ooo`0a0?oo
o`00<`3oool00`0co`00oooo0?ooo`060?ooo`0303<0o`3oool0oooo01T0oooo00<0<`3o0?ooo`3o
ool04P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3o
ool03P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3o
ool06@3oool00`0c0?l0oooo0?ooo`070?ooo`0303?o003oool0oooo0340oooo000d0?ooo`0303?o
003oool0oooo00@0oooo00<0<`3o0?ooo`3oool06@3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0
o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0I0?ooo`0303<0
o`3oool0oooo00D0oooo00<0<ol00?ooo`3oool0<P3oool003@0oooo00<0<ol00?ooo`3oool00`3o
ool00`0c0?l0oooo0?ooo`0J0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool03`3o
ool00`0c0?l0oooo0?ooo`0>0?ooo`0303<0o`3oool0oooo00h0oooo00<0<`3o0?ooo`3oool03`3o
ool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo01X0oooo00<0<`3o0?ooo`3oool00`3o
ool00`0co`00oooo0?ooo`0c0?ooo`00=@3oool01@0co`00oooo0?ooo`3oool0<`3o01`0oooo00<0
<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00h0oooo00<0
<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo01<0oooo00<0
<`3o0?ooo`3oool06P3oool01@0c0?l0oooo0?ooo`3oool0<ol003H0oooo000f0?ooo`0303?o003o
ool0<`3o01`0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3o
ool0oooo00h0oooo00<0<`3o0?ooo`3oool03P3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3o
ool0oooo01<0oooo00<0<`3o0?ooo`3oool06P3oool00`0c0?l0oooo03?o000g0?ooo`00=`3oool0
0`0c0?l0oooo0?ooo`0K0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool03`3oool0
0`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00l0oooo00<0<`3o0?ooo`3oool03`3oool0
0`0c0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01/0oooo00<0<`3o0?ooo`3oool0=P3oool0
03H0oooo00<0<`3o0?ooo`0co`006`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo
0100oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo
0100oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0I0?ooo`0303?o003oool0<`3o
03L0oooo000e0?ooo`0503<0o`3oool0oooo0?ooo`0co`006@3oool00`0c0?l0oooo0?ooo`0D0?oo
o`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0?0?oo
o`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0G0?oo
o`0503?o003oool0oooo0?ooo`0c0?l0=P3oool003@0oooo00<0<`3o0?ooo`3oool00`3oool203?o
01L0oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo
00l0oooo00<0<`3o0?ooo`3oool03`3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo
01@0oooo00<0<`3o0?ooo`3oool05@3oool203?o00D0oooo00<0<`3o0?ooo`3oool0<`3oool003<0
oooo00<0<`3o0?ooo`3oool01P3oool00`0co`00oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01@0
oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0?0?ooo`0303<0o`3oool0oooo00l0
oooo00<0<`3o0?ooo`3oool04@3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01<0
oooo00<0<ol00?ooo`3oool01P3oool00`0c0?l0oooo0?ooo`0b0?ooo`00<P3oool00`0c0?l0oooo
0?ooo`080?ooo`0303?o003oool0oooo0140oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo
0?ooo`0@0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo
0?ooo`0@0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool04@3oool00`0co`00oooo
0?ooo`080?ooo`0303<0o`3oool0oooo0340oooo000a0?ooo`0303<0o`3oool0oooo00X0oooo00<0
<ol00?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0140oooo00<0
<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo0140oooo00<0
<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0@0?ooo`0303?o003oool0oooo00X0oooo00<0
<`3o0?ooo`3oool0<03oool00300oooo00<0<`3o0?ooo`3oool0303oool203?o00l0oooo00<0<`3o
0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o
0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o
0?ooo`3oool03@3oool203?o00h0oooo00<0<`3o0?ooo`3oool0;`3oool002l0oooo00<0<`3o0?oo
o`3oool03`3oool00`0co`00oooo0?ooo`0;0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?oo
o`3oool04@3oool00`0c0?l0oooo0?ooo`0@0?ooo`0303<0o`3oool0oooo0100oooo00<0<`3o0?oo
o`3oool04@3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo00/0oooo00<0<ol00?oo
o`3oool03`3oool00`0c0?l0oooo0?ooo`0^0?ooo`00;P3oool00`0c0?l0oooo0?ooo`0A0?ooo`03
03?o003oool0oooo00X0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0B0?ooo`03
03<0o`3oool0oooo0100oooo00<0<`3o0?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0B0?ooo`03
03<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool02P3oool00`0co`00oooo0?ooo`0A0?ooo`03
03<0o`3oool0oooo02d0oooo00130?ooo`0303?o003oool0oooo00P0oooo00<0<`3o0?ooo`3oool0
5P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool0
4@3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool0
203oool00`0co`00oooo0?ooo`120?ooo`00A03oool00`0co`00oooo0?ooo`060?ooo`0303<0o`3o
ool0oooo01H0oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3o
ool0oooo0140oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3o
ool0oooo00H0oooo00<0<ol00?ooo`3oool0@`3oool004D0oooo00<0<ol00?ooo`3oool01@3oool0
0`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04@3oool0
0`0c0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool05P3oool0
0`0c0?l0oooo0?ooo`050?ooo`0303?o003oool0oooo04@0oooo00160?ooo`80<ol0103oool00`0c
0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04@3oool00`0c
0?l0oooo0?ooo`0A0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool05`3oool00`0c
0?l0oooo0?ooo`020?ooo`80<ol0A`3oool004P0oooo00@0<ol00?ooo`3oool0<`3o6@3oool00`0c
0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo0140oooo00<0<`3o0?ooo`3oool04@3oool00`0c
0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01L0oooo00@0<`3o0?ooo`3oool0<ol0B@3oool0
04T0oooo0P0co`000`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?oo
o`3oool04P3oool00`0c0?l0oooo0?ooo`0B0?ooo`0303<0o`3oool0oooo0180oooo00<0<`3o0?oo
o`3oool05`3oool00`0c0?l0<ol003?o001:0?ooo`00BP3oool00`0c0?l0oooo03?o000G0?ooo`03
03<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0B0?ooo`03
03<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3oool05@3oool203?o000303<0o`3oool0oooo04T0
oooo00190?ooo`0503<0o`3oool0oooo0?ooo`0co`005P3oool00`0c0?l0oooo0?ooo`0C0?ooo`03
03<0o`3oool0oooo0180oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0C0?ooo`03
03<0o`3oool0oooo01@0oooo00D0<ol00?ooo`3oool0oooo03<0o`1:0?ooo`00B@3oool00`0c0?l0
oooo0?ooo`020?ooo`80<ol04`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0180
oooo00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0140
oooo0P0co`040?ooo`0303<0o`3oool0oooo04P0oooo00180?ooo`0303<0o`3oool0oooo00D0oooo
00<0<ol00?ooo`3oool0403oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0180oooo
00<0<`3o0?ooo`3oool04P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0100oooo
00<0<ol00?ooo`3oool01@3oool00`0c0?l0oooo0?ooo`170?ooo`00A`3oool00`0c0?l0oooo0?oo
o`070?ooo`<0<ol03`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo01<0oooo00<0
<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0o`3oool0oooo00h0oooo0P0c
o`090?ooo`0303<0o`3oool0oooo04H0oooo00170?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol0
0?ooo`3oool02`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o
0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo00/0oooo0P0co`0;
0?ooo`0303<0o`3oool0oooo04H0oooo00160?ooo`0303<0o`3oool0oooo00`0oooo00<0<ol00?oo
o`3oool02P3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?oo
o`3oool04`3oool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo00X0oooo00<0<ol00?oo
o`3oool0303oool00`0c0?l0oooo0?ooo`150?ooo`00A@3oool00`0c0?l0oooo0?ooo`0>0?ooo`<0
<ol0203oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo01<0oooo00<0<`3o0?ooo`3o
ool04`3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00L0oooo0P0co`0@0?ooo`03
03<0o`3oool0oooo04@0oooo00150?ooo`0303<0o`3oool0oooo0140oooo0`0co`050?ooo`0303<0
o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool04`3oool00`0c0?l0oooo0?ooo`0C0?ooo`0303<0
o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool0103oool303?o0180oooo00<0<`3o0?ooo`3oool0
A03oool004@0oooo00<0<`3o0?ooo`3oool05@3oool303?o0080oooo00<0<`3o0?ooo`3oool0503o
ool00`0c0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool0503o
ool0100c0?l0oooo0?ooo`3oool303?o01H0oooo00<0<`3o0?ooo`3oool0@`3oool004<0oooo00<0
<`3o0?ooo`3oool06@3oool00`0co`00<`3o0?ooo`0F0?ooo`0303<0o`3oool0oooo01@0oooo00<0
<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`0co`00<ol001X0oooo00<0
<`3o0?ooo`3oool0@P3oool00600oooo00<0<`3o03?o003oool05@3oool00`0c0?l0oooo0?ooo`0D
0?ooo`0303<0o`3oool0oooo01@0oooo00<0<`3o0?ooo`3oool0503oool00`0co`00<`3o0?ooo`1P
0?ooo`00G`3oool00`0c0?l0oooo0?ooo`0203?o01@0oooo00<0<`3o0?ooo`3oool0503oool00`0c
0?l0oooo0?ooo`0D0?ooo`0303<0o`3oool0oooo0180oooo0P0co`020?ooo`0303<0o`3oool0oooo
05h0oooo001O0?ooo`0303<0o`3oool0oooo0080oooo0`0co`0A0?ooo`0303<0o`3oool0oooo01@0
oooo00<0<`3o0?ooo`3oool0503oool00`0c0?l0oooo0?ooo`0?0?ooo`<0<ol0103oool00`0c0?l0
oooo0?ooo`1N0?ooo`00G`3oool00`0c0?l0oooo0?ooo`050?ooo`<0<ol03@3oool00`0c0?l0oooo
0?ooo`0E0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool0303oool203?o00L0oooo
00<0<`3o0?ooo`3oool0GP3oool005h0oooo00<0<`3o0?ooo`3oool02@3oool303?o00X0oooo00<0
<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0oooo00T0oooo0`0c
o`0:0?ooo`0303<0o`3oool0oooo05d0oooo001N0?ooo`0303<0o`3oool0oooo00`0oooo1P0co`04
0?ooo`0303<0o`3oool0oooo01D0oooo00<0<`3o0?ooo`3oool05@3oool00`0c0?l0oooo0?ooo`03
0?ooo`H0<ol03@3oool00`0c0?l0oooo0?ooo`1M0?ooo`00G@3oool00`0c0?l0oooo0?ooo`0C0?oo
o`<0<ol000<0oooo03<0o`3oool05P3oool00`0c0?l0oooo0?ooo`0E0?ooo`0303<0o`3oool0<ol0
00<0<ol0503oool00`0c0?l0oooo0?ooo`1L0?ooo`00G@3oool00`0c0?l0oooo0?ooo`0F0?ooo`03
03?o000c0?l0<ol00080<ol0503oool00`0c0?l0oooo0?ooo`0B0?ooo`<0<ol000<0<`3o03?o003o
ool05`3oool00`0c0?l0oooo0?ooo`1L0?ooo`00G03oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0
o`3oool0oooo0080oooo200co`0<0?ooo`0303<0o`3oool0oooo00X0oooo200co`040?ooo`0303<0
o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool0F`3oool005`0oooo00<0<`3o0?ooo`3oool05`3o
ool00`0c0?l0oooo0?ooo`0:0?ooo``0<ol000<0<`3o03?o000co`002P0co`0<0?ooo`0303<0o`3o
ool0oooo01L0oooo00<0<`3o0?ooo`3oool0F`3oool005`0oooo00<0<`3o0?ooo`3oool05`3oool0
0`0c0?l0oooo0?ooo`0F0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool05`3oool0
0`0c0?l0oooo0?ooo`1K0?ooo`00F`3oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo
01H0oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo
05X0oooo001f0?ooo`0303<0o`3oool0oooo01H0oooo00<0<`3o0?ooo`3oool05P3oool00`0c0?l0
oooo0?ooo`1e0?ooo`00M@3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo01L0oooo
00<0<`3o0?ooo`3oool0M03oool007D0oooo00<0<`3o0?ooo`3oool05`3oool00`0c0?l0oooo0?oo
o`0G0?ooo`0303<0o`3oool0oooo07@0oooo001e0?ooo`0303<0o`3oool0oooo01L0oooo00<0<`3o
0?ooo`3oool05`3oool00`0c0?l0oooo0?ooo`1d0?ooo`00M@3oool00`0c0?l0oooo0?ooo`0G0?oo
o`0303<0o`3oool0oooo01L0oooo00<0<`3o0?ooo`3oool0M03oool007D0oooo00<0<`3o0?ooo`3o
ool05`3oool00`0c0?l0oooo0?ooo`0G0?ooo`0303<0o`3oool0oooo07@0oooo001d0?ooo`0303<0
o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool0603oool00`0c0?l0oooo0?ooo`1c0?ooo`00M03o
ool00`0c0?l0oooo0?ooo`0H0?ooo`0303<0o`3oool0oooo01P0oooo00<0<`3o0?ooo`3oool0L`3o
ool008l0oooo00<0<`3o0?ooo`3oool0SP3oool008l0oooo00<0<`3o0?ooo`3oool0SP3oool008l0
oooo00<0<`3o0?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.15501, -1.15501, 0.00804887, \
0.00804887}}],

Cell[CellGroupData[{

Cell["Discrete Fourier Basis", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "One way of visualising the discrete Fourier ",
  StyleBox["basis",
    FontSlant->"Italic"],
  " is to take the inverse (discrete) Fourier transform of unit vectors."
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The code ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptU]\_\(n_, m_:  32\) := 
            Table[If[n == i, 1, 0], {i, m}]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " generates unit vectors of default length 32 with a one in the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)]],
  " position. Show ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  "s of the real (",
  StyleBox["Re", "InlineInputTraditionalForm"],
  ") and imaginary (",
  StyleBox["Im", "InlineInputTraditionalForm"],
  ") parts of the ",
  StyleBox["InverseFourier", "InlineInputTraditionalForm"],
  " transform (of the numerical values) of various ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[ScriptU]\_n\)], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  " and relate them to trigonometric functions."
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell["Filter", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Add some uniformly distributed random noise to the \
signal, as follows:",
  FontSlant->"Plain"]], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptD] = \[ScriptS] + 
        Table[Random[Real, {\(-\(1\/2\)\), 1\/2}], {x, 256}]; \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Visualise ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  ".  Join up the data values using the ",
  StyleBox["PlotJoined", "InlineInputTraditionalForm"],
  " option and use ",
  StyleBox["PlotStyle", "InlineInputTraditionalForm"],
  " to show data in blue. Call your plot ",
  StyleBox["\[ScriptCapitalD]", "InlineInputTraditionalForm"],
  ". Use Show to display ",
  StyleBox["\[ScriptCapitalS]", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["\[ScriptCapitalD]", "InlineInputTraditionalForm"],
  " together."
}], "BeginEndQuestion"],

Cell[TextData[StyleBox["We can use the FT to construct a \"filter\" which \
removes the (high-frequency) random \"noise\" from the signal.",
  FontSlant->"Plain"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute the Fourier transform of ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  ", call it ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  ", and plot its absolute value. Only a couple of values are significant. \
Work out how to zero-out those elements of ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  " that have small absolute value (say ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x\[RightBracketingBar] < 1\)]],
  ").   (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": try using a substitution or  replacement rule). Taking the ",
  StyleBox["InverseFourier", "InlineInputTraditionalForm"],
  " of this result and, using ",
  StyleBox["Chop", "InlineInputTraditionalForm"],
  " to get rid of the small complex values, compare your filtered result \
(displayed in green) to the original pure signal, ",
  StyleBox["\[ScriptCapitalS]", "InlineInputTraditionalForm"],
  ". What do you see?"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Two-dimensional Example"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Centred Fourier Transform", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "It was pointed out in \[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "1D FFT"],
  " that the Fourier transform, displayed as of the function of (angular) \
frequency, is \[OpenCurlyDoubleQuote]wrapped\[CloseCurlyDoubleQuote], ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the low frequency terms appear at both ends of the plot and the high \
frequency terms are in the middle of these plots.  ",
  StyleBox["Fourier", "InlineInputTraditionalForm"],
  " can compute the FFT in ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-dimensions directly. Using list operations, it is simple to re-arrange \
the data so that the low frequency terms are in the middle and the high \
frequency terms are near the edge. Here is the centred FFT."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(FT(f_) := 
        RotateLeft[
          Fourier[f], \[LeftFloor]Dimensions[f]\/2\[RightFloor]];\)\)], \
"Input",
  InitializationCell->True],

Cell["and the corresponding inverse transform:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(IFT(F_) := 
        InverseFourier[
          RotateRight[
            F, \[LeftFloor]Dimensions[F]\/2\[RightFloor]]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Point Aperture", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Consider the following dataset:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ScriptD] = 
        Table[If[
            15 \[LessEqual] x \[LessEqual] 18 \[And] 
              15 \[LessEqual] y \[LessEqual] 18, 1.0, 0.0], {x, 33}, {y, 
            33}];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "Visualize this dataset using ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  "."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  "Visualize the absolute value of the (centred) Fourier transform, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]FT(\[ScriptD])\
\[RightBracketingBar]\)]],
  ",",
  " using ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["ListPlot3D", "InlineInputTraditionalForm"],
  ". ",
  "What do these plots remind you of? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": think about the diffraction pattern of an aperture)"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Alter the dataset ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  " so that the aperture is no longer near the centre of the region. What \
effect does this have on the diffraction pattern of the aperture?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell["Slit", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Modify ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  " to produce a ",
  StyleBox["vertical",
    FontSlant->"Italic"],
  " slit. Compute and display the (centred) Fourier transform. Explain the \
result."
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Simple Image Processing"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Letter E", "Subsubsection"],

Cell["Enter the following code for generating a rectangle:", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Box", "(", 
          RowBox[{"x_", ",", "y_", ",", "xw_", ",", "yw_", ",", 
            RowBox[{"(", "\[NoBreak]", GridBox[{
                  {"x0_", "y0_"},
                  {"x1_", "y1_"}
                  }], "\[NoBreak]", ")"}]}], ")"}], 
        ":=", \(1 /; 
          x0 - xw \[LessEqual] x \[LessEqual] x1 + xw \[And] 
            y0 - yw \[LessEqual] y \[LessEqual] y1 + yw\)}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"Box", "(", 
            RowBox[{"x_", ",", "y_", ",", "xw_", ",", "yw_", ",", 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"x0_", "y0_"},
                    {"x1_", "y1_"}
                    }], "\[NoBreak]", ")"}]}], ")"}], "=", "0"}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "Using ",
  StyleBox["Box", "InlineInputTraditionalForm"],
  " it is easy to construct many shapes including the letter ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalE]", "=", 
          RowBox[{"Transpose", "[", 
            RowBox[{"N", "[", 
              RowBox[{"Table", "[", 
                RowBox[{
                  RowBox[{
                    RowBox[{"Box", "[", 
                      RowBox[{"x", ",", "y", ",", "1", ",", "1", ",", 
                        FormBox[
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"0", \(-5\)},
                                {"0", "5"}
                                },
                              ColumnAlignments->{Decimal}], "\[NoBreak]", 
                            ")"}],
                          "TraditionalForm"]}], "]"}], "+", 
                    RowBox[{"Box", "[", 
                      RowBox[{"x", ",", "y", ",", "1", ",", "1", ",", 
                        FormBox[
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"3", \(-5\)},
                                {"5", \(-5\)}
                                },
                              ColumnAlignments->{Decimal}], "\[NoBreak]", 
                            ")"}],
                          "TraditionalForm"]}], "]"}], "+", 
                    RowBox[{"Box", "[", 
                      RowBox[{"x", ",", "y", ",", "1", ",", "1", ",", 
                        FormBox[
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"3", "0"},
                                {"5", "0"}
                                },
                              ColumnAlignments->{Decimal}], "\[NoBreak]", 
                            ")"}],
                          "TraditionalForm"]}], "]"}], "+", 
                    RowBox[{"Box", "[", 
                      RowBox[{"x", ",", "y", ",", "1", ",", "1", ",", 
                        FormBox[
                          RowBox[{"(", "\[NoBreak]", GridBox[{
                                {"3", "5"},
                                {"5", "5"}
                                },
                              ColumnAlignments->{Decimal}], "\[NoBreak]", 
                            ")"}],
                          "TraditionalForm"]}], "]"}]}], 
                  ",", \({x, \(-9\), 15}\), ",", \({y, \(-12\), 12}\)}], 
                "]"}], "]"}], "]"}]}], ";"}], TraditionalForm]], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Equation"],
  ". Use ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " to visualize ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ". Define ",
  StyleBox["\[ScriptF]", "InlineInputTraditionalForm"],
  " as the centred FT of ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ". Visualize ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[ScriptF]\[RightBracketingBar]\)\
], "InlineInputTraditionalForm"], "InlineInputTraditionalForm"],
  ". Describe the important features of this plot."
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[CellGroupData[{

Cell["Section of the transformed function", "Subsubsection"],

Cell[TextData[{
  "The FT arises in many areas of Optics. For example, ",
  StyleBox["holography",
    FontSlant->"Italic"],
  " and ",
  StyleBox["spatial filtering",
    FontSlant->"Italic"],
  " both rely on the FT. You may know that, taking a region from a hologram, \
the whole image can be reconstructed, albeit at a lower resolution.  In this \
example, you will sample the FT of \[ScriptCapitalE]  (corresponding to \
taking a region from a hologram) and reconstruct the image (using the inverse \
FT)."
}], "Text",
  CellTags->{"holography", "spatial filtering", "hologram"}],

Cell["Select the following region of frequency space:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptR]\  = \ 
        Transpose[
          Take[Transpose[Take[\[ScriptF], \ {5, \ 20}]], \ {5, \ 
              20}]];\)\(\ \)\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Take the absolute value of the centred inverse FT of ",
  StyleBox["\[ScriptR]", "InlineInputTraditionalForm"],
  " and call the result ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  ". Use ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " to visualize the absolute value of ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  ". Comment on the resulting image. To what region of frequency space does \
this image correspond?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[CellGroupData[{

Cell["Crude sampling", "Subsubsection"],

Cell["\<\
This image can be improved somewhat by rejecting all image (pixel) \
values that are less than a certain cutoff value.\
\>", "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Find the max and min values of the absolute value of ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  ". Hence all values lie in this range. Use ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " and experiment with different ",
  StyleBox["PlotRanges", "InlineInputTraditionalForm"],
  " to try to improve the image."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell["Another section of the transformed function", "Subsubsection"],

Cell["Select another region of frequency space:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptR] = 
      Take[Take[\[ScriptF], 10]\^T, 10]\^T; \)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Take the absolute value of the centred inverse FT of ",
  StyleBox["\[ScriptR]", "InlineInputTraditionalForm"],
  " and call the result ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  ". Use ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  " to visualize the absolute value of ",
  StyleBox["\[ScriptS]", "InlineInputTraditionalForm"],
  ". Comment on the resulting image. To what region of frequency space does \
this image correspond?"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Convolution"
}], "Subsection"],

Cell["\<\
In this section a \[OpenCurlyDoubleQuote]noisy\
\[CloseCurlyDoubleQuote] signal will be examined using a low-frequency filter \
using the technique of convolution.\
\>", "Text"],

Cell["Noisy signal", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Use ",
  StyleBox["Dimensions", "InlineInputTraditionalForm"],
  " to compute the dimensions of ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ".  Call the result ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({n, m}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Generate some uniformly distributed (white) random noise using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptN] = 
              Table[Random[Real, {\(-0.1\), 0.1}], {n}, {m}];\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " This ensures that ",
  StyleBox["\[ScriptN]", "InlineInputTraditionalForm"],
  " has the same dimensions as ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ". Add ",
  StyleBox["\[ScriptN]", "InlineInputTraditionalForm"],
  " to ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  " to produce ",
  StyleBox["\[ScriptN]\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  " and visualize."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{n, m} = Dimensions[\[ScriptCapitalE]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{25, 25}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`\(\[ScriptN] = 
        Table[Random[Real, {\(-0.1\), 0.1}], {n}, {m}];\)\)], "Input"],

Cell[BoxData[
    FormBox[
      StyleBox[\(\[ScriptN]\[ScriptCapitalE] = \[ScriptN] + \
\[ScriptCapitalE];\),
        "InlineInputTraditionalForm"], TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ListDensityPlot", "[", 
          StyleBox["\[ScriptN]\[ScriptCapitalE]",
            "InlineInputTraditionalForm"], 
          StyleBox["]",
            "InlineInputTraditionalForm"]}], 
        StyleBox[";",
          "InlineInputTraditionalForm"]}], TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
022900201B28211B0E0D030F1E2509191A1E0708202208281E
230807022511171F170D08001C0419112827111B061F13270D
170B2512051F0526221605091E271E0B211602050102052215
210A100F02041417162A0B23190C2902020924000004011509
231C06061E071A1A1E27210112271F2908031E29040208200B
10021917091229230C1B27100F2728070C0829020A00092124
281A0A1A161B120DFAF4D7FEFDF6FAF11E2222121E19001820
2920280A0D0E1A10EFE2F2E8F8E8D6F4001A1900111A000A12
2402000415121A16DEF5DCF3F6F4E8F20505110B160407231C
01061E071A170829FAE5EA090527220300151717260E1E2524
072A1D0A1B221E0FE1E2EB090E1412092228250D140900130C
0A0C091B12182410DBD8F0D7F1F0E7DF1D1F0420131F1B1409
121123212517131CF8FDE6D6DDEBDCE3121110241D20271B0A
0E032410211B0818FADFDDE6E4D8FAFE271C2A0B07200F0023
1C151A01010D0107F7DBF1231E0B1C26010B111E0B27112619
11212418041F1D22FFD9F9031D1128021100092115190E0703
2313192903212200FFFDF4E2EEFFF1FB181F241029111D0D05
28030E02070C0E02DFEDD6EAE0FCDBFC15022028040F122206
0B0420292A211D1FE7F5DEEAEBEFE2FF13240E250311161F22
0D2120221603001021241625071717110D081C0D261C281519
26081D0223080C0B291C12041104002008121E241614080A1A
0C16072104082623122122120D2001092501071E1023270304
0D1F0C2A042313170E000109182A220E162204281D26002310
071F240B0E0B0C270D0A020F0E121F22150E21051A0D281F12
180414040D221621021F07131B000F270D090A0D2A0B152511
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001@3oool;00820P/0:BTY2`00000;020P80/06a/K2`0X:2P<024Q8@/0
6a/K2`0>3Ph;00d=3@/00`<32`0?3`l;01hN7P/09BDU2`092@T;01TI6@/06QXJ2`0N7Qh;00L71``0
20P82`0P820;028R8P/020P82`0X:2P;01hN7PH0oooo00050?ooo`/00P822`0Y:BT;000000/0820P
2`0K6a/;02PX:0`08B4Q2`0K6a/;00h>3P/03@d=2`030`<;00l?3`/07QhN2`0U9BD;00T92@/06ATI
2`0J6QX;01hN7P/01`L7300820P;020P80/08R8R2`0820P;02PX:0/07QhN1P3oool000D0oooo2`02
0P8;02TY:@/000002`0P820;01/K6`/0:2PX300Q8B4;01/K6`/03Ph>2`0=3@d;00<30`/03`l?2`0N
7Qh;02DU9@/02@T92`0I6AT;01XJ6P/07QhN2`071`L<00P820/0820P2`0R8R8;00P820/0:2PX2`0N
7Qh60?ooo`001@3oool;00820P/0:BTY2`00000;020P80/06a/K2`0X:2P<024Q8@/06a/K2`0>3Ph;
00d=3@/00`<32`0?3`l;01hN7P/09BDU2`092@T;01TI6@/06QXJ2`0N7Qh;00L71``020P82`0P820;
028R8P/020P82`0X:2P;01hN7PH0oooo00050?ooo`/00P822`0Y:BT;000000/0820P2`0K6a/;02PX
:0`08B4Q2`0K6a/;00h>3P/03@d=2`030`<;00l?3`/07QhN2`0U9BD;00T92@/06ATI2`0J6QX;01hN
7P/01`L7300820P;020P80/08R8R2`0820P;02PX:0/07QhN1P3oool000D0oooo2`020P8;02TY:@/0
00002`0P820;01/K6`/0:2PX300Q8B4;01/K6`/03Ph>2`0=3@d;00<30`/03`l?2`0N7Qh;02DU9@/0
2@T92`0I6AT;01XJ6P/07QhN2`071`L<00P820/0820P2`0R8R8;00P820/0:2PX2`0N7Qh60?ooo`00
1@3oool;00820P/0:BTY2`00000;020P80/06a/K2`0X:2P<024Q8@/06a/K2`0>3Ph;00d=3@/00`<3
2`0?3`l;01hN7P/09BDU2`092@T;01TI6@/06QXJ2`0N7Qh;00L71``020P82`0P820;028R8P/020P8
2`0X:2P;01hN7PH0oooo00050?ooo`/00P822`0Y:BT;000000/0820P2`0K6a/;02PX:0`08B4Q2`0K
6a/;00h>3P/03@d=2`030`<;00l?3`/07QhN2`0U9BD;00T92@/06ATI2`0J6QX;01hN7P/01`L73008
20P;020P80/08R8R2`0820P;02PX:0/07QhN1P3oool000D0oooo2`020P8;02TY:@/000002`0P820;
01/K6`/0:2PX300Q8B4;01/K6`/03Ph>2`0=3@d;00<30`/03`l?2`0N7Qh;02DU9@/02@T92`0I6AT;
01XJ6P/07QhN2`071`L<00P820/0820P2`0R8R8;00P820/0:2PX2`0N7Qh60?ooo`001@3oool;0082
0P/0:BTY2`00000;020P80/06a/K2`0X:2P<024Q8@/06a/K2`0>3Ph;00d=3@/00`<32`0?3`l;01hN
7P/09BDU2`092@T;01TI6@/06QXJ2`0N7Qh;00L71``020P82`0P820;028R8P/020P82`0X:2P;01hN
7PH0oooo00050?ooo`/00P822`0Y:BT;000000/0820P2`0K6a/;02PX:0`08B4Q2`0K6a/;00h>3P/0
3@d=2`030`<;00l?3`/07QhN2`0U9BD;00T92@/06ATI2`0J6QX;01hN7P/01`L7300820P;020P80/0
8R8R2`0820P;02PX:0/07QhN1P3oool000D0oooo2`0S8b<;00P820/01`L72`020P8;02DU9@/04A4A
300G5aL;01lO7`/05aLG2`0=3@d;00P820/000002`0L71`;00@410/06ATI2`0A4A4;02PX:0/09bLW
2`0A4A4<01/K6`/01PH62`0O7al;01<C4`/09bLW2`0=3@d60?ooo`001@3oool;02<S8`/020P82`07
1`L;00820P/09BDU2`0A4A4<01LG5`/07alO2`0G5aL;00d=3@/020P82`00000;01`L70/010@42`0I
6AT;014A4@/0:2PX2`0W9bL;014A4@`06a/K2`061PH;01lO7`/04a<C2`0W9bL;00d=3@H0oooo0005
0?ooo`/08b<S2`0820P;00L71`/00P822`0U9BD;014A4@`05aLG2`0O7al;01LG5`/03@d=2`0820P;
000000/071`L2`0410@;01TI6@/04A4A2`0X:2P;02LW9`/04A4A300K6a/;00H61P/07alO2`0C4a<;
02LW9`/03@d=1P3oool000D0oooo2`0S8b<;00P820/01`L72`020P8;02DU9@/04A4A300G5aL;01lO
7`/05aLG2`0=3@d;00P820/000002`0L71`;00@410/06ATI2`0A4A4;02PX:0/09bLW2`0A4A4<01/K
6`/01PH62`0O7al;01<C4`/09bLW2`0=3@d60?ooo`001@3oool;02<S8`/020P82`071`L;00820P/0
9BDU2`0A4A4<01LG5`/07alO2`0G5aL;00d=3@/020P82`00000;01`L70/010@42`0I6AT;014A4@/0
:2PX2`0W9bL;014A4@`06a/K2`061PH;01lO7`/04a<C2`0W9bL;00d=3@H0oooo00050?ooo`/08b<S
2`0820P;00L71`/00P822`0U9BD;014A4@`05aLG2`0O7al;01LG5`/03@d=2`0820P;000000/071`L
2`0410@;01TI6@/04A4A2`0X:2P;02LW9`/04A4A300K6a/;00H61P/07alO2`0C4a<;02LW9`/03@d=
1P3oool000D0oooo2`0S8b<;00P820/01`L72`020P8;02DU9@/04A4A300G5aL;01lO7`/05aLG2`0=
3@d;00P820/000002`0L71`;00@410/06ATI2`0A4A4;02PX:0/09bLW2`0A4A4<01/K6`/01PH62`0O
7al;01<C4`/09bLW2`0=3@d60?ooo`001@3oool;02<S8`/020P82`071`L;00820P/09BDU2`0A4A4<
01LG5`/07alO2`0G5aL;00d=3@/020P82`00000;01`L70/010@42`0I6AT;014A4@/0:2PX2`0W9bL;
014A4@`06a/K2`061PH;01lO7`/04a<C2`0W9bL;00d=3@H0oooo00050?ooo`/08b<S2`0820P;00L7
1`/00P822`0U9BD;014A4@`05aLG2`0O7al;01LG5`/03@d=2`0820P;000000/071`L2`0410@;01TI
6@/04A4A2`0X:2P;02LW9`/04A4A300K6a/;00H61P/07alO2`0C4a<;02LW9`/03@d=1P3oool000D0
oooo2`0S8b<;00P820/01`L72`020P8;02DU9@/04A4A300G5aL;01lO7`/05aLG2`0=3@d;00P820/0
00002`0L71`;00@410/06ATI2`0A4A4;02PX:0/09bLW2`0A4A4<01/K6`/01PH62`0O7al;01<C4`/0
9bLW2`0=3@d60?ooo`001@3oool;02<S8`/020P82`071`L;00820P/09BDU2`0A4A4<01LG5`/07alO
2`0G5aL;00d=3@/020P82`00000;01`L70/010@42`0I6AT;014A4@/0:2PX2`0W9bL;014A4@`06a/K
2`061PH;01lO7`/04a<C2`0W9bL;00d=3@H0oooo00050?ooo`/05aLG2`0;2`/;02DU9@/04Q8B2`05
1@D;01lO7``01@D52`0V9RH;028R8P/05QHF2`051@D;00T92@/07QhN2`0W9bL;01hN7P/02`/;2`0Q
8B4;01HF5P/00P8230051@D;00410@/00P822`051@D;028R8P/05ADE1P3oool000D0oooo2`0G5aL;
00/;2`/09BDU2`0B4Q8;00D51@/07alO30051@D;02HV9P/08R8R2`0F5QH;00D51@/02@T92`0N7Qh;
02LW9`/07QhN2`0;2`/;024Q8@/05QHF2`020P8<00D51@/00@412`020P8;00D51@/08R8R2`0E5AD6
0?ooo`001@3oool;01LG5`/02`/;2`0U9BD;018B4P/01@D52`0O7al<00D51@/09RHV2`0R8R8;01HF
5P/01@D52`092@T;01hN7P/09bLW2`0N7Qh;00/;2`/08B4Q2`0F5QH;00820P`01@D52`010@4;0082
0P/01@D52`0R8R8;01DE5@H0oooo00050?ooo`/05aLG2`0;2`/;02DU9@/04Q8B2`051@D;01lO7``0
1@D52`0V9RH;028R8P/05QHF2`051@D;00T92@/07QhN2`0W9bL;01hN7P/02`/;2`0Q8B4;01HF5P/0
0P8230051@D;00410@/00P822`051@D;028R8P/05ADE1P3oool000D0oooo2`0G5aL;00/;2`/09BDU
2`0B4Q8;00D51@/07alO30051@D;02HV9P/08R8R2`0F5QH;00D51@/02@T92`0N7Qh;02LW9`/07QhN
2`0;2`/;024Q8@/05QHF2`020P8<00D51@/00@412`020P8;00D51@/08R8R2`0E5AD60?ooo`001@3o
ool;01LG5`/02`/;2`0U9BD;018B4P/01@D52`0O7al<00D51@/09RHV2`0R8R8;01HF5P/01@D52`09
2@T;01hN7P/09bLW2`0N7Qh;00/;2`/08B4Q2`0F5QH;00820P`01@D52`010@4;00820P/01@D52`0R
8R8;01DE5@H0oooo00050?ooo`/05aLG2`0;2`/;02DU9@/04Q8B2`051@D;01lO7``01@D52`0V9RH;
028R8P/05QHF2`051@D;00T92@/07QhN2`0W9bL;01hN7P/02`/;2`0Q8B4;01HF5P/00P8230051@D;
00410@/00P822`051@D;028R8P/05ADE1P3oool000D0oooo2`0G5aL;00/;2`/09BDU2`0B4Q8;00D5
1@/07alO30051@D;02HV9P/08R8R2`0F5QH;00D51@/02@T92`0N7Qh;02LW9`/07QhN2`0;2`/;024Q
8@/05QHF2`020P8<00D51@/00@412`020P8;00D51@/08R8R2`0E5AD60?ooo`001@3oool;01LG5`/0
2`/;2`0U9BD;018B4P/01@D52`0O7al<00D51@/09RHV2`0R8R8;01HF5P/01@D52`092@T;01hN7P/0
9bLW2`0N7Qh;00/;2`/08B4Q2`0F5QH;00820P`01@D52`010@4;00820P/01@D52`0R8R8;01DE5@H0
oooo00050?ooo`/05aLG2`0;2`/;02DU9@/04Q8B2`051@D;01lO7``01@D52`0V9RH;028R8P/05QHF
2`051@D;00T92@/07QhN2`0W9bL;01hN7P/02`/;2`0Q8B4;01HF5P/00P8230051@D;00410@/00P82
2`051@D;028R8P/05ADE1P3oool000D0oooo2`0G5aL;00/;2`/09BDU2`0B4Q8;00D51@/07alO3005
1@D;02HV9P/08R8R2`0F5QH;00D51@/02@T92`0N7Qh;02LW9`/07QhN2`0;2`/;024Q8@/05QHF2`02
0P8<00D51@/00@412`020P8;00D51@/08R8R2`0E5AD60?ooo`001@3oool;024Q8@/02PX:2`0@410;
00l?3`/00P822`0410@<01@D50/05aLG2`0F5QH;02XZ:P/02`/;2`0S8b<;01TI6@/030`<2`0Y:BTF
00820P/02@T92`0T92@G000000/010@42`010@4;01DE5@/02@T91P3oool000D0oooo2`0Q8B4;00X:
2P/0410@2`0?3`l;00820P/010@4300D51@;01LG5`/05QHF2`0Z:RX;00/;2`/08b<S2`0I6AT;00`<
30/0:BTY5P020P8;00T92@/092@T5`00000;00@410/00@412`0E5AD;00T92@H0oooo00050?ooo`/0
8B4Q2`0:2PX;010@40/03`l?2`020P8;00@410`051@D2`0G5aL;01HF5P/0:RXZ2`0;2`/;02<S8`/0
6ATI2`0<30`;02TY:AH00P822`092@T;02@T91L000002`0410@;00410@/05ADE2`092@T60?ooo`00
1@3oool;024Q8@/02PX:2`0@410;00l?3`/00P822`0410@<01@D50/05aLG2`0F5QH;02XZ:P/02`/;
2`0S8b<;01TI6@/030`<2`0Y:BTF00820P/02@T92`0T92@G000000/010@42`010@4;01DE5@/02@T9
1P3oool000D0oooo2`0Q8B4;00X:2P/0410@2`0?3`l;00820P/010@4300D51@;01LG5`/05QHF2`0Z
:RX;00/;2`/08b<S2`0I6AT;00`<30/0:BTY5P020P8;00T92@/092@T5`00000;00@410/00@412`0E
5AD;00T92@H0oooo00050?ooo`/08B4Q2`0:2PX;010@40/03`l?2`020P8;00@410`051@D2`0G5aL;
01HF5P/0:RXZ2`0;2`/;02<S8`/06ATI2`0<30`;02TY:AH00P822`092@T;02@T91L000002`0410@;
00410@/05ADE2`092@T60?ooo`001@3oool;024Q8@/02PX:2`0@410;00l?3`/00P822`0410@<01@D
50/05aLG2`0F5QH;02XZ:P/02`/;2`0S8b<;01TI6@/030`<2`0Y:BTF00820P/02@T92`0T92@G0000
00/010@42`010@4;01DE5@/02@T91P3oool000D0oooo2`0Q8B4;00X:2P/0410@2`0?3`l;00820P/0
10@4300D51@;01LG5`/05QHF2`0Z:RX;00/;2`/08b<S2`0I6AT;00`<30/0:BTY5P020P8;00T92@/0
92@T5`00000;00@410/00@412`0E5AD;00T92@H0oooo00050?ooo`/08B4Q2`0:2PX;010@40/03`l?
2`020P8;00@410`051@D2`0G5aL;01HF5P/0:RXZ2`0;2`/;02<S8`/06ATI2`0<30`;02TY:AH00P82
2`092@T;02@T91L000002`0410@;00410@/05ADE2`092@T60?ooo`001@3oool;024Q8@/02PX:2`0@
410;00l?3`/00P822`0410@<01@D50/05aLG2`0F5QH;02XZ:P/02`/;2`0S8b<;01TI6@/030`<2`0Y
:BTF00820P/02@T92`0T92@G000000/010@42`010@4;01DE5@/02@T91P3oool000D0oooo2`0Q8B4;
00X:2P/0410@2`0?3`l;00820P/010@4300D51@;01LG5`/05QHF2`0Z:RX;00/;2`/08b<S2`0I6AT;
00`<30/0:BTY5P020P8;00T92@/092@T5`00000;00@410/00@412`0E5AD;00T92@H0oooo00050?oo
o`/08b<S2`0L71`F00H61P/07QhN2`071`LG01XJ6P/07QhN2`0W9bL;024Q8@/00@412`0B4Q8;02LW
9`/07alO2`0Y:BT;00P820/00`<32`0N7Qh<02TY:@/010@42`020P8;00P820/0820P2`0;2`/60?oo
o`001@3oool;02<S8`/071`L5P061PH;01hN7P/01`L75`0J6QX;01hN7P/09bLW2`0Q8B4;00410@/0
4Q8B2`0W9bL;01lO7`/0:BTY2`0820P;00<30`/07QhN300Y:BT;00@410/00P822`0820P;020P80/0
2`/;1P3oool000D0oooo2`0S8b<;01`L71H01PH62`0N7Qh;00L71aL06QXJ2`0N7Qh;02LW9`/08B4Q
2`010@4;018B4P/09bLW2`0O7al;02TY:@/020P82`030`<;01hN7P`0:BTY2`0410@;00820P/020P8
2`0P820;00/;2`H0oooo00050?ooo`/08b<S2`0L71`F00H61P/07QhN2`071`LG01XJ6P/07QhN2`0W
9bL;024Q8@/00@412`0B4Q8;02LW9`/07alO2`0Y:BT;00P820/00`<32`0N7Qh<02TY:@/010@42`02
0P8;00P820/0820P2`0;2`/60?ooo`001@3oool;02<S8`/071`L5P061PH;01hN7P/01`L75`0J6QX;
01hN7P/09bLW2`0Q8B4;00410@/04Q8B2`0W9bL;01lO7`/0:BTY2`0820P;00<30`/07QhN300Y:BT;
00@410/00P822`0820P;020P80/02`/;1P3oool000D0oooo2`0S8b<;01`L71H01PH62`0N7Qh;00L7
1aL06QXJ2`0N7Qh;02LW9`/08B4Q2`010@4;018B4P/09bLW2`0O7al;02TY:@/020P82`030`<;01hN
7P`0:BTY2`0410@;00820P/020P82`0P820;00/;2`H0oooo00050?ooo`/08b<S2`0L71`F00H61P/0
7QhN2`071`LG01XJ6P/07QhN2`0W9bL;024Q8@/00@412`0B4Q8;02LW9`/07alO2`0Y:BT;00P820/0
0`<32`0N7Qh<02TY:@/010@42`020P8;00P820/0820P2`0;2`/60?ooo`001@3oool;02<S8`/071`L
5P061PH;01hN7P/01`L75`0J6QX;01hN7P/09bLW2`0Q8B4;00410@/04Q8B2`0W9bL;01lO7`/0:BTY
2`0820P;00<30`/07QhN300Y:BT;00@410/00P822`0820P;020P80/02`/;1P3oool000D0oooo2`0S
8b<;01`L71H01PH62`0N7Qh;00L71aL06QXJ2`0N7Qh;02LW9`/08B4Q2`010@4;018B4P/09bLW2`0O
7al;02TY:@/020P82`030`<;01hN7P`0:BTY2`0410@;00820P/020P82`0P820;00/;2`H0oooo0005
0?ooo`/08b<S2`0L71`F00H61P/07QhN2`071`LG01XJ6P/07QhN2`0W9bL;024Q8@/00@412`0B4Q8;
02LW9`/07alO2`0Y:BT;00P820/00`<32`0N7Qh<02TY:@/010@42`020P8;00P820/0820P2`0;2`/6
0?ooo`001@3oool;02<S8`/071`L5P061PH;01hN7P/01`L75`0J6QX;01hN7P/09bLW2`0Q8B4;0041
0@/04Q8B2`0W9bL;01lO7`/0:BTY2`0820P;00<30`/07QhN300Y:BT;00@410/00P822`0820P;020P
80/02`/;1P3oool000D0oooo2`0@410;00820P/06ATI2`0G5aL;00T92@/04Q8B300Y:BT;02<S8`/0
30`<2`0K6a/;02LW9`/0410@2`0?3`l;02LW9`/0:2PX2`071`L;00`<30/020P82`0Y:BT<00820P/0
2PX:2`00000;00T92@/08B4Q2`0T92@60?ooo`001@3oool;010@40/00P822`0I6AT;01LG5`/02@T9
2`0B4Q8<02TY:@/08b<S2`0<30`;01/K6`/09bLW2`0@410;00l?3`/09bLW2`0X:2P;00L71`/030`<
2`0820P;02TY:@`00P822`0:2PX;000000/02@T92`0Q8B4;02@T90H0oooo00050?ooo`/0410@2`02
0P8;01TI6@/05aLG2`092@T;018B4P`0:BTY2`0S8b<;00`<30/06a/K2`0W9bL;010@40/03`l?2`0W
9bL;02PX:0/01`L72`0<30`;00P820/0:BTY30020P8;00X:2P/000002`092@T;024Q8@/092@T1P3o
ool000D0oooo2`0@410;00820P/06ATI2`0G5aL;00T92@/04Q8B300Y:BT;02<S8`/030`<2`0K6a/;
02LW9`/0410@2`0?3`l;02LW9`/0:2PX2`071`L;00`<30/020P82`0Y:BT<00820P/02PX:2`00000;
00T92@/08B4Q2`0T92@60?ooo`001@3oool;010@40/00P822`0I6AT;01LG5`/02@T92`0B4Q8<02TY
:@/08b<S2`0<30`;01/K6`/09bLW2`0@410;00l?3`/09bLW2`0X:2P;00L71`/030`<2`0820P;02TY
:@`00P822`0:2PX;000000/02@T92`0Q8B4;02@T90H0oooo00050?ooo`/0410@2`020P8;01TI6@/0
5aLG2`092@T;018B4P`0:BTY2`0S8b<;00`<30/06a/K2`0W9bL;010@40/03`l?2`0W9bL;02PX:0/0
1`L72`0<30`;00P820/0:BTY30020P8;00X:2P/000002`092@T;024Q8@/092@T1P3oool000D0oooo
2`0@410;00820P/06ATI2`0G5aL;00T92@/04Q8B300Y:BT;02<S8`/030`<2`0K6a/;02LW9`/0410@
2`0?3`l;02LW9`/0:2PX2`071`L;00`<30/020P82`0Y:BT<00820P/02PX:2`00000;00T92@/08B4Q
2`0T92@60?ooo`001@3oool;010@40/00P822`0I6AT;01LG5`/02@T92`0B4Q8<02TY:@/08b<S2`0<
30`;01/K6`/09bLW2`0@410;00l?3`/09bLW2`0X:2P;00L71`/030`<2`0820P;02TY:@`00P822`0:
2PX;000000/02@T92`0Q8B4;02@T90H0oooo00050?ooo`/0410@2`020P8;01TI6@/05aLG2`092@T;
018B4P`0:BTY2`0S8b<;00`<30/06a/K2`0W9bL;010@40/03`l?2`0W9bL;02PX:0/01`L72`0<30`;
00P820/0:BTY30020P8;00X:2P/000002`092@T;024Q8@/092@T1P3oool000D0oooo2`0@410;0082
0P/06ATI2`0G5aL;00T92@/04Q8B300Y:BT;02<S8`/030`<2`0K6a/;02LW9`/0410@2`0?3`l;02LW
9`/0:2PX2`071`L;00`<30/020P82`0Y:BT<00820P/02PX:2`00000;00T92@/08B4Q2`0T92@60?oo
o`001@3oool;010@40/00P822`0I6AT;01LG5`/02@T92`0B4Q8<02TY:@/08b<S2`0<30`;01/K6`/0
9bLW2`0@410;00l?3`/09bLW2`0X:2P;00L71`/030`<2`0820P;02TY:@`00P822`0:2PX;000000/0
2@T92`0Q8B4;02@T90H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B
2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B
2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F
5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N
7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;
00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;
0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?oo
o`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?kn
oP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P
80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0
m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/0
00002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B
2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B
2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F
5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N
7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;
00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;
0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?oo
o`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?kn
oP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/000002`0H61P;020P
80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B2`0=3@d;0?[jnP/0
m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B2`0N7Qh;01TI6@/0
00002`0H61P;020P80H0oooo00050?ooo`/0:2PX2`0J6QX;00X:2P/06QXJ2`0F5QH;01/K6``04Q8B
2`0=3@d;0?[jnP/0m?Cd2`3GemL;0?knoP/0oOgm2`3fm_H;0?[jnP/0lO7a2`0N7QhF028R8P`04Q8B
2`0N7Qh;01TI6@/000002`0H61P;020P80H0oooo00050?ooo`/0:BTY2`0P820;02PX:0/02PX:2`0=
3@d;00h>3P`06QXJ2`0@410;0>o_k`/0h^;R2`3bl_8;0>SXj0/0n?Sh2`3Xj>P;0=KFeP/0m?Cd2`00
000;01XJ6P/06ATI3000000;014A4@/06QXJ2`00000;00X:2P/04Q8B1P3oool000D0oooo2`0Y:BT;
020P80/0:2PX2`0:2PX;00d=3@/03Ph>300J6QX;010@40/0kno_2`3Rh^8;0?;blP/0j>SX2`3hn?P;
0>SXj0/0e]KF2`3dm?@;000000/06QXJ2`0I6AT<000000/04A4A2`0J6QX;000000/02PX:2`0B4Q86
0?ooo`001@3oool;02TY:@/0820P2`0X:2P;00X:2P/03@d=2`0>3Ph<01XJ6P/0410@2`3_knl;0>;R
hP/0l_;b2`3Xj>P;0?Shn0/0j>SX2`3Fe]H;0?Cdm0/000002`0J6QX;01TI6@`000002`0A4A4;01XJ
6P/000002`0:2PX;018B4PH0oooo00050?ooo`/0:BTY2`0P820;02PX:0/02PX:2`0=3@d;00h>3P`0
6QXJ2`0@410;0>o_k`/0h^;R2`3bl_8;0>SXj0/0n?Sh2`3Xj>P;0=KFeP/0m?Cd2`00000;01XJ6P/0
6ATI3000000;014A4@/06QXJ2`00000;00X:2P/04Q8B1P3oool000D0oooo2`0Y:BT;020P80/0:2PX
2`0:2PX;00d=3@/03Ph>300J6QX;010@40/0kno_2`3Rh^8;0?;blP/0j>SX2`3hn?P;0>SXj0/0e]KF
2`3dm?@;000000/06QXJ2`0I6AT<000000/04A4A2`0J6QX;000000/02PX:2`0B4Q860?ooo`001@3o
ool;02TY:@/0820P2`0X:2P;00X:2P/03@d=2`0>3Ph<01XJ6P/0410@2`3_knl;0>;RhP/0l_;b2`3X
j>P;0?Shn0/0j>SX2`3Fe]H;0?Cdm0/000002`0J6QX;01TI6@`000002`0A4A4;01XJ6P/000002`0:
2PX;018B4PH0oooo00050?ooo`/0:BTY2`0P820;02PX:0/02PX:2`0=3@d;00h>3P`06QXJ2`0@410;
0>o_k`/0h^;R2`3bl_8;0>SXj0/0n?Sh2`3Xj>P;0=KFeP/0m?Cd2`00000;01XJ6P/06ATI3000000;
014A4@/06QXJ2`00000;00X:2P/04Q8B1P3oool000D0oooo2`0Y:BT;020P80/0:2PX2`0:2PX;00d=
3@/03Ph>300J6QX;010@40/0kno_2`3Rh^8;0?;blP/0j>SX2`3hn?P;0>SXj0/0e]KF2`3dm?@;0000
00/06QXJ2`0I6AT<000000/04A4A2`0J6QX;000000/02PX:2`0B4Q860?ooo`001@3oool;02TY:@/0
820P2`0X:2P;00X:2P/03@d=2`0>3Ph<01XJ6P/0410@2`3_knl;0>;RhP/0l_;b2`3Xj>P;0?Shn0/0
j>SX2`3Fe]H;0?Cdm0/000002`0J6QX;01TI6@`000002`0A4A4;01XJ6P/000002`0:2PX;018B4PH0
oooo00050?ooo`/0:BTY2`0P820;02PX:0/02PX:2`0=3@d;00h>3P`06QXJ2`0@410;0>o_k`/0h^;R
2`3bl_8;0>SXj0/0n?Sh2`3Xj>P;0=KFeP/0m?Cd2`00000;01XJ6P/06ATI3000000;014A4@/06QXJ
2`00000;00X:2P/04Q8B1P3oool000D0oooo2`0Y:BT;020P80/0:2PX2`0:2PX;00d=3@/03Ph>300J
6QX;010@40/0kno_2`3Rh^8;0?;blP/0j>SX2`3hn?P;0>SXj0/0e]KF2`3dm?@;000000/06QXJ2`0I
6AT<000000/04A4A2`0J6QX;000000/02PX:2`0B4Q860?ooo`001@3oool;02@T90/00P822`00000;
00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;
0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T
90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?Kf
mP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?oo
o`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0
g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/0
8b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF
2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF
2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B
4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A
4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;
00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;
0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T
90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?Kf
mP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?oo
o`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0
g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/0
8b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B4Q8<01XJ6P/05QHF
2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A4A4<00/;2`/05QHF
2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;00@410/05ADE2`0B
4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;0?;blQH01@D52`0A
4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;02@T90/00P822`00000;
00@410/05ADE2`0B4Q8<01XJ6P/05QHF2`3Ng]h;0?Gem@/0g=cL2`3clo<;0?KfmP/0m?Cd2`3Xj>P;
0?;blQH01@D52`0A4A4<00/;2`/05QHF2`0410@;00L71`/08b<S2`0L71`60?ooo`001@3oool;0041
0@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D5
1@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?oo
o`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0
j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/0
9BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY
2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV
2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G
5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E
5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;
00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;
00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;0041
0@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D5
1@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?oo
o`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0
j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/0
9BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY
2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV
2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;00L71`/06QXJ2`0G
5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;00<30`/000002`0E
5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;00410@/01PH62`0N7Qh;
00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D51@/09bLW2`0R8R8;
00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?ooo`001@3oool;0041
0@/01PH62`0N7Qh;00L71`/06QXJ2`0G5aL<00P820/0:BTY2`3jn_X;0>GUi@/0j^[Z2`092@T;00D5
1@/09bLW2`0R8R8;00<30`/000002`0E5ADG01LG5`/09RHV2`0>3Ph;01hN7P/09BDU2`0T92@60?oo
o`001@3oool;00L71`/0:RXZ2`0M7Ad;00X:2P/06a/K2`0R8R8<01hN7P/03`l?2`3QhN4;0>;RhP/0
jn_[2`092@T;00h>3P/051@D2`0B4Q8;00T92@/08R8R2`0X:2P;02DU9@`03@d=2`0D51@;00T92@/0
00002`0C4a<;00`<30H0oooo00050?ooo`/01`L72`0Z:RX;01dM7@/02PX:2`0K6a/;028R8P`07QhN
2`0?3`l;0>7Qh@/0h^;R2`3[jn/;00T92@/03Ph>2`0D51@;018B4P/02@T92`0R8R8;02PX:0/09BDU
300=3@d;01@D50/02@T92`00000;01<C4`/030`<1P3oool000D0oooo2`071`L;02XZ:P/07AdM2`0:
2PX;01/K6`/08R8R300N7Qh;00l?3`/0hN7Q2`3Rh^8;0>_[j`/02@T92`0>3Ph;01@D50/04Q8B2`09
2@T;028R8P/0:2PX2`0U9BD<00d=3@/051@D2`092@T;000000/04a<C2`0<30`60?ooo`001@3oool;
00L71`/0:RXZ2`0M7Ad;00X:2P/06a/K2`0R8R8<01hN7P/03`l?2`3QhN4;0>;RhP/0jn_[2`092@T;
00h>3P/051@D2`0B4Q8;00T92@/08R8R2`0X:2P;02DU9@`03@d=2`0D51@;00T92@/000002`0C4a<;
00`<30H0oooo00050?ooo`/01`L72`0Z:RX;01dM7@/02PX:2`0K6a/;028R8P`07QhN2`0?3`l;0>7Q
h@/0h^;R2`3[jn/;00T92@/03Ph>2`0D51@;018B4P/02@T92`0R8R8;02PX:0/09BDU300=3@d;01@D
50/02@T92`00000;01<C4`/030`<1P3oool000D0oooo2`071`L;02XZ:P/07AdM2`0:2PX;01/K6`/0
8R8R300N7Qh;00l?3`/0hN7Q2`3Rh^8;0>_[j`/02@T92`0>3Ph;01@D50/04Q8B2`092@T;028R8P/0
:2PX2`0U9BD<00d=3@/051@D2`092@T;000000/04a<C2`0<30`60?ooo`001@3oool;00L71`/0:RXZ
2`0M7Ad;00X:2P/06a/K2`0R8R8<01hN7P/03`l?2`3QhN4;0>;RhP/0jn_[2`092@T;00h>3P/051@D
2`0B4Q8;00T92@/08R8R2`0X:2P;02DU9@`03@d=2`0D51@;00T92@/000002`0C4a<;00`<30H0oooo
00050?ooo`/01`L72`0Z:RX;01dM7@/02PX:2`0K6a/;028R8P`07QhN2`0?3`l;0>7Qh@/0h^;R2`3[
jn/;00T92@/03Ph>2`0D51@;018B4P/02@T92`0R8R8;02PX:0/09BDU300=3@d;01@D50/02@T92`00
000;01<C4`/030`<1P3oool000D0oooo2`071`L;02XZ:P/07AdM2`0:2PX;01/K6`/08R8R300N7Qh;
00l?3`/0hN7Q2`3Rh^8;0>_[j`/02@T92`0>3Ph;01@D50/04Q8B2`092@T;028R8P/0:2PX2`0U9BD<
00d=3@/051@D2`092@T;000000/04a<C2`0<30`60?ooo`001@3oool;00L71`/0:RXZ2`0M7Ad;00X:
2P/06a/K2`0R8R8<01hN7P/03`l?2`3QhN4;0>;RhP/0jn_[2`092@T;00h>3P/051@D2`0B4Q8;00T9
2@/08R8R2`0X:2P;02DU9@`03@d=2`0D51@;00T92@/000002`0C4a<;00`<30H0oooo00050?ooo`/0
1`L72`0Z:RX;01dM7@/02PX:2`0K6a/;028R8P`07QhN2`0?3`l;0>7Qh@/0h^;R2`3[jn/;00T92@/0
3Ph>2`0D51@;018B4P/02@T92`0R8R8;02PX:0/09BDU300=3@d;01@D50/02@T92`00000;01<C4`/0
30`<1P3oool000D0oooo2`0:2PX;00`<30/02@T92`0K6a/;018B4P/061PH300T92@;010@40/0fm_K
2`3Hf=P;0?3`l0/0emOG2`3alO4;0?3`l0/0inOW2`3Ogml;01dM7@/07alO2`0410@<020P80/04a<C
2`0O7al;01/K6`/051@D2`092@T60?ooo`001@3oool;00X:2P/030`<2`092@T;01/K6`/04Q8B2`0H
61P<02@T90/0410@2`3Kfm/;0=SHf0/0l?3`2`3GemL;0?7al@/0l?3`2`3WinL;0=oOg`/07AdM2`0O
7al;00@410`0820P2`0C4a<;01lO7`/06a/K2`0D51@;00T92@H0oooo00050?ooo`/02PX:2`0<30`;
00T92@/06a/K2`0B4Q8;01PH60`092@T2`0@410;0=_Kf`/0f=SH2`3`l?0;0=OGe`/0lO7a2`3`l?0;
0>OWi`/0gmoO2`0M7Ad;01lO7`/010@4300P820;01<C4`/07alO2`0K6a/;01@D50/02@T91P3oool0
00D0oooo2`0:2PX;00`<30/02@T92`0K6a/;018B4P/061PH300T92@;010@40/0fm_K2`3Hf=P;0?3`
l0/0emOG2`3alO4;0?3`l0/0inOW2`3Ogml;01dM7@/07alO2`0410@<020P80/04a<C2`0O7al;01/K
6`/051@D2`092@T60?ooo`001@3oool;00X:2P/030`<2`092@T;01/K6`/04Q8B2`0H61P<02@T90/0
410@2`3Kfm/;0=SHf0/0l?3`2`3GemL;0?7al@/0l?3`2`3WinL;0=oOg`/07AdM2`0O7al;00@410`0
820P2`0C4a<;01lO7`/06a/K2`0D51@;00T92@H0oooo00050?ooo`/02PX:2`0<30`;00T92@/06a/K
2`0B4Q8;01PH60`092@T2`0@410;0=_Kf`/0f=SH2`3`l?0;0=OGe`/0lO7a2`3`l?0;0>OWi`/0gmoO
2`0M7Ad;01lO7`/010@4300P820;01<C4`/07alO2`0K6a/;01@D50/02@T91P3oool000D0oooo2`0:
2PX;00`<30/02@T92`0K6a/;018B4P/061PH300T92@;010@40/0fm_K2`3Hf=P;0?3`l0/0emOG2`3a
lO4;0?3`l0/0inOW2`3Ogml;01dM7@/07alO2`0410@<020P80/04a<C2`0O7al;01/K6`/051@D2`09
2@T60?ooo`001@3oool;00X:2P/030`<2`092@T;01/K6`/04Q8B2`0H61P<02@T90/0410@2`3Kfm/;
0=SHf0/0l?3`2`3GemL;0?7al@/0l?3`2`3WinL;0=oOg`/07AdM2`0O7al;00@410`0820P2`0C4a<;
01lO7`/06a/K2`0D51@;00T92@H0oooo00050?ooo`/02PX:2`0<30`;00T92@/06a/K2`0B4Q8;01PH
60`092@T2`0@410;0=_Kf`/0f=SH2`3`l?0;0=OGe`/0lO7a2`3`l?0;0>OWi`/0gmoO2`0M7Ad;01lO
7`/010@4300P820;01<C4`/07alO2`0K6a/;01@D50/02@T91P3oool000D0oooo2`0:2PX;00`<30/0
2@T92`0K6a/;018B4P/061PH300T92@;010@40/0fm_K2`3Hf=P;0?3`l0/0emOG2`3alO4;0?3`l0/0
inOW2`3Ogml;01dM7@/07alO2`0410@<020P80/04a<C2`0O7al;01/K6`/051@D2`092@T60?ooo`00
1@3oool;00X:2P/030`<2`092@T;01/K6`/04Q8B2`0H61P<02@T90/0410@2`3Kfm/;0=SHf0/0l?3`
2`3GemL;0?7al@/0l?3`2`3WinL;0=oOg`/07AdM2`0O7al;00@410`0820P2`0C4a<;01lO7`/06a/K
2`0D51@;00T92@H0oooo00050?ooo`/04Q8B2`0A4A4;02<S8`/08B4Q2`0U9BD;01LG5``04a<C2`0L
71`;0?Shn0/0oOgm2`3Vi^H;0=KFeP/0gMgM2`3[jn/;0=cLg0/0hn?S2`0B4Q8;014A4@/0410@300T
92@;01dM7@/0820P2`0W9bL;01/K6`/02PX:1P3oool000D0oooo2`0B4Q8;014A4@/08b<S2`0Q8B4;
02DU9@/05aLG300C4a<;01`L70/0n?Sh2`3moOd;0>KViP/0e]KF2`3MgMd;0>_[j`/0g=cL2`3Shn<;
018B4P/04A4A2`0@410<02@T90/07AdM2`0P820;02LW9`/06a/K2`0:2PX60?ooo`001@3oool;018B
4P/04A4A2`0S8b<;024Q8@/09BDU2`0G5aL<01<C4`/071`L2`3hn?P;0?gmo@/0i^KV2`3Fe]H;0=gM
g@/0jn_[2`3Lg=`;0>?Sh`/04Q8B2`0A4A4;010@40`092@T2`0M7Ad;020P80/09bLW2`0K6a/;00X:
2PH0oooo00050?ooo`/04Q8B2`0A4A4;02<S8`/08B4Q2`0U9BD;01LG5``04a<C2`0L71`;0?Shn0/0
oOgm2`3Vi^H;0=KFeP/0gMgM2`3[jn/;0=cLg0/0hn?S2`0B4Q8;014A4@/0410@300T92@;01dM7@/0
820P2`0W9bL;01/K6`/02PX:1P3oool000D0oooo2`0B4Q8;014A4@/08b<S2`0Q8B4;02DU9@/05aLG
300C4a<;01`L70/0n?Sh2`3moOd;0>KViP/0e]KF2`3MgMd;0>_[j`/0g=cL2`3Shn<;018B4P/04A4A
2`0@410<02@T90/07AdM2`0P820;02LW9`/06a/K2`0:2PX60?ooo`001@3oool;018B4P/04A4A2`0S
8b<;024Q8@/09BDU2`0G5aL<01<C4`/071`L2`3hn?P;0?gmo@/0i^KV2`3Fe]H;0=gMg@/0jn_[2`3L
g=`;0>?Sh`/04Q8B2`0A4A4;010@40`092@T2`0M7Ad;020P80/09bLW2`0K6a/;00X:2PH0oooo0005
0?ooo`/04Q8B2`0A4A4;02<S8`/08B4Q2`0U9BD;01LG5``04a<C2`0L71`;0?Shn0/0oOgm2`3Vi^H;
0=KFeP/0gMgM2`3[jn/;0=cLg0/0hn?S2`0B4Q8;014A4@/0410@300T92@;01dM7@/0820P2`0W9bL;
01/K6`/02PX:1P3oool000D0oooo2`0B4Q8;014A4@/08b<S2`0Q8B4;02DU9@/05aLG300C4a<;01`L
70/0n?Sh2`3moOd;0>KViP/0e]KF2`3MgMd;0>_[j`/0g=cL2`3Shn<;018B4P/04A4A2`0@410<02@T
90/07AdM2`0P820;02LW9`/06a/K2`0:2PX60?ooo`001@3oool;018B4P/04A4A2`0S8b<;024Q8@/0
9BDU2`0G5aL<01<C4`/071`L2`3hn?P;0?gmo@/0i^KV2`3Fe]H;0=gMg@/0jn_[2`3Lg=`;0>?Sh`/0
4Q8B2`0A4A4;010@40`092@T2`0M7Ad;020P80/09bLW2`0K6a/;00X:2PH0oooo00050?ooo`/04Q8B
2`0A4A4;02<S8`/08B4Q2`0U9BD;01LG5``04a<C2`0L71`;0?Shn0/0oOgm2`3Vi^H;0=KFeP/0gMgM
2`3[jn/;0=cLg0/0hn?S2`0B4Q8;014A4@/0410@300T92@;01dM7@/0820P2`0W9bL;01/K6`/02PX:
1P3oool000D0oooo2`0B4Q8;014A4@/08b<S2`0Q8B4;02DU9@/05aLG300C4a<;01`L70/0n?Sh2`3m
oOd;0>KViP/0e]KF2`3MgMd;0>_[j`/0g=cL2`3Shn<;018B4P/04A4A2`0@410<02@T90/07AdM2`0P
820;02LW9`/06a/K2`0:2PX60?ooo`001@3oool;00h>3P/00`<32`0T92@;010@40/08B4Q2`0K6a/<
00P820/061PH2`3jn_X;0=oOg`/0gMgM2`3Vi^H;0>CTi0/0f=SH2`3jn_X;0?knoP/09bLW2`0L71`;
02XZ:P`02`/;2`071`L;020P80/03`l?2`00000;02<S8`H0oooo00050?ooo`/03Ph>2`030`<;02@T
90/0410@2`0Q8B4;01/K6``020P82`0H61P;0?[jnP/0gmoO2`3MgMd;0>KViP/0i>CT2`3Hf=P;0?[j
nP/0o_kn2`0W9bL;01`L70/0:RXZ300;2`/;00L71`/0820P2`0?3`l;000000/08b<S1P3oool000D0
oooo2`0>3Ph;00<30`/092@T2`0@410;024Q8@/06a/K300820P;01PH60/0n_[j2`3Ogml;0=gMg@/0
i^KV2`3Ti>@;0=SHf0/0n_[j2`3no_h;02LW9`/071`L2`0Z:RX<00/;2`/01`L72`0P820;00l?3`/0
00002`0S8b<60?ooo`001@3oool;00h>3P/00`<32`0T92@;010@40/08B4Q2`0K6a/<00P820/061PH
2`3jn_X;0=oOg`/0gMgM2`3Vi^H;0>CTi0/0f=SH2`3jn_X;0?knoP/09bLW2`0L71`;02XZ:P`02`/;
2`071`L;020P80/03`l?2`00000;02<S8`H0oooo00050?ooo`/03Ph>2`030`<;02@T90/0410@2`0Q
8B4;01/K6``020P82`0H61P;0?[jnP/0gmoO2`3MgMd;0>KViP/0i>CT2`3Hf=P;0?[jnP/0o_kn2`0W
9bL;01`L70/0:RXZ300;2`/;00L71`/0820P2`0?3`l;000000/08b<S1P3oool000D0oooo2`0>3Ph;
00<30`/092@T2`0@410;024Q8@/06a/K300820P;01PH60/0n_[j2`3Ogml;0=gMg@/0i^KV2`3Ti>@;
0=SHf0/0n_[j2`3no_h;02LW9`/071`L2`0Z:RX<00/;2`/01`L72`0P820;00l?3`/000002`0S8b<6
0?ooo`001@3oool;00h>3P/00`<32`0T92@;010@40/08B4Q2`0K6a/<00P820/061PH2`3jn_X;0=oO
g`/0gMgM2`3Vi^H;0>CTi0/0f=SH2`3jn_X;0?knoP/09bLW2`0L71`;02XZ:P`02`/;2`071`L;020P
80/03`l?2`00000;02<S8`H0oooo00050?ooo`/03Ph>2`030`<;02@T90/0410@2`0Q8B4;01/K6``0
20P82`0H61P;0?[jnP/0gmoO2`3MgMd;0>KViP/0i>CT2`3Hf=P;0?[jnP/0o_kn2`0W9bL;01`L70/0
:RXZ300;2`/;00L71`/0820P2`0?3`l;000000/08b<S1P3oool000D0oooo2`0>3Ph;00<30`/092@T
2`0@410;024Q8@/06a/K300820P;01PH60/0n_[j2`3Ogml;0=gMg@/0i^KV2`3Ti>@;0=SHf0/0n_[j
2`3no_h;02LW9`/071`L2`0Z:RX<00/;2`/01`L72`0P820;00l?3`/000002`0S8b<60?ooo`001@3o
ool;00h>3P/00`<32`0T92@;010@40/08B4Q2`0K6a/<00P820/061PH2`3jn_X;0=oOg`/0gMgM2`3V
i^H;0>CTi0/0f=SH2`3jn_X;0?knoP/09bLW2`0L71`;02XZ:P`02`/;2`071`L;020P80/03`l?2`00
000;02<S8`H0oooo00050?ooo`/03Ph>2`030`<;02@T90/0410@2`0Q8B4;01/K6``020P82`0H61P;
0?[jnP/0gmoO2`3MgMd;0>KViP/0i>CT2`3Hf=P;0?[jnP/0o_kn2`0W9bL;01`L70/0:RXZ300;2`/;
00L71`/0820P2`0?3`l;000000/08b<S1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=
3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;
2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/0
6QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/0
9RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo
2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN
2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI
1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3a
lO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A
4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;
0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;
00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=
3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;
2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/0
6QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/0
9RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo
2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN
2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI
1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;0?Ogm`/0fm_K2`3a
lO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;00/;2`/09bLW2`0A
4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=3@`00@412`071`L;
0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;2`/04A4A300N7Qh;
00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo2`0L71`;01DE5@/06QXJ5P010@4;00d=
3@`00@412`071`L;0?Ogm`/0fm_K2`3alO4;02<S8`/07QhN2`0;2`/;01`L70/09RHV2`010@4;00/;
2`/04A4A300N7Qh;00/;2`/09bLW2`0A4A4;02HV9P/06ATI1P3oool000D0oooo2`0A4A4;024Q8@/0
92@T2`0H61P;00@410/07alO300M7Ad;028R8P/0oooo2`3IfMT;0?Win@/00`<32`0M7Ad;014A4@/0
:2PX2`020P8;014A4@/000002`092@T<024Q8@/05ADE2`0I6AT;00h>3P/01`L72`030`<60?ooo`00
1@3oool;014A4@/08B4Q2`0T92@;01PH60/010@42`0O7al<01dM7@/08R8R2`3oool;0=WIf@/0nOWi
2`030`<;01dM7@/04A4A2`0X:2P;00820P/04A4A2`00000;00T92@`08B4Q2`0E5AD;01TI6@/03Ph>
2`071`L;00<30`H0oooo00050?ooo`/04A4A2`0Q8B4;02@T90/061PH2`0410@;01lO7``07AdM2`0R
8R8;0?ooo`/0fMWI2`3inOT;00<30`/07AdM2`0A4A4;02PX:0/00P822`0A4A4;000000/02@T9300Q
8B4;01DE5@/06ATI2`0>3Ph;00L71`/00`<31P3oool000D0oooo2`0A4A4;024Q8@/092@T2`0H61P;
00@410/07alO300M7Ad;028R8P/0oooo2`3IfMT;0?Win@/00`<32`0M7Ad;014A4@/0:2PX2`020P8;
014A4@/000002`092@T<024Q8@/05ADE2`0I6AT;00h>3P/01`L72`030`<60?ooo`001@3oool;014A
4@/08B4Q2`0T92@;01PH60/010@42`0O7al<01dM7@/08R8R2`3oool;0=WIf@/0nOWi2`030`<;01dM
7@/04A4A2`0X:2P;00820P/04A4A2`00000;00T92@`08B4Q2`0E5AD;01TI6@/03Ph>2`071`L;00<3
0`H0oooo00050?ooo`/04A4A2`0Q8B4;02@T90/061PH2`0410@;01lO7``07AdM2`0R8R8;0?ooo`/0
fMWI2`3inOT;00<30`/07AdM2`0A4A4;02PX:0/00P822`0A4A4;000000/02@T9300Q8B4;01DE5@/0
6ATI2`0>3Ph;00L71`/00`<31P3oool000D0oooo2`0A4A4;024Q8@/092@T2`0H61P;00@410/07alO
300M7Ad;028R8P/0oooo2`3IfMT;0?Win@/00`<32`0M7Ad;014A4@/0:2PX2`020P8;014A4@/00000
2`092@T<024Q8@/05ADE2`0I6AT;00h>3P/01`L72`030`<60?ooo`001@3oool;014A4@/08B4Q2`0T
92@;01PH60/010@42`0O7al<01dM7@/08R8R2`3oool;0=WIf@/0nOWi2`030`<;01dM7@/04A4A2`0X
:2P;00820P/04A4A2`00000;00T92@`08B4Q2`0E5AD;01TI6@/03Ph>2`071`L;00<30`H0oooo0005
0?ooo`/04A4A2`0Q8B4;02@T90/061PH2`0410@;01lO7``07AdM2`0R8R8;0?ooo`/0fMWI2`3inOT;
00<30`/07AdM2`0A4A4;02PX:0/00P822`0A4A4;000000/02@T9300Q8B4;01DE5@/06ATI2`0>3Ph;
00L71`/00`<31P3oool000D0oooo2`0A4A4;024Q8@/092@T2`0H61P;00@410/07alO300M7Ad;028R
8P/0oooo2`3IfMT;0?Win@/00`<32`0M7Ad;014A4@/0:2PX2`020P8;014A4@/000002`092@T<024Q
8@/05ADE2`0I6AT;00h>3P/01`L72`030`<60?ooo`001@3oool;014A4@/08B4Q2`0T92@;01PH60/0
10@42`0O7al<01dM7@/08R8R2`3oool;0=WIf@/0nOWi2`030`<;01dM7@/04A4A2`0X:2P;00820P/0
4A4A2`00000;00T92@`08B4Q2`0E5AD;01TI6@/03Ph>2`071`L;00<30`H0oooo00050?ooo`/08b<S
2`0C4a<;01TI6@/0:BTY2`030`<;024Q8@`08R8R2`00000;0?ooo`/0oOgm2`3dm?@;0>;RhP/0k^k^
2`3oool;0?7al@/0no_k2`0H61P;01lO7`/092@T300@410;02TY:@/04A4A2`0M7Ad;00d=3@/01@D5
1P3oool000D0oooo2`0S8b<;01<C4`/06ATI2`0Y:BT;00<30`/08B4Q300R8R8;000000/0oooo2`3m
oOd;0?Cdm0/0h^;R2`3^k^h;0?ooo`/0lO7a2`3kno/;01PH60/07alO2`0T92@<010@40/0:BTY2`0A
4A4;01dM7@/03@d=2`051@D60?ooo`001@3oool;02<S8`/04a<C2`0I6AT;02TY:@/00`<32`0Q8B4<
028R8P/000002`3oool;0?gmo@/0m?Cd2`3Rh^8;0>k^kP/0oooo2`3alO4;0?_kn`/061PH2`0O7al;
02@T90`0410@2`0Y:BT;014A4@/07AdM2`0=3@d;00D51@H0oooo00050?ooo`/08b<S2`0C4a<;01TI
6@/0:BTY2`030`<;024Q8@`08R8R2`00000;0?ooo`/0oOgm2`3dm?@;0>;RhP/0k^k^2`3oool;0?7a
l@/0no_k2`0H61P;01lO7`/092@T300@410;02TY:@/04A4A2`0M7Ad;00d=3@/01@D51P3oool000D0
oooo2`0S8b<;01<C4`/06ATI2`0Y:BT;00<30`/08B4Q300R8R8;000000/0oooo2`3moOd;0?Cdm0/0
h^;R2`3^k^h;0?ooo`/0lO7a2`3kno/;01PH60/07alO2`0T92@<010@40/0:BTY2`0A4A4;01dM7@/0
3@d=2`051@D60?ooo`001@3oool;02<S8`/04a<C2`0I6AT;02TY:@/00`<32`0Q8B4<028R8P/00000
2`3oool;0?gmo@/0m?Cd2`3Rh^8;0>k^kP/0oooo2`3alO4;0?_kn`/061PH2`0O7al;02@T90`0410@
2`0Y:BT;014A4@/07AdM2`0=3@d;00D51@H0oooo00050?ooo`/08b<S2`0C4a<;01TI6@/0:BTY2`03
0`<;024Q8@`08R8R2`00000;0?ooo`/0oOgm2`3dm?@;0>;RhP/0k^k^2`3oool;0?7al@/0no_k2`0H
61P;01lO7`/092@T300@410;02TY:@/04A4A2`0M7Ad;00d=3@/01@D51P3oool000D0oooo2`0S8b<;
01<C4`/06ATI2`0Y:BT;00<30`/08B4Q300R8R8;000000/0oooo2`3moOd;0?Cdm0/0h^;R2`3^k^h;
0?ooo`/0lO7a2`3kno/;01PH60/07alO2`0T92@<010@40/0:BTY2`0A4A4;01dM7@/03@d=2`051@D6
0?ooo`001@3oool;02<S8`/04a<C2`0I6AT;02TY:@/00`<32`0Q8B4<028R8P/000002`3oool;0?gm
o@/0m?Cd2`3Rh^8;0>k^kP/0oooo2`3alO4;0?_kn`/061PH2`0O7al;02@T90`0410@2`0Y:BT;014A
4@/07AdM2`0=3@d;00D51@H0oooo00050?ooo`/08b<S2`0C4a<;01TI6@/0:BTY2`030`<;024Q8@`0
8R8R2`00000;0?ooo`/0oOgm2`3dm?@;0>;RhP/0k^k^2`3oool;0?7al@/0no_k2`0H61P;01lO7`/0
92@T300@410;02TY:@/04A4A2`0M7Ad;00d=3@/01@D51P3oool000D0oooo2`0S8b<;01<C4`/06ATI
2`0Y:BT;00<30`/08B4Q300R8R8;000000/0oooo2`3moOd;0?Cdm0/0h^;R2`3^k^h;0?ooo`/0lO7a
2`3kno/;01PH60/07alO2`0T92@<010@40/0:BTY2`0A4A4;01dM7@/03@d=2`051@D60?ooo`001@3o
ool;02PX:0/00`<32`0>3Ph;00820P/01`L72`0<30`<00h>3P/00P822`3Ogml;0>g]k@/0e]KF2`3Z
j^X;0>3Ph0/0o?cl2`3Kfm/;0?clo0/05ADE2`020P8;020P80`0:2PX2`0410@;00l?3`/04Q8B2`0R
8R8;00H61PH0oooo00050?ooo`/0:2PX2`030`<;00h>3P/00P822`071`L;00`<30`03Ph>2`020P8;
0=oOg`/0kNg]2`3Fe]H;0>[ZjP/0h>3P2`3lo?`;0=_Kf`/0o?cl2`0E5AD;00820P/0820P300X:2P;
00@410/03`l?2`0B4Q8;028R8P/01PH61P3oool000D0oooo2`0X:2P;00<30`/03Ph>2`020P8;00L7
1`/030`<300>3Ph;00820P/0gmoO2`3]kNd;0=KFeP/0j^[Z2`3Ph>0;0?clo0/0fm_K2`3lo?`;01DE
5@/00P822`0P820<02PX:0/010@42`0?3`l;018B4P/08R8R2`061PH60?ooo`001@3oool;02PX:0/0
0`<32`0>3Ph;00820P/01`L72`0<30`<00h>3P/00P822`3Ogml;0>g]k@/0e]KF2`3Zj^X;0>3Ph0/0
o?cl2`3Kfm/;0?clo0/05ADE2`020P8;020P80`0:2PX2`0410@;00l?3`/04Q8B2`0R8R8;00H61PH0
oooo00050?ooo`/0:2PX2`030`<;00h>3P/00P822`071`L;00`<30`03Ph>2`020P8;0=oOg`/0kNg]
2`3Fe]H;0>[ZjP/0h>3P2`3lo?`;0=_Kf`/0o?cl2`0E5AD;00820P/0820P300X:2P;00@410/03`l?
2`0B4Q8;028R8P/01PH61P3oool000D0oooo2`0X:2P;00<30`/03Ph>2`020P8;00L71`/030`<300>
3Ph;00820P/0gmoO2`3]kNd;0=KFeP/0j^[Z2`3Ph>0;0?clo0/0fm_K2`3lo?`;01DE5@/00P822`0P
820<02PX:0/010@42`0?3`l;018B4P/08R8R2`061PH60?ooo`001@3oool;02PX:0/00`<32`0>3Ph;
00820P/01`L72`0<30`<00h>3P/00P822`3Ogml;0>g]k@/0e]KF2`3Zj^X;0>3Ph0/0o?cl2`3Kfm/;
0?clo0/05ADE2`020P8;020P80`0:2PX2`0410@;00l?3`/04Q8B2`0R8R8;00H61PH0oooo00050?oo
o`/0:2PX2`030`<;00h>3P/00P822`071`L;00`<30`03Ph>2`020P8;0=oOg`/0kNg]2`3Fe]H;0>[Z
jP/0h>3P2`3lo?`;0=_Kf`/0o?cl2`0E5AD;00820P/0820P300X:2P;00@410/03`l?2`0B4Q8;028R
8P/01PH61P3oool000D0oooo2`0X:2P;00<30`/03Ph>2`020P8;00L71`/030`<300>3Ph;00820P/0
gmoO2`3]kNd;0=KFeP/0j^[Z2`3Ph>0;0?clo0/0fm_K2`3lo?`;01DE5@/00P822`0P820<02PX:0/0
10@42`0?3`l;018B4P/08R8R2`061PH60?ooo`001@3oool;02PX:0/00`<32`0>3Ph;00820P/01`L7
2`0<30`<00h>3P/00P822`3Ogml;0>g]k@/0e]KF2`3Zj^X;0>3Ph0/0o?cl2`3Kfm/;0?clo0/05ADE
2`020P8;020P80`0:2PX2`0410@;00l?3`/04Q8B2`0R8R8;00H61PH0oooo00050?ooo`/0:2PX2`03
0`<;00h>3P/00P822`071`L;00`<30`03Ph>2`020P8;0=oOg`/0kNg]2`3Fe]H;0>[ZjP/0h>3P2`3l
o?`;0=_Kf`/0o?cl2`0E5AD;00820P/0820P300X:2P;00@410/03`l?2`0B4Q8;028R8P/01PH61P3o
ool000D0oooo2`0;2`/;00@410/0820P2`0Y:BT;02XZ:P/08B4Q300M7Ad;01lO7`/0inOW2`3emOD;
0=kNgP/0j^[Z2`3[jn/;0>o_k`/0h^;R2`3oool;01<C4`/092@T2`0>3Ph<02DU9@/00`<32`0A4A4;
01HF5P/07alO2`0R8R860?ooo`001@3oool;00/;2`/010@42`0P820;02TY:@/0:RXZ2`0Q8B4<01dM
7@/07alO2`3WinL;0?Gem@/0g]kN2`3Zj^X;0>_[j`/0kno_2`3Rh^8;0?ooo`/04a<C2`0T92@;00h>
3P`09BDU2`030`<;014A4@/05QHF2`0O7al;028R8PH0oooo00050?ooo`/02`/;2`0410@;020P80/0
:BTY2`0Z:RX;024Q8@`07AdM2`0O7al;0>OWi`/0mOGe2`3Ng]h;0>[ZjP/0jn_[2`3_knl;0>;RhP/0
oooo2`0C4a<;02@T90/03Ph>300U9BD;00<30`/04A4A2`0F5QH;01lO7`/08R8R1P3oool000D0oooo
2`0;2`/;00@410/0820P2`0Y:BT;02XZ:P/08B4Q300M7Ad;01lO7`/0inOW2`3emOD;0=kNgP/0j^[Z
2`3[jn/;0>o_k`/0h^;R2`3oool;01<C4`/092@T2`0>3Ph<02DU9@/00`<32`0A4A4;01HF5P/07alO
2`0R8R860?ooo`001@3oool;00/;2`/010@42`0P820;02TY:@/0:RXZ2`0Q8B4<01dM7@/07alO2`3W
inL;0?Gem@/0g]kN2`3Zj^X;0>_[j`/0kno_2`3Rh^8;0?ooo`/04a<C2`0T92@;00h>3P`09BDU2`03
0`<;014A4@/05QHF2`0O7al;028R8PH0oooo00050?ooo`/02`/;2`0410@;020P80/0:BTY2`0Z:RX;
024Q8@`07AdM2`0O7al;0>OWi`/0mOGe2`3Ng]h;0>[ZjP/0jn_[2`3_knl;0>;RhP/0oooo2`0C4a<;
02@T90/03Ph>300U9BD;00<30`/04A4A2`0F5QH;01lO7`/08R8R1P3oool000D0oooo2`0;2`/;00@4
10/0820P2`0Y:BT;02XZ:P/08B4Q300M7Ad;01lO7`/0inOW2`3emOD;0=kNgP/0j^[Z2`3[jn/;0>o_
k`/0h^;R2`3oool;01<C4`/092@T2`0>3Ph<02DU9@/00`<32`0A4A4;01HF5P/07alO2`0R8R860?oo
o`001@3oool;00/;2`/010@42`0P820;02TY:@/0:RXZ2`0Q8B4<01dM7@/07alO2`3WinL;0?Gem@/0
g]kN2`3Zj^X;0>_[j`/0kno_2`3Rh^8;0?ooo`/04a<C2`0T92@;00h>3P`09BDU2`030`<;014A4@/0
5QHF2`0O7al;028R8PH0oooo00050?ooo`/02`/;2`0410@;020P80/0:BTY2`0Z:RX;024Q8@`07AdM
2`0O7al;0>OWi`/0mOGe2`3Ng]h;0>[ZjP/0jn_[2`3_knl;0>;RhP/0oooo2`0C4a<;02@T90/03Ph>
300U9BD;00<30`/04A4A2`0F5QH;01lO7`/08R8R1P3oool000D0oooo2`0;2`/;00@410/0820P2`0Y
:BT;02XZ:P/08B4Q300M7Ad;01lO7`/0inOW2`3emOD;0=kNgP/0j^[Z2`3[jn/;0>o_k`/0h^;R2`3o
ool;01<C4`/092@T2`0>3Ph<02DU9@/00`<32`0A4A4;01HF5P/07alO2`0R8R860?ooo`001@3oool;
00/;2`/010@42`0P820;02TY:@/0:RXZ2`0Q8B4<01dM7@/07alO2`3WinL;0?Gem@/0g]kN2`3Zj^X;
0>_[j`/0kno_2`3Rh^8;0?ooo`/04a<C2`0T92@;00h>3P`09BDU2`030`<;014A4@/05QHF2`0O7al;
028R8PH0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q
8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L
70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``0
00002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`0
3@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R
2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=
2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q
8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G
5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo0005
0?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;
02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;
01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q
8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L
70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``0
00002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`0
3@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R
2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=
2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/03@d=2`0Q
8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;02DU9@/01`L75P0G
5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;01TI6@H0oooo0005
0?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q8@/092@T2`0F5QH;
02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L70/0:2PX2`0E5AD;
01TI6@H0oooo00050?ooo`/03@d=2`0Q8B4;020P80/08R8R2`0F5QH;00<30``000002`0@410;024Q
8@/092@T2`0F5QH;02DU9@/01`L75P0G5aL;014A4@/03@d=2`0820P;01`L70`03@d=2`0V9RH;01`L
70/0:2PX2`0E5AD;01TI6@H0oooo00050?ooo`/09RHV2`0820P;01dM7@/00P822`0S8b<;00P820`0
30`<2`0;2`/;02TY:@/071`L2`0B4Q8;00@410/04A4A2`0410@;000000/0820P2`0820P;018B4P/0
7QhN300T92@;01HF5P/051@D2`0820P;00X:2P/06QXJ1P3oool000D0oooo2`0V9RH;00P820/07AdM
2`020P8;02<S8`/020P8300<30`;00/;2`/0:BTY2`0L71`;018B4P/010@42`0A4A4;00@410/00000
2`0P820;00P820/04Q8B2`0N7Qh<02@T90/05QHF2`0D51@;00P820/02PX:2`0J6QX60?ooo`001@3o
ool;02HV9P/020P82`0M7Ad;00820P/08b<S2`0820P<00`<30/02`/;2`0Y:BT;01`L70/04Q8B2`04
10@;014A4@/010@42`00000;020P80/020P82`0B4Q8;01hN7P`092@T2`0F5QH;01@D50/020P82`0:
2PX;01XJ6PH0oooo00050?ooo`/09RHV2`0820P;01dM7@/00P822`0S8b<;00P820`030`<2`0;2`/;
02TY:@/071`L2`0B4Q8;00@410/04A4A2`0410@;000000/0820P2`0820P;018B4P/07QhN300T92@;
01HF5P/051@D2`0820P;00X:2P/06QXJ1P3oool000D0oooo2`0V9RH;00P820/07AdM2`020P8;02<S
8`/020P8300<30`;00/;2`/0:BTY2`0L71`;018B4P/010@42`0A4A4;00@410/000002`0P820;00P8
20/04Q8B2`0N7Qh<02@T90/05QHF2`0D51@;00P820/02PX:2`0J6QX60?ooo`001@3oool;02HV9P/0
20P82`0M7Ad;00820P/08b<S2`0820P<00`<30/02`/;2`0Y:BT;01`L70/04Q8B2`0410@;014A4@/0
10@42`00000;020P80/020P82`0B4Q8;01hN7P`092@T2`0F5QH;01@D50/020P82`0:2PX;01XJ6PH0
oooo00050?ooo`/09RHV2`0820P;01dM7@/00P822`0S8b<;00P820`030`<2`0;2`/;02TY:@/071`L
2`0B4Q8;00@410/04A4A2`0410@;000000/0820P2`0820P;018B4P/07QhN300T92@;01HF5P/051@D
2`0820P;00X:2P/06QXJ1P3oool000D0oooo2`0V9RH;00P820/07AdM2`020P8;02<S8`/020P8300<
30`;00/;2`/0:BTY2`0L71`;018B4P/010@42`0A4A4;00@410/000002`0P820;00P820/04Q8B2`0N
7Qh<02@T90/05QHF2`0D51@;00P820/02PX:2`0J6QX60?ooo`001@3oool;02HV9P/020P82`0M7Ad;
00820P/08b<S2`0820P<00`<30/02`/;2`0Y:BT;01`L70/04Q8B2`0410@;014A4@/010@42`00000;
020P80/020P82`0B4Q8;01hN7P`092@T2`0F5QH;01@D50/020P82`0:2PX;01XJ6PH0oooo00050?oo
o`/09RHV2`0820P;01dM7@/00P822`0S8b<;00P820`030`<2`0;2`/;02TY:@/071`L2`0B4Q8;00@4
10/04A4A2`0410@;000000/0820P2`0820P;018B4P/07QhN300T92@;01HF5P/051@D2`0820P;00X:
2P/06QXJ1P3oool000D0oooo2`0V9RH;00P820/07AdM2`020P8;02<S8`/020P8300<30`;00/;2`/0
:BTY2`0L71`;018B4P/010@42`0A4A4;00@410/000002`0P820;00P820/04Q8B2`0N7Qh<02@T90/0
5QHF2`0D51@;00P820/02PX:2`0J6QX60?ooo`001@3oool;00`<30/05QHF2`071`L;024Q8@/010@4
2`0820P<02HV9P/08b<S2`0B4Q8;024Q8@/08R8R2`0B4Q8;00d=3@/0820P2`010@4;00T92@/09BDU
2`010@4;00L71``07QhN2`0@410;02<S8`/09bLW2`030`<;00@410H0oooo00050?ooo`/030`<2`0F
5QH;00L71`/08B4Q2`0410@;00P820`09RHV2`0S8b<;018B4P/08B4Q2`0R8R8;018B4P/03@d=2`0P
820;00410@/02@T92`0U9BD;00410@/01`L7300N7Qh;010@40/08b<S2`0W9bL;00<30`/010@41P3o
ool000D0oooo2`0<30`;01HF5P/01`L72`0Q8B4;00@410/020P8300V9RH;02<S8`/04Q8B2`0Q8B4;
028R8P/04Q8B2`0=3@d;020P80/00@412`092@T;02DU9@/00@412`071`L<01hN7P/0410@2`0S8b<;
02LW9`/00`<32`0410@60?ooo`001@3oool;00`<30/05QHF2`071`L;024Q8@/010@42`0820P<02HV
9P/08b<S2`0B4Q8;024Q8@/08R8R2`0B4Q8;00d=3@/0820P2`010@4;00T92@/09BDU2`010@4;00L7
1``07QhN2`0@410;02<S8`/09bLW2`030`<;00@410H0oooo00050?ooo`/030`<2`0F5QH;00L71`/0
8B4Q2`0410@;00P820`09RHV2`0S8b<;018B4P/08B4Q2`0R8R8;018B4P/03@d=2`0P820;00410@/0
2@T92`0U9BD;00410@/01`L7300N7Qh;010@40/08b<S2`0W9bL;00<30`/010@41P3oool000D0oooo
2`0<30`;01HF5P/01`L72`0Q8B4;00@410/020P8300V9RH;02<S8`/04Q8B2`0Q8B4;028R8P/04Q8B
2`0=3@d;020P80/00@412`092@T;02DU9@/00@412`071`L<01hN7P/0410@2`0S8b<;02LW9`/00`<3
2`0410@60?ooo`001@3oool;00`<30/05QHF2`071`L;024Q8@/010@42`0820P<02HV9P/08b<S2`0B
4Q8;024Q8@/08R8R2`0B4Q8;00d=3@/0820P2`010@4;00T92@/09BDU2`010@4;00L71``07QhN2`0@
410;02<S8`/09bLW2`030`<;00@410H0oooo00050?ooo`/030`<2`0F5QH;00L71`/08B4Q2`0410@;
00P820`09RHV2`0S8b<;018B4P/08B4Q2`0R8R8;018B4P/03@d=2`0P820;00410@/02@T92`0U9BD;
00410@/01`L7300N7Qh;010@40/08b<S2`0W9bL;00<30`/010@41P3oool000D0oooo2`0<30`;01HF
5P/01`L72`0Q8B4;00@410/020P8300V9RH;02<S8`/04Q8B2`0Q8B4;028R8P/04Q8B2`0=3@d;020P
80/00@412`092@T;02DU9@/00@412`071`L<01hN7P/0410@2`0S8b<;02LW9`/00`<32`0410@60?oo
o`001@3oool;00`<30/05QHF2`071`L;024Q8@/010@42`0820P<02HV9P/08b<S2`0B4Q8;024Q8@/0
8R8R2`0B4Q8;00d=3@/0820P2`010@4;00T92@/09BDU2`010@4;00L71``07QhN2`0@410;02<S8`/0
9bLW2`030`<;00@410H0oooo00050?ooo`/030`<2`0F5QH;00L71`/08B4Q2`0410@;00P820`09RHV
2`0S8b<;018B4P/08B4Q2`0R8R8;018B4P/03@d=2`0P820;00410@/02@T92`0U9BD;00410@/01`L7
300N7Qh;010@40/08b<S2`0W9bL;00<30`/010@41P3oool000D0oooo2`0=3@d;01lO7`/030`<2`0Z
:RX;00@410/08b<S300C4a<;01LG5`/03Ph>2`00000;00410@/02@T92`0H61P;02XZ:P/08R8R2`0>
3Ph;01HF5P/08R8R2`0410@<02PX:0/07AdM2`0V9RH;000000/08b<S2`0@41060?ooo`001@3oool;
00d=3@/07alO2`0<30`;02XZ:P/010@42`0S8b<<01<C4`/05aLG2`0>3Ph;000000/00@412`092@T;
01PH60/0:RXZ2`0R8R8;00h>3P/05QHF2`0R8R8;00@410`0:2PX2`0M7Ad;02HV9P/000002`0S8b<;
010@40H0oooo00050?ooo`/03@d=2`0O7al;00`<30/0:RXZ2`0410@;02<S8``04a<C2`0G5aL;00h>
3P/000002`010@4;00T92@/061PH2`0Z:RX;028R8P/03Ph>2`0F5QH;028R8P/010@4300X:2P;01dM
7@/09RHV2`00000;02<S8`/0410@1P3oool000D0oooo2`0=3@d;01lO7`/030`<2`0Z:RX;00@410/0
8b<S300C4a<;01LG5`/03Ph>2`00000;00410@/02@T92`0H61P;02XZ:P/08R8R2`0>3Ph;01HF5P/0
8R8R2`0410@<02PX:0/07AdM2`0V9RH;000000/08b<S2`0@41060?ooo`001@3oool;00d=3@/07alO
2`0<30`;02XZ:P/010@42`0S8b<<01<C4`/05aLG2`0>3Ph;000000/00@412`092@T;01PH60/0:RXZ
2`0R8R8;00h>3P/05QHF2`0R8R8;00@410`0:2PX2`0M7Ad;02HV9P/000002`0S8b<;010@40H0oooo
00050?ooo`/03@d=2`0O7al;00`<30/0:RXZ2`0410@;02<S8``04a<C2`0G5aL;00h>3P/000002`01
0@4;00T92@/061PH2`0Z:RX;028R8P/03Ph>2`0F5QH;028R8P/010@4300X:2P;01dM7@/09RHV2`00
000;02<S8`/0410@1P3oool000D0oooo2`0=3@d;01lO7`/030`<2`0Z:RX;00@410/08b<S300C4a<;
01LG5`/03Ph>2`00000;00410@/02@T92`0H61P;02XZ:P/08R8R2`0>3Ph;01HF5P/08R8R2`0410@<
02PX:0/07AdM2`0V9RH;000000/08b<S2`0@41060?ooo`001@3oool;00d=3@/07alO2`0<30`;02XZ
:P/010@42`0S8b<<01<C4`/05aLG2`0>3Ph;000000/00@412`092@T;01PH60/0:RXZ2`0R8R8;00h>
3P/05QHF2`0R8R8;00@410`0:2PX2`0M7Ad;02HV9P/000002`0S8b<;010@40H0oooo00050?ooo`/0
3@d=2`0O7al;00`<30/0:RXZ2`0410@;02<S8``04a<C2`0G5aL;00h>3P/000002`010@4;00T92@/0
61PH2`0Z:RX;028R8P/03Ph>2`0F5QH;028R8P/010@4300X:2P;01dM7@/09RHV2`00000;02<S8`/0
410@1P3oool000D0oooo2`0=3@d;01lO7`/030`<2`0Z:RX;00@410/08b<S300C4a<;01LG5`/03Ph>
2`00000;00410@/02@T92`0H61P;02XZ:P/08R8R2`0>3Ph;01HF5P/08R8R2`0410@<02PX:0/07AdM
2`0V9RH;000000/08b<S2`0@41060?ooo`001@3oool;00d=3@/07alO2`0<30`;02XZ:P/010@42`0S
8b<<01<C4`/05aLG2`0>3Ph;000000/00@412`092@T;01PH60/0:RXZ2`0R8R8;00h>3P/05QHF2`0R
8R8;00@410`0:2PX2`0M7Ad;02HV9P/000002`0S8b<;010@40H0oooo00050?ooo`/01`L72`0O7al;
02@T90/02`/;2`0>3Ph;00/;2``030`<2`0W9bL;00d=3@/02PX:2`020P8;00l?3`/03Ph>2`0B4Q8;
01lO7`/08R8R2`0E5AD;00h>3P/08B4Q30051@D;01XJ6P/03@d=2`0X:2P;01lO7`/04Q8B1P3oool0
00D0oooo2`071`L;01lO7`/092@T2`0;2`/;00h>3P/02`/;300<30`;02LW9`/03@d=2`0:2PX;0082
0P/03`l?2`0>3Ph;018B4P/07alO2`0R8R8;01DE5@/03Ph>2`0Q8B4<00D51@/06QXJ2`0=3@d;02PX
:0/07alO2`0B4Q860?ooo`001@3oool;00L71`/07alO2`0T92@;00/;2`/03Ph>2`0;2`/<00`<30/0
9bLW2`0=3@d;00X:2P/00P822`0?3`l;00h>3P/04Q8B2`0O7al;028R8P/05ADE2`0>3Ph;024Q8@`0
1@D52`0J6QX;00d=3@/0:2PX2`0O7al;018B4PH0oooo00050?ooo`/01`L72`0O7al;02@T90/02`/;
2`0>3Ph;00/;2``030`<2`0W9bL;00d=3@/02PX:2`020P8;00l?3`/03Ph>2`0B4Q8;01lO7`/08R8R
2`0E5AD;00h>3P/08B4Q30051@D;01XJ6P/03@d=2`0X:2P;01lO7`/04Q8B1P3oool000D0oooo2`07
1`L;01lO7`/092@T2`0;2`/;00h>3P/02`/;300<30`;02LW9`/03@d=2`0:2PX;00820P/03`l?2`0>
3Ph;018B4P/07alO2`0R8R8;01DE5@/03Ph>2`0Q8B4<00D51@/06QXJ2`0=3@d;02PX:0/07alO2`0B
4Q860?ooo`001@3oool;00L71`/07alO2`0T92@;00/;2`/03Ph>2`0;2`/<00`<30/09bLW2`0=3@d;
00X:2P/00P822`0?3`l;00h>3P/04Q8B2`0O7al;028R8P/05ADE2`0>3Ph;024Q8@`01@D52`0J6QX;
00d=3@/0:2PX2`0O7al;018B4PH0oooo00050?ooo`/01`L72`0O7al;02@T90/02`/;2`0>3Ph;00/;
2``030`<2`0W9bL;00d=3@/02PX:2`020P8;00l?3`/03Ph>2`0B4Q8;01lO7`/08R8R2`0E5AD;00h>
3P/08B4Q30051@D;01XJ6P/03@d=2`0X:2P;01lO7`/04Q8B1P3oool000D0oooo2`071`L;01lO7`/0
92@T2`0;2`/;00h>3P/02`/;300<30`;02LW9`/03@d=2`0:2PX;00820P/03`l?2`0>3Ph;018B4P/0
7alO2`0R8R8;01DE5@/03Ph>2`0Q8B4<00D51@/06QXJ2`0=3@d;02PX:0/07alO2`0B4Q860?ooo`00
1@3oool;00L71`/07alO2`0T92@;00/;2`/03Ph>2`0;2`/<00`<30/09bLW2`0=3@d;00X:2P/00P82
2`0?3`l;00h>3P/04Q8B2`0O7al;028R8P/05ADE2`0>3Ph;024Q8@`01@D52`0J6QX;00d=3@/0:2PX
2`0O7al;018B4PH0oooo00050?ooo`/01`L72`0O7al;02@T90/02`/;2`0>3Ph;00/;2``030`<2`0W
9bL;00d=3@/02PX:2`020P8;00l?3`/03Ph>2`0B4Q8;01lO7`/08R8R2`0E5AD;00h>3P/08B4Q3005
1@D;01XJ6P/03@d=2`0X:2P;01lO7`/04Q8B1P3oool000D0oooo2`071`L;01lO7`/092@T2`0;2`/;
00h>3P/02`/;300<30`;02LW9`/03@d=2`0:2PX;00820P/03`l?2`0>3Ph;018B4P/07alO2`0R8R8;
01DE5@/03Ph>2`0Q8B4<00D51@/06QXJ2`0=3@d;02PX:0/07alO2`0B4Q860?ooo`001@3oool;01PH
60/010@42`0D51@;00@410/03@d=2`0R8R8<01HF5P/08B4Q2`020P8;01lO7`/01`L72`0C4a<;01/K
6`/000002`0?3`l;02LW9`/03@d=2`092@T;00X:2P`03@d=2`0Z:RX;00/;2`/05ADE2`0U9BD;014A
4@H0oooo00050?ooo`/061PH2`0410@;01@D50/010@42`0=3@d;028R8P`05QHF2`0Q8B4;00820P/0
7alO2`071`L;01<C4`/06a/K2`00000;00l?3`/09bLW2`0=3@d;00T92@/02PX:300=3@d;02XZ:P/0
2`/;2`0E5AD;02DU9@/04A4A1P3oool000D0oooo2`0H61P;00@410/051@D2`0410@;00d=3@/08R8R
300F5QH;024Q8@/00P822`0O7al;00L71`/04a<C2`0K6a/;000000/03`l?2`0W9bL;00d=3@/02@T9
2`0:2PX<00d=3@/0:RXZ2`0;2`/;01DE5@/09BDU2`0A4A460?ooo`001@3oool;01PH60/010@42`0D
51@;00@410/03@d=2`0R8R8<01HF5P/08B4Q2`020P8;01lO7`/01`L72`0C4a<;01/K6`/000002`0?
3`l;02LW9`/03@d=2`092@T;00X:2P`03@d=2`0Z:RX;00/;2`/05ADE2`0U9BD;014A4@H0oooo0005
0?ooo`/061PH2`0410@;01@D50/010@42`0=3@d;028R8P`05QHF2`0Q8B4;00820P/07alO2`071`L;
01<C4`/06a/K2`00000;00l?3`/09bLW2`0=3@d;00T92@/02PX:300=3@d;02XZ:P/02`/;2`0E5AD;
02DU9@/04A4A1P3oool000D0oooo2`0H61P;00@410/051@D2`0410@;00d=3@/08R8R300F5QH;024Q
8@/00P822`0O7al;00L71`/04a<C2`0K6a/;000000/03`l?2`0W9bL;00d=3@/02@T92`0:2PX<00d=
3@/0:RXZ2`0;2`/;01DE5@/09BDU2`0A4A460?ooo`001@3oool;01PH60/010@42`0D51@;00@410/0
3@d=2`0R8R8<01HF5P/08B4Q2`020P8;01lO7`/01`L72`0C4a<;01/K6`/000002`0?3`l;02LW9`/0
3@d=2`092@T;00X:2P`03@d=2`0Z:RX;00/;2`/05ADE2`0U9BD;014A4@H0oooo00050?ooo`/061PH
2`0410@;01@D50/010@42`0=3@d;028R8P`05QHF2`0Q8B4;00820P/07alO2`071`L;01<C4`/06a/K
2`00000;00l?3`/09bLW2`0=3@d;00T92@/02PX:300=3@d;02XZ:P/02`/;2`0E5AD;02DU9@/04A4A
1P3oool000D0oooo2`0H61P;00@410/051@D2`0410@;00d=3@/08R8R300F5QH;024Q8@/00P822`0O
7al;00L71`/04a<C2`0K6a/;000000/03`l?2`0W9bL;00d=3@/02@T92`0:2PX<00d=3@/0:RXZ2`0;
2`/;01DE5@/09BDU2`0A4A460?ooo`001@3oool;01PH60/010@42`0D51@;00@410/03@d=2`0R8R8<
01HF5P/08B4Q2`020P8;01lO7`/01`L72`0C4a<;01/K6`/000002`0?3`l;02LW9`/03@d=2`092@T;
00X:2P`03@d=2`0Z:RX;00/;2`/05ADE2`0U9BD;014A4@H0oooo00050?ooo`/061PH2`0410@;01@D
50/010@42`0=3@d;028R8P`05QHF2`0Q8B4;00820P/07alO2`071`L;01<C4`/06a/K2`00000;00l?
3`/09bLW2`0=3@d;00T92@/02PX:300=3@d;02XZ:P/02`/;2`0E5AD;02DU9@/04A4A1P3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.500131, -0.500131, 0.0905933, \
0.0905933}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ListPlot3D", "[", 
          StyleBox["\[ScriptN]\[ScriptCapitalE]",
            "InlineInputTraditionalForm"], 
          StyleBox["]",
            "InlineInputTraditionalForm"]}], 
        StyleBox[";",
          "InlineInputTraditionalForm"]}], TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -9 -11.9926 ]
[.12586 .2075 0 .00736 ]
[.25429 .15697 -13.4005 -12 ]
[.25429 .15697 .5995 0 ]
[.38935 .10384 -12.7924 -12 ]
[.38935 .10384 1.2076 0 ]
[.53158 .04793 -12.1843 -12 ]
[.53158 .04793 1.81571 0 ]
[.68156 -0.01098 -11.5762 -12 ]
[.68156 -0.01098 2.42381 0 ]
[.75679 .08071 0 -8.23703 ]
[.75679 .08071 9 3.76297 ]
[.82083 .17876 0 -8.11081 ]
[.82083 .17876 14 3.88919 ]
[.87924 .26821 0 -7.99808 ]
[.87924 .26821 14 4.00192 ]
[.93273 .35014 0 -7.89677 ]
[.93273 .35014 14 4.10323 ]
[.98191 .42546 0 -7.80525 ]
[.98191 .42546 14 4.19475 ]
[.02134 .2825 -9 -3.67601 ]
[.02134 .2825 0 8.32399 ]
[.00694 .37276 -16.5 -3.778 ]
[.00694 .37276 0 8.222 ]
[-0.00833 .46844 -9 -3.88675 ]
[-0.00833 .46844 0 8.11325 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
gsave
.75679 .08071 -61 -12.237 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.80845 .18312 m
.80226 .18529 L
s
gsave
.82083 .17876 -61 -12.1108 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.86679 .27235 m
.86056 .27443 L
s
gsave
.87924 .26821 -61 -11.9981 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.92022 .35409 m
.91397 .35607 L
s
gsave
.93273 .35014 -61 -11.8968 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.8052 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
.73096 .06459 m
.72728 .06598 L
s
.71716 .04348 m
.71349 .04489 L
s
.70309 .02196 m
.69942 .02338 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03357 .27776 m
.03969 .27539 L
s
gsave
.02134 .2825 -70 -7.67601 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01924 .36821 m
.02539 .36593 L
s
gsave
.00694 .37276 -77.5 -7.778 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.00405 .46408 m
.01024 .4619 L
s
gsave
-0.00833 .46844 -70 -7.88675 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03077 .29544 m
.03445 .29403 L
s
.02794 .31332 m
.03162 .31192 L
s
.02507 .3314 m
.02876 .33001 L
s
.02217 .3497 m
.02586 .34832 L
s
.01627 .38693 m
.01997 .38558 L
s
.01327 .40588 m
.01697 .40453 L
s
.01023 .42505 m
.01394 .42372 L
s
.00716 .44445 m
.01087 .44313 L
s
.03634 .26029 m
.04001 .25886 L
s
.0009 .48395 m
.00462 .48266 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.356 .442 .811 r
.39215 .59721 .40447 .62234 .42641 .60055 .41308 .60884 Mtetra
.257 0 0 r
.41308 .60884 .42641 .60055 .44772 .606 .4348 .6061 Mtetra
.892 .931 .836 r
.4348 .6061 .44772 .606 .46974 .58752 .45719 .58073 Mtetra
.569 .817 .992 r
.45719 .58073 .46974 .58752 .4916 .58766 .47923 .57651 Mtetra
.698 .768 .906 r
.47923 .57651 .4916 .58766 .51369 .59734 .50151 .56756 Mtetra
.636 .569 .763 r
.50151 .56756 .51369 .59734 .5361 .58186 .52395 .56144 Mtetra
.221 .413 .839 r
.52395 .56144 .5361 .58186 .55873 .58308 .54671 .57568 Mtetra
.87 .835 .809 r
.54671 .57568 .55873 .58308 .58114 .55313 .5694 .54865 Mtetra
.678 .901 .976 r
.5694 .54865 .58114 .55313 .60449 .5683 .59235 .53908 Mtetra
.685 .6 .755 r
.59235 .53908 .60449 .5683 .6271 .54315 .61538 .52644 Mtetra
.498 .617 .9 r
.61538 .52644 .6271 .54315 .65065 .5449 .63904 .5288 Mtetra
.672 .701 .869 r
.63904 .5288 .65065 .5449 .67442 .54409 .6626 .52094 Mtetra
.616 .607 .819 r
.6626 .52094 .67442 .54409 .69708 .5165 .68656 .51714 Mtetra
.183 0 0 r
.68656 .51714 .69708 .5165 .72155 .52104 .71113 .51983 Mtetra
.319 .801 .896 r
.71113 .51983 .72155 .52104 .74687 .53281 .73561 .5155 Mtetra
.762 .725 .818 r
.73561 .5155 .74687 .53281 .76973 .50462 .75942 .49801 Mtetra
.752 .893 .942 r
.75942 .49801 .76973 .50462 .79397 .49458 .78361 .48452 Mtetra
.185 .561 .934 r
.78361 .48452 .79397 .49458 .81869 .48806 .80975 .49242 Mtetra
.837 .984 .702 r
.80975 .49242 .81869 .48806 .8438 .48311 .83281 .46242 Mtetra
.409 .524 .863 r
.83281 .46242 .8438 .48311 .87125 .49815 .8597 .4714 Mtetra
.725 .643 .766 r
.8597 .4714 .87125 .49815 .89404 .46645 .88415 .45365 Mtetra
.111 .453 .885 r
.88415 .45365 .89404 .46645 .9205 .46667 .91239 .46745 Mtetra
.583 .944 .834 r
.91239 .46745 .9205 .46667 .94793 .47158 .9376 .45259 Mtetra
.759 .722 .819 r
.9376 .45259 .94793 .47158 .97191 .44797 .96252 .43465 Mtetra
0 .487 .845 r
.37896 .59007 .39215 .59721 .41308 .60884 .40014 .5968 Mtetra
.807 .763 .811 r
.40014 .5968 .41308 .60884 .4348 .6061 .4225 .57574 Mtetra
.311 .377 .77 r
.4225 .57574 .4348 .6061 .45719 .58073 .44397 .59215 Mtetra
.895 .976 .681 r
.44397 .59215 .45719 .58073 .47923 .57651 .46681 .55653 Mtetra
.093 .341 .813 r
.46681 .55653 .47923 .57651 .50151 .56756 .48889 .57317 Mtetra
.708 .981 .793 r
.48889 .57317 .50151 .56756 .52395 .56144 .51162 .55418 Mtetra
.549 .808 .993 r
.51162 .55418 .52395 .56144 .54671 .57568 .53441 .55042 Mtetra
.707 .632 .771 r
.53441 .55042 .54671 .57568 .5694 .54865 .55734 .53623 Mtetra
.783 .774 .845 r
.55734 .53623 .5694 .54865 .59235 .53908 .58031 .51899 Mtetra
.653 .649 .834 r
.58031 .51899 .59235 .53908 .61538 .52644 .60358 .51227 Mtetra
.546 .68 .926 r
.60358 .51227 .61538 .52644 .63904 .5288 .62723 .51142 Mtetra
.45 .587 .898 r
.62723 .51142 .63904 .5288 .6626 .52094 .65138 .51596 Mtetra
0 .493 .81 r
.65138 .51596 .6626 .52094 .68656 .51714 .67599 .52241 Mtetra
.387 .819 .661 r
.67599 .52241 .68656 .51714 .71113 .51983 .69996 .50897 Mtetra
.837 .818 .831 r
.69996 .50897 .71113 .51983 .73561 .5155 .72348 .48588 Mtetra
.582 .55 .784 r
.72348 .48588 .73561 .5155 .75942 .49801 .74849 .48508 Mtetra
.458 .666 .952 r
.74849 .48508 .75942 .49801 .78361 .48452 .77401 .48703 Mtetra
.898 .987 .747 r
.77401 .48703 .78361 .48452 .80975 .49242 .79712 .45541 Mtetra
.367 .386 .748 r
.79712 .45541 .80975 .49242 .83281 .46242 .82483 .47604 Mtetra
.04 0 0 r
.82483 .47604 .83281 .46242 .8597 .4714 .84961 .46013 Mtetra
.506 .725 .971 r
.84961 .46013 .8597 .4714 .88415 .45365 .87609 .45922 Mtetra
.859 .955 .609 r
.87609 .45922 .88415 .45365 .91239 .46745 .89867 .42149 Mtetra
.432 .398 .72 r
.89867 .42149 .91239 .46745 .9376 .45259 .92813 .44144 Mtetra
.847 .85 .845 r
.92813 .44144 .9376 .45259 .96252 .43465 .95253 .41769 Mtetra
.501 .674 .942 r
.36581 .57704 .37896 .59007 .40014 .5968 .38729 .57754 Mtetra
.751 .684 .787 r
.38729 .57754 .40014 .5968 .4225 .57574 .40965 .56004 Mtetra
.048 .381 .845 r
.40965 .56004 .4225 .57574 .44397 .59215 .4312 .57323 Mtetra
.811 .704 .748 r
.4312 .57323 .44397 .59215 .46681 .55653 .4541 .5438 Mtetra
.599 .72 .929 r
.4541 .5438 .46681 .55653 .48889 .57317 .4765 .54028 Mtetra
.353 .392 .762 r
.4765 .54028 .48889 .57317 .51162 .55418 .49899 .55617 Mtetra
.464 .891 .855 r
.49899 .55617 .51162 .55418 .53441 .55042 .522 .54672 Mtetra
.841 .915 .885 r
.522 .54672 .53441 .55042 .55734 .53623 .54511 .52677 Mtetra
.282 .641 .966 r
.54511 .52677 .55734 .53623 .58031 .51899 .56854 .53079 Mtetra
.228 0 0 r
.56854 .53079 .58031 .51899 .60358 .51227 .59213 .52455 Mtetra
0 0 0 r
.59213 .52455 .60358 .51227 .62723 .51142 .61556 .50458 Mtetra
.705 .871 .96 r
.61556 .50458 .62723 .51142 .65138 .51596 .63934 .49406 Mtetra
.441 .533 .855 r
.63934 .49406 .65138 .51596 .67599 .52241 .664 .50091 Mtetra
.817 .706 .742 r
.664 .50091 .67599 .52241 .69996 .50897 .6872 .46941 Mtetra
.585 .508 .735 r
.6872 .46941 .69996 .50897 .72348 .48588 .71197 .46836 Mtetra
.172 .427 .863 r
.71197 .46836 .72348 .48588 .74849 .48508 .73808 .48305 Mtetra
.942 .928 .762 r
.73808 .48305 .74849 .48508 .77401 .48703 .76109 .44699 Mtetra
.602 .518 .733 r
.76109 .44699 .77401 .48703 .79712 .45541 .78649 .44356 Mtetra
.156 .512 .914 r
.78649 .44356 .79712 .45541 .82483 .47604 .81339 .45379 Mtetra
.746 .686 .793 r
.81339 .45379 .82483 .47604 .84961 .46013 .83806 .43547 Mtetra
.466 .526 .835 r
.83806 .43547 .84961 .46013 .87609 .45922 .86545 .44258 Mtetra
.623 .697 .897 r
.86545 .44258 .87609 .45922 .89867 .42149 .89194 .43734 Mtetra
0 0 0 r
.89194 .43734 .89867 .42149 .92813 .44144 .91494 .4009 Mtetra
.628 .535 .731 r
.91494 .4009 .92813 .44144 .95253 .41769 .94145 .39332 Mtetra
.902 .984 .779 r
.35142 .5844 .36581 .57704 .38729 .57754 .37445 .55462 Mtetra
.369 .478 .84 r
.37445 .55462 .38729 .57754 .40965 .56004 .39587 .56392 Mtetra
.897 .973 .817 r
.39587 .56392 .40965 .56004 .4312 .57323 .41884 .53673 Mtetra
.336 .362 .74 r
.41884 .53673 .4312 .57323 .4541 .5438 .4406 .55461 Mtetra
.78 .971 .679 r
.4406 .55461 .4541 .5438 .4765 .54028 .46371 .52663 Mtetra
.593 .708 .923 r
.46371 .52663 .4765 .54028 .49899 .55617 .48645 .52338 Mtetra
.643 .564 .751 r
.48645 .52338 .49899 .55617 .522 .54672 .50945 .51546 Mtetra
.342 .398 .775 r
.50945 .51546 .522 .54672 .54511 .52677 .53269 .53106 Mtetra
.668 .972 .815 r
.53269 .53106 .54511 .52677 .56854 .53079 .55614 .51378 Mtetra
.743 .719 .829 r
.55614 .51378 .56854 .53079 .59213 .52455 .57969 .49876 Mtetra
.733 .646 .763 r
.57969 .49876 .59213 .52455 .61556 .50458 .60325 .48026 Mtetra
.522 .556 .831 r
.60325 .48026 .61556 .50458 .63934 .49406 .62751 .48305 Mtetra
.79 .812 .87 r
.62751 .48305 .63934 .49406 .664 .50091 .65136 .46577 Mtetra
.656 .566 .741 r
.65136 .46577 .664 .50091 .6872 .46941 .67559 .45518 Mtetra
0 .316 .802 r
.67559 .45518 .6872 .46941 .71197 .46836 .70149 .47268 Mtetra
.823 .994 .752 r
.70149 .47268 .71197 .46836 .73808 .48305 .72526 .44555 Mtetra
.57 .51 .748 r
.72526 .44555 .73808 .48305 .76109 .44699 .75086 .44594 Mtetra
0 .571 .742 r
.75086 .44594 .76109 .44699 .78649 .44356 .77688 .44728 Mtetra
.077 0 0 r
.77688 .44728 .78649 .44356 .81339 .45379 .80294 .44455 Mtetra
.817 .869 .885 r
.80294 .44455 .81339 .45379 .83806 .43547 .82775 .42504 Mtetra
.671 .818 .954 r
.82775 .42504 .83806 .43547 .86545 .44258 .85368 .416 Mtetra
.726 .652 .775 r
.85368 .416 .86545 .44258 .89194 .43734 .87886 .39815 Mtetra
.621 .537 .738 r
.87886 .39815 .89194 .43734 .91494 .4009 .90546 .39163 Mtetra
.288 .652 .969 r
.90546 .39163 .91494 .4009 .94145 .39332 .93371 .39589 Mtetra
.454 .459 .774 r
.33882 .55249 .35142 .5844 .37445 .55462 .36006 .56096 Mtetra
0 0 0 r
.36006 .56096 .37445 .55462 .39587 .56392 .38237 .55321 Mtetra
.615 .765 .951 r
.38237 .55321 .39587 .56392 .41884 .53673 .40475 .54832 Mtetra
0 0 0 r
.40475 .54832 .41884 .53673 .4406 .55461 .42767 .53204 Mtetra
.765 .673 .761 r
.42767 .53204 .4406 .55461 .46371 .52663 .4508 .50974 Mtetra
.689 .699 .854 r
.4508 .50974 .46371 .52663 .48645 .52338 .47371 .50033 Mtetra
.467 .537 .845 r
.47371 .50033 .48645 .52338 .50945 .51546 .49666 .50552 Mtetra
.173 .574 .936 r
.49666 .50552 .50945 .51546 .53269 .53106 .51998 .51171 Mtetra
.626 .654 .858 r
.51998 .51171 .53269 .53106 .55614 .51378 .54363 .50675 Mtetra
.817 .872 .886 r
.54363 .50675 .55614 .51378 .57969 .49876 .56734 .48808 Mtetra
.303 .635 .965 r
.56734 .48808 .57969 .49876 .60325 .48026 .59156 .49232 Mtetra
.693 .907 .558 r
.59156 .49232 .60325 .48026 .62751 .48305 .6152 .46162 Mtetra
.463 .556 .864 r
.6152 .46162 .62751 .48305 .65136 .46577 .63995 .46664 Mtetra
.382 .845 .847 r
.63995 .46664 .65136 .46577 .67559 .45518 .66456 .4587 Mtetra
.442 .869 .758 r
.66456 .4587 .67559 .45518 .70149 .47268 .68916 .44617 Mtetra
.673 .622 .79 r
.68916 .44617 .70149 .47268 .72526 .44555 .71402 .43554 Mtetra
.722 .833 .933 r
.71402 .43554 .72526 .44555 .75086 .44594 .73898 .42373 Mtetra
.421 .527 .86 r
.73898 .42373 .75086 .44594 .77688 .44728 .76556 .43154 Mtetra
.792 .769 .832 r
.76556 .43154 .77688 .44728 .80294 .44455 .79032 .41124 Mtetra
.433 .451 .779 r
.79032 .41124 .80294 .44455 .82775 .42504 .81807 .42357 Mtetra
.711 .98 .909 r
.81807 .42357 .82775 .42504 .85368 .416 .84357 .40724 Mtetra
.371 .717 .988 r
.84357 .40724 .85368 .416 .87886 .39815 .87105 .40837 Mtetra
0 0 0 r
.87105 .40837 .87886 .39815 .90546 .39163 .89608 .38476 Mtetra
.513 .833 .999 r
.89608 .38476 .90546 .39163 .93371 .39589 .92343 .37986 Mtetra
.736 .745 .858 r
.32507 .53885 .33882 .55249 .36006 .56096 .34747 .52608 Mtetra
.361 .388 .754 r
.34747 .52608 .36006 .56096 .38237 .55321 .36871 .54062 Mtetra
.488 .69 .957 r
.36871 .54062 .38237 .55321 .40475 .54832 .391 .54082 Mtetra
.625 .832 .98 r
.391 .54082 .40475 .54832 .42767 .53204 .41379 .53437 Mtetra
.687 .978 .894 r
.41379 .53437 .42767 .53204 .4508 .50974 .437 .51962 Mtetra
0 0 0 r
.437 .51962 .4508 .50974 .47371 .50033 .46021 .50992 Mtetra
.135 0 0 r
.46021 .50992 .47371 .50033 .49666 .50552 .48354 .504 Mtetra
.937 .618 .407 r
.48354 .504 .49666 .50552 .51998 .51171 .5062 .66205 Mtetra
.562 .315 .498 r
.5062 .66205 .51998 .51171 .54363 .50675 .53117 .6668 Mtetra
.495 .26 .488 r
.53117 .6668 .54363 .50675 .56734 .48808 .55624 .63989 Mtetra
.558 .311 .497 r
.55624 .63989 .56734 .48808 .59156 .49232 .58175 .64266 Mtetra
.54 .295 .493 r
.58175 .64266 .59156 .49232 .6152 .46162 .60743 .63646 Mtetra
.547 .306 .502 r
.60743 .63646 .6152 .46162 .63995 .46664 .63344 .63264 Mtetra
.517 .28 .495 r
.63344 .63264 .63995 .46664 .66456 .4587 .65915 .6137 Mtetra
.585 .333 .501 r
.65915 .6137 .66456 .4587 .68916 .44617 .68667 .63168 Mtetra
0 0 .352 r
.68667 .63168 .68916 .44617 .71402 .43554 .70257 .42546 Mtetra
.239 .613 .955 r
.70257 .42546 .71402 .43554 .73898 .42373 .72882 .4309 Mtetra
.66 .927 .639 r
.72882 .4309 .73898 .42373 .76556 .43154 .75335 .40548 Mtetra
.413 .49 .83 r
.75335 .40548 .76556 .43154 .79032 .41124 .78062 .4154 Mtetra
.882 .981 .693 r
.78062 .4154 .79032 .41124 .81807 .42357 .80451 .38042 Mtetra
.551 .483 .732 r
.80451 .38042 .81807 .42357 .84357 .40724 .83179 .38301 Mtetra
.607 .616 .834 r
.83179 .38301 .84357 .40724 .87105 .40837 .8588 .3788 Mtetra
.582 .565 .8 r
.8588 .3788 .87105 .40837 .89608 .38476 .88641 .37702 Mtetra
.547 .835 .998 r
.88641 .37702 .89608 .38476 .92343 .37986 .91393 .37138 Mtetra
.93 .969 .749 r
.30965 .548 .32507 .53885 .34747 .52608 .33364 .5123 Mtetra
.473 .664 .946 r
.33364 .5123 .34747 .52608 .36871 .54062 .35558 .51336 Mtetra
.716 .628 .758 r
.35558 .51336 .36871 .54062 .391 .54082 .37859 .49676 Mtetra
.595 .498 .714 r
.37859 .49676 .391 .54082 .41379 .53437 .40118 .49329 Mtetra
.597 .509 .726 r
.40118 .49329 .41379 .53437 .437 .51962 .42401 .48975 Mtetra
.625 .573 .776 r
.42401 .48975 .437 .51962 .46021 .50992 .44715 .48399 Mtetra
.72 .641 .769 r
.44715 .48399 .46021 .50992 .48354 .504 .47068 .46743 Mtetra
.971 .656 .304 r
.47068 .46743 .48354 .504 .5062 .66205 .4925 .64174 Mtetra
.43 .567 .891 r
.4925 .64174 .5062 .66205 .53117 .6668 .51751 .64697 Mtetra
.805 .723 .774 r
.51751 .64697 .53117 .6668 .55624 .63989 .54277 .61947 Mtetra
.318 .505 .883 r
.54277 .61947 .55624 .63989 .58175 .64266 .56843 .62923 Mtetra
.759 .789 .877 r
.56843 .62923 .58175 .64266 .60743 .63646 .59407 .61333 Mtetra
.167 .382 .829 r
.59407 .61333 .60743 .63646 .63344 .63264 .62075 .63074 Mtetra
.932 .925 .779 r
.62075 .63074 .63344 .63264 .65915 .6137 .64613 .59384 Mtetra
0 .283 .784 r
.64613 .59384 .65915 .6137 .68667 .63168 .67385 .61566 Mtetra
.967 .724 .519 r
.67385 .61566 .68667 .63168 .70257 .42546 .69075 .41234 Mtetra
.83 .807 .829 r
.69075 .41234 .70257 .42546 .72882 .4309 .7154 .38849 Mtetra
.423 .405 .735 r
.7154 .38849 .72882 .4309 .75335 .40548 .7427 .40415 Mtetra
.139 .681 .821 r
.7427 .40415 .75335 .40548 .78062 .4154 .76935 .40281 Mtetra
.903 .822 .757 r
.76935 .40281 .78062 .4154 .80451 .38042 .79329 .36502 Mtetra
.492 .663 .938 r
.79329 .36502 .80451 .38042 .83179 .38301 .82056 .36582 Mtetra
.626 .704 .902 r
.82056 .36582 .83179 .38301 .8588 .3788 .84755 .35982 Mtetra
.454 .594 .902 r
.84755 .35982 .8588 .3788 .88641 .37702 .87597 .36408 Mtetra
.885 .84 .795 r
.87597 .36408 .88641 .37702 .91393 .37138 .9006 .33234 Mtetra
.77 .716 .802 r
.2956 .53076 .30965 .548 .33364 .5123 .31878 .51162 Mtetra
.239 .751 .862 r
.31878 .51162 .33364 .5123 .35558 .51336 .34109 .50877 Mtetra
0 .47 .756 r
.34109 .50877 .35558 .51336 .37859 .49676 .36325 .51406 Mtetra
.802 .942 .588 r
.36325 .51406 .37859 .49676 .40118 .49329 .38755 .47702 Mtetra
0 .29 .785 r
.38755 .47702 .40118 .49329 .42401 .48975 .40979 .49277 Mtetra
.263 .768 .752 r
.40979 .49277 .42401 .48975 .44715 .48399 .43319 .48595 Mtetra
.931 .937 .781 r
.43319 .48595 .44715 .48399 .47068 .46743 .45737 .45153 Mtetra
.959 .649 .396 r
.45737 .45153 .47068 .46743 .4925 .64174 .47815 .65676 Mtetra
.15 0 0 r
.47815 .65676 .4925 .64174 .51751 .64697 .50356 .6472 Mtetra
.702 .975 .92 r
.50356 .6472 .51751 .64697 .54277 .61947 .52916 .63157 Mtetra
.471 .816 .529 r
.52916 .63157 .54277 .61947 .56843 .62923 .55482 .60874 Mtetra
.485 .6 .892 r
.55482 .60874 .56843 .62923 .59407 .61333 .58091 .61136 Mtetra
.28 0 0 r
.58091 .61136 .59407 .61333 .62075 .63074 .60752 .61914 Mtetra
.802 .83 .873 r
.60752 .61914 .62075 .63074 .64613 .59384 .63373 .59911 Mtetra
.268 0 0 r
.63373 .59911 .64613 .59384 .67385 .61566 .66086 .60034 Mtetra
.968 .726 .519 r
.66086 .60034 .67385 .61566 .69075 .41234 .67872 .39917 Mtetra
.537 .723 .959 r
.67872 .39917 .69075 .41234 .7154 .38849 .70482 .397 Mtetra
.186 0 0 r
.70482 .397 .7154 .38849 .7427 .40415 .73114 .39277 Mtetra
.847 .843 .84 r
.73114 .39277 .7427 .40415 .76935 .40281 .75627 .36791 Mtetra
.437 .451 .776 r
.75627 .36791 .76935 .40281 .79329 .36502 .78431 .37932 Mtetra
0 0 0 r
.78431 .37932 .79329 .36502 .82056 .36582 .80944 .35169 Mtetra
.475 .682 .956 r
.80944 .35169 .82056 .36582 .84755 .35982 .83728 .35231 Mtetra
.836 .923 .892 r
.83728 .35231 .84755 .35982 .87597 .36408 .86315 .33056 Mtetra
.683 .602 .759 r
.86315 .33056 .87597 .36408 .9006 .33234 .88986 .3158 Mtetra
.474 .513 .818 r
.28205 .5038 .2956 .53076 .31878 .51162 .30372 .50858 Mtetra
.446 .846 .975 r
.30372 .50858 .31878 .51162 .34109 .50877 .32629 .50407 Mtetra
.803 .897 .91 r
.32629 .50407 .34109 .50877 .36325 .51406 .34975 .48716 Mtetra
.755 .65 .746 r
.34975 .48716 .36325 .51406 .38755 .47702 .37357 .46371 Mtetra
0 .312 .782 r
.37357 .46371 .38755 .47702 .40979 .49277 .39592 .47735 Mtetra
.687 .73 .883 r
.39592 .47735 .40979 .49277 .43319 .48595 .41952 .46793 Mtetra
.601 .669 .887 r
.41952 .46793 .43319 .48595 .45737 .45153 .44315 .46406 Mtetra
.918 .607 .439 r
.44315 .46406 .45737 .45153 .47815 .65676 .46383 .64254 Mtetra
.877 .775 .746 r
.46383 .64254 .47815 .65676 .50356 .6472 .48971 .60206 Mtetra
.336 .345 .721 r
.48971 .60206 .50356 .6472 .52916 .63157 .51517 .62304 Mtetra
.962 .728 .538 r
.51517 .62304 .52916 .63157 .55482 .60874 .54018 .40855 Mtetra
.534 .355 .584 r
.54018 .40855 .55482 .60874 .58091 .61136 .56509 .42117 Mtetra
.59 .398 .59 r
.56509 .42117 .58091 .61136 .60752 .61914 .58993 .40347 Mtetra
.54 .357 .582 r
.58993 .40347 .60752 .61914 .63373 .59911 .61563 .41372 Mtetra
.625 .425 .591 r
.61563 .41372 .63373 .59911 .66086 .60034 .64008 .37477 Mtetra
.551 .365 .582 r
.64008 .37477 .66086 .60034 .67872 .39917 .66617 .37865 Mtetra
.783 .723 .796 r
.66617 .37865 .67872 .39917 .70482 .397 .6913 .35606 Mtetra
.569 .503 .741 r
.6913 .35606 .70482 .397 .73114 .39277 .71777 .35522 Mtetra
.45 .447 .763 r
.71777 .35522 .73114 .39277 .75627 .36791 .74541 .36588 Mtetra
.765 .984 .905 r
.74541 .36588 .75627 .36791 .78431 .37932 .77134 .34712 Mtetra
.607 .568 .784 r
.77134 .34712 .78431 .37932 .80944 .35169 .79854 .3421 Mtetra
.795 .884 .91 r
.79854 .3421 .80944 .35169 .83728 .35231 .8248 .32376 Mtetra
.691 .635 .788 r
.8248 .32376 .83728 .35231 .86315 .33056 .85159 .30966 Mtetra
.698 .703 .85 r
.85159 .30966 .86315 .33056 .88986 .3158 .87874 .29715 Mtetra
.746 .889 .944 r
.2667 .49858 .28205 .5038 .30372 .50858 .28972 .48578 Mtetra
.601 .615 .838 r
.28972 .48578 .30372 .50858 .32629 .50407 .31227 .48221 Mtetra
.792 .692 .754 r
.31227 .48221 .32629 .50407 .34975 .48716 .33642 .45501 Mtetra
.639 .572 .762 r
.33642 .45501 .34975 .48716 .37357 .46371 .35953 .44697 Mtetra
.466 .627 .923 r
.35953 .44697 .37357 .46371 .39592 .47735 .3824 .44884 Mtetra
.713 .628 .761 r
.3824 .44884 .39592 .47735 .41952 .46793 .40629 .43197 Mtetra
.591 .53 .754 r
.40629 .43197 .41952 .46793 .44315 .46406 .42986 .42874 Mtetra
.973 .662 .337 r
.42986 .42874 .44315 .46406 .46383 .64254 .44941 .62166 Mtetra
.82 .723 .758 r
.44941 .62166 .46383 .64254 .48971 .60206 .47541 .58943 Mtetra
0 .424 .853 r
.47541 .58943 .48971 .60206 .51517 .62304 .50098 .60103 Mtetra
.942 .712 .561 r
.50098 .60103 .51517 .62304 .54018 .40855 .52696 .41897 Mtetra
0 0 0 r
.52696 .41897 .54018 .40855 .56509 .42117 .55191 .40646 Mtetra
.814 .782 .823 r
.55191 .40646 .56509 .42117 .58993 .40347 .57686 .38336 Mtetra
.412 .562 .894 r
.57686 .38336 .58993 .40347 .61563 .41372 .60249 .38888 Mtetra
.557 .59 .842 r
.60249 .38888 .61563 .41372 .64008 .37477 .62837 .38801 Mtetra
.754 .911 .532 r
.62837 .38801 .64008 .37477 .66617 .37865 .65311 .34966 Mtetra
.553 .556 .811 r
.65311 .34966 .66617 .37865 .6913 .35606 .67945 .34961 Mtetra
.466 .822 .996 r
.67945 .34961 .6913 .35606 .71777 .35522 .70596 .34555 Mtetra
.327 .689 .98 r
.70596 .34555 .71777 .35522 .74541 .36588 .7332 .34765 Mtetra
.809 .763 .81 r
.7332 .34765 .74541 .36588 .77134 .34712 .75891 .32314 Mtetra
.293 .451 .847 r
.75891 .32314 .77134 .34712 .79854 .3421 .78778 .33691 Mtetra
.881 .952 .849 r
.78778 .33691 .79854 .3421 .8248 .32376 .81355 .3097 Mtetra
.245 .557 .933 r
.81355 .3097 .8248 .32376 .85159 .30966 .84286 .31813 Mtetra
0 0 0 r
.84286 .31813 .85159 .30966 .87874 .29715 .86969 .29865 Mtetra
.722 .652 .779 r
.25261 .47414 .2667 .49858 .28972 .48578 .27594 .45798 Mtetra
.114 .296 .77 r
.27594 .45798 .28972 .48578 .31227 .48221 .297 .47592 Mtetra
.849 .86 .85 r
.297 .47592 .31227 .48221 .33642 .45501 .32117 .4526 Mtetra
.242 0 0 r
.32117 .4526 .33642 .45501 .35953 .44697 .34372 .45836 Mtetra
0 0 0 r
.34372 .45836 .35953 .44697 .3824 .44884 .36755 .44557 Mtetra
.858 .916 .869 r
.36755 .44557 .3824 .44884 .40629 .43197 .39194 .42254 Mtetra
.147 .586 .93 r
.39194 .42254 .40629 .43197 .42986 .42874 .41537 .42772 Mtetra
.939 .624 .416 r
.41537 .42772 .42986 .42874 .44941 .62166 .43453 .61048 Mtetra
.864 .817 .801 r
.43453 .61048 .44941 .62166 .47541 .58943 .4608 .5793 Mtetra
.681 .832 .956 r
.4608 .5793 .47541 .58943 .50098 .60103 .48671 .56915 Mtetra
.545 .541 .801 r
.48671 .56915 .50098 .60103 .52696 .41897 .5128 .56969 Mtetra
.514 .261 .469 r
.5128 .56969 .52696 .41897 .55191 .40646 .53923 .55966 Mtetra
.494 .246 .466 r
.53923 .55966 .55191 .40646 .57686 .38336 .56578 .54137 Mtetra
.58 .318 .484 r
.56578 .54137 .57686 .38336 .60249 .38888 .59324 .56334 Mtetra
.531 .281 .481 r
.59324 .56334 .60249 .38888 .62837 .38801 .62071 .55929 Mtetra
0 0 .284 r
.62071 .55929 .62837 .38801 .65311 .34966 .64157 .36514 Mtetra
0 0 0 r
.64157 .36514 .65311 .34966 .67945 .34961 .66753 .34738 Mtetra
0 .568 .772 r
.66753 .34738 .67945 .34961 .70596 .34555 .69465 .34972 Mtetra
.877 .988 .722 r
.69465 .34972 .70596 .34555 .7332 .34765 .71995 .31537 Mtetra
.667 .602 .773 r
.71995 .31537 .7332 .34765 .75891 .32314 .74662 .30311 Mtetra
.276 .49 .884 r
.74662 .30311 .75891 .32314 .78778 .33691 .77539 .31447 Mtetra
.781 .723 .799 r
.77539 .31447 .78778 .33691 .81355 .3097 .80172 .2913 Mtetra
.788 .767 .834 r
.80172 .2913 .81355 .3097 .84286 .31813 .82826 .27002 Mtetra
.4 .381 .722 r
.82826 .27002 .84286 .31813 .86969 .29865 .85919 .2892 Mtetra
.675 .793 .937 r
.23717 .46326 .25261 .47414 .27594 .45798 .26005 .45479 Mtetra
.251 0 0 r
.26005 .45479 .27594 .45798 .297 .47592 .28204 .46103 Mtetra
.683 .74 .894 r
.28204 .46103 .297 .47592 .32117 .4526 .30545 .45181 Mtetra
.368 .829 .912 r
.30545 .45181 .32117 .4526 .34372 .45836 .3288 .44663 Mtetra
.791 .801 .86 r
.3288 .44663 .34372 .45836 .36755 .44557 .3531 .42822 Mtetra
.707 .721 .86 r
.3531 .42822 .36755 .44557 .39194 .42254 .37715 .41644 Mtetra
.344 .759 .979 r
.37715 .41644 .39194 .42254 .41537 .42772 .40095 .4154 Mtetra
.953 .636 .391 r
.40095 .4154 .41537 .42772 .43453 .61048 .41952 .59428 Mtetra
.562 .704 .936 r
.41952 .59428 .43453 .61048 .4608 .5793 .44537 .59122 Mtetra
.684 .938 .648 r
.44537 .59122 .4608 .5793 .48671 .56915 .47194 .56295 Mtetra
.838 .905 .884 r
.47194 .56295 .48671 .56915 .5128 .56969 .4984 .54025 Mtetra
.567 .572 .818 r
.4984 .54025 .5128 .56969 .53923 .55966 .52489 .5385 Mtetra
.426 .577 .9 r
.52489 .5385 .53923 .55966 .56578 .54137 .55178 .54304 Mtetra
.766 .995 .865 r
.55178 .54304 .56578 .54137 .59324 .56334 .57873 .52139 Mtetra
.574 .513 .749 r
.57873 .52139 .59324 .56334 .62071 .55929 .60619 .5191 Mtetra
.933 .69 .547 r
.60619 .5191 .62071 .55929 .64157 .36514 .62798 .33158 Mtetra
.645 .583 .77 r
.62798 .33158 .64157 .36514 .66753 .34738 .65432 .32168 Mtetra
.654 .639 .823 r
.65432 .32168 .66753 .34738 .69465 .34972 .68092 .31239 Mtetra
.475 .469 .771 r
.68092 .31239 .69465 .34972 .71995 .31537 .70874 .31958 Mtetra
.439 .86 .72 r
.70874 .31958 .71995 .31537 .74662 .30311 .73562 .30463 Mtetra
.225 .744 .753 r
.73562 .30463 .74662 .30311 .77539 .31447 .76329 .29786 Mtetra
.57 .708 .935 r
.76329 .29786 .77539 .31447 .80172 .2913 .79154 .29408 Mtetra
.601 .942 .769 r
.79154 .29408 .80172 .2913 .82826 .27002 .81868 .27472 Mtetra
.605 .922 .682 r
.81868 .27472 .82826 .27002 .85919 .2892 .84554 .2517 Mtetra
.626 .648 .852 r
.22238 .44211 .23717 .46326 .26005 .45479 .24509 .43645 Mtetra
.691 .701 .854 r
.24509 .43645 .26005 .45479 .28204 .46103 .2684 .42603 Mtetra
.461 .462 .772 r
.2684 .42603 .28204 .46103 .30545 .45181 .29067 .4324 Mtetra
.733 .705 .824 r
.29067 .4324 .30545 .45181 .3288 .44663 .31475 .41714 Mtetra
.588 .568 .799 r
.31475 .41714 .3288 .44663 .3531 .42822 .33824 .41382 Mtetra
.426 .659 .958 r
.33824 .41382 .3531 .42822 .37715 .41644 .36177 .4154 Mtetra
.868 .948 .864 r
.36177 .4154 .37715 .41644 .40095 .4154 .38678 .39081 Mtetra
.965 .644 .346 r
.38678 .39081 .40095 .4154 .41952 .59428 .4051 .55397 Mtetra
.641 .554 .741 r
.4051 .55397 .41952 .59428 .44537 .59122 .4311 .54324 Mtetra
.415 .391 .724 r
.4311 .54324 .44537 .59122 .47194 .56295 .45681 .55704 Mtetra
.887 .893 .829 r
.45681 .55704 .47194 .56295 .4984 .54025 .48367 .52656 Mtetra
0 .343 .799 r
.48367 .52656 .4984 .54025 .52489 .5385 .51024 .54111 Mtetra
.324 .809 .786 r
.51024 .54111 .52489 .5385 .55178 .54304 .53734 .53217 Mtetra
.762 .852 .918 r
.53734 .53217 .55178 .54304 .57873 .52139 .56462 .51572 Mtetra
.737 .93 .953 r
.56462 .51572 .57873 .52139 .60619 .5191 .59206 .50018 Mtetra
.962 .728 .536 r
.59206 .50018 .60619 .5191 .62798 .33158 .61505 .32407 Mtetra
.577 .858 .996 r
.61505 .32407 .62798 .33158 .65432 .32168 .64175 .31681 Mtetra
.907 .931 .818 r
.64175 .31681 .65432 .32168 .68092 .31239 .66761 .28534 Mtetra
.295 .432 .83 r
.66761 .28534 .68092 .31239 .70874 .31958 .69584 .29927 Mtetra
.768 .741 .828 r
.69584 .29927 .70874 .31958 .73562 .30463 .72258 .2792 Mtetra
.525 .583 .856 r
.72258 .2792 .73562 .30463 .76329 .29786 .75089 .27977 Mtetra
.706 .75 .886 r
.75089 .27977 .76329 .29786 .79154 .29408 .77856 .26682 Mtetra
.703 .661 .806 r
.77856 .26682 .79154 .29408 .81868 .27472 .80622 .25142 Mtetra
.744 .713 .822 r
.80622 .25142 .81868 .27472 .84554 .2517 .83373 .23278 Mtetra
0 .038 .549 r
.20692 .42581 .22238 .44211 .24509 .43645 .22739 .44567 Mtetra
.601 .937 .746 r
.22739 .44567 .24509 .43645 .2684 .42603 .25163 .42753 Mtetra
.862 .965 .866 r
.25163 .42753 .2684 .42603 .29067 .4324 .2764 .40356 Mtetra
.442 .496 .819 r
.2764 .40356 .29067 .4324 .31475 .41714 .29907 .4092 Mtetra
.463 .789 .999 r
.29907 .4092 .31475 .41714 .33824 .41382 .32267 .40654 Mtetra
.696 .872 .964 r
.32267 .40654 .33824 .41382 .36177 .4154 .34702 .39565 Mtetra
.772 .72 .804 r
.34702 .39565 .36177 .4154 .38678 .39081 .37202 .37496 Mtetra
.956 .636 .377 r
.37202 .37496 .38678 .39081 .4051 .55397 .38941 .54426 Mtetra
.597 .823 .986 r
.38941 .54426 .4051 .55397 .4311 .54324 .41549 .53748 Mtetra
.251 .72 .944 r
.41549 .53748 .4311 .54324 .45681 .55704 .44167 .5374 Mtetra
.949 .716 .551 r
.44167 .5374 .45681 .55704 .48367 .52656 .47164 .33576 Mtetra
.555 .365 .579 r
.47164 .33576 .48367 .52656 .51024 .54111 .49704 .33057 Mtetra
.55 .358 .574 r
.49704 .33057 .51024 .54111 .53734 .53217 .52273 .32728 Mtetra
.564 .37 .577 r
.52273 .32728 .53734 .53217 .56462 .51572 .5487 .31645 Mtetra
.576 .38 .579 r
.5487 .31645 .56462 .51572 .59206 .50018 .57479 .2997 Mtetra
.52 .338 .575 r
.57479 .2997 .59206 .50018 .61505 .32407 .60171 .31162 Mtetra
.556 .768 .977 r
.60171 .31162 .61505 .32407 .64175 .31681 .6287 .30715 Mtetra
.69 .864 .965 r
.6287 .30715 .64175 .31681 .66761 .28534 .65573 .29552 Mtetra
.638 .899 .58 r
.65573 .29552 .66761 .28534 .69584 .29927 .68209 .26616 Mtetra
.586 .561 .793 r
.68209 .26616 .69584 .29927 .72258 .2792 .70989 .26219 Mtetra
.762 .782 .869 r
.70989 .26219 .72258 .2792 .75089 .27977 .7371 .24436 Mtetra
.696 .609 .755 r
.7371 .24436 .75089 .27977 .77856 .26682 .76443 .22655 Mtetra
.485 .467 .763 r
.76443 .22655 .77856 .26682 .80622 .25142 .79403 .23292 Mtetra
.737 .764 .875 r
.79403 .23292 .80622 .25142 .83373 .23278 .82204 .21694 Mtetra
.598 .663 .885 r
.1915 .40653 .20692 .42581 .22739 .44567 .21421 .40233 Mtetra
.413 .394 .729 r
.21421 .40233 .22739 .44567 .25163 .42753 .23585 .41299 Mtetra
.825 .767 .797 r
.23585 .41299 .25163 .42753 .2764 .40356 .26103 .38637 Mtetra
.26 .534 .918 r
.26103 .38637 .2764 .40356 .29907 .4092 .28365 .39316 Mtetra
.698 .742 .885 r
.28365 .39316 .29907 .4092 .32267 .40654 .3079 .38223 Mtetra
.75 .679 .782 r
.3079 .38223 .32267 .40654 .34702 .39565 .33289 .36197 Mtetra
.194 .313 .758 r
.33289 .36197 .34702 .39565 .37202 .37496 .35588 .38039 Mtetra
.927 .609 .419 r
.35588 .38039 .37202 .37496 .38941 .54426 .37257 .55246 Mtetra
.783 .993 .771 r
.37257 .55246 .38941 .54426 .41549 .53748 .39975 .52499 Mtetra
.529 .76 .981 r
.39975 .52499 .41549 .53748 .44167 .5374 .42617 .52149 Mtetra
.954 .722 .548 r
.42617 .52149 .44167 .5374 .47164 .33576 .45723 .31902 Mtetra
.697 .746 .89 r
.45723 .31902 .47164 .33576 .49704 .33057 .48284 .30762 Mtetra
.019 .303 .795 r
.48284 .30762 .49704 .33057 .52273 .32728 .50849 .32638 Mtetra
.634 .955 .932 r
.50849 .32638 .52273 .32728 .5487 .31645 .53476 .31291 Mtetra
.921 .924 .796 r
.53476 .31291 .5487 .31645 .57479 .2997 .56095 .27803 Mtetra
.684 .694 .853 r
.56095 .27803 .57479 .2997 .60171 .31162 .58743 .26648 Mtetra
.467 .433 .737 r
.58743 .26648 .60171 .31162 .6287 .30715 .6147 .27467 Mtetra
.63 .589 .789 r
.6147 .27467 .6287 .30715 .65573 .29552 .64191 .2662 Mtetra
.64 .616 .81 r
.64191 .2662 .65573 .29552 .68209 .26616 .66939 .25712 Mtetra
.248 .669 .963 r
.66939 .25712 .68209 .26616 .70989 .26219 .6978 .25976 Mtetra
.882 .98 .83 r
.6978 .25976 .70989 .26219 .7371 .24436 .72463 .23033 Mtetra
.355 .648 .966 r
.72463 .23033 .7371 .24436 .76443 .22655 .75381 .23356 Mtetra
.113 0 0 r
.75381 .23356 .76443 .22655 .79403 .23292 .78292 .22956 Mtetra
.542 .915 .947 r
.78292 .22956 .79403 .23292 .82204 .21694 .8118 .21863 Mtetra
.898 .987 .751 r
.17242 .41874 .1915 .40653 .21421 .40233 .19853 .38385 Mtetra
.685 .706 .864 r
.19853 .38385 .21421 .40233 .23585 .41299 .22213 .37359 Mtetra
.591 .521 .745 r
.22213 .37359 .23585 .41299 .26103 .38637 .24543 .3689 Mtetra
.335 .575 .929 r
.24543 .3689 .26103 .38637 .28365 .39316 .26823 .3737 Mtetra
.688 .703 .858 r
.26823 .3737 .28365 .39316 .3079 .38223 .29258 .36279 Mtetra
.547 .652 .904 r
.29258 .36279 .3079 .38223 .33289 .36197 .31654 .36077 Mtetra
.651 .948 .953 r
.31654 .36077 .33289 .36197 .35588 .38039 .34141 .34849 Mtetra
.969 .649 .326 r
.34141 .34849 .35588 .38039 .37257 .55246 .35767 .51115 Mtetra
.373 .397 .757 r
.35767 .51115 .37257 .55246 .39975 .52499 .38319 .52408 Mtetra
.895 .949 .833 r
.38319 .52408 .39975 .52499 .42617 .52149 .41082 .49296 Mtetra
.291 .436 .835 r
.41082 .49296 .42617 .52149 .45723 .31902 .43722 .50506 Mtetra
.509 .251 .459 r
.43722 .50506 .45723 .31902 .48284 .30762 .46455 .49899 Mtetra
.501 .246 .459 r
.46455 .49899 .48284 .30762 .50849 .32638 .49225 .48876 Mtetra
.47 .213 .442 r
.49225 .48876 .50849 .32638 .53476 .31291 .52022 .46847 Mtetra
.522 .254 .45 r
.52022 .46847 .53476 .31291 .56095 .27803 .54843 .46943 Mtetra
0 0 .226 r
.54843 .46943 .56095 .27803 .58743 .26648 .57366 .25339 Mtetra
.664 .804 .95 r
.57366 .25339 .58743 .26648 .6147 .27467 .60063 .24362 Mtetra
.525 .544 .817 r
.60063 .24362 .6147 .27467 .64191 .2662 .62821 .24427 Mtetra
.717 .715 .846 r
.62821 .24427 .64191 .2662 .66939 .25712 .65558 .22917 Mtetra
.54 .579 .842 r
.65558 .22917 .66939 .25712 .6978 .25976 .68386 .22827 Mtetra
.751 .66 .76 r
.68386 .22827 .6978 .25976 .72463 .23033 .71115 .20385 Mtetra
.629 .639 .841 r
.71115 .20385 .72463 .23033 .75381 .23356 .73961 .19586 Mtetra
.381 .421 .778 r
.73961 .19586 .75381 .23356 .78292 .22956 .77014 .20925 Mtetra
.725 .748 .87 r
.77014 .20925 .78292 .22956 .8118 .21863 .79879 .19359 Mtetra
.766 .82 .895 r
.15533 .40816 .17242 .41874 .19853 .38385 .17965 .39264 Mtetra
.194 0 0 r
.17965 .39264 .19853 .38385 .22213 .37359 .20272 .39066 Mtetra
.782 .965 .66 r
.20272 .39066 .22213 .37359 .24543 .3689 .22897 .35773 Mtetra
.597 .791 .973 r
.22897 .35773 .24543 .3689 .26823 .3737 .25276 .35188 Mtetra
.647 .667 .856 r
.25276 .35188 .26823 .3737 .29258 .36279 .27698 .34385 Mtetra
.46 .623 .922 r
.27698 .34385 .29258 .36279 .31654 .36077 .30077 .34513 Mtetra
.764 .77 .857 r
.30077 .34513 .31654 .36077 .34141 .34849 .32612 .32773 Mtetra
.961 .644 .376 r
.32612 .32773 .34141 .34849 .35767 .51115 .34045 .51103 Mtetra
.779 .979 .91 r
.34045 .51103 .35767 .51115 .38319 .52408 .36771 .4909 Mtetra
.437 .487 .814 r
.36771 .4909 .38319 .52408 .41082 .49296 .394 .49714 Mtetra
.628 .961 .841 r
.394 .49714 .41082 .49296 .43722 .50506 .42156 .47933 Mtetra
.406 .536 .875 r
.42156 .47933 .43722 .50506 .46455 .49899 .44871 .48493 Mtetra
.817 .822 .853 r
.44871 .48493 .46455 .49899 .49225 .48876 .47681 .46081 Mtetra
.766 .688 .777 r
.47681 .46081 .49225 .48876 .52022 .46847 .50495 .43552 Mtetra
.199 .348 .789 r
.50495 .43552 .52022 .46847 .54843 .46943 .53321 .45444 Mtetra
.971 .728 .51 r
.53321 .45444 .54843 .46943 .57366 .25339 .55951 .23132 Mtetra
.215 .451 .871 r
.55951 .23132 .57366 .25339 .60063 .24362 .58706 .24336 Mtetra
.486 .9 .893 r
.58706 .24336 .60063 .24362 .62821 .24427 .6146 .23246 Mtetra
.877 .862 .822 r
.6146 .23246 .62821 .24427 .65558 .22917 .64165 .20198 Mtetra
.453 .54 .855 r
.64165 .20198 .65558 .22917 .68386 .22827 .67025 .20619 Mtetra
.557 .65 .897 r
.67025 .20619 .68386 .22827 .71115 .20385 .69899 .2031 Mtetra
.878 .991 .802 r
.69899 .2031 .71115 .20385 .73961 .19586 .72626 .17171 Mtetra
.544 .622 .881 r
.72626 .17171 .73961 .19586 .77014 .20925 .75567 .16971 Mtetra
.572 .53 .77 r
.75567 .16971 .77014 .20925 .79879 .19359 .78541 .16601 Mtetra
.782 .753 .827 r
.13856 .39197 .15533 .40816 .17965 .39264 .16355 .3718 Mtetra
.77 .711 .797 r
.16355 .3718 .17965 .39264 .20272 .39066 .18871 .35046 Mtetra
.477 .454 .753 r
.18871 .35046 .20272 .39066 .22897 .35773 .21134 .35495 Mtetra
.691 .936 .965 r
.21134 .35495 .22897 .35773 .25276 .35188 .23594 .34244 Mtetra
.519 .798 .996 r
.23594 .34244 .25276 .35188 .27698 .34385 .25999 .33835 Mtetra
.78 .911 .93 r
.25999 .33835 .27698 .34385 .30077 .34513 .28531 .32158 Mtetra
.692 .674 .828 r
.28531 .32158 .30077 .34513 .32612 .32773 .31044 .30899 Mtetra
.959 .645 .389 r
.31044 .30899 .32612 .32773 .34045 .51103 .32308 .50547 Mtetra
.709 .919 .965 r
.32308 .50547 .34045 .51103 .36771 .4909 .35031 .49149 Mtetra
.915 .949 .805 r
.35031 .49149 .36771 .4909 .394 .49714 .37869 .45572 Mtetra
.096 .223 .707 r
.37869 .45572 .394 .49714 .42156 .47933 .40463 .48262 Mtetra
.334 .814 .784 r
.40463 .48262 .42156 .47933 .44871 .48493 .43247 .47297 Mtetra
.736 .846 .932 r
.43247 .47297 .44871 .48493 .47681 .46081 .46069 .45779 Mtetra
.373 .825 .934 r
.46069 .45779 .47681 .46081 .50495 .43552 .489 .45214 Mtetra
0 0 0 r
.489 .45214 .50495 .43552 .53321 .45444 .51769 .4346 Mtetra
.965 .726 .527 r
.51769 .4346 .53321 .45444 .55951 .23132 .54534 .23841 Mtetra
0 0 0 r
.54534 .23841 .55951 .23132 .58706 .24336 .5729 .23161 Mtetra
.653 .833 .969 r
.5729 .23161 .58706 .24336 .6146 .23246 .60072 .2216 Mtetra
.834 .882 .878 r
.60072 .2216 .6146 .23246 .64165 .20198 .62835 .1979 Mtetra
.149 .674 .876 r
.62835 .1979 .64165 .20198 .67025 .20619 .65705 .19816 Mtetra
.713 .916 .964 r
.65705 .19816 .67025 .20619 .69899 .2031 .68546 .18348 Mtetra
.845 .789 .796 r
.68546 .18348 .69899 .2031 .72626 .17171 .71304 .15246 Mtetra
.248 .515 .908 r
.71304 .15246 .72626 .17171 .75567 .16971 .74349 .16211 Mtetra
.417 .804 .989 r
.74349 .16211 .75567 .16971 .78541 .16601 .77352 .1581 Mtetra
.714 .608 .737 r
.12386 .35684 .13856 .39197 .16355 .3718 .14891 .33646 Mtetra
.346 .403 .778 r
.14891 .33646 .16355 .3718 .18871 .35046 .17059 .34661 Mtetra
.653 .916 .978 r
.17059 .34661 .18871 .35046 .21134 .35495 .19493 .33602 Mtetra
.772 .735 .819 r
.19493 .33602 .21134 .35495 .23594 .34244 .22039 .3158 Mtetra
.54 .582 .846 r
.22039 .3158 .23594 .34244 .25999 .33835 .24422 .31443 Mtetra
.252 .456 .865 r
.24422 .31443 .25999 .33835 .28531 .32158 .2675 .32389 Mtetra
.621 .958 .897 r
.2675 .32389 .28531 .32158 .31044 .30899 .29306 .3097 Mtetra
.875 .967 .851 r
.29306 .3097 .31044 .30899 .32308 .50547 .31963 .2824 Mtetra
.519 .325 .557 r
.31963 .2824 .32308 .50547 .35031 .49149 .3444 .28541 Mtetra
.526 .333 .562 r
.3444 .28541 .35031 .49149 .37869 .45572 .36975 .28554 Mtetra
.597 .395 .579 r
.36975 .28554 .37869 .45572 .40463 .48262 .39671 .25696 Mtetra
.546 .346 .56 r
.39671 .25696 .40463 .48262 .43247 .47297 .42298 .24695 Mtetra
.505 .314 .556 r
.42298 .24695 .43247 .47297 .46069 .45779 .449 .25702 Mtetra
.546 .351 .567 r
.449 .25702 .46069 .45779 .489 .45214 .47593 .24798 Mtetra
.6 .39 .569 r
.47593 .24798 .489 .45214 .51769 .4346 .50334 .21061 Mtetra
.538 .34 .56 r
.50334 .21061 .51769 .4346 .54534 .23841 .53059 .20468 Mtetra
.661 .606 .783 r
.53059 .20468 .54534 .23841 .5729 .23161 .55811 .19188 Mtetra
.299 .361 .759 r
.55811 .19188 .5729 .23161 .60072 .2216 .58647 .20893 Mtetra
.92 .844 .753 r
.58647 .20893 .60072 .2216 .62835 .1979 .61385 .16613 Mtetra
.575 .577 .818 r
.61385 .16613 .62835 .1979 .65705 .19816 .64241 .16197 Mtetra
.698 .617 .762 r
.64241 .16197 .65705 .19816 .68546 .18348 .67067 .14324 Mtetra
.562 .523 .769 r
.67067 .14324 .68546 .18348 .71304 .15246 .69999 .14005 Mtetra
.057 .495 .891 r
.69999 .14005 .71304 .15246 .74349 .16211 .73069 .15012 Mtetra
.608 .833 .986 r
.73069 .15012 .74349 .16211 .77352 .1581 .76061 .14126 Mtetra
.734 .96 .942 r
.10448 .35644 .12386 .35684 .14891 .33646 .12916 .34128 Mtetra
.863 .983 .848 r
.12916 .34128 .14891 .33646 .17059 .34661 .15529 .31493 Mtetra
.634 .59 .788 r
.15529 .31493 .17059 .34661 .19493 .33602 .17943 .30619 Mtetra
.278 .411 .817 r
.17943 .30619 .19493 .33602 .22039 .3158 .2018 .31681 Mtetra
.885 .954 .845 r
.2018 .31681 .22039 .3158 .24422 .31443 .22841 .28847 Mtetra
.367 .502 .863 r
.22841 .28847 .24422 .31443 .2675 .32389 .25193 .29464 Mtetra
.634 .612 .811 r
.25193 .29464 .2675 .32389 .29306 .3097 .2771 .28604 Mtetra
.608 .65 .865 r
.2771 .28604 .29306 .3097 .31963 .2824 .30234 .27993 Mtetra
.247 .75 .89 r
.30234 .27993 .31963 .2824 .3444 .28541 .32767 .27718 Mtetra
.732 .887 .951 r
.32767 .27718 .3444 .28541 .36975 .28554 .35399 .26293 Mtetra
.836 .734 .751 r
.35399 .26293 .36975 .28554 .39671 .25696 .38149 .22712 Mtetra
.444 .514 .836 r
.38149 .22712 .39671 .25696 .42298 .24695 .40727 .23129 Mtetra
.159 .523 .918 r
.40727 .23129 .42298 .24695 .449 .25702 .43343 .23915 Mtetra
.751 .772 .87 r
.43343 .23915 .449 .25702 .47593 .24798 .4607 .22188 Mtetra
.525 .597 .868 r
.4607 .22188 .47593 .24798 .50334 .21061 .48792 .22078 Mtetra
.835 .976 .674 r
.48792 .22078 .50334 .21061 .53059 .20468 .51568 .18327 Mtetra
.713 .728 .862 r
.51568 .18327 .53059 .20468 .55811 .19188 .54336 .16851 Mtetra
.203 .442 .867 r
.54336 .16851 .55811 .19188 .58647 .20893 .57166 .18074 Mtetra
.527 .584 .855 r
.57166 .18074 .58647 .20893 .61385 .16613 .60035 .17963 Mtetra
.759 .919 .549 r
.60035 .17963 .61385 .16613 .64241 .16197 .6281 .13804 Mtetra
.683 .7 .86 r
.6281 .13804 .64241 .16197 .67067 .14324 .65682 .12516 Mtetra
.57 .722 .945 r
.65682 .12516 .67067 .14324 .69999 .14005 .68623 .11988 Mtetra
.259 .52 .91 r
.68623 .11988 .69999 .14005 .73069 .15012 .71698 .1289 Mtetra
.827 .785 .813 r
.71698 .1289 .73069 .15012 .76061 .14126 .74563 .10026 Mtetra
.811 .742 .788 r
.08703 .33821 .10448 .35644 .12916 .34128 .11344 .31094 Mtetra
.589 .58 .81 r
.11344 .31094 .12916 .34128 .15529 .31493 .13702 .30602 Mtetra
.665 .852 .971 r
.13702 .30602 .15529 .31493 .17943 .30619 .16144 .29628 Mtetra
.803 .846 .883 r
.16144 .29628 .17943 .30619 .2018 .31681 .18716 .27662 Mtetra
.602 .534 .75 r
.18716 .27662 .2018 .31681 .22841 .28847 .21169 .26941 Mtetra
.364 .591 .931 r
.21169 .26941 .22841 .28847 .25193 .29464 .23548 .27287 Mtetra
.628 .679 .879 r
.23548 .27287 .25193 .29464 .2771 .28604 .26065 .26541 Mtetra
.665 .706 .878 r
.26065 .26541 .2771 .28604 .30234 .27993 .28628 .25539 Mtetra
.321 .5 .878 r
.28628 .25539 .30234 .27993 .32767 .27718 .31096 .26253 Mtetra
.872 .799 .776 r
.31096 .26253 .32767 .27718 .35399 .26293 .3388 .22656 Mtetra
.35 .413 .786 r
.3388 .22656 .35399 .26293 .38149 .22712 .36401 .23704 Mtetra
.472 .861 .663 r
.36401 .23704 .38149 .22712 .40727 .23129 .3911 .21858 Mtetra
.801 .842 .881 r
.3911 .21858 .40727 .23129 .43343 .23915 .41839 .19776 Mtetra
.316 .365 .754 r
.41839 .19776 .43343 .23915 .4607 .22188 .44483 .21237 Mtetra
.925 .857 .756 r
.44483 .21237 .4607 .22188 .48792 .22078 .47298 .16903 Mtetra
.605 .503 .712 r
.47298 .16903 .48792 .22078 .51568 .18327 .50054 .15902 Mtetra
.576 .645 .882 r
.50054 .15902 .51568 .18327 .54336 .16851 .52839 .15431 Mtetra
0 .426 .855 r
.52839 .15431 .54336 .16851 .57166 .18074 .55681 .16615 Mtetra
.906 .835 .764 r
.55681 .16615 .57166 .18074 .60035 .17963 .58489 .12541 Mtetra
.608 .501 .706 r
.58489 .12541 .60035 .17963 .6281 .13804 .61357 .11427 Mtetra
.612 .674 .885 r
.61357 .11427 .6281 .13804 .65682 .12516 .6427 .10685 Mtetra
.697 .776 .912 r
.6427 .10685 .65682 .12516 .68623 .11988 .6719 .09349 Mtetra
.389 .53 .877 r
.6719 .09349 .68623 .11988 .71698 .1289 .70256 .09955 Mtetra
.744 .691 .801 r
.70256 .09955 .71698 .1289 .74563 .10026 .7319 .07769 Mtetra
.735 .679 .797 r
.07023 .31327 .08703 .33821 .11344 .31094 .09556 .29493 Mtetra
0 .334 .793 r
.09556 .29493 .11344 .31094 .13702 .30602 .11709 .30647 Mtetra
.852 .957 .877 r
.11709 .30647 .13702 .30602 .16144 .29628 .14355 .28212 Mtetra
.788 .796 .859 r
.14355 .28212 .16144 .29628 .18716 .27662 .16949 .26232 Mtetra
0 .354 .794 r
.16949 .26232 .18716 .27662 .21169 .26941 .19218 .27345 Mtetra
.886 .977 .828 r
.19218 .27345 .21169 .26941 .23548 .27287 .21953 .24327 Mtetra
.063 .287 .776 r
.21953 .24327 .23548 .27287 .26065 .26541 .24248 .26019 Mtetra
.678 .918 .974 r
.24248 .26019 .26065 .26541 .28628 .25539 .26855 .24783 Mtetra
.806 .898 .908 r
.26855 .24783 .28628 .25539 .31096 .26253 .2954 .22779 Mtetra
.738 .636 .746 r
.2954 .22779 .31096 .26253 .3388 .22656 .32263 .20332 Mtetra
.603 .663 .881 r
.32263 .20332 .3388 .22656 .36401 .23704 .34881 .19703 Mtetra
.419 .437 .772 r
.34881 .19703 .36401 .23704 .3911 .21858 .37465 .20415 Mtetra
.472 .726 .981 r
.37465 .20415 .3911 .21858 .41839 .19776 .40143 .20208 Mtetra
.622 .958 .825 r
.40143 .20208 .41839 .19776 .44483 .21237 .42916 .18368 Mtetra
.77 .691 .775 r
.42916 .18368 .44483 .21237 .47298 .16903 .45718 .15782 Mtetra
.044 .52 .887 r
.45718 .15782 .47298 .16903 .50054 .15902 .48475 .1652 Mtetra
.565 .924 .75 r
.48475 .1652 .50054 .15902 .52839 .15431 .51306 .14558 Mtetra
.863 .913 .864 r
.51306 .14558 .52839 .15431 .55681 .16615 .54144 .11814 Mtetra
.595 .513 .732 r
.54144 .11814 .55681 .16615 .58489 .12541 .57009 .10969 Mtetra
.712 .814 .928 r
.57009 .10969 .58489 .12541 .61357 .11427 .59894 .09552 Mtetra
.654 .756 .925 r
.59894 .09552 .61357 .11427 .6427 .10685 .62817 .08511 Mtetra
.63 .712 .906 r
.62817 .08511 .6427 .10685 .6719 .09349 .6578 .07617 Mtetra
.047 .426 .868 r
.6578 .07617 .6719 .09349 .70256 .09955 .68906 .08979 Mtetra
.814 .932 .91 r
.68906 .08979 .70256 .09955 .7319 .07769 .71873 .06682 Mtetra
.877 .849 .812 r
.05041 .30656 .07023 .31327 .09556 .29493 .07791 .27488 Mtetra
.661 .706 .881 r
.07791 .27488 .09556 .29493 .11709 .30647 .10226 .26538 Mtetra
.652 .56 .738 r
.10226 .26538 .11709 .30647 .14355 .28212 .12737 .25174 Mtetra
0 .208 .73 r
.12737 .25174 .14355 .28212 .16949 .26232 .14867 .27071 Mtetra
.809 1 .815 r
.14867 .27071 .16949 .26232 .19218 .27345 .17582 .2443 Mtetra
.574 .593 .834 r
.17582 .2443 .19218 .27345 .21953 .24327 .20061 .23988 Mtetra
.312 .784 .928 r
.20061 .23988 .21953 .24327 .24248 .26019 .22564 .23638 Mtetra
.721 .7 .83 r
.22564 .23638 .24248 .26019 .26855 .24783 .25217 .22006 Mtetra
.721 .671 .8 r
.25217 .22006 .26855 .24783 .2954 .22779 .27897 .20212 Mtetra
.699 .68 .828 r
.27897 .20212 .2954 .22779 .32263 .20332 .30565 .18749 Mtetra
.748 .797 .892 r
.30565 .18749 .32263 .20332 .34881 .19703 .33264 .17108 Mtetra
.16 .396 .842 r
.33264 .17108 .34881 .19703 .37465 .20415 .35816 .18374 Mtetra
.829 .765 .791 r
.35816 .18374 .37465 .20415 .40143 .20208 .38636 .15337 Mtetra
.441 .413 .732 r
.38636 .15337 .40143 .20208 .42916 .18368 .41308 .16022 Mtetra
.729 .721 .843 r
.41308 .16022 .42916 .18368 .45718 .15782 .44109 .1429 Mtetra
.088 .5 .901 r
.44109 .1429 .45718 .15782 .48475 .1652 .46876 .15157 Mtetra
.667 .827 .96 r
.46876 .15157 .48475 .1652 .51306 .14558 .49728 .14021 Mtetra
.88 .949 .85 r
.49728 .14021 .51306 .14558 .54144 .11814 .52609 .11025 Mtetra
.346 .767 .976 r
.52609 .11025 .54144 .11814 .57009 .10969 .5551 .10788 Mtetra
.858 .989 .843 r
.5551 .10788 .57009 .10969 .59894 .09552 .58406 .07866 Mtetra
.122 .493 .904 r
.58406 .07866 .59894 .09552 .62817 .08511 .61416 .08861 Mtetra
.617 .95 .784 r
.61416 .08861 .62817 .08511 .6578 .07617 .64374 .06739 Mtetra
.067 .57 .888 r
.64374 .06739 .6578 .07617 .68906 .08979 .67484 .07302 Mtetra
.881 .85 .809 r
.67484 .07302 .68906 .08979 .71873 .06682 .70414 .03869 Mtetra
.037 .154 .658 r
.03606 .26208 .05041 .30656 .07791 .27488 .05538 .28487 Mtetra
.941 .948 .757 r
.05538 .28487 .07791 .27488 .10226 .26538 .08492 .24143 Mtetra
0 .208 .732 r
.08492 .24143 .10226 .26538 .12737 .25174 .10598 .25818 Mtetra
.504 .907 .811 r
.10598 .25818 .12737 .25174 .14867 .27071 .13157 .24461 Mtetra
.456 .565 .877 r
.13157 .24461 .14867 .27071 .17582 .2443 .15554 .246 Mtetra
.677 .971 .917 r
.15554 .246 .17582 .2443 .20061 .23988 .18185 .23021 Mtetra
.748 .87 .936 r
.18185 .23021 .20061 .23988 .22564 .23638 .20829 .21475 Mtetra
.764 .734 .825 r
.20829 .21475 .22564 .23638 .25217 .22006 .23538 .19409 Mtetra
.655 .663 .845 r
.23538 .19409 .25217 .22006 .27897 .20212 .26167 .1835 Mtetra
.765 .768 .856 r
.26167 .1835 .27897 .20212 .30565 .18749 .28888 .16431 Mtetra
.486 .618 .907 r
.28888 .16431 .30565 .18749 .33264 .17108 .3149 .16373 Mtetra
.134 .638 .904 r
.3149 .16373 .33264 .17108 .35816 .18374 .34119 .16586 Mtetra
.543 .716 .953 r
.34119 .16586 .35816 .18374 .38636 .15337 .36832 .16158 Mtetra
.85 .994 .746 r
.36832 .16158 .38636 .15337 .41308 .16022 .39715 .12692 Mtetra
.452 .509 .827 r
.39715 .12692 .41308 .16022 .44109 .1429 .42455 .12997 Mtetra
.649 .832 .971 r
.42455 .12997 .44109 .1429 .46876 .15157 .45283 .11945 Mtetra
.597 .6 .826 r
.45283 .11945 .46876 .15157 .49728 .14021 .48137 .11231 Mtetra
.804 .72 .772 r
.48137 .11231 .49728 .14021 .52609 .11025 .5104 .08148 Mtetra
.645 .652 .843 r
.5104 .08148 .52609 .11025 .5551 .10788 .53945 .07056 Mtetra
.368 .436 .8 r
.53945 .07056 .5551 .10788 .58406 .07866 .56913 .07991 Mtetra
.355 .829 .815 r
.56913 .07991 .58406 .07866 .61416 .08861 .59905 .06972 Mtetra
.865 .821 .804 r
.59905 .06972 .61416 .08861 .64374 .06739 .62849 .03613 Mtetra
.219 .392 .822 r
.62849 .03613 .64374 .06739 .67484 .07302 .66008 .05151 Mtetra
.76 .782 .871 r
.66008 .05151 .67484 .07302 .70414 .03869 .69055 .03116 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00^03oool400000080oooo0P00001P0?ooo`00^03oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`3oool0G@3oool00;T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1M0?ooo`00^P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05d0
oooo002k0?ooo`030000003oool0000000800000H03oool00;P0oooo00H000000?ooo`3oool00000
0?ooo`00001R0?ooo`00^@3oool200000080oooo1000001O0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00`P3oool2000005`0oooo002o0?ooo`<0000000<0
oooo000000000000F`3oool00;d0oooo0P0000040?ooo`800000F`3oool00;X0oooo0`0000060?oo
o`030000003oool0000005X0oooo002h0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000005X0oooo002@0?ooo`@000000P3oool2000001d0oooo0`00000;0?ooo`040000
003oool0oooo000005T0oooo002@0?ooo`060000003oool0oooo0000003oool000000P3oool00`00
0000oooo0?ooo`0G0?ooo`<000003P3oool00`000000oooo0?ooo`02000005P0oooo002A0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool00`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000F03oool00980oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`<000004`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo05D0oooo002C0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0403oool2000001H0oooo00<0`/SN00000032b=h00`3oool00`000000oooo0?ooo`1D0?oo
o`00T03oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool03@3oool3
000000030?ooo`000000oooo00H0oooo0P0hI=8<0?ooo`80`/SN00<000000<;8gP32b=h00P3oool0
0`000000oooo0?ooo`1D0?ooo`00T@3oool2000000<0oooo0P00000>0?ooo`800000303oool00`3M
d/d0>6CB03QTdP0:0?ooo`<0`/SN00<000000<;8gP32b=h00`3oool2000005@0oooo002S0?ooo`<0
00003@3oool20=gBc@@0>6CB1P3oool50<;8gP0400000032b=h0`/SN0>7Ic`80oooo0P00001D0?oo
o`00X@3oool2000000030?ooo`000000oooo00`0oooo103Md/d503QTdP<0oooo1P32b=h010000000
`/SN0>7Ic`3QfLl30?ooo`030000003oool0oooo0580oooo002N0?ooo`<00000403oool50=gBc@H0
>6CB00<0oooo0<;8gP32b=h01@32b=h00`000000hMW?0>7Ic`020>7Ic`<0oooo00<000000?ooo`3o
ool0D@3oool009/0oooo0`00000B0?ooo`H0gM;=1P0hI=880<;8gP030000003QfLl0hMW?0080hMW?
0`3oool00`000000oooo0?ooo`1A0?ooo`00V@3oool2000000030?ooo`000000oooo0140oooo203M
d/d603QTdPH0`/SN00<0hMW?0000003QfLl0103QfLl30?ooo`030000003oool0oooo0500oooo002F
0?ooo`<00000103oool00`000000oooo0?ooo`0>0?ooo`T0gM;=1`0hI=850<;8gP030>7Ic`000000
hMW?00@0hMW?103oool00`000000oooo0?ooo`070?ooo`800000AP3oool009@0oooo0P00000G0?oo
o`/0gM;=1`0hI=830<;8gP80hMW?00<000000>7Ic`3QfLl0103QfLl30?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool00000A@3oool006/0oooo0`0000020?ooo`8000007`3oool30000
00030?ooo`000000oooo01@0oooo00<0F]C@0=gBc@3Md/d02@3Md/d309gcb0<04I7S0`0hI=801@32
b=h0hMW?0>7Ic`3QfLl0000000D0hMW?0`3@k^P20?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0@`3oool006`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0J
0?ooo`8000002@3oool20:FVe`<0GVo<2@3oool505[Dd0T0gM;=1@2MllP5016Ah`@0hMW?00<00000
0>7Ic`3QfLl00P3QfLl60=3^j0030?ooo`000000oooo00P0oooo00<000000?ooo`3oool0@`3oool0
06`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`<000001`3oool70:FV
e`H0GVo<0P3oool905[Dd0H0gM;=1@2MllP20:6fi`8036gN100ATN<30>7Ic`040000003QfLl0hMW?
0>7Ic`H0d>kX00<0_[3=0?ooo`0000001P3oool3000004H0oooo001/0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool200000080oooo00<000000?ooo`3oool00`3oool90:FV
e`X0GVo<0P3KoML201mni`@0F]C@0`3Md/d309gcb0L0XKKW0`0<KMh3016Ah`80hMW?00<000000>7I
c`3@k^P01P3@k^P30;j`c@030?ooo`000000000000@0oooo00<000000?ooo`3oool0AP3oool006`0
oooo00<000000?ooo`3oool00`00000E0?ooo`<000002P3oool00`3=^<D0YJKG0:FVe`070:FVe`P0
GVo<103KoML501mni`0405[Dd03Md/d0WO?80:O1k0X0XKKW100<KMh0100ATN<0hMW?0>7Ic`000007
0=3^j0@0_[3=00<000000?ooo`000000103oool4000004D0oooo001[0?ooo`8000000P3oool00`00
0000oooo0?ooo`0B0?ooo`<00000303oool30<fha@P0YJKG1`1NKl`60=_me`@07gkW1@2W`N`:0:6f
i`D036gN00<0hMW?0000003@k^P0103@k^P70;j`c@030?ooo`000000oooo04`0oooo001/0?ooo`03
0000003oool0oooo00@000003`3oool200000080oooo00<000000?ooo`3oool02@3oool40<fha@P0
YJKG1P1NKl`80=_me`0301mni`2W`N`0Yl7/00H0Yl7/2P2Q]^L600a]gP040000003@k^P0d>kX0=3^
j0P0_[3=0P3oool00`000000oooo0?ooo`1:0?ooo`00O`3oool3000000l0oooo1P3=^<D80:FVe`@0
GVo<203KoML00`2fd>d0Yl7/0:O1k0070:O1k0T0XKKW00<0//KY06>7h01SQn000`1SQn00100<KMh0
000000a]gP3@k^P:0;j`c@80oooo00<000000?ooo`3oool0B@3oool007d0oooo0P00000A0?ooo`L0
cKS5202UY]L305i_c0L0fogG102fd>d90:O1k0D0XKKW1@2ba^T506>7h0030000001SQn00_[3=00X0
_[3=0P3oool00`000000oooo0?ooo`190?ooo`00NP3oool300000080oooo00<000000?ooo`3oool0
3P3oool80<fha@P0YJKG00<0GVo<0=_me`3KoML0103KoML70;K@k@T0Yl7/00<0XKKW0;;6j@2ba^T0
1P2ba^T506>7h0030000001SQn00HhOP00X0_[3=00<0dlS@0?ooo`3oool00P0000190?ooo`00N03o
ool2000001D0oooo2P3=^<D40:FVe`H0F<Ci0P3KoML:0;K@k@H0Yl7/0P2L[>8:0;;6j@@0HhOP00<0
000006>7h01SQn002@2n/<d20=?8d0<0oooo00<000000?ooo`3oool0A`3oool007D0oooo0`00000F
0?ooo`/0cKS50P3Ql]T705S4n@<0V8>k2`2fd>d20:O1k0H0W:cR2P2ba^T306>7h0040000001SQn00
HhOP06>7h0L0_[3=0`3Cb=030?ooo`030000003oool0oooo04L0oooo001c0?ooo`8000000`3oool0
0`000000oooo0?ooo`0>0?ooo`@0V9WC2`3=^<D50>7bf@80F<Ci1`2HPk/90;K@k@0309^0]02L[>80
W:cR00L0W:cR2@2ba^T306>7h0040000001SQn00HhOP06>7h0H0_[3=1@3Cb=030?ooo`030000003o
ool0oooo04H0oooo001`0?ooo`<000004@3oool00`2Ve?P0V9WC09RId`0709RId`T0cKS51@3Ql]T0
0`3LjMd0V8>k09R3^`0809R3^`D0]]3]1@2KP;@909b/hPT0//KY0P1SQn000`000000HhOP06>7h002
06>7h0@0_[3=1P3Cb=040?ooo`030000003oool0oooo04D0oooo00170?ooo`<000000P3oool20000
01l0oooo1000000@0?ooo`D0Y]Ch202HVM<80<fha@D0hO;I0P3LjMd;09R3^`030;K@k@2KP;@0Vh2d
00H0Vh2d2P2L[>840;;6j@@0TKSa0P12QNP00`000000HhOP06>7h00206>7h0<0_[3=1`3Cb=040?oo
o`800000AP3oool004P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0J0?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`D0Lh;C0`3oool70:KDn0T0V9WC1P3=^<D50>7b
f@@0g>WM2P2HPk/:09^0]0P0W:cR00<0[[?L096hl@2A^?401`2A^?400`12QNP0000004:5j00304:5
j00306>7h02n/<d0dlS@00P0dlS@103oool00`000000oooo0?ooo`140?ooo`00B03oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01L0oooo0`00000<0?ooo`030=Wn_P1cP]<0Lh;C
00D0Lh;C202Ve?P909RId`@0cKS51@3Ql]T50=cYg@X0V8>k2P2KP;@509b/hPD0[[?L2@2A^?400`00
0000@XGX04:5j00304:5j0X0dlS@1@3oool00`000000oooo0?ooo`130?ooo`00B03oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo1000000<0?ooo`80fOjn201cP]<70:KD
n0T0V9WC0`3=^<D50>7bf@H0g>WM2@2HPk/20>OE``X0Vh2d00<0W:cR0:jcg02^/m`01`2^/m`8096h
l@0300000012QNP0@XGX00@0@XGX2@3Cb=050?ooo`030000003oool0oooo04<0oooo00180?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool04P3oool3000000l0oooo103Io[h807>2
d`H0Y]Ch2P2HVM<00`3=^<D0hO;I0>7bf@030>7bf@P0g>WM1`2HPk/30>OE``X0Vh2d2`2^/m`7096h
l@0300000012QNP0@XGX00D0@XGX2@3Cb=050?ooo`030000003oool0oooo0480oooo00170?ooo`80
00000P3oool010000000oooo0?ooo`00000B0?ooo`8000004@3oool50=Wn_PT0Lh;C1P2Ve?P809RI
d`@0Z]?e0P3Ql]T90=cYg@L0V8>k0`3WeL<:09^0]0030<;[S02^/m`0[[?L00T0[[?L102A^?4208n5
a0040000002?QL@0ShG400ini0@0@XGX1`3Cb=0209_Eo0D0oooo0P0000130?ooo`00B03oool01000
0000oooo0?ooo`3oool200000100oooo0`0000000`3oool000000?ooo`0?0?ooo`H0fOjn201cP]<3
0;Zhe`0401IoiP2Ve?P0Y]Ch0:KDn0D0V9WC1`2ZdoD3093/_`P0g>WM1P2HPk/50>OE``P0Vh2d0P32
jh`:0:jcg0030;:M``2?QL@0ShG400@0ShG400@0000008n5a02?QL@0ShG4100>O^@00`12QNP0dlS@
0=?8d00709_Eo0D0oooo00<000000?ooo`3oool0@@3oool005`0oooo0P00000D0?ooo`P0fOjn1@1c
P]<60;Zhe`<05WoV00<0Y]Ch09RId`2ZdoD0202ZdoD5093/_`P0g>WM102HPk/60>OE``L0Vh2d1032
jh`80:jcg0<0/Yg31@2?QL@00`000000ShG408n5a00208n5a0D03WkT2@2KeO`50?ooo`030000003o
ool0oooo0400oooo001I0?ooo`<000005@3oool20=Wn_P0408^gl`1`JK/0L6Vk071Y^`<0fOjn101c
P]<80;Zhe`D05WoV1P2ZdoD8093/_`L0g>WM102HPk/60>OE``L0Vh2d1@32jh`50:jcg0D0/Yg31@2?
QL@00`000000ShG408n5a00208n5a080?h?X100>O^@909_Eo0D0oooo00<000000?ooo`3oool0?`3o
ool005L0oooo0P0000020?ooo`030000003oool0oooo0180oooo0`2;]o<00`3D`lX0L6Vk071Y^`04
071Y^`030=Wn_P1cP]<0^[SG00T0^[SG0P35/<H00`0;QN<05WoV01IoiP0201IoiP<0Z]?e1P2@k;l5
09>Uh@D0g>WM0`2HPk/70>OE``H0Vh2d1P32jh`30:jcg0L0/Yg31P2?QL@01@000000ShG408n5a02?
QL@0f<W;00@0?h?X0P0>O^@909_Eo0@0oooo00<000000?ooo`3oool0?`3oool005@0oooo0`00000F
0?ooo`D0RkOc0`3D`lX6071Y^`X0^[SG1@35/<H300^5h`0301IoiP2ZdoD0T>bo0080VX2f2P2CYN42
001]fP<0g>WM0P2HPk/80>OE``@0Vh2d2032jh`00`2^/m`0/Yg30;:M``070;:M``D0ShG400<00000
08n5a02?QL@00`3HbL/603n3j0@0VmGl1P1ZcOd30?ooo`800000203oool300000080oooo0P00000`
0?ooo`00D@3oool4000000@0oooo00<0`lCK07bNj01lW^P01`1lW^P302:Si`@0oooo1`2;]o<40=C3
bPL0L6Vk202j^=L70<F`aP802hGS1P2JP;H:09>Uh@@006gJ00<0V8>k0>OE``3WeL<01`3WeL<409^0
]0D0`^^<0`2CTm4:0;:M``D0ShG400<0000008n5a03HbL/00`3HbL/803n3j0T0J/gm0P3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool0
04l0oooo0P0000040?ooo`030000003oool0oooo00<0`lCK2`1lW^P302:Si`L0RkOc1@3D`lX8071Y
^`H0^[SG2035/<H909Z0]PP0TjGQ00<0][[L03=ag@0cLMd00`00KMX90>OE``<0Vh2d00<0`^^<08JE
fP2CTm401`2CTm4:0;:M``@0ShG400<000000=S9b`3HbL/0103HbL/803n3j0@0J/gm102BQlD30?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]
0?ooo`00C03oool3000000L0oooo1P33a=/907bNj0030;o<i00XIML0:6GG00808Z?W1@2;]o<70=C3
bPL0L6Vk1@2j^=L90<F`aPT0VX2f1P2CYN440;Jjg0<0<g7M0P00KMX90>OE``80Vh2d0P26UMX00`3[
f<00Ti?A09>Cd@0509>Cd@X0/Yg3102?QL@00`000000f<W;0=S9b`040=S9b`P0RioQ2@2BQlD30?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]
0?ooo`00:@3oool2000001l0oooo0P0000000`3oool000000?ooo`060?ooo`P0`lCK1P1lW^P40;o<
i0<0:6GG00@08Z?W08^gl`2;]o<0RkOc203D`lX8071Y^`<0^[SG2@35/<H20>cK`@T0VX2f102CYN46
0;Jjg0@0<g7M00<006gJ0>OE``3WeL<01P3WeL<00`2KP;@0QYGJ08JEfP020>_H`0P0Ti?A2@2bWL<3
08n5a0030=S9b`000000f<W;00D0f<W;00<0h?g=08^Oh@2;Wn401P2;Wn4809:7a@<0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo000X
0?ooo`040000003oool0oooo000001/0oooo0`00000:0?ooo`X0`lCK101lW^P50;o<i0D0:6GG00<0
RkOc0=C3bP3D`lX01`3D`lX9071Y^`030;Zhe`35/<H0aK3600L0aK360`3/fl4:09Z0]P0309>Uh@2f
^]`0][[L00H0][[L1P0cLMd40>OE``D0QYGJ0`3[f<0809>Cd@X0/Yg300@0ShG40=S9b`3HbL/00000
1@3HbL/30>3mc@L0RioQ2@2BQlD30?ooo`8000001@3oool200000080oooo00@000000?ooo`3oool0
0000;`3oool002/0oooo00<000000?ooo`3oool05`3oool2000000/0oooo0P2WZMP;0<?4f`0307bN
j02oc>@0_lcT00H0_lcT100XIML;0=C3bPL0L6Vk00<0WoGC0<F`aP35/<H02035/<H30>cK`@X0VX2f
2P2f^]`503=ag@P0QYGJ1@3[f<0709>Cd@T0/Yg300D0]^[f0=S9b`3HbL/0f<W;000000040=S9b`@0
h?g=1`2;Wn4909:7a@80oooo00<000000?ooo`0000001P3oool010000000oooo0?ooo`3oool20000
0300oooo000[0?ooo`030000003oool0oooo01@0oooo0`0000000`3oool000000?ooo`070?ooo`H0
YjWH2@33a=/20;:^d`T0_lcT100XIML:0=C3bPH0L6Vk0`2OmM<80<F`aPD0k=_12@2JP;H00`3EnJ`0
][[L0;Jjg0080;Jjg0D0<g7M1`26UMX50>_H`0P0Ti?A1P2bWL<40;KZmP80f<W;00@000000=S9b`3H
bL/0f<W;1P3PoLd708^Oh@P0TXO5103oool00`000000oooo0?ooo`0j0?ooo`00:03oool3000001D0
oooo0P00000;0?ooo`T0YjWH1P33a=/50;:^d`P0_lcT1@0XIML90=C3bP@0L6Vk1@2OmM<70<F`aPH0
k=_1202JP;H30=Gi[0P0][[L00<0ZI_804aL`P1<G<800`0cLMd608JEfPH0jmS0202CTm440;:M``L0
]^[f00@0f<W;0000003HbL/0f<W;203PoLd608^Oh@T0TXO5103oool00`000000oooo0?ooo`0i0?oo
o`00:03oool00`000000oooo0?ooo`0B0?ooo`<000002`3oool00`33^m<0YjWH0:NYf0090:NYf0@0
`lCK1`2b[]<80;o<i0D0:6GG2@3D`lX2071Y^`L0WoGC1P35/<H60>cK`@L0VX2f103EnJ`60;Jjg0@0
ZI_80P1<G<8303=ag@@0QYGJ203[f<0809>Cd@030;:M``2fj_H0]^[f00L0]^[f00<0f<W;0000003H
bL/0203PoLd00`2QXmL0HF_7065[a`0508^Oh@L0TXO500<0^KoN0?ooo`3oool00`3oool00`000000
oooo0?ooo`0h0?ooo`00:03oool4000000h0oooo0`0000030?ooo`030000003oool0oooo00L0oooo
0`33^m<;0:NYf0030<?4f`2b[]<0/ZkC00P0/ZkC102oc>@309ZYh@<0Jfo50`0XIML80=C3bP04071Y
^`2OmM<0N;Wk0<gGh@80D5g10`2OmM<50<F`aPL0k=_11`2JP;H50=Gi[0@0][[L1@2YVlP404aL`P03
03=ag@26UMX0QYGJ0080QYGJ1`3[f<040=GQh0L09ZcP2@2fj_H00`000000h?g=0>3mc@040>3mc@@0
XJ?G101QJlL308^Oh@D0TXO5102i_mh40?ooo`800000>@3oool003P0oooo0P00000>0?ooo`H0`k_C
2@2WZMP00`2hZl`0/ZkC0;:^d`090;:^d`P0VZWQ1@1[KlD00`0XIML0e<?:0=C3bP020=C3bPD0N;Wk
0`3=en43051M`@80WoGC0`35/<H90>cK`@D0VX2f1`3EnJ`00`2f^]`0ZI_80:VKb0050:VKb0D0C5c2
0`26UMX70>_H`0H0eN7P1@1cR]X302J/h0@0]^[f0`2>Y^D010000000SZKU08jVi@3PoLd80:6Se`D0
HF_700<0RioQ09:7a@2BQlD00P2BQlD60;VogP@0oooo00<000000?ooo`3oool0=`3oool003D0oooo
0`0000000`3oool000000?ooo`0<0?ooo`P0`k_C1`2WZMP30;R[c0T0/ZkC0P2lX[h709ZYh@P0Jfo5
1@1h^O/50<gGh@@0D5g100@0WoGC0<F`aP35/<H0aK362@3/fl4409Z0]PD0eOV/0`29Ehl90:VKb0D0
C5c200<0QYGJ0>_H`03[f<001@3[f<070=GQh0030>3LdP1cR]X0Lh[J00D0Lh[J1`2>Y^D00`000000
SZKU0<2X`P090:6Se`L0HF_700<0TXO50;VogP2i_mh01P2i_mh50?ooo`030000003oool0oooo03H0
oooo000c0?ooo`8000004@3oool90<>kd`D0YjWH1@2hZl`80;:^d`<0_::n1`2JZN4906]_a@<0N;Wk
1P3=en46051M`@030<F`aP3/fl40k=_100P0k=_10`2JP;H00`3EnJ`0QYSN08UGS`0708UGS`P0ZI_8
1`1<G<850>_H`0L0eN7P0P3Pg=8807>:fPH0SZKU00@000000<2X`P30Z<80`:S2202QXmL7065[a`X0
^KoN103oool00`000000oooo0?ooo`0f0?ooo`00<03oool300000140oooo00<0_mk_0<>kd`33^m<0
2@33^m<30:NYf0L0^:_<1P2b[]<50;bR_PL0VZWQ2@1[KlD00`1h^O/0cMOQ0<gGh@060<gGh@L0D5g1
2P3/fl4209Z0]P80QYSN2029Ehl80:VKb0P0C5c20`3[f<070=GQh0@0h=cB1`1cR]X608jVi@040000
0030Z<80`:S20<2X`PT0XJ?G1`1QJlL:0;VogP@0oooo00<000000?ooo`3oool0=@3oool002h0oooo
0P0000030?ooo`030000003oool0oooo00d0oooo0`2og^l;0<>kd`030:NYf02hZl`0^:_<00L0^:_<
102b[]<70;bR_PH0VZWQ201[KlD207SLZ@P0cMOQ2@1@GL480>cK`@0409Z0]P26V=h0QYSN09UST@T0
REN?202YVlP804aL`P030>_H`03EhN00eN7P00D0eN7P1P3Pg=8707>:fP@0SZKU0P30Z<8010000000
`:S20<2X`P30Z<880:6Se`P0HF_7202i_mh208[ZlP80_<?O00<0oooo000000000000=P3oool002/0
oooo0`00000C0?ooo`H0_mk_2@33^m<00`2h/m@0^:_<0;R[c0080;R[c0<0/ZkC202lX[h709ZYh@H0
Jfo5101hg:T70<gGh@P0D5g100<0`<GN08JHgP26V=h02026V=h209UST@T0REN?202YVlP704aL`P<0
YmGh1@3EhN070>3LdPL0Lh[J0`2>Y^D30<2X`P0300000030Z<80`:S20080`:S21`2QXmL8065[a`D0
^KoN0`2:j_850;c3g`030?ooo`000000oooo03D0oooo000Y0?ooo`@000004`3oool80;oNk`H0`k_C
102h/m@:0;R[c0030;:^d`2lX[h0_::n00P0_::n1P2JZN4406]_a@L0N=bY1`3=en46051M`@<0`<GN
2026V=h309UST@T0REN?202YVlP404aL`PL0YmGh0`3EhN090>3LdPL0Lh[J00<0SZKU0<2X`P30Z<80
0P30Z<800`000000`:S20<2X`P020<2X`PP0XJ?G201QJlL00`2i_mh0R^[b08[ZlP0308[ZlPL0_<?O
00<0oooo0000003oool0=03oool002H0oooo0`00000F0?ooo`X0_mk_1033^m<50;Rce0T0^:_<00<0
c^GX0;bR_P2lX[h02@2lX[h305UYb@<0VZWQ0`1[KlD207SLZ@0305UYb@1aPmH0LH?F0080LH?F0P1h
g:T60<gGh@@0D5g11@30aMh708JHgP@0VF>A2P29Ehl80:VKb00304aL`P2WeOP0YmGh00P0YmGh00<0
eN7P0>3LdP3Pg=801`3Pg=800`2g]mP0RYCG08ZDe`0508ZDe`D0`:S200<000000<2X`P30Z<800`30
Z<870:6Se`@0HF_7101lMl<301`0000308[ZlP2l`ml0_<?O00P0_<?O00<0oooo0000003oool0<`3o
ool002<0oooo0`00000G0?ooo`<0[OSZ2P2og^l00`33^m<0^;?D0;Rce0060;Rce0L0^:_<0`3>iNP:
0;bR_P030=o<aP1IJLT0FFW900<0FFW900<0VZWQ06]_a@1IJLT00`1IJLT00`3F^l00LH?F0763eP04
0763eP80:8G[0`3=en43051M`@L0`<GN1P26V=h409UST@X0REN?1P2YVlP4000000P0YmGh0P1li^@7
0>3LdP@0]kOH1`2:U=L40<2X`P0300000030Z<80`:S200<0`:S200<0hO[D05ZUm`1JYOL0101JYOL4
0;:K`@L0O7O32P2l`ml0102n]]80oooo00000000000c0?ooo`008@3oool200000080oooo00<00000
0?ooo`3oool04`3oool80:ghjP@0_mk_0`1?b>d:0;Rce0@0^:_<1@3>iNP90;bR_P80glc62P1IJLT2
0=Jk`0L0LH?F100XQN/00`3=en40D5g10<35gP080<35gP@0QYSN1@2IHi4;08UGS`80ZI_800<0mkV6
0?RjPP0gLmh00`0gLmh2000000@0YmGh1P1li^@40>3LdPH0]kOH1`2:U=L40<2X`P0300000030Z<80
`:S20080`:S20`3Qn]@405ZUm`D0/Y_1201lMl<80;c3g`<0_[KB0P00000c0?ooo`007P3oool30000
00@0oooo00<003Fk0?ooo`3oool04P3oool60:ghjPL0TYOE101?b>d90;Rce0<0^:_<1`3>iNP70;bR
_P@0glc6201IJLT40=Jk`0L0LH?F100XQN/:0<35gP<0QYSN1P2IHi4;08UGS`<0mkV60P3h^X8603Mc
gP030:OEn01li^@0O>KT00L0O>KT00<0h=cB0;Ngf02g]mP01P2g]mP808ZDe`<0`:S200@000000<2X
`P30Z<80`:S21@3Qn]@00`1JYOL0/Y_10;:K`@050;:K`@T0O7O31@2l`ml60;jfdP030?ooo`000000
oooo0340oooo000L0?ooo`@000001@3oool00`3`l/4003Fk0?ooo`080?ooo`03087Xc`1dT>00M93P
0080M93P0`3oool20:ghjP80M93P302BUmD20119aP80ClS]2@2h/m@00`2hZl`0c^GX0<kUj0060<kU
j0H0_::n1@3Oc<H705UYb@D0e[_0201aPmH402R5j`X0`<GN00<0QYSN09UST@2IHi401@2IHi4;08UG
S`<0mkV60P3h^X8803McgP030:W=l`26Rm40QX_A00D0QX_A2P2g]mP708ZDe`80`:S20P0000020<2X
`PD0hO[D00<0`lSN0;:K`@2bVl401`2bVl4807ag``<0_<?O202n]]800`3oool000000?ooo`0a0?oo
o`006@3oool3000000P0oooo0P3`l/42000e^`H0oooo1021j<l907B@h080coo@2`2BUmD0103Rn]<0
44W60119aP1?b>d80;Rce0<0[N_i1`3>iNP50;bR_PH0glc61P1IJLT70=Jk`0H0LH?F00<0ReR?085@
SP21D8h00`0XQN/80<35gP0308]IT@2IHi40VF>A00L0VF>A2P29Ehl30?NiQP<0n;Z2100gLmh50:W=
l`L0QX_A2@2g]mP608ZDe`<0000000<0`:S200000030Z<801@3Qn]@30<?8gPP0/Y_12@1lMl<00`2l
`ml0_[KB0;jfdP080;jfdP030?ooo`000000oooo0300oooo000H0?ooo`8000002@3oool40?3b`@80
03Fk103oool2087Xc`030:J?_000=KX0PNS?00P0M93P103?om0909:Ge@80h_[C100@BLH40;Rce0P0
[N_i1P3>iNP40;bR_PL0glc6101IJLT80=Jk`0@0LH?F0`2;F8l5085@SP0302R5j`30aMh0`<GN0080
`<GN102;FI4909UST@X0REN?0P3g^HH50?RjPP0303McgP2YcO<0ZLgc00D0ZLgc2026Rm480;Ngf0<0
RYCG0`00000208ZDe`<0`:S200@000000>7je03Qn]@0hO[D1@33b=h90;:K`@L0O7O300<0/jW>0;jf
dP2n]]80202n]]80102Jk:h0oooo0000000000080?ooo`<000000P3oool200000240oooo000H0?oo
o`<00000203oool50?3b`@8003Fk00<0oooo087Xc`00=K/0102VSk`00`00=KX0PNS?07B@h00507B@
h0D0coo@202BUmD40>;jd`@044W600<0^;?D0:g[n@2]joT01`2]joT0102Z]>00DWoP059oh01BOn03
0<kUj0<0_::n203Oc<H305UYb@X0e[_000<0LH?F08]HS`2;F8l00`2;F8l7085@SP030<35gP2;FI40
ReVA00@0ReVA2@2IHi4908UGS`<0mkV61@3h^X820000>@L0ZLgc1`26Rm480;Ngf0<000001P2:U=L0
1@30Z<80hO[D0>7je0000000hO[D00H0`lSN2@2bVl4507ag``@0/jW>202n]]8209[/[P80oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01h0oooo
000H0?ooo`040000003oool0oooo000000H0oooo1P3`l/44000e^`D0YXnl0P00=KX00`21j<l0M93P
07B@h00207B@h0L0coo@1P2BUmD50>;jd`H044W61P2]joT40:Zdh0D0DWoP00<0c^GX0;bR_P3Oc<H0
2@3Oc<H00`1IJLT0e[_00=Jk`0080=Jk`00309QUU02;F8l0ReR?00@0ReR?1`21D8h708]IT@T0VF>A
2@29Ehl30?NiQPD0n;Z20`0003T60:W=l`P0QX_A102g]mP3000000<0Xig?2@0oZoH00`3Qn]@00000
0<?8gP060<?8gPP0/Y_1101lMl<60;>YcPH0_[KB102Jk:h20?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`00603oool01@000000oooo0?oo
o`3oool0000000@0oooo203`l/400`00=K/0YXnl0:J?_0060:J?_08003Fj0`1dT>030<ood080bL_K
00<005[;0<ood03?om001@2BUmD70>;jd`P044W600<0[N_i0:Zdh02Z]>001@2Z]>06059oh0T0glc6
00<0^n?c0=Jk`03F^l00203F^l0209QUU0H0ReR?1`21D8h708]IT@T0VF>A2@29Ehl30?NiQPD0n;Z2
100003T60:W=l`P0QX_A0`0000080:>Mc`@0?j_f0`2FSl/00`33b=h000000<?8gP060<?8gPT0/Y_1
00<0O7O30;>YcP2cZLh01P2cZLh50;jfdPD0V^b^0`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool001L0oooo00<0000000TWZ03oool00`3o
ool010000000oooo0?ooo`3oool70?3b`@030:Vdh@2VSk`0YXnl00L0YXnl0`00=KX0101dT>00coo@
000e^P00=KX40<W;f`8005[;00@0coo@09:Ge@2BUmD0TYOE203Rn]<60119aP80X:gQ2@2Z]>06059o
h0H0glc6102kho<80=Jk`0<0V6FD1P2;F8l7085@SPL0ReVA2@2IHi4908UGS`<0mkV61@3h^X830000
>@040:nafP1gK[`0Mfjl07M^_0<0ZLgc1@26Rm43000000/0Xig?202FSl/00`33b=h000000<?8gP06
0<?8gPL0/Y_100<0];oR0;>YcP2cZLh0202cZLh30;jfdPH0V^b^0`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<000008@3oool001L0oooo0P0000000`099jP0oooo0?ooo`020?oo
o`030000003oool0l?;100@0l?;11@2Y]>490:J?_0@003Fj1`39bm/3001Jb`0309:Ge@3Rn]<0h_[C
0080VXRo101MUnh20>;jd`8044W61P2P[N480:Zdh0L0DWoP103Oc<H60;_Sl`H0e[_0102HII@608]H
S`L0PE2>1`2;FI4909UST@T0REN?0`3g^HH50?RjPP@0[k7J1P1gK[`00`2YcO<0QX_A000000020000
00@0XIK92P2SWLl00`2SiY@0UXo;09J?b`0609J?b`030<?8gP000000`lSN00D0`lSN1@2bVl440;Bo
hPX0/jW>00@0_[KB0<W4e@1VHKP0IV6h1@2Jk:h20?ooo`8000001@3oool200000080oooo00<00000
0?ooo`3oool08@3oool001L0oooo00@000000?ooo`099jP02BNX103oool30?3b`@0300TWZ02Y]>40
ZKCQ00D0ZKCQ2@2VSk`3000e^PT0bL_K0P00F//609Z8_`D0GIO^2@2P[N480:Zdh0L0DWoP00<0glc6
0;_Sl`2kho<01P2kho<50=Jk`0D0V6FD1P2;F8l7085@SPP0ReVA202IHi4908UGS`<0mkV6103h^X86
0:nafP@0Mfjl0`0000070:6Fb@T0Xig?0P2SiY@909J?b`0300000033b=h0`lSN00@0`lSN102bVl45
0;BohPT0/jW>00<0VO740<W4e@39a=D00`1VHKP409[/[P<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0400000200oooo000G0?ooo`030000003oool02BNX00802BNX0`3oool01@3`
l/402BNX00TWZ0099jP0h=W?00H0ZKCQ2P2VSk`00`00=KX0bL_K0<W;f`070<W;f`030<gHhP2JR;l0
VXRo00L0VXRo1@1MUnh90:2]h@P0Z[CP0`1BOn0503noh`P0^n?c0`3F^l0609QUU0H0ReR?1`21D8h8
08]IT@P0VF>A2@29Ehl30?NiQP@0n;Z21P2_/MX207M^_08000000`1gK[`80:6Fb@L0Xig?0`2SiY@8
09J?b`030<Bmd`26UM/0000000<0QYGK0`33b=h00`2bVl40];oR0;BohP060;BohPL0/jW>00<0VO74
0<W4e@39a=D00P39a=D406IQ^080V^b^103oool00`000000oooo0?ooo`0Z0?ooo`003P3oool20000
00L0oooo00<000000?ooo`099jP00`099jP00`3oool02BNX00TWZ00200TWZ0<0h=W?1P2Y]>490:J?
_080f_CP1`39bm/30<gHhPT0VXRo1@1MUnh90:2]h@@0Z[CP1`2KY]d508ACSP80?koS1P2kho<00`3F
^l00V6FD09QUU00509QUU0H0ReR?1`21D8h808]IT@P0VF>A2029Ehl40?NiQP@0n;Z21@2_/MX30000
00D0Mfjl202QU/T60:>Mc`D0XnJD1P2FSl/30<Bmd`0308JEf`000000QYGK00@0QYGK2@2d_n850;>Y
cP80VO741@39a=D606IQ^00309[/[P3oool0oooo0080oooo00<000000?ooo`3oool0:@3oool000d0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0700TWZ0@0h=W?1P2Y]>480:J?
_0@0f_CP1@39bm/40<gHhPX0VXRo1@1MUnh60:2]h@80XYc?2P2KY]d00`3OmmT0Q5>>08ACSP0508AC
SPH0QUF?202HII@708]HS`H0PE2>202;FI4809UST@P0REN?0`3g^HH50?RjPP80[k7J0`0000000`2_
/MX0Mfjl07M^_00607M^_0P0XIK9102SWLl204]^e0@0XnJD1@2FSl/40<Bmd`80QYGK00<0000008JE
f`26UM/00`26UM/80;BohP<0/jW>0`2IlL@60<W4e@L0IV6h103oool2000002X0oooo000=0?ooo`04
0000003oool0oooo000000D0oooo0P0000020?ooo`H02BNX1P3PfLl50:Vdh@L0YXnl1P3Jm>030<W;
f`D0cMSR2P2JR;l405f0g080GIO^0P2P[N460::Lc`P0VjKM0P3OmmT708ACSPH0QUF?202HII@708]H
S`H0PE2>202;FI4809UST@P0REN?0`3g^HH40?RjPP<000001@2_/MX707M^_0P0XIK90`2SWLl00`2`
gOL0j>kA04]^e00204]^e080XnJD102FSl/60<Bmd`0308JEf`000000QYGK00D0QYGK202d_n80102c
ZLh0VO7409Waa02IlL@80<W4e@L0IV6h103oool00`000000oooo0?ooo`0X0?ooo`003@3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`D02BNX203PfLl50:Vdh@D0YXnl203J
m>000`39bm/0cMSR0<gHhP050<gHhPP0VXRo0P3Rm=P505f0g0T0XYc?1P2KY]d30=ogf@L0Q5>>1P26
EHl809QUU0L0ReR?1`21D8h708]IT@P0VF>A2029Ehl30?NiQP050?RjPP00000000000000003h^X80
1`2_/MX707M^_0T0XIK900@0Xig?0;3Mm`3Xk]40j>kA101;K]@20:?VU080UXo;2034_M<00`26UM/0
000008JEf`0508JEf`@0];oR1@2A]Nl00`37^L`0bLCE0<W4e@070<W4e@P0IV6h103oool00`000000
oooo0?ooo`0W0?ooo`003@3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?oo
o`@02BNX203PfLl30;b]c0<0ZKCQ102VSk`70=[dh0@0Z][h1P3=f>8709Z8_`<0h_CH1P1MP=`80::L
c`D0VjKM103OmmT708ACSPH0QUF?202HII@708]HS`L0PE2>1`2;FI4809UST@P0REN?00@0mkV60000
000000000000103h^X800`3[k</0[k7J0:nafP040:nafPP0Mfjl1`2QU/T20;3Mm`@0j>kA1@1;K]@0
0`2FSl/0a;gC0<Bmd`070<Bmd`80QYGK00@0000008JEf`26UM/0QYGK0P0i_/08096ek`<0akW<2039
a=D906IQ^0040?ooo`2b/mT0oooo000002T0oooo000=0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool00P3oool200TWZ0P0h=W?1@2l[L`00`00EL/0ZKCQ0:J?_0020:J?_0D0f_CP
202Zf_P60<gHhPD0VXRo1@3Rm=P605f0g0P0XYc?0`2KY]d50=ogf@L0Q5>>1P26EHl809QUU0L0ReR?
1`21D8h708]IT@P0VF>A1P29Ehl300000080mkV61@3h^X800`2CHI@0QEJC08EFT`040:nafPP0Mfjl
102QU/T40;3Mm`D0j>kA1@1;K]@;0<Bmd`80QYGK00<0000003Vn`00i_/000`0i_/06096ek`D0akW<
2039a=D706IQ^0@0/[?I00<0oooo0000000000009`3oool000h0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<02BNX0>3Ic`3PfLl01@3PfLl80;b]c08005G;00@0YXnl0=[dh03Jm>0005G;
0`2FU<l90:[Jn0D0cMSR102JR;l70>;df0D0GH3L2@2RW<l00`2KY]d0goOI0=ogf@040=ogf@L0Q5>>
1P26EHl809QUU0L0ReR?1`21D8h708]IT@P0VF>A0`29Ehl30000000308UGS`3g^HH0mkV60080mkV6
103h^X8209=QU0D0QEJC0P2_/MX807M^_0030:6Fb@2`gOL0/=gg00<0/=gg1P3Xk]4604]^e0T0a;gC
0`1`g;P00`000000AWgR04ImhP0403Vn`0@0TKG_1`37^L`70<W4e@H0IV6h1P2b/mT2000002L0oooo
000F0?ooo`030000003oool0oooo00H0oooo0`3PfLl:0;b]c08005G;202FU<l60:[Jn0040::Gb@17
JM40AfWA04MYd@80cMSR0`2JR;l80>;df0H0GH3L1`2RW<l509kei@030;6/d`3OmmT0goOI00L0Q5>>
1P26EHl809QUU0L0ReR?1`21D8h708]IT@P0VF>A0`00000408UGS`@0mkV6103h^X8209=QU0L0QEJC
101gK[`608k4nP<0/=gg203Xk]4604]^e0H0a;gC0P1`g;P40:ZJa@0300000016ON80AWgR0080AWgR
00@0>Kk0096ek`2A]Nl0TKG_2037^L`203j>kPD0bLCE101VHKP80;:cf@030?ooo`000000oooo02H0
oooo000E0?ooo`030000003oool0oooo00T0oooo2`2l[L`;09JDc`80Z][h1@2RUlT504MYd@0309Z8
_`3Rm=P0h_CH00P0h_CH1@1MP=`60::Lc`@0W_GU0`2a[=<20=ogf@L0Q5>>1`26EHl709QUU0L0ReR?
1`21D8h708]IT@H0VF>A0P00000708UGS`@0mkV6103h^X8209=QU0T0QEJC2@2>a?X00`2`gOL0j>kA
0>S^d@060>S^d@040:NSdP1iN<D0NGS507Uha@@0BfkD1034_M<00`1`g;P0ZY[50:ZJa@050:ZJa@03
00000016ON80AWgR00<0AWgR00<0TKG_0<Nic037^L`01`37^L`00`3QlmT0?Xk^03j>kP0203j>kP<0
bLCE0P1VHKP00`2`X/T0/[?I0;:cf@070;:cf@030?ooo`000000oooo02D0oooo000E0?ooo`030000
003oool0oooo00X0oooo2@2l[L`20<nmb@X0UYC?1`2RUlT904MYd@030<Fld@2:U=P0RYCH00@0RYCH
0`10M=d305f0g0<0XYc?1@2NmND40;6/d`80goOI1`24Dhh708IES`P0V6FD1P2;F8l7085@SPL0ReVA
0`2IHi4300000080VF>A1`29Ehl30?NiQPD0n;Z20P2CHI@:08EFT`H0S/Cj102Cfoh40>S^d@D0Yj?B
1P1iN<D0101;K]@0a;gC073L^01iN<D80:ZJa@0300000016ON80AWgR00<0AWgR2@37^L`30>7cf@@0
?Xk^0P2`X/T00`1VHKP0/:;90;2Rb@080;:cf@040:jJ`P3oool0oooo000002D0oooo000E0?ooo`03
0000003oool0oooo00X0oooo202l[L`30<nmb@T0UYC?0P3LnmT70::Gb@L0AfWA0`35_=4608ZDf0D0
@7CM00<0GH3L0::Lc`2NmND00`2NmND60;6/d`80goOI1`24Dhh708IES`P0V6FD1P2;F8l7085@SPL0
ReVA0`00000609UST@H0REN?0`3g^HH50?RjPP<0Tf6D2P25EY<208k4nPP0Tm_n00<0j>kA0:NSdP2W
Xm801@2WXm8:07Uha@030>3l^02ZV/D0ZY[500H0ZY[500<0000004ImhP16ON800`16ON870<Nic0D0
hO?I00<0?Xk^0;2Rb@2`X/T01P2`X/T50;:cf@@0[Y[200<0oooo000000000000903oool001D0oooo
00<000000?ooo`3oool02`3oool60;b]c0D0ckg91`2FU<l30=ckf@P0XYO91017JM450<Fld@L0RYCH
2010M=d00`37jNh0/JcC0;6/d`050;6/d`80goOI1`24Dhh708IES`P0V6FD1P2;F8l7085@SP@0ReVA
0`0000000`2;FI40VF>A09UST@0609UST@H0REN?0`3g^HH50?RjPP<0Tf6D2P25EY<20?JjR@H0Tm_n
0P2UULD80:NSdPT0NGS50P3Po;P80:ZJa@030<o3c`000000Bg?H00<0AWgR1P37^L`50>7cf@030<_R
j02`X/T0/:;900L0/:;9102b/mT60:jJ`P030?ooo`000000oooo02<0oooo000E0?ooo`8000003@3o
ool40;b]c0H0ckg91P2FU<l50=ckf@L0XYO90`17JM470<Fld@L0RYCH1P10M=d30<OYkPH0/JcC0P3O
mmT708ACSPL0QUF?202HII@608]HS`L0PE2>00@0ReVA0000000000000000102;FI4809UST@D0REN?
103g^HH50?RjPP<0Tf6D2P25EY<30?JjR@80Tm_n1P2UULD80:NSdPL0NGS50`3Po;P70:ZJa@<0cl??
00<0000004]cf01;LmP00P16ON840<Nic0D0hO?I0`3;h^P90;2Rb@030;:cf@2^V/80[Y[200L0[Y[2
00<0oooo0000003oool08P3oool001D0oooo00<000000?ooo`3oool0303oool30;b]c0P0ckg9102F
U<l60=ckf@P0XYO900<0AfWA0<Fld@35_=401`35_=4708ZDf0<0@7CM1P37jNh50;6/d`80goOI1`24
Dhh708IES`P0V6FD1P2;F8l5085@SP<000001`2;FI4809UST@D0REN?103g^HH50?RjPP<0Tf6D2P25
EY<30?JjR@T0YIG51`2WXm8607Uha@D0h?bh1@2ZV/D40<o3c`050000001;LmP0Bg?H04]cf016ON80
0`37^L`40>7cf@D0bn;X202`X/T00`3Fk>@0[Y[20:jJ`P080:jJ`P030?ooo`000000oooo00P0oooo
100000020?ooo`8000004P3oool001D0oooo00<000000?ooo`3oool03@3oool00`2l[L`0ckg90<nm
b@070<nmb@<0UYC?0P3LnmT00`2kmO40F6O705QWa`030=ckf@H0XYO90P2Wj_X90<Fld@P0RYCH00<0
@7CM0<OYkP37jNh01@37jNh50;6/d`80goOI1`24Dhh708IES`P0V6FD1P2;F8l2085@SP<000000P21
D8h808]IT@P0VF>A1@29Ehl40?NiQP@0n;Z2102CHI@:08EFT`<0m[Z900<0k[2<0:FEa@2UULD01P2U
ULD80:NSdP@0NGS51P3Po;P40:ZJa@H0cl??00<0000004]cf01;LmP00P1;LmP00`37^L`0hO?I0>7c
f@020>7cf@H0bn;X1`2`X/T30=K/i0T0[Y[200@0h]O;0?ooo`00000000001`3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool03`3oool001@0oooo00<000000?ooo`3o
ool03`3oool:0<nmb@0409JDc`2kmO40^oGa0;_el@80]Y^l0`1HIlL00`3LnmT0XYO90::Gb@020::G
b@D0Yn[j2@35_=4408ZDf0H0Q<cn1P37jNh30;6/d`030<?5f`3OmmT0goOI00L0Q5>>1`26EHl809QU
U0D0ReR?0`000005085@SPP0ReVA202IHi4508UGS`@0mkV6103h^X8409=QU0X0QEJC0`3f^XT00`3^
/8`0YIG50:FEa@070:FEa@L0Yj?B101iN<D60>3l^0<0ZY[51`3?`ll00`1;LmP0000004]cf00504]c
f0030>7cf@3;h^P0bn;X00H0bn;X1@2`X/T40=K/i0P0[Y[20P3Rel/20?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00l0oooo000D0?oo
o`030000003oool0oooo0100oooo203?_LT40;_el@<0]Y^l1@1HIlL00`2RUlT0Yn[j0:OZnP060:OZ
nPL0aKcA0`2`koL808C<oP030:FZf`1eWn`0MIo/0080MIo/0P37jNh01@2a[=<0`lGK0<?5f`33aM/0
goOI00L0Q5>>1`26EHl809QUU080ReR?0`0000000`2;F8l0PE2>085@SP05085@SPP0ReVA202IHi45
08UGS`@0mkV6103h^X8409=QU0T0QEJC103f^XT20>j`S0T0YIG51P2WXm8307Uha@P0h?bh00<0ZY[5
0<o3c`3?`ll01`3?`ll0101;LmP0000004]cf01;LmP509^Ab0L0bn;X102`X/T60=K/i0H0[Y[20`3R
el/20?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0?0?ooo`00503oool200000180oooo1P3?_LT40;_el@@0]Y^l2@1HIlL60:OZnP@0aKcA1`2`
koL408C<oP@0YJ[K1P1eWn`30<?5f`030=ogf@24Dhh0Q5>>00D0Q5>>1`26EHl809QUU0800000102;
F8l7085@SPP0ReVA202IHi4508UGS`<0mkV61@3h^X8409=QU0T0QEJC103f^XT20>j`S0P0YIG51000
0002002Aa@80Yj?B00<0NGS50>3l^01gd_h00P1gd_h505>`nPT0cl??00<0`o_W09^Ab0000000202K
TLP60<_Rj0<0/:;91`3Fk>@60:jJ`P@0h]O;0P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool03`3oool001@0oooo00<000000?ooo`3oool04P3oool3
0<nmb@D0^oGa1P2fVk`805QWa`030<Ffc01jM<00NWC00080NWC00P2Wj_X00`35_=40/>og0;3_m`08
0;3_m`0308C<oP2UZ]/0YJ[K00D0YJ[K1P1eWn`20<?5f`030=ogf@24Dhh0Q5>>00D0Q5>>1`26EHl5
09QUU0<000001P2;F8l7085@SPP0ReVA202IHi4508UGS`<0mkV61@3h^X8409=QU0T0QEJC103f^XT2
0>j`S0L0YIG51`2=S/l807OBoPD0Dk3j1`3?`ll30<?ki`0309^Ab0000000Vi7800H0Vi781@1i[_@2
0<_Rj0030;2Rb@3Fk>@0e^cT00H0e^cT1@2^V/850>;Gb`<0oooo00<000000?ooo`3oool00`3oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool03`3oool001@0oooo00<0
00000?ooo`3oool04`3oool00`3?_LT0^oGa0;_el@030;_el@L0]Y^l1`1HIlL30<Ffc0P0NWC01@2`
koL309S:n@T0YJ[K1P1eWn`00`33aM/0goOI08ACSP0608ACSPL0QUF?0P2HII@3000000<0V6FD1P2;
F8l7085@SPP0ReVA202IHi4408UGS`@0mkV61@3h^X8409=QU0T0QEJC0`3f^XT40>j`S0@0YIG500<0
`NV808f>c`2=S/l01`2=S/l407OBoP<0TH2m0P1cL/<405>`nP@0cl??1@33nnL209^Ab0030000002K
TLP0Vi7800@0Vi7800<0000007V^m01i[_@01P1i[_@80=K/i0<0[Y[21P3Rel/20?ooo`8000001P3o
ool2000000<0oooo0P00000B0?ooo`00503oool00`000000oooo0?ooo`0H0?ooo`T0]Y^l1@1HIlL4
0<Ffc0T0NWC00P38mjP609S:n@T0YJ[K1P1eWn`00`3OmmT0Q5>>08ACSP0508ACSPH0QUF?0`000006
09QUU0L0ReR?1`21D8h708]IT@P0VF>A1029Ehl40?NiQPD0n;Z2102CHI@908EFT`<0m[Z9103^/8`3
0:FEa@80`NV8202=S/l00`38^L/0TH2m0960_@060960_@@0Lg;300@0Dk3j0<o3c`3?`ll0cl??1`33
nnL209^Ab0030000002KTLP0Vi780080Vi780`00000807V^m0L0e^cT0`2^V/870>;Gb`<0oooo00<0
00000?ooo`3oool0703oool001<0oooo0`00000J0?ooo`P0]Y^l101HIlL50<Ffc0T0NWC01038mjP5
09S:n@L0YJ[K00<0/;?K08bVi`2<Y^L0102<Y^L00`3OmmT0Q5>>08ACSP0508ACSP<0QUF?0`000000
0`26EHl0V6FD09QUU00609QUU0L0ReR?1`21D8h708]IT@P0VF>A1029Ehl40?NiQPD0n;Z21@2CHI@8
08EFT`<0m[Z91@3^/8`0102UULD0`NV80<7YR031jHP708f>c`<0b;W;1`2AP;d607=b``030<o3c`33
nnL0`o_W00H0`o_W0P2KTLP010000000Vi7809^Ab02KTLP5000000@0NJkd0`2P]>H507BHiP<0e^cT
00<0[Y[20>;Gb`3Rel/01P3Rel/40?ooo`030000003oool0oooo01/0oooo000C0?ooo`030000003o
ool0oooo01X0oooo202fVk`305QWa`L0aKK<1`1jM<060<SgZ0D0V<[i102UZ]/40;2cf`D0S:KW00<0
goOI08ACSP24Dhh01@24Dhh3000000@0QUF?202HII@708]HS`L0PE2>1`2;FI4809UST@@0REN?103g
^HH40?RjPPH0Tf6D2025EY<30?JjR@D0k[2<00<000180<7YR031jHP00P31jHP508f>c`@0b;W;1`2A
P;d907=b``H0`o_W0`2KTLP00`000000Vi7807fYl00507fYl0P0X;CV1`1dV>H90>;Gb`@0oooo0P00
000L0?ooo`000`3oool2000000<0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0
oooo01/0oooo202fVk`00`1HIlL0aKK<0<Ffc0060<Ffc0H0NWC01038mjP309N5_P@0EI?]0P2Hb_T0
0`2UZ]/0/;?K0;2cf`050;2cf`@0S:KW00<0goOI08ACSP24Dhh00P24Dhh3000000P0QUF?1`2HII@7
08]HS`L0PE2>1`2;FI4809UST@@0REN?103g^HH40?RjPPH0Tf6D2025EY<30?JjR@D0k[2<1@31jHP4
08f>c`D0b;W;202AP;d807=b``80Kg?61@33nnL309^Ab0030000001mZO00OJW`00D0OJW`202P]>H7
07BHiPT0h]O;0`3oool2000001`0oooo00020?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0K0?ooo`L0]Y^l00<0b<3C0<Ffc035]/`01`35
]/`607Yd`0030<SgZ02GQKh0UhFn00D0UhFn1@1ETnd80;2cf`@0S:KW00<0goOI08ACSP0000000P00
000308ACSPP0QUF?1`2HII@708]HS`L0PE2>1`2;FI4809UST@@0REN?103g^HH40?RjPPH0Tf6D1`25
EY<40?JjR@D0k[2<1@31jHP308f>c`L0b;W;1`2AP;d707=b``80f=OG101_LlH20<?ki`<0Vi7800<0
00000>OB`@1mZO001P1mZO070:2diPP0M9SV103Rel/508cEo`@0oooo00<000000?ooo`3oool06@3o
ool00080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01/0oooo1P2fVk`30<S0d`T0aKK<101jM<000`38mjP0[kCM09N5_P0709N5_PD0EI?]202`
/m/208bVi`<000001P24Dhh808IES`L0V6FD1`2;F8l7085@SPP0ReVA1`2IHi4308UGS`D0mkV6103h
^X8609=QU0L0QEJC103f^XT50>j`S0@0SEfD0P31jHP00`2=S/l0b;W;0<Rib`060<Rib`P0TH2m1@1c
L/<30=SGe`L0Kg?600D0Vi780>OB`@3Wd/4000000>OB`@0607fYl0P0X;CV101dV>H509B@c0P0S=Go
0`3oool00`000000oooo0?ooo`0I0?ooo`000P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0703oool40;JK_0D0b<3C2035]/`307Yd`0040<Sg
Z02_]=d0[kCM0:ndg@P0UhFn1@1ETnd60;2cf`<0000000<0_jg80=ogf@24Dhh01P24Dhh808IES`L0
V6FD1`2;F8l7085@SPP0ReVA1`2IHi4308UGS`@0mkV61@3h^X8609=QU0L0QEJC103f^XT50>j`S0H0
SEfD2P38^L/70960_@@0Lg;31@3HemL606mcaP@0im;100<0000008ek^`2=Nk/00`2=Nk/207fYl0@0
X;CV0`2KWMD:09B@c0@0S=Go0`23eOl40?ooo`8000006@3oool00080oooo00@000000?ooo`3oool0
0000103oool3000000D0oooo00<000000?ooo`3oool07@3oool30;JK_0L0b<3C1`35]/`307Yd`0@0
[kCM2@2GQKh505FCk@<0/;?K0P0000001@2`/m/0/[gR0;n]b02o[LP0goOI00L0Q5>>2026EHl709QU
U0L0ReR?1`21D8h808]IT@L0VF>A0`29Ehl40?NiQPD0n;Z21P2CHI@708EFT`@0m[Z9103^/8`00`2O
K9L0SEfD08eMU00508eMU0T0b;W;1`2AP;d307=b``H0f=OG1@1_LlH60>OB`@030000002=Nk/0SG^k
00@0SG^k202KWMD809B@c08000001`23eOl30?ooo`030000003oool0oooo01P0oooo00020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?oo
o`030;JK_038`=<0b<3C00L0b<3C1`35]/`00`1jM<00[kCM0:ndg@030:ndg@T0UhFn00D0dlC<04:8
j`12R>/0@XS[05FCk@03000000D0/[gR00<0_jg80=ogf@24Dhh01`24Dhh708IES`L0V6FD1`2;F8l7
085@SPP0ReVA1`2IHi4308UGS`@0mkV61@3h^X8609=QU0L0QEJC103f^XT40>j`S00309m/U`2=GI@0
SEfD00H0SEfD2038^L/80960_@0307=b``3HemL0f=OG00D0f=OG1@1_LlH50>OB`@030>7k/@000000
SG^k00H0SG^k1`2KWMD709B@c0@000001`23eOl30?ooo`030000003oool0oooo01L0oooo00030?oo
o`8000001@3oool4000000@0oooo00<000000?ooo`3oool07`3oool80<S0d`D0a=7U103Uo<060:nd
g@L0UhFn0`3Ca<`30000000304:8j`2b_N80/[gR00H0/[gR0P3OmmT708ACSPL0QUF?1`2HII@708]H
S`L0PE2>202;FI4709UST@<0REN?103g^HH50?RjPPH0Tf6D1`25EY<30?JjR@D0k[2<00<0WfbG08eM
U02=GI@01`2=GI@80<Rib`@0TH2m0P1/Ik`202l000P0f=OG0`1_LlH50>OB`@<0hO^a00<0000008ek
^`2=Nk/0102=Nk/809^Me@D0U93<0`00000409j9_0<0BJKh0`23eOl01019Y_P0X8Rk0?ooo`00000H
0?ooo`004P3oool00`000000oooo0?ooo`0P0?ooo`H0b<3C1@34dND60>Gl`0D0[kCM1P2GQKh01@3C
a<`00000000000000000dlC<00@0@XS[1`2b_N820=ogf@L0Q5>>1`26EHl709QUU0L0ReR?1`21D8h8
08]IT@P0VF>A0P29Ehl40?NiQP@0n;Z200<0T5jC09=QU02CHI@0102CHI@708EFT`<0m[Z91@3^/8`0
0`2OK9L0SEfD08eMU00808eMU0@0b;W;0`29^OD30=C>e0D0K6Nl00<0;`000=SGe`3HemL01@3HemL2
06mcaPH0im;10`3Qnk400`2=Nk/0000008ek^`0508ek^`L0VigE102DT<`00`000000WXVl09j9_006
09j9_080BJKh1P2PR;/2000001L0oooo000B0?ooo`8000008P3oool30<S0d`L0a=7U1`3Uo<040:nd
g@@0UhFn0`0000050=?4c0@0@XS[1P2b_N820=ogf@L0Q5>>1`26EHl709QUU0L0ReR?1`21D8h808]I
T@P0VF>A00<0REN?0?NiQP3g^HH00`3g^HH40?RjPP03091NT`2CHI@0Tf6D00D0Tf6D1P25EY<30?Jj
R@D0k[2<0P2OK9L908eMU0030?NiQ029^OD0RKWe00<0RKWe103Dc]@706aW_0L0f=OG00<0Kg?60>OB
`@3Wd/400`3Wd/450>7k/@0308ek^`000000SG^k00@0SG^k1`2KWMD309B@c0X0WXVl202PR;/00`3o
ool000000?ooo`0F0?ooo`004P3oool00`000000oooo0?ooo`0R0?ooo`030<S0d`34dND0a=7U00D0
a=7U1@3Uo<0309VYhP80JFBj0P2_]=d0102GQKh000000000000000070=?4c0040=cgg@1aO]40LGkA
075nd@80@XS[1@2b_N820=ogf@L0Q5>>1`26EHl709QUU0L0ReR?1`21D8h808]IT@P0VF>A00<0REN?
0?NiQP3g^HH00`3g^HH40?RjPP03091NT`2CHI@0Tf6D00D0Tf6D1@25EY<40?JjR@D0k[2<0P2OK9L9
08eMU080mkV40`29^OD60=C>e0P0K6Nl1P0S[]840>OB`@H0hO^a00<0SG^k0000002=Nk/01@2=Nk/7
09^Me@0309B@c02iY/H0^JK600T0WXVl2@2PR;/00`3oool000000?ooo`0E0?ooo`004@3oool00`00
0000oooo0?ooo`0U0?ooo`D0a=7U0P3Uo<000`3oool0VJWR09VYhP0409VYhP80JFBj0`00000209N5
_PL0dlC<0`3Lmmd5075nd@<0/[gR0P1fbOl00`3OmmT0Q5>>08ACSP0508ACSPL0QUF?1`2HII@708]H
S`L0PE2>202;FI4809UST@0308UGS`3g^HH0mkV600<0mkV6103h^X800`2@GY<0Tf6D09=QU00509=Q
U0D0QEJC103f^XT50>j`S080WfbG2@2=GI@30?NiQ00308Vim@3Dc]@0e<kD00D0e<kD201/Ik`306Um
e0@08jkB0`3Wd/460>7k/@80SG^k00<0000008ek^`2=Nk/00P2=Nk/30;Kjj0<0G[Ol1@2iY/H809j9
_0800000202PR;/00`3oool000000?ooo`080?ooo`@000000P3oool2000000D0oooo000A0?ooo`03
0000003oool0oooo02L0oooo0`34dND40?ooo`@0VJWR0`00000306UT^P0309N5_P3Ca<`0dlC<00D0
dlC<103Lmmd7075nd@<0M/Wo00<0goOI08ACSP24Dhh01@24Dhh708IES`L0V6FD1`2;F8l7085@SPP0
ReVA202IHi400`29Ehl0mkV60?NiQP020?NiQPD0n;Z200<0T5jC09=QU02CHI@01@2CHI@508EFT`@0
m[Z91@3^/8`209m/U`T0SEfD0`3g^H@80=C>e0L0K6Nl0P2XkJ<606Ume00302>^dP3Wd/40b/CD0080
KW?7103Qnk4308ek^`030000002=Nk/0]_[X00D0]_[X00<0G[Ol0;VVaP2iY/H0102iY/H709j9_0<0
0000202PR;/20?ooo`8000001`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<00000
0?ooo`3oool00P3oool00140oooo00<000000?ooo`3oool0:03oool00`34dND0oooo0?ooo`040?oo
o`<000000P2IZN8606UT^PD0dlC<1P3Lmmd8075nd@0307K9o`3OmmT0Q5>>00H0Q5>>1`26EHl709QU
U0L0ReR?1`21D8h808]IT@P0VF>A00<0REN?0?NiQP3g^HH00P3g^HH50?RjPP03091NT`2CHI@0Tf6D
00D0Tf6D1@25EY<40?JjR@D0k[2<0P2OK9L908eMU0@0mkV4203Dc]@506aW_0@0Z>fS1P1YOM@30<[4
e0@0KW?70P3Qnk4208ek^`030000002fn^P0]_[X00@0]_[X00<0Zm7d0;VVaP2iY/H01P2iY/H609j9
_0<000002@2PR;/20?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`004@3oool2000002h0oooo0P0000000`3oool0VJWR09VYhP0209VYhPL0
JFBj0`3Ca<`70=cgg@L0LGkA00<0^kCB09JAc03OmmT01`24Dhh708IES`L0V6FD1`2;F8l7085@SPP0
ReVA202IHi400`29Ehl0mkV60?NiQP020?NiQPD0n;Z200<0T5jC09=QU02CHI@01@2CHI@508EFT`@0
m[Z9103^/8`309m/U`T0SEfD1@3g^H@70=C>e0@0K6Nl1@2XkJ<506Ume0@0b/CD1P1^LlL0102=Nk/0
]_[X0;Kjj00000020;Kjj0D0Zm7d1`2iY/H509j9_0D000001`2PR;/0103HfMP0oooo0?ooo`000009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00140oooo00<000000?oo
o`3oool0:P3oool3000000@0oooo102IZN8706UT^P030=?4c03Lmmd0g?OM00L0g?OM1@1aO]430;^d
dP030=ogf@24Dhh0Q5>>00D0Q5>>1`26EHl709QUU0L0ReR?2021D8h708]IT@P0VF>A00<0REN?0?Ni
QP3g^HH00P3g^HH50?RjPP03091NT`2CHI@0Tf6D00D0Tf6D1@25EY<40?JjR@@0k[2<0`2OK9L808eM
U0L0mkV41P3Dc]@306aW_0040;SEkP1[Q]`0JhKL06^6g0<0Z>fS0`1YOM@50<[4e0T0KW?700<0]_[X
0000002[dO@01@2[dO@80;VVaP@0WXVl00<0KVFh0000000000000P0000060:28^`<0f=WH0P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool00000008000001@3oool00140oooo00<000000?oo
o`3oool09`3oool3000000P0oooo0`2IZN8606UT^PD0VNnn00@0/;?J07Ifa@1fM/D0MWK50P3Lmmd3
075nd@D0^kCB00<0goOI08ACSP24Dhh01@24Dhh808IES`L0V6FD1P2;F8l8085@SPP0ReVA1`2IHi45
0?NiQP@0n;Z20P2@GY<709=QU0D0QEJC103f^XT40>j`S0<0WfbG202=GI@70?NiQ0030000FP0mW?@0
?Icd0080?Icd0P3Dc]@0101/Ik`0^=G^0;SEkP2heNh506^6g0030:S]X`1YOM@0b/CD00H0b/CD1`1^
LlL20=7NhP030:_Am0000000Zm7d00D0Zm7d1`2iY/H309j9_0<0KVFh0`0000050:28^`@0f=WH00@0
oooo00000000000000001@3oool01P000000oooo0?ooo`000000oooo000000L0oooo000@0?ooo`03
0000003oool0oooo02D0oooo0`00000<0?ooo`80VJWR1@1YI;X409W__P@0/;?J1@1fM/D00`1aO]40
^kCB0;^ddP040;^ddP030=ogf@24Dhh0Q5>>00D0Q5>>2026EHl709QUU0H0ReR?2021D8h808]IT@L0
VF>A1@3g^HH40?RjPP80T5jC1`2CHI@408EFT`@0m[Z91@3^/8`309m/U`P0SEfD1`3g^H@20000FP@0
?Icd1@2heNh606^6g0P0b/CD1P1^LlL40=7NhP030000002[dO@0Zm7d00@0Zm7d1`2iY/H209j9_080
foBK101^IKP00`000000X8Rk0:28^`020:28^`H0f=WH0P3oool00`000000oooo0?ooo`040?ooo`80
00000P3oool4000000@0oooo000@0?ooo`030000003oool0oooo0280oooo0`00000@0?ooo`0309VY
hP1YI;X0JFBj0080JFBj0`2Ikkh60;2cfPD0MWK51`2k]=800`3OmmT0Q5>>08ACSP0508ACSPP0QUF?
1`2HII@708]HS`L0PE2>202;FI4609UST@030000003g^HH0mkV600<0mkV6103h^X82091NT`L0Tf6D
1025EY<40?JjR@D0k[2<0`2OK9L808eMU0L0mkV40`0005X00`0mW?@0^=G^0;SEkP060;SEkPH0JhKL
1`3:a=@406ica`L0dMkR00<000000:_Am02[dO@00`2[dO@80;VVaP0309j9_03Km9/0foBK00D0KVFh
00<000000:28^`2PR;/01P3HfMP01032^=40oooo0?ooo`00000B0?ooo`00403oool00`000000oooo
0?ooo`0O0?ooo`<00000503oool00`2IZN80JFBj06UT^P0209W__P030:2UfP2`/mX0/;?J00D0/;?J
1P1fM/D60;^ddP030=ogf@24Dhh0Q5>>00D0Q5>>2026EHl709QUU0L0ReR?1`21D8h808]IT@D0VF>A
00<0<UW9000000000000103g^HH40?RjPP80T5jC1`2CHI@408EFT`@0m[Z91@3^/8`309m/U`P0SEfD
1`3g^H@00`0005X0[9o:0:bObP020:bObPL0^=G^1`1[Q]`70<[4e080KW?71`3Ag^800`2n[l/0MhKE
0000000307N6e@80Zm7d102iY/H309nbi@<0foBK1P1^IKP00`2PR;/0f=WH0=SIf0040=SIf0<0`[SA
00<0oooo0000003oool04@3oool00100oooo0P00000M0?ooo`<000005`3oool00`2PYMX0JFBj0:2U
fP040:2UfPL0/;?J1P1fM/D50;^ddP030=ogf@24Dhh0Q5>>00D0Q5>>2026EHl709QUU0L0ReR?1`21
D8h808]IT@<0VF>A0P34/<H2039Ib@8000000`3g^HH40?RjPP<0T5jC1`2CHI@308EFT`@0m[Z91@3^
/8`309m/U`P0SEfD1`3g^H@60:bObPL0^=G^1P1[Q]`70<[4e00306ica`3Ag^80dMkR00@0dMkR102n
[l/00`1gQ]D0000007N6e@0307N6e@H0Wk;U103Km9/706iU^0D0f=WH1@32^=400`000000oooo0?oo
o`0@0?ooo`00403oool00`000000oooo0?ooo`0I0?ooo`<000006`3oool70:2UfPH0/;?J1`1fM/D4
0;^ddP030=ogf@24Dhh0Q5>>00D0Q5>>2026EHl709QUU0L0ReR?1`21D8h808]IT@80VF>A0`34/<H4
039Ib@80mkV61@3h^X83091NT`L0Tf6D0`25EY<40?JjR@D0k[2<102OK9L708eMU0L0mkV41P2/WlX9
0962_`<009:m0P1[Q]`30<[4e0809h?Y0`0C00040=7NhPD0_Zo;00<0MhKE0000001gQ]D0101gQ]D5
09nbi@D0foBK1`1^IKP30=SIf0L0`[SA00<000000?ooo`3oool03`3oool00100oooo00<000000?oo
o`3oool05P3oool3000001l0oooo1`2PYMX50;2cfPP0MWK50P2k]=800`1Ne>T0goOI08ACSP0608AC
SPP0QUF?1`2HII@708]HS`L0PE2>202;FI400`2IHi40a;360<B`aP030<B`aP@0<UW900<0mkV60?Rj
PP3h^X800`3h^X83091NT`L0Tf6D0`25EY<40?JjR@@0k[2<1@2OK9L708eMU0L0mkV41P2/WlX90962
_`T0VXBk100WPnT00`0C0000dMkR0;j_b`070;j_b`0307N6e@000000MhKE00@0MhKE0`2O/^D60=_d
V`P0KVFh00<0f=WH0<:hd@32^=401P32^=400`000000oooo0?ooo`0?0?ooo`00403oool00`000000
oooo0?ooo`0D0?ooo`8000008P3oool80:2UfPD0/;?J1@1fM/D50:jmi0030=ogf@24Dhh0Q5>>00D0
Q5>>2026EHl709QUU0L0ReR?1`21D8h408]IT@<0Gm?_1`34/<H5039Ib@D0n;Z20`2@GY<709=QU0<0
QEJC103f^XT40>j`S0D0WfbG1`2=GI@70?NiQ0D0[9o:0P3Bo/080962_`030?7]``2JQ;/0VXBk00L0
VXBk100WPnT90;j_b`80MhKE00<0000007N6e@1gQ]D00P1gQ]D209nbi@030=_dV`0LLn8077?R00@0
foBK1`1^IKP00`2ElMD0`[SA0<:hd@060<:hd@030?ooo`000000oooo0100oooo000?0?ooo`<00000
4P3oool3000002D0oooo1P2PYMX40:c;k`040;RVa`2`/mX0MWK507Ifa@L0[[gT00<0fMcI0=ogf@24
Dhh01P24Dhh808IES`0301Pi]02HII@0V6FD00@0V6FD1`2;F8l6085@SPD0_=S^0P1Odnl90<B`aPH0
<UW90P3h^X84091NT`L0Tf6D0`25EY<40?JjR@@0k[2<1@2OK9L708eMU0H0mkV41@2/WlX30=;n`0L0
TH:o0P3akL<909Z4^`80GF:o0`0WPnT90;j_b`0307N6e@000000MhKE00@0MhKE00<0Wk;U0;VTa02i
Y<@00`0LLn820=_dV`D0KVFh102ElMD60<:hd@80oooo00<000000?ooo`3oool03`3oool000l0oooo
00<000000?ooo`3oool03`3oool3000002T0oooo0P2PYMX60:c;k`<0^:K700<07D_50:jmi02^_N@0
1@2^_N@20=WLf@030=ogf@24Dhh0Q5>>00D0Q5>>2026EHl00`3Zl/h063Vd09QUU00409QUU0L0ReR?
1021D8h70;cHkP030=7BfP34/<H0a;3600P0a;361`0bFLT00`3h^X80T5jC091NT`02091NT`L0Tf6D
0P25EY<50?JjR@@0k[2<1@2OK9L708eMU0H0mkV4102/WlX40=;n`0H0TH:o0`3akL<909Z4^`<0GF:o
0P0WPnT80;j_b`0400X00021^OP0PKWh00000080PKWh1@2iY<@401achP80foBK0`1^IKP609Gae@@0
`[SA0`3oool00`000000oooo0?ooo`0?0?ooo`001P3oool3000000H0oooo00<000000?ooo`3oool0
303oool3000002h0oooo1@2/bnl40;RVa`807D_51@2^_N@30=WLf@030=ogf@24Dhh0Q5>>00D0Q5>>
1`26EHl20>[bcP8063Vd102HII@708]HS`<0PE2>1`2lf>h30=7BfPX0a;361`0bFLT4091NT`L0Tf6D
0P25EY<50?JjR@@0k[2<1@2OK9L608eMU0L0mkV40`2/WlX60=;n`0D0TH:o103akL<709Z4^`80iObo
101MH[l00`0WPnT0_Zo;0;j_b`030;j_b`0406R6g00:00002P0000X00080PKWh00<000000;VTa02i
Y<@01@2iY<@501achP0306iU^02ElMD0UO7E00H0UO7E0`32^=440?ooo`030000003oool0oooo00l0
oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool300000380oooo
0`2/bnl50;RVa`<07D_50`2^_N@40=WLf@030=ogf@24Dhh0Q5>>00D0Q5>>1P26EHl30>[bcP<063Vd
0`2HII@708]HS`03085@SP2lf>h0_=S^00H0_=S^103Ad]X90<B`aPD0S5^B1`2@GY<709=QU080QEJC
103f^XT50>j`S0D0WfbG1P2=GI@70?NiQ00309F2_02/WlX0UH:l0080;6gL103Bo/040962_`D0lNg3
1P2JQ;/30>Gl_`D0GF:o102n[l/506R6g00400X00021^OP0^JC4000000H0^JC4303oool309Gae@03
0<:hd@3oool0oooo00<0oooo00<000000?ooo`3oool03`3oool000L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`060?ooo`<00000=P3oool00`2/bnl0^:K70;RVa`050;RVa`<07D_5
00<0[[gT0=WLf@3Ig=T0103Ig=T708ACSPD0QUF?1@3Zl/h301Pi]080V6FD1P2;F8l205G@b0L0_=S^
1P3Ad]X70<B`aPH0S5^B1`2@GY<709=QU080QEJC103f^XT50>j`S0D0WfbG1P2=GI@70?NiQ0@0UH:l
0`0/KM`20=;n`0<0TH:o1`3akL<409Z4^`@0iObo1P1MH[l0102n[l/0e_^c0=Kk/`3Fnk<506R6g080
^JC400<000000;VTa02iY<@0102iY<@F0?ooo`030000003oool0oooo00h0oooo00070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool3000003T0oooo202hY/L501e;a@@0fMcI
00<0b[7108ACSP24Dhh01@24Dhh408IES`H0j_;>100H>K@0102HII@0ReR?08]HS`2;F8l605G@b0D0
_=S^1`3Ad]X60<B`aPL0S5^B1`2@GY<709=QU080QEJC103f^XT50>j`S0D0WfbG1P2=GI@70?NiQ0D0
UH:l0`0/KM`20=;n`080TH:o1`3akL<409Z4^`D0iObo1@1MH[l40=Kk/`H0J8KL0P2iY<@00`000000
^JC40;VTa0020;VTa1L0oooo00<000000?ooo`3oool03P3oool000L0oooo00<000000?ooo`3oool0
103oool200000080oooo0`00000m0?ooo`L0^:K71`0MBlD00`3Ig=T0b[710<Za`@0708ACSP<0QUF?
1`3Zl/h501Pi]00408]HS`1Ed<P063Vd0:3fe`<0IhWO0`1Ed<P30;cHkPT0dM;J1034/<H808aKTPL0
T5jC1`2CHI@208EFT`@0m[Z91@3^/8`509m/U`H0SEfD1`3g^H@609F2_0@0;6gL00<0TH:o0?7]``3a
kL<01P3akL<309Z4^`H0iObo101MH[l60=Kk/`D0J8KL0`2iY<@00`000000^JC40;VTa00H0?ooo`03
0000003oool0oooo00h0oooo00060?ooo`8000001P3oool400000400oooo202hY/L301e;a@<0VIgF
0`3:/L4708ACSP80QUF?2@3Zl/h601Pi]0<0X?KG1@1WRMl00`1Ed<P0_=S^0=7BfP090=7BfP<0a;36
00<0SUfD08aKTP2<Fi801P2<Fi87091NT`P0Tf6D00<0QEJC0?JjR@3f^XT00P3f^XT40>j`S0H0WfbG
1P2=GI@70?NiQ0L0UH:l1P0/KM`70?7]``0409Z4^`30i?40`>Ca02n?k`@0iObo101MH[l30=Kk/`D0
oooo101XQ]`30;VTa0030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool000L0oooo
00<000000?ooo`3oool0103oool2000004<0oooo1P2hY/L00`2nho40VIgF09VMeP0509VMeP80b[71
1`24Dhh00`26EHl0j_;>0>[bcP080>[bcP@063Vd1@2Pm]L806N9g`X0dM;J00<0a;3608iMU02>GI@0
202<Fi87091NT`P0Tf6D00<0QEJC0?JjR@3f^XT00P3f^XT40>j`S0L0WfbG1@2=GI@70?NiQ0H0UH:l
00<0e]7D09B<b02DS<P01@2DS<P607FZl`@0`>Ca0`0_Snl20>Gl_`80GF:o2`3oool206R6g0<0^JC4
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?oo
o`100?ooo`@0^:K7102nho4709VMeP030<Za`@24Dhh0Q5>>00@0Q5>>1@2ejoL01037n^P0Kgc@06ml
d01_O=030>[bcP<063Vd1`2Pm]L806N9g`L0dM;J1@2>GI@808aKTPP0T5jC1`2CHI@50?JjR@@0k[2<
1`2OK9L508eMU0L0mkV41@2EP[`30=KAe0L0U8c80`1eZ_<70<3Tl@80;ho_0P3oool00`1MH[l0oooo
0?ooo`0;0?ooo`0606R6g02iY<@0^JC40;VTa03oool00000603oool00`000000oooo0?ooo`0>0?oo
o`004@3oool00`000000oooo0?ooo`100?ooo`030;RVa`2nho40_^?a00D0_^?a1P2IWMH00`3:/L40
Q5>>08ACSP0208ACSPH0]N_g0`37n^P506mld0030>[bcP0H>K@0X?KG0080Kgc@0P1:KmD40:3fe`P0
IhWO0P3Ad]X30?:gS@H0SUfD202<Fi88091NT`L0Tf6D1@3f^XT40>j`S0L0WfbG1@2=GI@70?NiQ0@0
UH:l103FdM@809B<b00307FZl`30i?40`>Ca00D0`>Ca5@3oool01@2iY<@0oooo0?ooo`3oool00000
01L0oooo00<000000?ooo`3oool03P3oool00180oooo00<000000?ooo`3oool0@@3oool60;kSl@L0
VIgF0`24Dhh50;G[m`D0ao[X2P1_O=000`3Ul]D0BVoE04Y_e@0204Y_e@030:3fe`1WRMl0IhWO00@0
IhWO1`3b]hd608iMU0P0S5^B202@GY<709=QU0D0m[Z9103^/8`709m/U`D0SEfD1`3g^H@309F2_0D0
e]7D1`2DS<P30<>id@@0`>Ca6`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0
oooo000C0?ooo`800000@`3oool50;kSl@H0VIgF00<0Q5>>0;G[m`2ejoL0102ejoL70<Ojj0P0Kgc@
0P3Ul]D404Y_e@80m;R<0P1WRMl:0?:gS@H0SUfD202<Fi88091NT`H0Tf6D00<0_>kc0?JjR@3f^XT0
0`3f^XT40>j`S0L0WfbG102=GI@80?NiQ080UH:l1`3FdM@509B<b0D0`kWA00<0`>Ca0?ooo`3oool0
703oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003o
ool0oooo0400oooo101iPm420;kSl@<0VIgF1P1bf?T20;G[m`P0ao[X1`1_O=040>Gbe@<0BVoE103d
^8`:0?:gS@L0SUfD202<Fi87091NT`@0Tf6D102lk_<30?JjR@D0k[2<1`2OK9L408eMU0L0mkV400<0
dKBm09F2_03FdM@01`3FdM@409B<b0H0`kWA803oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00d0oooo000F0?ooo`030000003oool0oooo0400oooo201iPm4407;Hn@H0?L3L00<007S1
05mU`@1OIL400`37n^P606mld0H0iO;E0P1:KmD40?BhS0X0l[N=1`2>GI@808aKTPL0T5jC0`2CHI@6
0;c^l`80m[Z91@3^/8`709m/U`@0SEfD1`3g^H@206?AZ@P0e]7D0`2DS<P70<>idB40oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`005`3oool00`000000oooo0?ooo`0o0?oo
o`P0NH?A1@35]ld20>kh_`@0NJWb00@0]j3205mU`@1OIL40GfG10P37n^P406mld0L0iO;E00<0BVoE
0?BhS03d^8`00`3d^8`:0?:gS@L0SUfD202<Fi87091NT`0309=QU02lk_<0_>kc00L0_>kc00<0m[Z9
0>j`S03^/8`00P3^/8`00`2:Fi@0WfbG09m/U`0509m/U`@0SEfD1`3g^H@306?AZ@P0e]7D00<0U8c8
0<>id@33^M401@33^M4R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool0
01P0oooo0P0000100?ooo`H0NH?A1P35]ld30>kh_`@0NJWb101OIL401037n^P0Kgc@06mld01_O=09
0>Gbe@D0m;R<2P3b]hd708iMU0P0S5^B1P2@GY<40<?Jj`P0_>kc103^/8`00`2:Fi@0WfbG09m/U`05
09m/U`@0SEfD1`3g^H@0102MVm40oooo06?AZ@1SdJT40=KAe0<0DLgU1`33^M4T0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool001X0oooo00<000000?ooo`3oool0?P3oool4
07V3d@H0aKO=1@3^n;l307VYlPH0GfG100<0Kgc@0>Gbe@3Ul]D01@3Ul]D408O2n`@0m;R<2P3b]hd7
08iMU0P0S5^B102@GY<50<?Jj`030<Cng@2BPkl0TX>o00H0TX>o103^/8`00`2:Fi@0WfbG09m/U`05
09m/U`@0SEfD1`3g^H@00`2MVm40oooo0?ooo`060?ooo`<0DLgU1@33^M4V0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool03@3oool001/0oooo00<000000?ooo`3oool0?@3oool307V3
d@H0aKO=1@3^n;l00`2l_]/0G6?105aS`@0207VYlPT0GfG10P38o/D708O2n`<0m;R<2P3b]hd00`3S
i=@005O<08iMU00408iMU0P0S5^B0`2@GY<50<?Jj`<0a?kM1`2BPkl40>j`S00308YKU02OK9L0WfbG
00D0WfbG102=GI@70?NiQ0`0oooo00@0DLgU0<>id@33^M40`kWA:03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo000L0?ooo`030000003oool0oooo03d0oooo00<0NH?A0<Fg
c@35]ld01@35]ld40>kh_`80_;kK0`1LHl400`1iZO80GfG105mU`@0605mU`@@0b?k51`27`_/00`3d
^8`0l[N=0?:gS@090?:gS@80hnCD0P00El`308iMU0P0S5^B00<0T5jC0<?Jj`33f^/01033f^/40<Cn
g@P0TX>o0`3^/8`00`2:Fi@0WfbG09m/U`0509m/U`@0SEfD1`3g^H@>0?ooo`030<>id@3oool0oooo
02L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool2000003h0
oooo1P35]ld30>kh_`D0_;kK0`1LHl4705mU`@H0b?k51`27`_/:0?:gS@@0hnCD0P00El`208iMU0H0
S5^B0`1BclT50<?Jj`D0a?kM202BPkl30>j`S00308YKU02OK9L0WfbG00H0WfbG0`2=GI@70?NiQ3T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`007`3oool00`000000oooo
0?ooo`0l0?ooo`@0aKO=0`3^n;l60;bnf`@0G6?11@1OIL460<Sna@<0V=;l1@10^?490?:gS@H0hnCD
0`00El`208aKTPP0D/o90`33f^/70<Cng@L0TX>o0`3^/8`00`2:Fi@0WfbG09m/U`0609m/U`<0SEfD
1`3g^H@j0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00200oooo00<0
00000?ooo`3oool0?03oool30<Fgc@030>kh_`3oool0oooo00H0_;kK101LHl4405mU`@@0b?k52@2H
d_`3042hl@L0l[N=1P3Si=@00`3Fin80TI;A096Bd@05096Bd@D0KI?V0P1BclT00`33f^/0a?kM06fC
iP0308QJU@<0a?kM202BPkl20>j`S00308YKU02OK9L0WfbG00H0WfbG0`2=GI@70?NiQ3X0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00`000000oooo0?ooo`0l
0?ooo`030<Fgc@3oool0oooo00<0oooo1P2l_]/305aS`@<0GfG10P38o/D307b`m0P0V=;l00<0Y8fm
06YT^@1ZI;T00P10^?450?:gS@H0hnCD0`3Fin87096Bd@P0KI?V1@28FYD20<Cng@P0TX>o0P3^/8`2
08YKU0L0WfbG0P2=GI@80?NiQ3/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<
0?ooo`008P3oool2000004<0oooo1@2l_]/405aS`@0305mU`@1LHl40O;3d00D0O;3d102Hd_`40:B=
_@<0JVBi00<0@;Sa0?:gS@3b]hd00`3b]hd50>?Te0@0e^OR202AT]4506fCiPL0R5ZE00<0UfFG0<Cn
g@34o]d01`2BPkl0103^/8`0RU^D08YKU02:Fi@709m/U`80SEfD203g^H@l0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool002@0oooo00<000000?ooo`3oool0@03oool207Ae
aP<0_;kK1`1LHl4207b`m0@0WL?c00<0V=;l0:B=_@2TSKd01@2TSKd406YT^@<0l[N=1@3Si=@60=KW
hPP0TI;A0`1]TnH00`3f^XT0R5ZE08QJU@0508QJU@80UfFG00<0a?kM09:3_`2BPkl01P2BPkl308YK
U0L0WfbG0P2=GI@80?NiQ3d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`009@3oool00`000000oooo0?ooo`100?ooo`<0M7G60P2l_]/505aS`@0305ije`000000000000<0
WL?c00<0iOWA0:B=_@2TSKd01P2TSKd506YT^@030?:gS@3Si=@0hnCD00<0hnCD1`3Fin89096Bd@03
06fCiP3f^XT0m[Z900L0R5ZE0`2GIIL809:3_`<0RU^D1`2OK9L208eMU0P0mkV4?@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo000V0?ooo`030000003oool0oooo03l0oooo
1@1dMLH205aS`@80M7G600<0i__705ije`1NN]L00P1NN]L0102M`o<0iOWA05ije`30[lT70:B=_@P0
JVBi0P3Si=@90=KWhPL0TI;A103f^XT708QJU@@0UfFG102BPkl608YKU0L0WfbG0P2=GI@70?NiQ3l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`009`3oool200000400oooo
1`1dMLH20>Kka`H0GW[G0P30[lT70:B=_@T0JVBi0P2_l:D80=KWhP@0TI;A1`3f^XT708QJU@L0UfFG
1`2:Fi@709m/U`80SEfD1`3g^HA00?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool002T0oooo00<000000?ooo`3oool0?@3oool607AeaP@0i__7101NN]L30<2_b@P0Y8fm201Z
I;T40:o`Y@L0e^OR00<0TI;A0?6fS`3a]Xl01`3f^XT708QJU@L0UfFG1`2:Fi@709m/U`80SEfD1`3g
^HA10?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool002X0oooo00<00000
0?ooo`3oool0?03oool507AeaPD0i__70`1NN]L50<2_b@L0Y8fm1`1ZI;T30:o`Y@80[]Cd1@2;R/d5
0?6fS`L0m[Z91`28FYD709MUU`L0RU^D1`2OK9L208eMU0L0mkV4@@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo000[0?ooo`030000003oool0oooo03`0oooo101dMLH60>Kk
a`0305ije`30[lT0`:o900@0`:o91`2TSKd606YT^@030:o`Y@2^e?@0[]Cd00@0[]Cd102;R/d40?6f
S`P0m[Z91`28FYD709MUU`L0RU^D1`2OK9L208eMU0L0mkV4@P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00/0oooo000/0?ooo`800000?03oool307AeaP<0oooo1020[?480<2_b@H0
Y8fm1@1ZI;T20=gAc@H0[]Cd102;R/d40?6fS`P0m[Z91`28FYD709MUU`L0RU^D202OK9L00`2=GI@0
mkV40?NiQ0050?NiQ4<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00
;P3oool00`000000oooo0?ooo`0j0?ooo`0307AeaP3oool0oooo00<0oooo1020[?460<2_b@030<k3
c`2TSKd0Y8fm00@0Y8fm101ZI;T0102?]>l0gM7=0=gAc@3MdLd60:kDm0<0Rh[=103a]Xl90?JjR@H0
R5ZE1`2GIIL808YKU0L0WfbG00<0SEfD0?NiQ03g^H@01@3g^HA40?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool02`3oool002l0oooo00<000000?ooo`3oool0@03oool4082/l@@0`:o9
0P3>`ll70:B=_@80JVBi00<0SkC_0=gAc@3MdLd00`3MdLd50:kDm0<0Rh[=103a]Xl90?JjR@H0R5ZE
1`2GIIL808YKU0L0WfbG203g^HA40?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2P3oool00300oooo00<000000?ooo`3oool0@@3oool2082/l@<0`:o9103>`ll60:B=_@0306YT^@2?
]>l0gM7=00D0gM7=0P3A^L840:kDm080Rh[=103a]Xl90?JjR@L0R5ZE1P2GIIL808YKU0L0WfbG203g
^HA50?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool00340oooo0P000012
0?ooo`8007cH00<0`:o90<k3c`3>`ll00`3>`ll708ndk`L0gM7=0`3A^L82001/fP030:kDm02;R/d0
lKJ?00@0lKJ?2@3f^XT708QJU@H0UfFG202:Fi@709m/U`P0mkV4AP3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00X0oooo000c0?ooo`030000003oool0oooo03l0oooo0P1KLLl2001l
f0D0c/??1@2?]>l70=gAc@D0dKW20`00K=X50?6fS`T0m[Z91`28FYD709MUU`L0RU^D1`2OK9L80?Ni
Q4H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00=03oool00`000000
oooo0?ooo`0o0?ooo`<0Fg7?00<007cH0<k3c`3>`ll00`3>`ll408ndk`H0gM7=1P3A^L8205IH^003
001/fP3a]Xl0lKJ?00<0lKJ?2@3f^XT708QJU@L0UfFG1P2:Fi@30<gDg`<0k^c70P00B<P80?NiQ4L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`00=@3oool00`000000oooo
0?ooo`0n0?ooo`D0Fg7?0`3>`ll0103oool0SkC_08ndk`2?]>l60=gAc@L0dKW200@0h<Jn05IH^01F
F;P006cJ103a]Xl90?JjR@L0R5ZE1`2GIIL508YKU0<0cMCO1@3^k<L20018b0L0mkV4B03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo000f0?ooo`800000?`3oool605]ac`<0
oooo00<0SkC_0=gAc@3MdLd0103MdLd70=6i`P80h<Jn0`1FF;P00`00K=X0lKJ?0?6fS`090?JjR@03
07S@Q`1lVN@0O9WT00<0O9WT0P28FYD709MUU`<0RU^D1@3=e=l60>k/a`8004S81@3g^HA:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool003P0oooo00<000000?ooo`3oool0
?@3oool405]ac`H0oooo1@3MdLd60=6i`P<0h<Jn101FF;P20?6fS`P0m[Z90`1hd8L807bIi0030<;9
h02GIIL0UfFG0080UfFG0P2:Fi@50<gDg`H0k^c70`3oool00`00B<P0mkV40?NiQ0020?NiQ4X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`00>@3oool00`000000oooo0?oo
o`0l0?ooo`<0Fg7?203oool30=gAc@L0dKW2103Pa[h405IH^0030?6fS`3f^XT0m[Z900D0m[Z91@1h
d8L607bIi0<0`/WP0P0ZHM@00`2GIIL0RU^D0<gDg`040<gDg`H0k^c71@3oool01000B<P0mkV40?Ni
Q03g^HA;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool003X0oooo00<0
00000?ooo`3oool0?03oool00`1KLLl0oooo0?ooo`080?ooo`030=gAc@3A^L80dKW200D0dKW21@3P
a[h505IH^0H0m[Z900<0/oW[0561hP1APN800`1hd8L507bIi0D0`/WP0`0ZHM@40<gDg`D0k^c72@3o
ool20?NiQ4`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00>`3oool2
000003`0oooo00<000000?ooo`3oool0203oool70=6i`PH0h<Jn1`1FF;P30?JjR@030;?ij`3>^LH0
c[W600@0DH7R00@0N=2707bIi01lVN@0O9WT1P32bN0402YQe0<0cMCO103^k<L;0?ooo`030?NiQ03o
ool0oooo04/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00?@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00T0oooo1P3A^L870>36_PL0EURh00<0m[Z90;?ij`3>^LH00`3>
^LH50561hP0307bIi032bN00`/WP00H0`/WP100ZHM@00`3=e=l0k^c70>k/a`020>k/aeX0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`00?P3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo00X0oooo103A^L880>36_PH0EURh0P2cnN/60<jiaPD0DH7R2@32bN0402YQe5l0oooo00@0
00000?ooo`3oool000002`3oool003l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0;0?ooo`<0dKW2203Pa[h505IH^080/oW[203>^LH50561hPH0`/WPIP3oool00`000000oooo0000
000;0?ooo`00@03oool2000003L0oooo00<000000?ooo`3oool0303oool00`3A^L80h<Jn0>36_P08
0>36_P80EURh0`2cnN/90<jiaP@0oooo0P1APN820<;9h6T0oooo00@000000?ooo`3oool000002P3o
ool00480oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`X0h<Jn00@0EURh
0;?ij`2cnN/0/oW[2@3>^LIc0?ooo`030000003oool0000000X0oooo00130?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool03P3oool80>36_P@0KY7T2@3>^LIe0?ooo`8000002P3oool0
04@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`@0h<Jn0`3oool506jA
i0L0c[W6M@3oool3000000X0oooo00150?ooo`800000<@3oool00`000000oooo0?ooo`0A0?ooo`03
0>36_P3oool0oooo00<0oooo1P1^TN@50<jiaW80oooo1000000=0?ooo`00A`3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo01P0oooo1P1^TN@30<jiaVl0oooo1000000A0?ooo`00B03o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01d0oooo0P1^TN@00`3>^LH0oooo0?oo
o`1[0?ooo`<000005@3oool004T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`29
0?ooo`@00000603oool004X0oooo0P00000/0?ooo`030000003oool0oooo08D0oooo1000000L0?oo
o`00C03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0840oooo1000000P0?ooo`00
C@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07d0oooo1000000T0?ooo`00CP3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo07T0oooo1000000X0?ooo`00C`3oool2
000002L0oooo00<000000?ooo`3oool0M@3oool4000002`0oooo001A0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0LP3oool300000300oooo001B0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0KP3oool4000003<0oooo001C0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0JP3oool4000003L0oooo001D0?ooo`8000008P3oool00`000000oooo0?oo
o`1V0?ooo`@00000>`3oool005H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1R
0?ooo`@00000?`3oool005L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?oo
o`@00000@`3oool005P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1J0?ooo`@0
0000A`3oool005T0oooo0P00000M0?ooo`030000003oool0oooo05L0oooo0`00001;0?ooo`00F`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo05<0oooo1000001>0?ooo`00G03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04l0oooo1000001B0?ooo`00G@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo1000001F0?ooo`00GP3oool2000001P0
oooo00<000000?ooo`3oool0A`3oool4000005X0oooo001P0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0@`3oool4000005h0oooo001Q0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0?`3oool400000680oooo001R0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?03oool3000006H0oooo001S0?ooo`8000004`3oool00`000000oooo0?ooo`0h0?oo
o`@00000J@3oool006D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`@0
0000K@3oool006H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`@00000
L@3oool006L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0]0?ooo`@00000M@3o
ool006P0oooo0P00000=0?ooo`030000003oool0oooo02T0oooo1000001i0?ooo`00JP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo1000001m0?ooo`00J`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0280oooo0`0000210?ooo`00K03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01h0oooo100000240?ooo`00K@3oool2000000P0oooo00<0
00000?ooo`3oool06P3oool4000008P0oooo001_0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool05P3oool4000008`0oooo001`0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04P3oool400000900oooo001a0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool4000009@0oooo001b0?ooo`8000000`3oool00`000000oooo0?ooo`0:0?ooo`@00000
V03oool007@0oooo00@000000?ooo`3oool000002@3oool3000009`0oooo001e0?ooo`030000003o
ool0000000D0oooo1000002O0?ooo`00MP3oool2000000030?ooo`000000000000800000X`3oool0
07L0oooo0P00002W0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0531382, 0.00308314, \
0.00362088, 0.00362088}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(ListPlot3D[\[ScriptN]\[ScriptCapitalE] \
/. \[InvisibleSpace]{x_ /; x < 0.2 \[Rule] 0, 
            x_ /; x > 0.8 \[Rule] 1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.21264e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -9 -11.9926 ]
[.12586 .2075 0 .00736 ]
[.25429 .15697 -13.4005 -12 ]
[.25429 .15697 .5995 0 ]
[.38935 .10384 -12.7924 -12 ]
[.38935 .10384 1.2076 0 ]
[.53158 .04793 -12.1843 -12 ]
[.53158 .04793 1.81571 0 ]
[.68156 -0.01098 -11.5762 -12 ]
[.68156 -0.01098 2.42381 0 ]
[.75679 .08071 0 -8.23703 ]
[.75679 .08071 9 3.76297 ]
[.82083 .17876 0 -8.11081 ]
[.82083 .17876 14 3.88919 ]
[.87924 .26821 0 -7.99808 ]
[.87924 .26821 14 4.00192 ]
[.93273 .35014 0 -7.89677 ]
[.93273 .35014 14 4.10323 ]
[.98191 .42546 0 -7.80525 ]
[.98191 .42546 14 4.19475 ]
[.02411 .26511 -9 -3.65642 ]
[.02411 .26511 0 8.34358 ]
[.01568 .31795 -21.5 -3.71599 ]
[.01568 .31795 0 8.28401 ]
[.00696 .37264 -16.5 -3.77786 ]
[.00696 .37264 0 8.22214 ]
[-0.00208 .42927 -21.5 -3.84215 ]
[-0.00208 .42927 0 8.15785 ]
[-0.01144 .48795 -9 -3.90901 ]
[-0.01144 .48795 0 8.09099 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
gsave
.75679 .08071 -61 -12.237 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.80845 .18312 m
.80226 .18529 L
s
gsave
.82083 .17876 -61 -12.1108 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.86679 .27235 m
.86056 .27443 L
s
gsave
.87924 .26821 -61 -11.9981 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.92022 .35409 m
.91397 .35607 L
s
gsave
.93273 .35014 -61 -11.8968 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.8052 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
.73096 .06459 m
.72728 .06598 L
s
.71716 .04348 m
.71349 .04489 L
s
.70309 .02196 m
.69942 .02338 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
gsave
.02411 .26511 -70 -7.65642 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02795 .31328 m
.03408 .31095 L
s
gsave
.01568 .31795 -82.5 -7.71599 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.01926 .36808 m
.02541 .3658 L
s
gsave
.00696 .37264 -77.5 -7.77786 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.01027 .42483 m
.01644 .42261 L
s
gsave
-0.00208 .42927 -82.5 -7.84215 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.00095 .48363 m
.00715 .48147 L
s
gsave
-0.01144 .48795 -70 -7.90901 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39236 .59183 .40512 .60371 .42651 .5973 .41385 .58532 Mtetra
.41385 .58532 .42651 .5973 .44806 .59083 .43552 .57875 Mtetra
.43552 .57875 .44806 .59083 .46979 .58431 .45736 .57214 Mtetra
.45736 .57214 .46979 .58431 .4917 .57774 .47938 .56547 Mtetra
.47938 .56547 .4917 .57774 .51378 .57112 .50157 .55874 Mtetra
.50157 .55874 .51378 .57112 .53604 .56444 .52395 .55197 Mtetra
.52395 .55197 .53604 .56444 .55848 .55771 .54651 .54513 Mtetra
.54651 .54513 .55848 .55771 .58111 .55092 .56926 .53824 Mtetra
.56926 .53824 .58111 .55092 .60392 .54407 .5922 .53129 Mtetra
.5922 .53129 .60392 .54407 .62692 .53717 .61532 .52429 Mtetra
.61532 .52429 .62692 .53717 .65011 .53022 .63864 .51722 Mtetra
.63864 .51722 .65011 .53022 .67349 .5232 .66216 .5101 Mtetra
.66216 .5101 .67349 .5232 .69706 .51613 .68587 .50292 Mtetra
.68587 .50292 .69706 .51613 .72084 .509 .70978 .49567 Mtetra
.70978 .49567 .72084 .509 .74481 .50181 .7339 .48837 Mtetra
.7339 .48837 .74481 .50181 .76899 .49455 .75822 .481 Mtetra
.75822 .481 .76899 .49455 .79338 .48724 .78275 .47357 Mtetra
.78275 .47357 .79338 .48724 .81797 .47986 .80749 .46607 Mtetra
.80749 .46607 .81797 .47986 .84277 .47242 .83244 .45851 Mtetra
.83244 .45851 .84277 .47242 .86778 .46492 .85762 .45089 Mtetra
.85762 .45089 .86778 .46492 .89301 .45735 .883 .4432 Mtetra
.883 .4432 .89301 .45735 .91846 .44971 .90862 .43544 Mtetra
.90862 .43544 .91846 .44971 .94414 .44201 .93445 .42761 Mtetra
.93445 .42761 .94414 .44201 .97003 .43424 .96052 .41972 Mtetra
.37941 .57977 .39236 .59183 .41385 .58532 .40101 .57316 Mtetra
.40101 .57316 .41385 .58532 .43552 .57875 .42278 .5665 Mtetra
.42278 .5665 .43552 .57875 .45736 .57214 .44473 .55978 Mtetra
.44473 .55978 .45736 .57214 .47938 .56547 .46687 .55301 Mtetra
.46687 .55301 .47938 .56547 .50157 .55874 .48918 .54619 Mtetra
.48918 .54619 .50157 .55874 .52395 .55197 .51168 .5393 Mtetra
.51168 .5393 .52395 .55197 .54651 .54513 .53436 .53236 Mtetra
.53436 .53236 .54651 .54513 .56926 .53824 .55723 .52537 Mtetra
.55723 .52537 .56926 .53824 .5922 .53129 .5803 .51831 Mtetra
.5803 .51831 .5922 .53129 .61532 .52429 .60355 .5112 Mtetra
.60355 .5112 .61532 .52429 .63864 .51722 .627 .50402 Mtetra
.627 .50402 .63864 .51722 .66216 .5101 .65065 .49679 Mtetra
.65065 .49679 .66216 .5101 .68587 .50292 .6745 .48949 Mtetra
.6745 .48949 .68587 .50292 .70978 .49567 .69855 .48214 Mtetra
.69855 .48214 .70978 .49567 .7339 .48837 .72281 .47472 Mtetra
.72281 .47472 .7339 .48837 .75822 .481 .74728 .46723 Mtetra
.74728 .46723 .75822 .481 .78275 .47357 .77196 .45968 Mtetra
.77196 .45968 .78275 .47357 .80749 .46607 .79685 .45207 Mtetra
.79685 .45207 .80749 .46607 .83244 .45851 .82196 .44439 Mtetra
.82196 .44439 .83244 .45851 .85762 .45089 .84728 .43664 Mtetra
.84728 .43664 .85762 .45089 .883 .4432 .87283 .42882 Mtetra
.87283 .42882 .883 .4432 .90862 .43544 .89861 .42094 Mtetra
.89861 .42094 .90862 .43544 .93445 .42761 .92461 .41298 Mtetra
.92461 .41298 .93445 .42761 .96052 .41972 .95085 .40496 Mtetra
.36626 .56753 .37941 .57977 .40101 .57316 .38797 .56082 Mtetra
.38797 .56082 .40101 .57316 .42278 .5665 .40985 .55406 Mtetra
.40985 .55406 .42278 .5665 .44473 .55978 .43192 .54724 Mtetra
.43192 .54724 .44473 .55978 .46687 .55301 .45417 .54037 Mtetra
.45417 .54037 .46687 .55301 .48918 .54619 .4766 .53344 Mtetra
.4766 .53344 .48918 .54619 .51168 .5393 .49922 .52645 Mtetra
.49922 .52645 .51168 .5393 .53436 .53236 .52202 .5194 Mtetra
.52202 .5194 .53436 .53236 .55723 .52537 .54502 .5123 Mtetra
.54502 .5123 .55723 .52537 .5803 .51831 .56821 .50513 Mtetra
.56821 .50513 .5803 .51831 .60355 .5112 .5916 .49791 Mtetra
.5916 .49791 .60355 .5112 .627 .50402 .61518 .49062 Mtetra
.61518 .49062 .627 .50402 .65065 .49679 .63896 .48327 Mtetra
.63896 .48327 .65065 .49679 .6745 .48949 .66295 .47586 Mtetra
.66295 .47586 .6745 .48949 .69855 .48214 .68715 .46839 Mtetra
.68715 .46839 .69855 .48214 .72281 .47472 .71155 .46085 Mtetra
.71155 .46085 .72281 .47472 .74728 .46723 .73616 .45324 Mtetra
.73616 .45324 .74728 .46723 .77196 .45968 .76099 .44557 Mtetra
.76099 .44557 .77196 .45968 .79685 .45207 .78603 .43783 Mtetra
.78603 .43783 .79685 .45207 .82196 .44439 .8113 .43003 Mtetra
.8113 .43003 .82196 .44439 .84728 .43664 .83678 .42216 Mtetra
.83678 .42216 .84728 .43664 .87283 .42882 .86249 .41421 Mtetra
.86249 .41421 .87283 .42882 .89861 .42094 .88844 .4062 Mtetra
.88844 .4062 .89861 .42094 .92461 .41298 .91461 .39811 Mtetra
.91461 .39811 .92461 .41298 .95085 .40496 .94101 .38995 Mtetra
.35291 .5551 .36626 .56753 .38797 .56082 .37473 .54829 Mtetra
.37473 .54829 .38797 .56082 .40985 .55406 .39673 .54143 Mtetra
.39673 .54143 .40985 .55406 .43192 .54724 .41891 .53451 Mtetra
.41891 .53451 .43192 .54724 .45417 .54037 .44127 .52753 Mtetra
.44127 .52753 .45417 .54037 .4766 .53344 .46382 .52049 Mtetra
.46382 .52049 .4766 .53344 .49922 .52645 .48656 .51339 Mtetra
.48656 .51339 .49922 .52645 .52202 .5194 .50949 .50624 Mtetra
.50949 .50624 .52202 .5194 .54502 .5123 .53262 .49902 Mtetra
.53262 .49902 .54502 .5123 .56821 .50513 .55593 .49175 Mtetra
.55593 .49175 .56821 .50513 .5916 .49791 .57945 .48441 Mtetra
.57945 .48441 .5916 .49791 .61518 .49062 .60317 .47701 Mtetra
.60317 .47701 .61518 .49062 .63896 .48327 .62709 .46954 Mtetra
.62709 .46954 .63896 .48327 .66295 .47586 .65122 .46201 Mtetra
.65122 .46201 .66295 .47586 .68715 .46839 .67555 .45442 Mtetra
.67555 .45442 .68715 .46839 .71155 .46085 .7001 .44676 Mtetra
.7001 .44676 .71155 .46085 .73616 .45324 .72486 .43903 Mtetra
.72486 .43903 .73616 .45324 .76099 .44557 .74984 .43123 Mtetra
.74984 .43123 .76099 .44557 .78603 .43783 .77504 .42337 Mtetra
.77504 .42337 .78603 .43783 .8113 .43003 .80046 .41544 Mtetra
.80046 .41544 .8113 .43003 .83678 .42216 .82611 .40743 Mtetra
.82611 .40743 .83678 .42216 .86249 .41421 .85199 .39936 Mtetra
.85199 .39936 .86249 .41421 .88844 .4062 .87809 .39121 Mtetra
.87809 .39121 .88844 .4062 .91461 .39811 .90444 .38299 Mtetra
.90444 .38299 .91461 .39811 .94101 .38995 .93102 .3747 Mtetra
.33937 .54249 .35291 .5551 .37473 .54829 .3613 .53557 Mtetra
.3613 .53557 .37473 .54829 .39673 .54143 .38341 .5286 Mtetra
.38341 .5286 .39673 .54143 .41891 .53451 .4057 .52158 Mtetra
.4057 .52158 .41891 .53451 .44127 .52753 .42818 .51449 Mtetra
.42818 .51449 .44127 .52753 .46382 .52049 .45085 .50734 Mtetra
.45085 .50734 .46382 .52049 .48656 .51339 .47371 .50014 Mtetra
.47371 .50014 .48656 .51339 .50949 .50624 .49677 .49287 Mtetra
.49677 .49287 .50949 .50624 .53262 .49902 .52002 .48554 Mtetra
.52002 .48554 .53262 .49902 .55593 .49175 .54347 .47815 Mtetra
.54347 .47815 .55593 .49175 .57945 .48441 .56712 .47069 Mtetra
.56712 .47069 .57945 .48441 .60317 .47701 .59097 .46317 Mtetra
.59097 .46317 .60317 .47701 .62709 .46954 .61503 .45559 Mtetra
.61503 .45559 .62709 .46954 .65122 .46201 .6393 .44794 Mtetra
.6393 .44794 .65122 .46201 .67555 .45442 .66378 .44022 Mtetra
.66378 .44022 .67555 .45442 .7001 .44676 .68847 .43244 Mtetra
.68847 .43244 .7001 .44676 .72486 .43903 .71338 .42459 Mtetra
.71338 .42459 .72486 .43903 .74984 .43123 .73852 .41666 Mtetra
.73852 .41666 .74984 .43123 .77504 .42337 .76387 .40867 Mtetra
.76387 .40867 .77504 .42337 .80046 .41544 .78945 .40061 Mtetra
.78945 .40061 .80046 .41544 .82611 .40743 .81526 .39247 Mtetra
.81526 .39247 .82611 .40743 .85199 .39936 .8413 .38426 Mtetra
.8413 .38426 .85199 .39936 .87809 .39121 .86758 .37598 Mtetra
.86758 .37598 .87809 .39121 .90444 .38299 .8941 .36762 Mtetra
.8941 .36762 .90444 .38299 .93102 .3747 .92085 .35918 Mtetra
.32561 .52968 .33937 .54249 .3613 .53557 .34765 .52266 Mtetra
.34765 .52266 .3613 .53557 .38341 .5286 .36988 .51558 Mtetra
.36988 .51558 .38341 .5286 .4057 .52158 .39229 .50845 Mtetra
.39229 .50845 .4057 .52158 .42818 .51449 .41489 .50125 Mtetra
.41489 .50125 .42818 .51449 .45085 .50734 .43768 .49399 Mtetra
.43768 .49399 .45085 .50734 .47371 .50014 .46066 .48667 Mtetra
.46066 .48667 .47371 .50014 .49677 .49287 .48384 .47929 Mtetra
.957 .647 .4 r
.48384 .47929 .49677 .49287 .52002 .48554 .50609 .68302 Mtetra
.543 .307 .507 r
.50609 .68302 .52002 .48554 .54347 .47815 .53118 .676 Mtetra
.53118 .676 .54347 .47815 .56712 .47069 .55651 .66891 Mtetra
.55651 .66891 .56712 .47069 .59097 .46317 .58206 .66175 Mtetra
.58206 .66175 .59097 .46317 .61503 .45559 .60786 .65453 Mtetra
.60786 .65453 .61503 .45559 .6393 .44794 .63389 .64724 Mtetra
.63389 .64724 .6393 .44794 .66378 .44022 .66017 .63988 Mtetra
.66017 .63988 .66378 .44022 .68847 .43244 .6867 .63245 Mtetra
0 0 .356 r
.6867 .63245 .68847 .43244 .71338 .42459 .70172 .4099 Mtetra
.664 .741 .908 r
.70172 .4099 .71338 .42459 .73852 .41666 .727 .40185 Mtetra
.727 .40185 .73852 .41666 .76387 .40867 .75252 .39373 Mtetra
.75252 .39373 .76387 .40867 .78945 .40061 .77826 .38553 Mtetra
.77826 .38553 .78945 .40061 .81526 .39247 .80423 .37726 Mtetra
.80423 .37726 .81526 .39247 .8413 .38426 .83044 .36891 Mtetra
.83044 .36891 .8413 .38426 .86758 .37598 .85689 .36049 Mtetra
.85689 .36049 .86758 .37598 .8941 .36762 .88358 .35199 Mtetra
.88358 .35199 .8941 .36762 .92085 .35918 .91052 .34341 Mtetra
.31165 .51668 .32561 .52968 .34765 .52266 .3338 .50955 Mtetra
.3338 .50955 .34765 .52266 .36988 .51558 .35614 .50236 Mtetra
.35614 .50236 .36988 .51558 .39229 .50845 .37866 .49511 Mtetra
.37866 .49511 .39229 .50845 .41489 .50125 .40138 .4878 Mtetra
.40138 .4878 .41489 .50125 .43768 .49399 .4243 .48043 Mtetra
.4243 .48043 .43768 .49399 .46066 .48667 .4474 .47299 Mtetra
.4474 .47299 .46066 .48667 .48384 .47929 .47071 .46549 Mtetra
.957 .647 .4 r
.47071 .46549 .48384 .47929 .50609 .68302 .49224 .67 Mtetra
.646 .762 .934 r
.49224 .67 .50609 .68302 .53118 .676 .51748 .66286 Mtetra
.51748 .66286 .53118 .676 .55651 .66891 .54296 .65564 Mtetra
.54296 .65564 .55651 .66891 .58206 .66175 .56867 .64836 Mtetra
.56867 .64836 .58206 .66175 .60786 .65453 .59463 .64102 Mtetra
.59463 .64102 .60786 .65453 .63389 .64724 .62083 .6336 Mtetra
.62083 .6336 .63389 .64724 .66017 .63988 .64727 .62611 Mtetra
.64727 .62611 .66017 .63988 .6867 .63245 .67397 .61855 Mtetra
.97 .724 .508 r
.67397 .61855 .6867 .63245 .70172 .4099 .68986 .39498 Mtetra
.664 .741 .908 r
.68986 .39498 .70172 .4099 .727 .40185 .7153 .3868 Mtetra
.7153 .3868 .727 .40185 .75252 .39373 .74097 .37853 Mtetra
.74097 .37853 .75252 .39373 .77826 .38553 .76688 .3702 Mtetra
.76688 .3702 .77826 .38553 .80423 .37726 .79302 .36179 Mtetra
.79302 .36179 .80423 .37726 .83044 .36891 .8194 .3533 Mtetra
.8194 .3533 .83044 .36891 .85689 .36049 .84602 .34473 Mtetra
.84602 .34473 .85689 .36049 .88358 .35199 .87289 .33609 Mtetra
.87289 .33609 .88358 .35199 .91052 .34341 .90001 .32736 Mtetra
.29746 .50347 .31165 .51668 .3338 .50955 .31973 .49623 Mtetra
.31973 .49623 .3338 .50955 .35614 .50236 .34218 .48893 Mtetra
.34218 .48893 .35614 .50236 .37866 .49511 .36483 .48157 Mtetra
.36483 .48157 .37866 .49511 .40138 .4878 .38767 .47414 Mtetra
.38767 .47414 .40138 .4878 .4243 .48043 .4107 .46665 Mtetra
.4107 .46665 .4243 .48043 .4474 .47299 .43394 .4591 Mtetra
.43394 .4591 .4474 .47299 .47071 .46549 .45737 .45148 Mtetra
.957 .647 .4 r
.45737 .45148 .47071 .46549 .49224 .67 .47815 .65676 Mtetra
.646 .762 .934 r
.47815 .65676 .49224 .67 .51748 .66286 .50354 .64949 Mtetra
.50354 .64949 .51748 .66286 .54296 .65564 .52918 .64215 Mtetra
.52918 .64215 .54296 .65564 .56867 .64836 .55505 .63475 Mtetra
.55505 .63475 .56867 .64836 .59463 .64102 .58117 .62727 Mtetra
.58117 .62727 .59463 .64102 .62083 .6336 .60753 .61972 Mtetra
.60753 .61972 .62083 .6336 .64727 .62611 .63415 .6121 Mtetra
.63415 .6121 .64727 .62611 .67397 .61855 .66102 .60441 Mtetra
.97 .724 .508 r
.66102 .60441 .67397 .61855 .68986 .39498 .6778 .37981 Mtetra
.664 .741 .908 r
.6778 .37981 .68986 .39498 .7153 .3868 .7034 .37149 Mtetra
.7034 .37149 .7153 .3868 .74097 .37853 .72923 .36309 Mtetra
.72923 .36309 .74097 .37853 .76688 .3702 .7553 .35461 Mtetra
.7553 .35461 .76688 .3702 .79302 .36179 .78161 .34606 Mtetra
.78161 .34606 .79302 .36179 .8194 .3533 .80816 .33742 Mtetra
.80816 .33742 .8194 .3533 .84602 .34473 .83496 .32871 Mtetra
.83496 .32871 .84602 .34473 .87289 .33609 .86201 .31992 Mtetra
.86201 .31992 .87289 .33609 .90001 .32736 .88931 .31104 Mtetra
.28306 .49006 .29746 .50347 .31973 .49623 .30544 .4827 Mtetra
.30544 .4827 .31973 .49623 .34218 .48893 .32801 .47529 Mtetra
.32801 .47529 .34218 .48893 .36483 .48157 .35077 .46781 Mtetra
.35077 .46781 .36483 .48157 .38767 .47414 .37373 .46026 Mtetra
.37373 .46026 .38767 .47414 .4107 .46665 .39689 .45266 Mtetra
.39689 .45266 .4107 .46665 .43394 .4591 .42025 .44498 Mtetra
.42025 .44498 .43394 .4591 .45737 .45148 .44381 .43724 Mtetra
.957 .647 .4 r
.44381 .43724 .45737 .45148 .47815 .65676 .46382 .64329 Mtetra
.646 .762 .934 r
.46382 .64329 .47815 .65676 .50354 .64949 .48936 .63589 Mtetra
.48936 .63589 .50354 .64949 .52918 .64215 .51515 .62842 Mtetra
.956 .719 .539 r
.51515 .62842 .52918 .64215 .55505 .63475 .54017 .40558 Mtetra
.57 .378 .581 r
.54017 .40558 .55505 .63475 .58117 .62727 .56479 .39749 Mtetra
.56479 .39749 .58117 .62727 .60753 .61972 .58964 .38932 Mtetra
.58964 .38932 .60753 .61972 .63415 .6121 .61471 .38108 Mtetra
.61471 .38108 .63415 .6121 .66102 .60441 .64001 .37277 Mtetra
.64001 .37277 .66102 .60441 .6778 .37981 .66554 .36438 Mtetra
.664 .741 .908 r
.66554 .36438 .6778 .37981 .7034 .37149 .6913 .35592 Mtetra
.6913 .35592 .7034 .37149 .72923 .36309 .71729 .34738 Mtetra
.71729 .34738 .72923 .36309 .7553 .35461 .74353 .33876 Mtetra
.74353 .33876 .7553 .35461 .78161 .34606 .77001 .33006 Mtetra
.77001 .33006 .78161 .34606 .80816 .33742 .79674 .32127 Mtetra
.79674 .32127 .80816 .33742 .83496 .32871 .82371 .31241 Mtetra
.82371 .31241 .83496 .32871 .86201 .31992 .85094 .30346 Mtetra
.85094 .30346 .86201 .31992 .88931 .31104 .87843 .29443 Mtetra
.26843 .47643 .28306 .49006 .30544 .4827 .29092 .46896 Mtetra
.29092 .46896 .30544 .4827 .32801 .47529 .31361 .46143 Mtetra
.31361 .46143 .32801 .47529 .35077 .46781 .33649 .45383 Mtetra
.33649 .45383 .35077 .46781 .37373 .46026 .35957 .44616 Mtetra
.35957 .44616 .37373 .46026 .39689 .45266 .38286 .43843 Mtetra
.38286 .43843 .39689 .45266 .42025 .44498 .40634 .43063 Mtetra
.40634 .43063 .42025 .44498 .44381 .43724 .43004 .42276 Mtetra
.957 .647 .4 r
.43004 .42276 .44381 .43724 .46382 .64329 .44924 .62958 Mtetra
.646 .762 .934 r
.44924 .62958 .46382 .64329 .48936 .63589 .47494 .62205 Mtetra
.47494 .62205 .48936 .63589 .51515 .62842 .50088 .61446 Mtetra
.956 .719 .539 r
.50088 .61446 .51515 .62842 .54017 .40558 .52694 .39058 Mtetra
.664 .741 .908 r
.52694 .39058 .54017 .40558 .56479 .39749 .55171 .38236 Mtetra
.55171 .38236 .56479 .39749 .58964 .38932 .57671 .37406 Mtetra
.57671 .37406 .58964 .38932 .61471 .38108 .60193 .36568 Mtetra
.60193 .36568 .61471 .38108 .64001 .37277 .62738 .35723 Mtetra
.62738 .35723 .64001 .37277 .66554 .36438 .65307 .3487 Mtetra
.65307 .3487 .66554 .36438 .6913 .35592 .67899 .34009 Mtetra
.67899 .34009 .6913 .35592 .71729 .34738 .70515 .3314 Mtetra
.70515 .3314 .71729 .34738 .74353 .33876 .73156 .32263 Mtetra
.73156 .32263 .74353 .33876 .77001 .33006 .75821 .31378 Mtetra
.75821 .31378 .77001 .33006 .79674 .32127 .78511 .30485 Mtetra
.78511 .30485 .79674 .32127 .82371 .31241 .81227 .29583 Mtetra
.81227 .29583 .82371 .31241 .85094 .30346 .83968 .28672 Mtetra
.83968 .28672 .85094 .30346 .87843 .29443 .86736 .27753 Mtetra
.25356 .46259 .26843 .47643 .29092 .46896 .27617 .455 Mtetra
.27617 .455 .29092 .46896 .31361 .46143 .29897 .44735 Mtetra
.29897 .44735 .31361 .46143 .33649 .45383 .32198 .43963 Mtetra
.32198 .43963 .33649 .45383 .35957 .44616 .34518 .43184 Mtetra
.34518 .43184 .35957 .44616 .38286 .43843 .36859 .42398 Mtetra
.36859 .42398 .38286 .43843 .40634 .43063 .39221 .41605 Mtetra
.39221 .41605 .40634 .43063 .43004 .42276 .41604 .40805 Mtetra
.957 .647 .4 r
.41604 .40805 .43004 .42276 .44924 .62958 .4344 .61563 Mtetra
.646 .762 .934 r
.4344 .61563 .44924 .62958 .47494 .62205 .46026 .60797 Mtetra
.46026 .60797 .47494 .62205 .50088 .61446 .48636 .60024 Mtetra
.48636 .60024 .50088 .61446 .52694 .39058 .51272 .59243 Mtetra
.527 .282 .487 r
.51272 .59243 .52694 .39058 .55171 .38236 .53933 .58455 Mtetra
.53933 .58455 .55171 .38236 .57671 .37406 .56621 .57659 Mtetra
.56621 .57659 .57671 .37406 .60193 .36568 .59334 .56855 Mtetra
.59334 .56855 .60193 .36568 .62738 .35723 .62075 .56044 Mtetra
0 0 .299 r
.62075 .56044 .62738 .35723 .65307 .3487 .64039 .33274 Mtetra
.664 .741 .908 r
.64039 .33274 .65307 .3487 .67899 .34009 .66647 .32398 Mtetra
.66647 .32398 .67899 .34009 .70515 .3314 .6928 .31515 Mtetra
.6928 .31515 .70515 .3314 .73156 .32263 .71938 .30623 Mtetra
.71938 .30623 .73156 .32263 .75821 .31378 .74621 .29722 Mtetra
.74621 .29722 .75821 .31378 .78511 .30485 .77329 .28813 Mtetra
.77329 .28813 .78511 .30485 .81227 .29583 .80062 .27895 Mtetra
.80062 .27895 .81227 .29583 .83968 .28672 .82822 .26969 Mtetra
.82822 .26969 .83968 .28672 .86736 .27753 .85609 .26033 Mtetra
.23846 .44853 .25356 .46259 .27617 .455 .26118 .44082 Mtetra
.26118 .44082 .27617 .455 .29897 .44735 .28411 .43304 Mtetra
.28411 .43304 .29897 .44735 .32198 .43963 .30723 .42519 Mtetra
.30723 .42519 .32198 .43963 .34518 .43184 .33056 .41728 Mtetra
.33056 .41728 .34518 .43184 .36859 .42398 .3541 .40929 Mtetra
.3541 .40929 .36859 .42398 .39221 .41605 .37784 .40123 Mtetra
.37784 .40123 .39221 .41605 .41604 .40805 .4018 .3931 Mtetra
.957 .647 .4 r
.4018 .3931 .41604 .40805 .4344 .61563 .4193 .60143 Mtetra
.646 .762 .934 r
.4193 .60143 .4344 .61563 .46026 .60797 .44531 .59364 Mtetra
.44531 .59364 .46026 .60797 .48636 .60024 .47158 .58577 Mtetra
.47158 .58577 .48636 .60024 .51272 .59243 .4981 .57782 Mtetra
.4981 .57782 .51272 .59243 .53933 .58455 .52489 .5698 Mtetra
.52489 .5698 .53933 .58455 .56621 .57659 .55193 .56169 Mtetra
.55193 .56169 .56621 .57659 .59334 .56855 .57925 .55351 Mtetra
.57925 .55351 .59334 .56855 .62075 .56044 .60683 .54524 Mtetra
.97 .724 .508 r
.60683 .54524 .62075 .56044 .64039 .33274 .62749 .31651 Mtetra
.664 .741 .908 r
.62749 .31651 .64039 .33274 .66647 .32398 .65374 .3076 Mtetra
.65374 .3076 .66647 .32398 .6928 .31515 .68024 .29861 Mtetra
.68024 .29861 .6928 .31515 .71938 .30623 .70699 .28953 Mtetra
.70699 .28953 .71938 .30623 .74621 .29722 .73399 .28037 Mtetra
.73399 .28037 .74621 .29722 .77329 .28813 .76125 .27112 Mtetra
.76125 .27112 .77329 .28813 .80062 .27895 .78877 .26178 Mtetra
.78877 .26178 .80062 .27895 .82822 .26969 .81656 .25235 Mtetra
.81656 .25235 .82822 .26969 .85609 .26033 .84462 .24283 Mtetra
.22311 .43424 .23846 .44853 .26118 .44082 .24595 .4264 Mtetra
.24595 .4264 .26118 .44082 .28411 .43304 .269 .4185 Mtetra
.269 .4185 .28411 .43304 .30723 .42519 .29224 .41052 Mtetra
.29224 .41052 .30723 .42519 .33056 .41728 .3157 .40247 Mtetra
.3157 .40247 .33056 .41728 .3541 .40929 .33936 .39435 Mtetra
.33936 .39435 .3541 .40929 .37784 .40123 .36324 .38616 Mtetra
.36324 .38616 .37784 .40123 .4018 .3931 .38733 .3779 Mtetra
.957 .647 .4 r
.38733 .3779 .4018 .3931 .4193 .60143 .40393 .58698 Mtetra
.646 .762 .934 r
.40393 .58698 .4193 .60143 .44531 .59364 .4301 .57905 Mtetra
.4301 .57905 .44531 .59364 .47158 .58577 .45653 .57103 Mtetra
.45653 .57103 .47158 .58577 .4981 .57782 .48322 .56294 Mtetra
.48322 .56294 .4981 .57782 .52489 .5698 .51018 .55477 Mtetra
.51018 .55477 .52489 .5698 .55193 .56169 .5374 .54652 Mtetra
.5374 .54652 .55193 .56169 .57925 .55351 .56489 .53818 Mtetra
.56489 .53818 .57925 .55351 .60683 .54524 .59266 .52977 Mtetra
.97 .724 .508 r
.59266 .52977 .60683 .54524 .62749 .31651 .61436 .3 Mtetra
.664 .741 .908 r
.61436 .3 .62749 .31651 .65374 .3076 .64078 .29094 Mtetra
.64078 .29094 .65374 .3076 .68024 .29861 .66745 .28179 Mtetra
.66745 .28179 .68024 .29861 .70699 .28953 .69438 .27255 Mtetra
.69438 .27255 .70699 .28953 .73399 .28037 .72156 .26322 Mtetra
.72156 .26322 .73399 .28037 .76125 .27112 .749 .25381 Mtetra
.749 .25381 .76125 .27112 .78877 .26178 .77671 .2443 Mtetra
.77671 .2443 .78877 .26178 .81656 .25235 .80469 .2347 Mtetra
.80469 .2347 .81656 .25235 .84462 .24283 .83294 .225 Mtetra
.20751 .41972 .22311 .43424 .24595 .4264 .23047 .41175 Mtetra
.23047 .41175 .24595 .4264 .269 .4185 .25364 .40372 Mtetra
.25364 .40372 .269 .4185 .29224 .41052 .27701 .39561 Mtetra
.27701 .39561 .29224 .41052 .3157 .40247 .30059 .38743 Mtetra
.30059 .38743 .3157 .40247 .33936 .39435 .32438 .37917 Mtetra
.32438 .37917 .33936 .39435 .36324 .38616 .34839 .37084 Mtetra
.34839 .37084 .36324 .38616 .38733 .3779 .37262 .36244 Mtetra
.957 .647 .4 r
.37262 .36244 .38733 .3779 .40393 .58698 .38828 .57227 Mtetra
.646 .762 .934 r
.38828 .57227 .40393 .58698 .4301 .57905 .41462 .56419 Mtetra
.41462 .56419 .4301 .57905 .45653 .57103 .44121 .55603 Mtetra
.956 .719 .539 r
.44121 .55603 .45653 .57103 .48322 .56294 .47177 .32804 Mtetra
.558 .361 .57 r
.47177 .32804 .48322 .56294 .51018 .55477 .49714 .31924 Mtetra
.49714 .31924 .51018 .55477 .5374 .54652 .52274 .31035 Mtetra
.52274 .31035 .5374 .54652 .56489 .53818 .54859 .30139 Mtetra
.54859 .30139 .56489 .53818 .59266 .52977 .57467 .29234 Mtetra
.57467 .29234 .59266 .52977 .61436 .3 .60101 .2832 Mtetra
.664 .741 .908 r
.60101 .2832 .61436 .3 .64078 .29094 .6276 .27397 Mtetra
.6276 .27397 .64078 .29094 .66745 .28179 .65444 .26466 Mtetra
.65444 .26466 .66745 .28179 .69438 .27255 .68154 .25526 Mtetra
.68154 .25526 .69438 .27255 .72156 .26322 .7089 .24577 Mtetra
.7089 .24577 .72156 .26322 .749 .25381 .73653 .23618 Mtetra
.73653 .23618 .749 .25381 .77671 .2443 .76443 .2265 Mtetra
.76443 .2265 .77671 .2443 .80469 .2347 .7926 .21673 Mtetra
.7926 .21673 .80469 .2347 .83294 .225 .82105 .20686 Mtetra
.19166 .40496 .20751 .41972 .23047 .41175 .21474 .39686 Mtetra
.21474 .39686 .23047 .41175 .25364 .40372 .23802 .38869 Mtetra
.23802 .38869 .25364 .40372 .27701 .39561 .26152 .38045 Mtetra
.26152 .38045 .27701 .39561 .30059 .38743 .28523 .37213 Mtetra
.28523 .37213 .30059 .38743 .32438 .37917 .30915 .36374 Mtetra
.30915 .36374 .32438 .37917 .34839 .37084 .33329 .35527 Mtetra
.33329 .35527 .34839 .37084 .37262 .36244 .35765 .34672 Mtetra
.957 .647 .4 r
.35765 .34672 .37262 .36244 .38828 .57227 .37235 .55729 Mtetra
.646 .762 .934 r
.37235 .55729 .38828 .57227 .41462 .56419 .39885 .54907 Mtetra
.39885 .54907 .41462 .56419 .44121 .55603 .42561 .54076 Mtetra
.956 .719 .539 r
.42561 .54076 .44121 .55603 .47177 .32804 .45739 .31173 Mtetra
.664 .741 .908 r
.45739 .31173 .47177 .32804 .49714 .31924 .4829 .30277 Mtetra
.4829 .30277 .49714 .31924 .52274 .31035 .50866 .29373 Mtetra
.50866 .29373 .52274 .31035 .54859 .30139 .53467 .28461 Mtetra
.53467 .28461 .54859 .30139 .57467 .29234 .56092 .2754 Mtetra
.56092 .2754 .57467 .29234 .60101 .2832 .58742 .2661 Mtetra
.58742 .2661 .60101 .2832 .6276 .27397 .61418 .25671 Mtetra
.61418 .25671 .6276 .27397 .65444 .26466 .6412 .24723 Mtetra
.6412 .24723 .65444 .26466 .68154 .25526 .66847 .23766 Mtetra
.66847 .23766 .68154 .25526 .7089 .24577 .69602 .228 Mtetra
.69602 .228 .7089 .24577 .73653 .23618 .72384 .21824 Mtetra
.72384 .21824 .73653 .23618 .76443 .2265 .75192 .20838 Mtetra
.75192 .20838 .76443 .2265 .7926 .21673 .78029 .19843 Mtetra
.78029 .19843 .7926 .21673 .82105 .20686 .80894 .18838 Mtetra
.17555 .38995 .19166 .40496 .21474 .39686 .19874 .38172 Mtetra
.19874 .38172 .21474 .39686 .23802 .38869 .22215 .37341 Mtetra
.22215 .37341 .23802 .38869 .26152 .38045 .24577 .36503 Mtetra
.24577 .36503 .26152 .38045 .28523 .37213 .2696 .35657 Mtetra
.2696 .35657 .28523 .37213 .30915 .36374 .29366 .34804 Mtetra
.29366 .34804 .30915 .36374 .33329 .35527 .31793 .33942 Mtetra
.31793 .33942 .33329 .35527 .35765 .34672 .34243 .33073 Mtetra
.957 .647 .4 r
.34243 .33073 .35765 .34672 .37235 .55729 .35612 .54204 Mtetra
.646 .762 .934 r
.35612 .54204 .37235 .55729 .39885 .54907 .38278 .53366 Mtetra
.38278 .53366 .39885 .54907 .42561 .54076 .40971 .5252 Mtetra
.40971 .5252 .42561 .54076 .45739 .31173 .43691 .51665 Mtetra
.506 .252 .464 r
.43691 .51665 .45739 .31173 .4829 .30277 .46439 .50801 Mtetra
.46439 .50801 .4829 .30277 .50866 .29373 .49214 .49929 Mtetra
.49214 .49929 .50866 .29373 .53467 .28461 .52019 .49047 Mtetra
.52019 .49047 .53467 .28461 .56092 .2754 .54852 .48157 Mtetra
0 0 .23 r
.54852 .48157 .56092 .2754 .58742 .2661 .57359 .2487 Mtetra
.664 .741 .908 r
.57359 .2487 .58742 .2661 .61418 .25671 .60052 .23914 Mtetra
.60052 .23914 .61418 .25671 .6412 .24723 .62771 .22949 Mtetra
.62771 .22949 .6412 .24723 .66847 .23766 .65517 .21975 Mtetra
.65517 .21975 .66847 .23766 .69602 .228 .6829 .20991 Mtetra
.6829 .20991 .69602 .228 .72384 .21824 .71091 .19997 Mtetra
.71091 .19997 .72384 .21824 .75192 .20838 .73919 .18993 Mtetra
.73919 .18993 .75192 .20838 .78029 .19843 .76776 .17979 Mtetra
.76776 .17979 .78029 .19843 .80894 .18838 .79661 .16955 Mtetra
.15916 .3747 .17555 .38995 .19874 .38172 .18248 .36633 Mtetra
.18248 .36633 .19874 .38172 .22215 .37341 .20601 .35788 Mtetra
.20601 .35788 .22215 .37341 .24577 .36503 .22975 .34936 Mtetra
.22975 .34936 .24577 .36503 .2696 .35657 .25372 .34075 Mtetra
.25372 .34075 .2696 .35657 .29366 .34804 .2779 .33207 Mtetra
.2779 .33207 .29366 .34804 .31793 .33942 .30231 .32331 Mtetra
.30231 .32331 .31793 .33942 .34243 .33073 .32695 .31446 Mtetra
.957 .647 .4 r
.32695 .31446 .34243 .33073 .35612 .54204 .3396 .52651 Mtetra
.646 .762 .934 r
.3396 .52651 .35612 .54204 .38278 .53366 .36642 .51797 Mtetra
.36642 .51797 .38278 .53366 .40971 .5252 .39352 .50935 Mtetra
.39352 .50935 .40971 .5252 .43691 .51665 .42089 .50063 Mtetra
.42089 .50063 .43691 .51665 .46439 .50801 .44855 .49183 Mtetra
.44855 .49183 .46439 .50801 .49214 .49929 .47649 .48294 Mtetra
.47649 .48294 .49214 .49929 .52019 .49047 .50471 .47396 Mtetra
.50471 .47396 .52019 .49047 .54852 .48157 .53324 .46488 Mtetra
.97 .724 .508 r
.53324 .46488 .54852 .48157 .57359 .2487 .55951 .23098 Mtetra
.664 .741 .908 r
.55951 .23098 .57359 .2487 .60052 .23914 .58661 .22125 Mtetra
.58661 .22125 .60052 .23914 .62771 .22949 .61399 .21143 Mtetra
.61399 .21143 .62771 .22949 .65517 .21975 .64163 .2015 Mtetra
.64163 .2015 .65517 .21975 .6829 .20991 .66955 .19148 Mtetra
.66955 .19148 .6829 .20991 .71091 .19997 .69774 .18136 Mtetra
.69774 .18136 .71091 .19997 .73919 .18993 .72622 .17114 Mtetra
.72622 .17114 .73919 .18993 .76776 .17979 .75499 .16081 Mtetra
.75499 .16081 .76776 .17979 .79661 .16955 .78405 .15038 Mtetra
.1425 .35918 .15916 .3747 .18248 .36633 .16594 .35067 Mtetra
.16594 .35067 .18248 .36633 .20601 .35788 .18959 .34208 Mtetra
.18959 .34208 .20601 .35788 .22975 .34936 .21347 .33341 Mtetra
.21347 .33341 .22975 .34936 .25372 .34075 .23756 .32466 Mtetra
.23756 .32466 .25372 .34075 .2779 .33207 .26188 .31583 Mtetra
.26188 .31583 .2779 .33207 .30231 .32331 .28642 .30691 Mtetra
.28642 .30691 .30231 .32331 .32695 .31446 .3112 .29792 Mtetra
.957 .647 .4 r
.3112 .29792 .32695 .31446 .3396 .52651 .32276 .51068 Mtetra
.646 .762 .934 r
.32276 .51068 .3396 .52651 .36642 .51797 .34975 .50198 Mtetra
.34975 .50198 .36642 .51797 .39352 .50935 .37702 .49319 Mtetra
.37702 .49319 .39352 .50935 .42089 .50063 .40457 .48432 Mtetra
.40457 .48432 .42089 .50063 .44855 .49183 .4324 .47535 Mtetra
.4324 .47535 .44855 .49183 .47649 .48294 .46053 .46629 Mtetra
.46053 .46629 .47649 .48294 .50471 .47396 .48894 .45713 Mtetra
.48894 .45713 .50471 .47396 .53324 .46488 .51766 .44788 Mtetra
.97 .724 .508 r
.51766 .44788 .53324 .46488 .55951 .23098 .54517 .21294 Mtetra
.664 .741 .908 r
.54517 .21294 .55951 .23098 .58661 .22125 .57245 .20304 Mtetra
.57245 .20304 .58661 .22125 .61399 .21143 .60001 .19303 Mtetra
.60001 .19303 .61399 .21143 .64163 .2015 .62783 .18292 Mtetra
.62783 .18292 .64163 .2015 .66955 .19148 .65594 .17271 Mtetra
.65594 .17271 .66955 .19148 .69774 .18136 .68433 .1624 Mtetra
.68433 .1624 .69774 .18136 .72622 .17114 .71301 .15199 Mtetra
.71301 .15199 .72622 .17114 .75499 .16081 .74198 .14147 Mtetra
.74198 .14147 .75499 .16081 .78405 .15038 .77124 .13084 Mtetra
.12556 .34341 .1425 .35918 .16594 .35067 .14912 .33475 Mtetra
.14912 .33475 .16594 .35067 .18959 .34208 .1729 .32601 Mtetra
.1729 .32601 .18959 .34208 .21347 .33341 .1969 .31719 Mtetra
.1969 .31719 .21347 .33341 .23756 .32466 .22112 .30829 Mtetra
.22112 .30829 .23756 .32466 .26188 .31583 .24557 .29931 Mtetra
.24557 .29931 .26188 .31583 .28642 .30691 .27026 .29023 Mtetra
.27026 .29023 .28642 .30691 .3112 .29792 .29518 .28108 Mtetra
.29518 .28108 .3112 .29792 .32276 .51068 .32033 .27183 Mtetra
.544 .342 .557 r
.32033 .27183 .32276 .51068 .34975 .50198 .34573 .2625 Mtetra
.34573 .2625 .34975 .50198 .37702 .49319 .37137 .25308 Mtetra
.37137 .25308 .37702 .49319 .40457 .48432 .39726 .24356 Mtetra
.39726 .24356 .40457 .48432 .4324 .47535 .42341 .23396 Mtetra
.42341 .23396 .4324 .47535 .46053 .46629 .44981 .22426 Mtetra
.44981 .22426 .46053 .46629 .48894 .45713 .47646 .21446 Mtetra
.47646 .21446 .48894 .45713 .51766 .44788 .50338 .20457 Mtetra
.50338 .20457 .51766 .44788 .54517 .21294 .53057 .19457 Mtetra
.664 .741 .908 r
.53057 .19457 .54517 .21294 .57245 .20304 .55803 .18448 Mtetra
.55803 .18448 .57245 .20304 .60001 .19303 .58577 .17429 Mtetra
.58577 .17429 .60001 .19303 .62783 .18292 .61378 .164 Mtetra
.61378 .164 .62783 .18292 .65594 .17271 .64208 .1536 Mtetra
.64208 .1536 .65594 .17271 .68433 .1624 .67067 .14309 Mtetra
.67067 .14309 .68433 .1624 .71301 .15199 .69955 .13248 Mtetra
.69955 .13248 .71301 .15199 .74198 .14147 .72872 .12176 Mtetra
.72872 .12176 .74198 .14147 .77124 .13084 .7582 .11093 Mtetra
.10832 .32736 .12556 .34341 .14912 .33475 .13201 .31856 Mtetra
.13201 .31856 .14912 .33475 .1729 .32601 .15591 .30967 Mtetra
.15591 .30967 .1729 .32601 .1969 .31719 .18004 .30069 Mtetra
.18004 .30069 .1969 .31719 .22112 .30829 .2044 .29164 Mtetra
.2044 .29164 .22112 .30829 .24557 .29931 .22898 .28249 Mtetra
.22898 .28249 .24557 .29931 .27026 .29023 .25381 .27326 Mtetra
.25381 .27326 .27026 .29023 .29518 .28108 .27887 .26394 Mtetra
.27887 .26394 .29518 .28108 .32033 .27183 .30417 .25453 Mtetra
.30417 .25453 .32033 .27183 .34573 .2625 .32971 .24503 Mtetra
.32971 .24503 .34573 .2625 .37137 .25308 .35551 .23544 Mtetra
.35551 .23544 .37137 .25308 .39726 .24356 .38156 .22575 Mtetra
.38156 .22575 .39726 .24356 .42341 .23396 .40786 .21597 Mtetra
.40786 .21597 .42341 .23396 .44981 .22426 .43442 .20609 Mtetra
.43442 .20609 .44981 .22426 .47646 .21446 .46125 .19612 Mtetra
.46125 .19612 .47646 .21446 .50338 .20457 .48834 .18604 Mtetra
.48834 .18604 .50338 .20457 .53057 .19457 .5157 .17587 Mtetra
.5157 .17587 .53057 .19457 .55803 .18448 .54334 .16559 Mtetra
.54334 .16559 .55803 .18448 .58577 .17429 .57126 .15521 Mtetra
.57126 .15521 .58577 .17429 .61378 .164 .59947 .14472 Mtetra
.59947 .14472 .61378 .164 .64208 .1536 .62796 .13412 Mtetra
.62796 .13412 .64208 .1536 .67067 .14309 .65675 .12342 Mtetra
.65675 .12342 .67067 .14309 .69955 .13248 .68583 .1126 Mtetra
.68583 .1126 .69955 .13248 .72872 .12176 .71521 .10167 Mtetra
.71521 .10167 .72872 .12176 .7582 .11093 .7449 .09063 Mtetra
.09079 .31104 .10832 .32736 .13201 .31856 .1146 .30208 Mtetra
.1146 .30208 .13201 .31856 .15591 .30967 .13863 .29303 Mtetra
.13863 .29303 .15591 .30967 .18004 .30069 .16289 .2839 Mtetra
.16289 .2839 .18004 .30069 .2044 .29164 .18738 .27469 Mtetra
.18738 .27469 .2044 .29164 .22898 .28249 .2121 .26538 Mtetra
.2121 .26538 .22898 .28249 .25381 .27326 .23706 .25599 Mtetra
.23706 .25599 .25381 .27326 .27887 .26394 .26226 .2465 Mtetra
.26226 .2465 .27887 .26394 .30417 .25453 .28771 .23692 Mtetra
.28771 .23692 .30417 .25453 .32971 .24503 .31341 .22725 Mtetra
.31341 .22725 .32971 .24503 .35551 .23544 .33936 .21748 Mtetra
.33936 .21748 .35551 .23544 .38156 .22575 .36556 .20762 Mtetra
.36556 .20762 .38156 .22575 .40786 .21597 .39203 .19766 Mtetra
.39203 .19766 .40786 .21597 .43442 .20609 .41875 .1876 Mtetra
.41875 .1876 .43442 .20609 .46125 .19612 .44575 .17744 Mtetra
.44575 .17744 .46125 .19612 .48834 .18604 .47302 .16718 Mtetra
.47302 .16718 .48834 .18604 .5157 .17587 .50056 .15681 Mtetra
.50056 .15681 .5157 .17587 .54334 .16559 .52838 .14634 Mtetra
.52838 .14634 .54334 .16559 .57126 .15521 .55649 .13576 Mtetra
.55649 .13576 .57126 .15521 .59947 .14472 .58488 .12507 Mtetra
.58488 .12507 .59947 .14472 .62796 .13412 .61357 .11427 Mtetra
.61357 .11427 .62796 .13412 .65675 .12342 .64256 .10336 Mtetra
.64256 .10336 .65675 .12342 .68583 .1126 .67184 .09234 Mtetra
.67184 .09234 .68583 .1126 .71521 .10167 .70144 .0812 Mtetra
.70144 .0812 .71521 .10167 .7449 .09063 .73135 .06994 Mtetra
.07296 .29443 .09079 .31104 .1146 .30208 .09689 .28531 Mtetra
.09689 .28531 .1146 .30208 .13863 .29303 .12104 .27611 Mtetra
.12104 .27611 .13863 .29303 .16289 .2839 .14543 .26682 Mtetra
.14543 .26682 .16289 .2839 .18738 .27469 .17005 .25744 Mtetra
.17005 .25744 .18738 .27469 .2121 .26538 .19491 .24797 Mtetra
.19491 .24797 .2121 .26538 .23706 .25599 .22002 .2384 Mtetra
.22002 .2384 .23706 .25599 .26226 .2465 .24536 .22874 Mtetra
.24536 .22874 .26226 .2465 .28771 .23692 .27096 .21899 Mtetra
.27096 .21899 .28771 .23692 .31341 .22725 .29681 .20914 Mtetra
.29681 .20914 .31341 .22725 .33936 .21748 .32291 .1992 Mtetra
.32291 .1992 .33936 .21748 .36556 .20762 .34927 .18915 Mtetra
.34927 .18915 .36556 .20762 .39203 .19766 .3759 .17901 Mtetra
.3759 .17901 .39203 .19766 .41875 .1876 .40279 .16876 Mtetra
.40279 .16876 .41875 .1876 .44575 .17744 .42996 .15841 Mtetra
.42996 .15841 .44575 .17744 .47302 .16718 .4574 .14796 Mtetra
.4574 .14796 .47302 .16718 .50056 .15681 .48513 .13739 Mtetra
.48513 .13739 .50056 .15681 .52838 .14634 .51313 .12672 Mtetra
.51313 .12672 .52838 .14634 .55649 .13576 .54143 .11594 Mtetra
.54143 .11594 .55649 .13576 .58488 .12507 .57002 .10505 Mtetra
.57002 .10505 .58488 .12507 .61357 .11427 .5989 .09404 Mtetra
.5989 .09404 .61357 .11427 .64256 .10336 .62809 .08292 Mtetra
.62809 .08292 .64256 .10336 .67184 .09234 .65759 .07168 Mtetra
.65759 .07168 .67184 .09234 .70144 .0812 .6874 .06033 Mtetra
.6874 .06033 .70144 .0812 .73135 .06994 .71752 .04885 Mtetra
.05481 .27753 .07296 .29443 .09689 .28531 .07886 .26825 Mtetra
.07886 .26825 .09689 .28531 .12104 .27611 .10315 .25889 Mtetra
.10315 .25889 .12104 .27611 .14543 .26682 .12766 .24943 Mtetra
.12766 .24943 .14543 .26682 .17005 .25744 .15242 .23988 Mtetra
.15242 .23988 .17005 .25744 .19491 .24797 .17742 .23024 Mtetra
.17742 .23024 .19491 .24797 .22002 .2384 .20266 .2205 Mtetra
.20266 .2205 .22002 .2384 .24536 .22874 .22815 .21067 Mtetra
.22815 .21067 .24536 .22874 .27096 .21899 .2539 .20073 Mtetra
.2539 .20073 .27096 .21899 .29681 .20914 .2799 .19071 Mtetra
.2799 .19071 .29681 .20914 .32291 .1992 .30616 .18058 Mtetra
.30616 .18058 .32291 .1992 .34927 .18915 .33268 .17034 Mtetra
.33268 .17034 .34927 .18915 .3759 .17901 .35947 .16001 Mtetra
.35947 .16001 .3759 .17901 .40279 .16876 .38654 .14957 Mtetra
.38654 .14957 .40279 .16876 .42996 .15841 .41388 .13902 Mtetra
.41388 .13902 .42996 .15841 .4574 .14796 .4415 .12837 Mtetra
.4415 .12837 .4574 .14796 .48513 .13739 .4694 .11761 Mtetra
.4694 .11761 .48513 .13739 .51313 .12672 .49759 .10673 Mtetra
.49759 .10673 .51313 .12672 .54143 .11594 .52608 .09574 Mtetra
.52608 .09574 .54143 .11594 .57002 .10505 .55486 .08464 Mtetra
.55486 .08464 .57002 .10505 .5989 .09404 .58395 .07342 Mtetra
.58395 .07342 .5989 .09404 .62809 .08292 .61335 .06208 Mtetra
.61335 .06208 .62809 .08292 .65759 .07168 .64305 .05062 Mtetra
.64305 .05062 .65759 .07168 .6874 .06033 .67308 .03904 Mtetra
.67308 .03904 .6874 .06033 .71752 .04885 .70343 .02733 Mtetra
.03634 .26033 .05481 .27753 .07886 .26825 .06052 .25089 Mtetra
.06052 .25089 .07886 .26825 .10315 .25889 .08493 .24135 Mtetra
.08493 .24135 .10315 .25889 .12766 .24943 .10958 .23173 Mtetra
.10958 .23173 .12766 .24943 .15242 .23988 .13447 .222 Mtetra
.13447 .222 .15242 .23988 .17742 .23024 .15961 .21218 Mtetra
.15961 .21218 .17742 .23024 .20266 .2205 .18499 .20227 Mtetra
.18499 .20227 .20266 .2205 .22815 .21067 .21063 .19226 Mtetra
.21063 .19226 .22815 .21067 .2539 .20073 .23652 .18214 Mtetra
.23652 .18214 .2539 .20073 .2799 .19071 .26268 .17193 Mtetra
.26268 .17193 .2799 .19071 .30616 .18058 .2891 .16161 Mtetra
.2891 .16161 .30616 .18058 .33268 .17034 .31578 .15118 Mtetra
.31578 .15118 .33268 .17034 .35947 .16001 .34274 .14065 Mtetra
.34274 .14065 .35947 .16001 .38654 .14957 .36997 .13002 Mtetra
.36997 .13002 .38654 .14957 .41388 .13902 .39749 .11927 Mtetra
.39749 .11927 .41388 .13902 .4415 .12837 .42528 .10841 Mtetra
.42528 .10841 .4415 .12837 .4694 .11761 .45337 .09744 Mtetra
.45337 .09744 .4694 .11761 .49759 .10673 .48175 .08636 Mtetra
.48175 .08636 .49759 .10673 .52608 .09574 .51043 .07515 Mtetra
.51043 .07515 .52608 .09574 .55486 .08464 .53942 .06383 Mtetra
.53942 .06383 .55486 .08464 .58395 .07342 .56871 .05239 Mtetra
.56871 .05239 .58395 .07342 .61335 .06208 .59831 .04083 Mtetra
.59831 .04083 .61335 .06208 .64305 .05062 .62823 .02914 Mtetra
.62823 .02914 .64305 .05062 .67308 .03904 .65848 .01733 Mtetra
.65848 .01733 .67308 .03904 .70343 .02733 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00^P3oool400000080oooo0P00
001N0?ooo`00^P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
F`3oool00;/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1K0?ooo`00_03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo05/0oooo002m0?ooo`030000003oool00000
00800000GP3oool00;X0oooo00H000000?ooo`3oool000000?ooo`00001P0?ooo`00^`3oool20000
0080oooo1000001M0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00a@3oool2000005T0oooo00320?ooo`<0000000<0oooo0000003oool0F03oool00<00oooo
0P0000030?ooo`030:Vmj0000000000005P0oooo002m0?ooo`<000000P3oool40:Vmj0030000003o
ool0000005L0oooo002C0?ooo`@000000P3oool2000001l0oooo0`0000000`3oool000000:Vmj006
0:Vmj0030000003oool0000005L0oooo002C0?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`0J0?ooo`8000000`3oool90:Vmj0040000002Y_NP0oooo000005H0oooo
002D0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooo`<00000
0P3oool<0:Vmj0030000002Y_NP0000000800000E@3oool009D0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool00`000000ZKgX0:Vmj00<0:Vmj0050000
002Y_NP0ZKgX0?ooo`000000E@3oool009H0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0B0?ooo`<000000P3ooolA0:Vmj0030000002Y_NP0ZKgX0080oooo00<000000?ooo`3oool0
DP3oool009<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0100
oooo0P0000020?oooa@0ZKgX00H000000:Vmj02Y_NP0ZKgX0?ooo`00001D0?ooo`00U03oool20000
00<0oooo0P00000@0?ooo`<0000000<0oooo0000002Y_NP05@2Y_NP00`000000ZKgX0:Vmj0020:Vm
j0030?ooo`000000oooo0580oooo002X0?ooo`<000000P3ooolJ0:Vmj0030000002Y_NP0ZKgX0080
ZKgX0P00001B0?ooo`00YP3oool200000080oooo7@2Y_NP00`000000ZKgX0:Vmj0030:Vmj0030000
003oool0oooo0500oooo002S0?ooo`<0000000<0oooo0000002Y_NP07P2Y_NP00`000000ZKgX0:Vm
j0030:Vmj0030?ooo`000000oooo0500oooo002Q0?ooo`8000000`3ooolQ0:Vmj0030000002Y_NP0
ZKgX00@0ZKgX00<0oooo0000003oool0C`3oool009h0oooo0`0000020?ooob@0ZKgX00<000000:Vm
j02Y_NP0102Y_NP00`3oool000000?ooo`1?0?ooo`00W03oool200000080oooo00<000000:Vmj02Y
_NP0902Y_NP00`000000ZKgX0:Vmj0050:Vmj0030?ooo`000000oooo00P0oooo0P0000140?ooo`00
V@3oool300000080oooo:@2Y_NP00`000000ZKgX0:Vmj0050:Vmj0030000003oool0000000L0oooo
00@000000?ooo`3oool00000@`3oool009H0oooo0`0000020?ooob`0ZKgX00<000000:Vmj02Y_NP0
1P2Y_NP00`3oool000000?ooo`090?ooo`030000003oool0oooo0440oooo001_0?ooo`<000000P3o
ool2000001h0oooo0P0000030?ooo`030000002Y_NP0ZKgX02/0ZKgX00<000000:Vmj02Y_NP01P2Y
_NP20?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@@3oool00700oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0H0?ooo`<000000`3oool`0:Vmj0030000002Y
_NP0ZKgX00L0ZKgX0P3oool00`000000oooo0?ooo`030?ooo`<00000A03oool00700oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`<000000P3ooolc0:Vmj0030000002Y_NP0
ZKgX00P0ZKgX00<0oooo0000003oool0103oool00`000000oooo0?ooo`140?ooo`00L03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo0`0000030?ooocD0ZKgX00<000000:Vm
j02Y_NP02@2Y_NP2000000@0oooo100000130?ooo`00L03oool00`000000oooo0?ooo`03000001@0
oooo0P0000040?ooocL0ZKgX00<000000:Vmj02Y_NP02P2Y_NP00`3oool000000?ooo`190?ooo`00
K`3oool200000080oooo00<000000?ooo`3oool04@3oool400000080oooo>P2Y_NP00`000000ZKgX
0:Vmj00:0:Vmj0030?ooo`000000oooo04T0oooo001`0?ooo`030000003oool0oooo00@000003@3o
ool3000000<0oooo?@2Y_NP00`000000ZKgX0:Vmj00;0:Vmj0030?ooo`000000oooo04P0oooo0022
0?ooo`800000103ooolo0:Vmj0030000002Y_NP0ZKgX00`0ZKgX00<000000?ooo`3oool0A`3oool0
07l0oooo0`0000000`3oool000000?ooo`120:Vmj0030000002Y_NP0ZKgX00`0ZKgX0P0000180?oo
o`00O@3oool2000000@0ooooA02Y_NP00`000000ZKgX0:Vmj00=0:Vmj0030?ooo`000000oooo04H0
oooo001j0?ooo`<000000`3ooom70:Vmj0030000002Y_NP0ZKgX00d0ZKgX00<0oooo0000003oool0
AP3oool007P0oooo0P0000020?ooo`030000002Y_NP0ZKgX04P0ZKgX00<000000:Vmj02Y_NP03P2Y
_NP00`3oool000000?ooo`150?ooo`00M@3oool300000080ooooC@2Y_NP00`000000ZKgX0:Vmj00?
0:Vmj0030?ooo`000000oooo04@0oooo001<0?ooo`<000000P3oool2000001l0oooo0`0000020?oo
oe40ZKgX00<000000:Vmj02Y_NP03`2Y_NP2000004@0oooo001=0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool06P3oool2000000<0oooo00<000000:Vmj02Y_NP0D02Y_NP00`00
0000ZKgX0:Vmj00@0:Vmj0030000003oool0oooo0480oooo001=0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool05`3oool3000000<0ooooE@2Y_NP00`000000ZKgX0:Vmj00@0:Vm
j0030?ooo`000000oooo0480oooo001=0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool05@3oool4000000030?ooo`2Y_NP0ZKgX05H0ZKgX00<000000:Vmj02Y_NP04@2Y_NP00`00
0000oooo0?ooo`110?ooo`00C@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0180oooo0`0000030?oooeX0ZKgX00<000000:Vmj02Y_NP04P2Y_NP00`000000oooo0?ooo`100?oo
o`00C03oool200000080oooo00@000000?ooo`3oool000004P3oool2000000@0ooooG02Y_NP00`00
0000ZKgX0:Vmj00B0:Vmj0800000@@3oool004d0oooo00@000000?ooo`3oool0oooo0P00000@0?oo
o`<0000000<0oooo0000003oool0G`2Y_NP00`000000ZKgX0:Vmj00C0:Vmj0030000003oool0oooo
03l0oooo001Q0?ooo`800000103ooomQ0:Vmj0030000002Y_NP0ZKgX01<0ZKgX00<0oooo0000003o
ool0?`3oool005h0oooo0`0000030?ooof@0ZKgX00<000000:Vmj02Y_NP0502Y_NP00`000000oooo
0?ooo`0n0?ooo`00F`3oool300000080oooo00<000000:Vmj02Y_NP0I@2Y_NP00`000000ZKgX0:Vm
j00E0:Vmj0030000003oool0oooo03d0oooo001I0?ooo`8000000`3ooomZ0:Vmj0030000002Y_NP0
ZKgX01D0ZKgX0P0000080?ooo`<000000P3oool2000002l0oooo001F0?ooo`@000000P3ooom/0:Vm
j0030000002Y_NP0ZKgX01H0ZKgX00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo02`0oooo001D0?ooo`800000103oool00`000000ZKgX0:Vmj01[0:Vm
j0030000002Y_NP0ZKgX01H0ZKgX00<0oooo0000003oool01`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo02`0oooo000`0?ooo`8000007`3oool3000000@0ooooL02Y_NP00`00
0000ZKgX0:Vmj00G0:Vmj0030?ooo`000000oooo00H0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0/0?ooo`00;`3oool010000000oooo0?ooo`00000L0?ooo`8000000P3oool0
0`000000oooo0:Vmj01b0:Vmj0030000002Y_NP0ZKgX01P0ZKgX00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02`0oooo000b0?ooo`030000003oool0
oooo01L0oooo0`0000040?ooogD0ZKgX00<000000:Vmj02Y_NP0602Y_NP2000000D0oooo0P000002
0?ooo`040000003oool0oooo000002h0oooo000b0?ooo`030000003oool0oooo01@0oooo10000003
0?ooogP0ZKgX00<000000:Vmj02Y_NP06@2Y_NP00`3oool000000?ooo`040?ooo`040000003oool0
oooo0?ooo`800000;`3oool002l0oooo0`00000E0?ooo`800000103ooomk0:Vmj0030000002Y_NP0
ZKgX01T0ZKgX00<0oooo0000003oool0>@3oool002l0oooo00<000000?ooo`3oool04P3oool30000
00<0ooooOP2Y_NP00`000000ZKgX0:Vmj00J0:Vmj0030?ooo`000000oooo03P0oooo000_0?ooo`@0
00003`3oool200000080oooo00<000000?ooo`2Y_NP0DP2Y_NP308]GSRX0ZKgX00<000000:Vmj02Y
_NP06`2Y_NP00`3oool000000?ooo`0g0?ooo`00?`3oool3000000@0ooooDP2Y_NP708]GSRT0ZKgX
00<000000:Vmj02Y_NP06`2Y_NP2000003P0oooo000m0?ooo`800000103ooomB0:Vmj0/0ReN>:@2Y
_NP00`000000ZKgX0:Vmj00K0:Vmj0030?ooo`000000oooo03H0oooo000j0?ooo`<000000P3oool0
0`000000ZKgX0:Vmj01@0:Vmj0l0ReN>:02Y_NP00`000000ZKgX0:Vmj00K0:Vmj080oooo00<00000
0?ooo`3oool0=03oool003L0oooo0`0000030?oooe<0ZKgX4@2;EhhX0:Vmj0030000002Y_NP0ZKgX
01`0ZKgX00<0oooo0000003oool0=@3oool003D0oooo0P000000103oool000000?ooo`3ooomC0:Vm
j1<0ReN>00<0n;V20:Vmj02Y_NP09@2Y_NP00`000000ZKgX0:Vmj00M0:Vmj0800000=@3oool00380
oooo0`0000040?ooo`030000002Y_NP0ZKgX04l0ZKgX5P2;Ehh20?RiPRH0ZKgX00<000000:Vmj02Y
_NP07P2Y_NP00`000000oooo0?ooo`0c0?ooo`00<03oool3000000@0ooooD@2Y_NPI08]GSP<0n;V2
9@2Y_NP00`000000ZKgX0:Vmj00N0:Vmj0030?ooo`000000oooo03<0oooo000]0?ooo`<000000P3o
ool00`000000oooo0:Vmj01@0:Vmj1`0ReN>103h^H8T0:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<0
oooo0000003oool0<P3oool002/0oooo0P0000040?oooe80ZKgX7@2;Ehh50?RiPR@0ZKgX00<00000
0:Vmj02Y_NP0802Y_NP00`000000oooo0?ooo`0a0?ooo`00:03oool3000000030?ooo`000000oooo
0580ZKgX802;Ehh60?RiPR<0ZKgX00<000000:Vmj02Y_NP0802Y_NP200000380oooo000U0?ooo`<0
0000103ooomA0:Vmj2<0ReN>1`3h^H8R0:Vmj0030000002Y_NP0ZKgX0240ZKgX00<0oooo0000003o
ool0<03oool002<0oooo100000030?oooe00ZKgX9P2;Ehh70?RiPR40ZKgX0P00000S0:Vmj0030?oo
o`000000oooo0300oooo000P0?ooo`<00000103ooom@0:Vmj2T0ReN>203h^H8M0:Vmj0<0000000<0
ZKgX0000002Y_NP08`2Y_NP00`3oool000000?ooo`0_0?ooo`007`3oool2000000<0ooooD@2Y_NP[
08]GSPP0n;V200<0000j0:Vmj02Y_NP05`2Y_NP3000000D0ZKgX00<000000:Vmj02Y_NP08P2Y_NP2
000000P0oooo0`0000020?ooo`800000803oool001l0oooo0P00001B0:Vmj2d0ReN>203h^H820000
>QD0ZKgX0`0000090:Vmj0030000002Y_NP0ZKgX0280ZKgX00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo01d0oooo000O0?ooo`030000002Y_NP0ZKgX
04h0ZKgX<02;Ehh80?RiPP<0000j4@2Y_NP3000000d0ZKgX00<000000:Vmj02Y_NP08@2Y_NP00`3o
ool000000?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool001H0
oooo0P0000070?ooo`030000003oool0ZKgX04X0ZKgX=02;Ehh80?RiPP@0000j3@2Y_NP300000100
ZKgX00<000000:Vmj02Y_NP08P2Y_NP00`3oool000000?ooo`060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07@3oool001D0oooo00@000000?ooo`3oool000001@3oool200000080
ooooA`2Y_NPf08]GSPT0n;V20P0003X<0:Vmj0<00000502Y_NP00`000000ZKgX0:Vmj00R0:Vmj003
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`00000P0?ooo`005@3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0080ooooA02Y_NPh08]GSPT0n;V22`2Y_NP3000001P0
ZKgX00<000000:Vmj02Y_NP08@2Y_NP2000000D0oooo0P0000020?ooo`030000003oool0oooo0200
oooo000E0?ooo`040000003oool0oooo000000D0oooo0P0000040?oood<0ZKgX>02;Ehh80?RiPPT0
ZKgX0`00000K0:Vmj0030000002Y_NP0ZKgX0280ZKgX00<0oooo0000003oool0103oool00`000000
oooo0?ooo`04000001l0oooo000E0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0103ooom20:Vmj3P0ReN>203h^H870:Vmj08000007`2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj003
0?ooo`000000oooo02X0oooo000E0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool01@3ooom10:Vmj3P0ReN>203h^H840:Vmj0<0000000<0SUbA0:Vmj02Y_NP07`2Y_NP00`000000
ZKgX0:Vmj00Q0:Vmj0030?ooo`000000oooo02T0oooo000F0?ooo`8000001P3oool00`000000oooo
0?ooo`060?oood00ZKgX>02;Ehh80?RiPP040:Vmj00000000000000000D0SUbA8@2Y_NP00`000000
ZKgX0:Vmj00Q0:Vmj0800000:@3oool001h0oooo00<000000?ooo`3oool01`3ooolo0:Vmj3P0ReN>
1P3h^H83000000030:Vmj02>G940SUbA00H0SUbA802Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000
003oool0oooo02L0oooo000M0?ooo`030000003oool0oooo00X0oooo?@2Y_NPh08]GSP<0n;V20`00
00020?RiPP/0SUbA802Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0030?ooo`000000oooo02L0oooo000M
0?ooo`800000303oooll0:Vmj3L0ReN>00@0n;V200000000000000001@3h^H8<08iLTB00ZKgX00<0
00000:Vmj02Y_NP08@2Y_NP00`000000oooo0?ooo`0V0?ooo`007@3oool00`000000oooo0?ooo`0<
0?oooc/0ZKgX=@2;Ehh3000000P0n;V2302>G94Q0:Vmj0030000002Y_NP0ZKgX0240ZKgX0P00000V
0?ooo`007@3oool2000000h0oooo>P2Y_NPb08]GSP<000000P2;Ehh90?RiPP`0SUbA00<0n;V20:Vm
j02Y_NP07P2Y_NP00`000000ZKgX0:Vmj00R0:Vmj0030000003oool0oooo02@0oooo000M0?ooo`03
0000003oool0oooo00d0oooo>P2Y_NP_08]GSP<000001@2;Ehh90?RiPP`0SUbA0P3h^H8P0:Vmj003
0000002Y_NP0ZKgX0240ZKgX00<000000?ooo`3oool0903oool001d0oooo00<000000?ooo`3oool0
3P3oooli0:Vmj2d0ReN>0P00000808]GSPP0n;V23@2>G9430?RiPR00ZKgX00<000000:Vmj02Y_NP0
8@2Y_NP00`000000oooo0?ooo`0S0?ooo`001`3oool2000000<0oooo00<000000?ooo`0000000`00
00020?ooo`8000001`3oool00`000000oooo0?ooo`0?0?ooocP0ZKgX:P2;Ehh3000000X0ReN>203h
^H8=08iLT@<0n;V28@2Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo0280oooo0006
0?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool04@3ooolg0:Vmj2L0ReN>0`00000=08]GSPP0
n;V23@2>G9440?RiPR00ZKgX00<000000:Vmj02Y_NP08@2Y_NP00`000000oooo0?ooo`0R0?ooo`00
1P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0B0?ooocH0ZKgX902;Ehh300000100ReN>203h^H8<08iLT@H0
n;V2802Y_NP00`000000ZKgX0:Vmj00Q0:Vmj0030000003oool0oooo0240oooo00060?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`80
00005@3ooold0:Vmj240ReN>0`00000C08]GSPP0n;V2302>G9470?RiPR00ZKgX00<000000:Vmj02Y
_NP0802Y_NP00`3oool000000?ooo`0Q0?ooo`001P3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool00000008000001P3oool00`000000oooo0?ooo`0E0?oooc<0ZKgX7P2;Ehh3000001D0
ReN>2@3h^H8<08iLT@L0n;V2802Y_NP00`000000ZKgX0:Vmj00Q0:Vmj08000001`3oool400000080
oooo0P00000B0?ooo`001P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000
003oool00000203oool00`000000oooo0?ooo`0F0?oooc80ZKgX6`2;Ehh3000001P0ReN>2@3h^H8<
08iLT@L0n;V200<0001<0:Vmj02Y_NP07P2Y_NP00`000000ZKgX0:Vmj00P0:Vmj08000001`3oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool03`3oool000L0oooo0P00
00060?ooo`8000000P3oool4000000@0oooo0P00000I0?oooc40ZKgX602;Ehh3000001/0ReN>2@3h
^H8<08iLT@L0n;V20P0004`P0:Vmj0030000002Y_NP0ZKgX0200ZKgX00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03`3oool001/0oooo00<0
00000?ooo`3oool06@3oool`0:Vmj1D0ReN>0`00000N08]GSPT0n;V2302>G9470?RiPP<0001<802Y
_NP00`000000ZKgX0:Vmj00O0:Vmj0030?ooo`000000oooo00L0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooobl0ZKgX4`2;
Ehh200000240ReN>2@3h^H8<08iLT@L0n;V20P0004`Q0:Vmj0030000002Y_NP0ZKgX0200ZKgX00<0
oooo0000000000001`3oool00`000000oooo000000020?ooo`030000003oool0oooo00l0oooo000K
0?ooo`800000703oool^0:Vmj100ReN>0`00000S08]GSPP0n;V23@2>G9470?RiPR@0ZKgX00<00000
0:Vmj02Y_NP0802Y_NP00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooobd0ZKgX3@2;
Ehh3000002H0ReN>203h^H8=08iLT@L0n;V29@2Y_NP00`000000ZKgX0:Vmj00P0:Vmj0030000003o
ool0oooo00<0oooo0P0000030?ooo`8000004P3oool001/0oooo0P00000N0?ooob`0ZKgX2P2;Ehh3
000002T0ReN>203h^H8<08iLT@L0n;V29`2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030?ooo`000000
oooo01`0oooo000J0?ooo`800000803oool[0:Vmj0L0ReN>0`00000/08]GSPP0n;V2302>G9470?Ri
PPH0ZKgX0P2AH9@O0:Vmj0030000002Y_NP0ZKgX0200ZKgX0P00000L0?ooo`002P3oool2000000<0
oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0oooo01l0oooo:P2Y_NP408]GSP<0
0000;P2;Ehh90?RiPP`0SUbA1`3h^H830:Vmj0H0TF2D7`2Y_NP00`000000ZKgX0:Vmj00O0:Vmj080
0000703oool000T0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0240oooo:@2Y_NP0102;Ehh0000000000000000a08]GSPT0n;V2302>G947
0?RiPPX0TF2D7`2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030?ooo`000000oooo01X0oooo00090?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`3oool00`3oool2000002<0oooo9P2Y_NP3
000003@0ReN>2@3h^H8<08iLT@L0n;V22`2AH9@N0:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<0oooo
0000003oool06P3oool000T0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02<0oooo8`2Y_NP200000080ZKgX=@2;Ehh90?RiPP`0SUbA1`3h^H8;
095PU1l0ZKgX00<000000:Vmj02Y_NP07`2Y_NP00`3oool000000000000I0?ooo`002@3oool01000
0000oooo0?ooo`0000040?ooo`<000001P3oool00`000000oooo0?ooo`0T0?oooal0ZKgX0`000004
0:Vmj3D0ReN>2@3h^H8<08iLT@L0n;V22`2AH9@00`3h^H80ZKgX0:Vmj00M0:Vmj0030000002Y_NP0
ZKgX01l0ZKgX0P00000I0?ooo`002@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool09@3ooolK0:Vmj0<00000202Y_NPd08]GSPP0n;V23@2>G947
0?RiPP/0TF2D0P3h^H8O0:Vmj0030000002Y_NP0ZKgX01l0ZKgX00<000000?ooo`3oool05`3oool0
00X0oooo0P0000050?ooo`@000001@3oool00`000000oooo0?ooo`0W0?oooaH0ZKgX0`00000;0:Vm
j3@0ReN>203h^H8=08iLT@L0n;V22`2AH9@30?RiPQh0ZKgX00<000000:Vmj02Y_NP0802Y_NP00`00
0000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`0Y0?oooa40ZKgX0`00000>0:Vmj3@0
ReN>203h^H8=08iLT@L0n;V22`2AH9@30?RiPQl0ZKgX00<000000:Vmj02Y_NP0802Y_NP00`000000
oooo0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`0[0?ooo`d0ZKgX0`00000A0:Vmj3<0ReN>
2@3h^H8<08iLT@P0n;V22`2AH9@40?RiPQl0ZKgX00<000000:Vmj02Y_NP07`2Y_NP00`000000oooo
0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`0/0?ooo`T0ZKgX0`00000D0:Vmj3<0ReN>2@3h
^H8<08iLT@L0n;V2302AH9@50?RiPQl0ZKgX00<000000:Vmj02Y_NP07`2Y_NP00`000000oooo0?oo
o`0D0?ooo`006@3oool2000002h0oooo1@2Y_NP3000001L0ZKgX<`2;Ehh90?RiPP`0SUbA1`3h^H8;
095PU0L0n;V27P2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030000003oool0oooo00L0oooo10000002
0?ooo`8000001@3oool001T0oooo00<000000?ooo`3oool0;P3oool0102Y_NP0000000000000000J
0:Vmj3<0ReN>2@3h^H8<08iLT@L0n;V22`2AH9@70?RiPP030000F`2Y_NP0ZKgX01`0ZKgX00<00000
0:Vmj02Y_NP07`2Y_NP2000000L0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000
003oool0oooo0080oooo000I0?ooo`030000003oool0oooo02d0oooo0P00000M0:Vmj3<0ReN>2@3h
^H8<08iLT@L0n;V22`2AH9@70?RiPP80001K7P2Y_NP00`000000ZKgX0:Vmj00O0:Vmj0030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`006@3oool2
000002/0oooo0`0000030?oooa`0ZKgX<`2;Ehh90?RiPP`0SUbA1`3h^H8;095PU0L0n;V20`0005/N
0:Vmj0030000002Y_NP0ZKgX01h0ZKgX00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo000H0?ooo`030000003oool0oooo02P0oooo0`0000070?oo
oa/0ZKgX<`2;Ehh90?RiPP`0SUbA1`3h^H8;095PU0L0n;V20P0005/O0:Vmj0030000002Y_NP0ZKgX
01l0ZKgX00<000000?ooo`3oool01`3oool00`000000oooo00000002000000D0oooo00030?ooo`80
00000`3oool010000000oooo0?ooo`0000040?ooo`8000001P3oool00`000000oooo0?ooo`0U0?oo
o`<000002`3ooolJ0:Vmj3<0ReN>203h^H8=08iLT@L0n;V22`2AH9@70?RiPR80ZKgX00<000000:Vm
j02Y_NP07P2Y_NP2000000D0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`000P3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`8000008`3oool3000000l0oooo6@2Y_NPc08]GSPP0n;V23@2>G9470?RiPP/0TF2D
1`3h^H8S0:Vmj0030000002Y_NP0ZKgX01h0ZKgX00<000000?ooo`3oool0103oool200000080oooo
100000040?ooo`000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`<000004P3ooolI0:Vmj380ReN>
2@3h^H8=08iLT@L0n;V22`2AH9@70?RiPR<0ZKgX00<000000:Vmj02Y_NP07@2Y_NP00`3oool00000
0?ooo`0A0?ooo`000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`<000005P3ooolH0:Vmj380ReN>
2@3h^H8<08iLT@P0n;V22`2AH9@70?RiPR@0ZKgX00<000000:Vmj02Y_NP06@2Y_NP40?ooo`030000
003oool0oooo0100oooo00020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`000000
0P0000050?ooo`8000006`3oool3000001X0oooo5`2Y_NPb08]GSPT0n;V2302>G9480?RiPP/0TF2D
1P3h^H8V0:Vmj0030000002Y_NP0ZKgX01@0ZKgX203oool00`000000oooo0?ooo`0@0?ooo`000P3o
ool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool00000203oool00`00
0000oooo0?ooo`0F0?ooo`<000007P3ooolF0:Vmj340ReN>00<0YL?_0?RiPP3h^H801`3h^H8<08iL
T@P0n;V22`2AH9@60?RiPRL0ZKgX00<000000:Vmj02Y_NP0402Y_NP<0?ooo`030000003oool0oooo
00l0oooo00030?ooo`8000001@3oool4000000030?ooo`000000000000800000103oool00`000000
oooo0?ooo`0E0?ooo`8000008`3ooolD0:Vmj2h0ReN>1@2U`nl80?RiPP`0SUbA1`3h^H8;095PU0L0
n;V29`2Y_NP00`000000ZKgX0:Vmj00=0:Vmj0l0oooo00<000000?ooo`3oool03`3oool001L0oooo
0P00000C0?ooo`<000009P3ooolC0:Vmj2`0ReN>202U`nl70?RiPP`0SUbA1`3h^H8;095PU0L0n;V2
:02Y_NP00`000000ZKgX0:Vmj0090:Vmj180oooo00<000000?ooo`3oool03`3oool001L0oooo00<0
00000?ooo`3oool03`3oool3000002X0oooo4P2Y_NPY08]GSP`0YL?_1P3h^H8<08iLT@L0n;V22`2A
H9@70?RiPRT0ZKgX00<000000:Vmj02Y_NP0102Y_NPF0?ooo`030000003oool0oooo00l0oooo000G
0?ooo`030000003oool0oooo00`0oooo0`00000^0?oooa40ZKgX9@2;EhhA0:G3k`D0n;V2302>G947
0?RiPP/0TF2D1`3h^H8Z0:Vmj0030000002Y_NP0ZKgX01T0oooo00<000000?ooo`3oool03`3oool0
01L0oooo00<000000?ooo`3oool02@3oool300000380oooo402Y_NPQ08]GSQH0YL?_0`3h^H8=08iL
T@L0n;V22`2AH9@70?RiPRX0ZKgX00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?oo
o`005P3oool2000000P0oooo0`00000f0?ooo`l0ZKgX7P2;EhhJ0:G3k`80n;V23@2>G9470?RiPP/0
TF2D1`3h^H8W0:Vmj0@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`00
5`3oool00`000000oooo0?ooo`030?ooo`<00000>P3oool>0:Vmj1/0ReN>7P2U`nl00`3h^H80SUbA
08iLT@0:08iLT@P0n;V22`2AH9@70?RiPR@0ZKgX203oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00h0oooo000F0?ooo`8000000P3oool3000003l0oooo302Y_NPH08]GSR80YL?_302>
G9480?RiPP/0TF2D1`3h^H8Q0:Vmj0/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0>0?ooo`005P3oool4000004<0oooo2`2Y_NPF08]GSR80YL?_3P2>G9480?RiPP/0TF2D1`3h^H8L
0:Vmj140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0>0?ooo`003@3oool30000
00H0oooo0P0000160?ooo`X0ZKgX4`2;EhhQ0:G3ka80SUbA203h^H8;095PU0L0n;V25`2Y_NPG0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`140?ooo`T0ZKgX402;EhhQ0:G3kaD0SUbA203h^H8;095PU0L0
n;V2502Y_NPK0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool000h0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`P0ZKgX302;EhhR0:G3kaP0SUbA
203h^H8:095PU0P0n;V24@2Y_NPN0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
3P3oool000h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`140?ooo`L0ZKgX2@2;
EhhS0:G3kaX0SUbA1`3h^H8;095PU0L0n;V23`2Y_NPR0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03P3oool000h0oooo00<000000?ooo`3oool02P3oool2000004D0oooo1P2Y_NP5
08]GSR@0YL?_7@2>G9470?RiPP/0TF2D1`3h^H8<0:Vmj2H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0=0?ooo`003@3oool2000000h0oooo00<000000?ooo`3oool0@`3oool50:Vm
j080ReN>902U`nl20?BhRAh0SUbA1`3h^H8;095PU0L0n;V22@2Y_NPZ0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`130?ooo`@0ZKgX8P2U`nl60?BhRAh0SUbA1`3h^H8;095PU0L0n;V21P2Y_NP]0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
@`3oool40:Vmj1h0YL?_2@3d^8TM08iLT@P0n;V22`2AH9@70?RiPP<0ZKgX<@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo000P0?ooo`030000003oool0oooo04@0oooo0`2Y
_NPI0:G3k`d0m;R97@2>G9480?RiPP/0TF2D1`3h^H8e0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03@3oool00240oooo0P0000150?ooo`<0ZKgX602U`nl=0?BhRAd0SUbA203h^H8;
095PU0L0n;V2=P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo000S0?oo
o`030000003oool0oooo04<0oooo0`2Y_NPG0:G3k`h0m;R9702>G9480?RiPP/0TF2D1`3h^H8f0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool002@0oooo00<000000?ooo`3o
ool0@P3oool50:Vmj1@0YL?_3`3d^8TK08iLT@80YL?_1`3h^H8;095PU0L0n;V2=`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo000U0?ooo`030000003oool0oooo0480oooo
1@2Y_NPC0:G3k`l0m;R9602>G9460:G3k`H0n;V22`2AH9@70?RiPSP0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0<0?ooo`009P3oool2000004<0oooo1@2Y_NPB0:G3k`l0m;R95P2>
G9490:G3k`D0n;V22`2AH9@70?RiPSP0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0<0?ooo`00:03oool00`000000oooo0?ooo`110?ooo`D0ZKgX4P2U`nl>0?BhRA<0SUbA3@2U`nl3
0?RiPP/0TF2D203h^H8i0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool0
02T0oooo00<000000?ooo`3oool0@P3oool50:Vmj140YL?_3@3d^8T@08iLTA00YL?_0`3h^H8;095P
U0P0n;V2>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo000Z0?ooo`03
0000003oool0oooo0480oooo1@2Y_NPA0:G3k``0m;R9302>G94E0:G3k`80n;V22`2AH9@80?RiPS/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00:`3oool2000004<0oooo
1@2Y_NPA0:G3k`/0m;R92@2>G94I0:G3k`030?RiPP2AH9@0TF2D00T0TF2D203h^H8k0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool002d0oooo00<000000?ooo`3oool0@@3o
ool50:Vmj140YL?_2P3d^8T508iLTAh0YL?_2`2AH9@70?RiPSd0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`00;P3oool00`000000oooo0?ooo`110?ooo`D0ZKgX4@2U`nl9
0?BhR@80SUbA7`2U`nl=095PU0L0n;V2?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo000_0?ooo`030000003oool0oooo0440oooo1@2Y_NPA0:G3k`H0m;R9802U`nl@095P
U0L0n;V2?`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000`0?ooo`03
0000003oool0oooo0480oooo102Y_NPA0:G3k`80m;R97`2U`nlD095PU0L0n;V2?`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000a0?ooo`800000@`3oool40:Vmj2h0YL?_
5`2AH9@70?RiPT00oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00<`3o
ool00`000000oooo0?ooo`110?ooo`@0ZKgX:@2U`nlK095PU0L0n;V2@@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00/0oooo000d0?ooo`030000003oool0oooo0440oooo102Y_NPU
0:G3k`030?BhR@2AH9@0TF2D01/0TF2D1`3h^H910?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02`3oool003D0oooo00<000000?ooo`3oool0@@3oool40:Vmj240YL?_103d^8TL095P
U0P0n;V2@P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo000f0?ooo`80
0000@P3oool40:Vmj1d0YL?_1`3d^8TL095PU0P0n;V2@`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo000h0?ooo`030000003oool0oooo0400oooo102Y_NPH0:G3k`/0m;R9
702AH9@80?RiPT@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00>@3o
ool00`000000oooo0?ooo`100?ooo`@0ZKgX5`2U`nl<0?BhRA/0TF2D203h^H940?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool003X0oooo00<000000?ooo`3oool0@03oool3
0:Vmj0030?ooo`2U`nl0YL?_01<0YL?_3@3d^8TK095PU0P0n;V2A@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo000k0?ooo`800000@03oool00`000000oooo0?ooo`030?oo
oa<0YL?_3@3d^8TJ095PU080YL?_1`3h^H960?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02P3oool003d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?oooa80
YL?_3@3d^8TG095PU0H0YL?_1P3h^H970?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool003h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`050?oooa40YL?_
3@3d^8TC095PU0/0YL?_103h^H980?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool003l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`050?oooa40YL?_3@3d
^8T@095PU0l0YL?_0`3h^H990?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00400oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`060?oooa40YL?_303d^8T<
095PU1<0YL?_0`3h^H9:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0440oooo0P00000j0?ooo`030000003oool0oooo00L0oooo4@2U`nl;0?BhR@T0TF2D5`2U`nl20?Ri
PT/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00@`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00P0oooo4@2U`nl:0?BhR@D0TF2D702U`nl00`3h^H80oooo0?ooo`190?oo
o`050000003oool0oooo0?ooo`0000002`3oool004@0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0:0?oooa40YL?_203d^8T2095PU200YL?_C03oool010000000oooo0?ooo`00000;
0?ooo`00A@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo4@2U`nl60?Bh
RB40YL?_C`3oool00`000000oooo0000000;0?ooo`00AP3oool2000003D0oooo00<000000?ooo`3o
ool0303ooolA0:G3k`80m;R98@2U`nmB0?ooo`040000003oool0oooo000000X0oooo00180?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool03@3oool^0:G3keP0oooo00<000000?ooo`00
00002P3oool004T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0>0?ooobP0YL?_
GP3oool2000000X0oooo001:0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0403o
oolT0:G3kf00oooo0`00000:0?ooo`00B`3oool2000002l0oooo00<000000?ooo`3oool04@3ooolO
0:G3kf00oooo1000000=0?ooo`00C@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0180oooo6`2U`nmO0?ooo`@000004@3oool004h0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0C0?oooaL0YL?_G`3oool3000001D0oooo001?0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0503ooolC0:G3keh0oooo1000000H0?ooo`00D03oool2000002X0oooo00<0
00000?ooo`3oool05@3oool>0:G3keh0oooo1000000L0?ooo`00DP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo01H0oooo2P2U`nmM0?ooo`@00000803oool005<0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0G0?ooo`H0YL?_G03oool4000002@0oooo001D0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0603oool20:G3ke/0oooo1000000X0?ooo`00
E@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0740oooo1000000/0?ooo`00EP3o
ool2000002@0oooo00<000000?ooo`3oool0KP3oool300000300oooo001H0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0JP3oool4000003<0oooo001I0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0IP3oool4000003L0oooo001J0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0HP3oool4000003/0oooo001K0?ooo`8000007`3oool00`000000oooo
0?ooo`1N0?ooo`@00000?`3oool005d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1J0?ooo`@00000@`3oool005h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1F
0?ooo`@00000A`3oool005l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1C0?oo
o`<00000B`3oool00600oooo0P00000J0?ooo`030000003oool0oooo04l0oooo1000001>0?ooo`00
HP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04/0oooo1000001B0?ooo`00H`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04L0oooo1000001F0?ooo`00I03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo1000001J0?ooo`00I@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo1000001N0?ooo`00IP3oool2000001@0
oooo00<000000?ooo`3oool0?03oool300000680oooo001X0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0>03oool4000006D0oooo001Y0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0=03oool4000006T0oooo001Z0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0<03oool4000006d0oooo001[0?ooo`8000003P3oool00`000000oooo0?ooo`0]0?oo
o`@00000L@3oool006d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y0?ooo`@0
0000M@3oool006h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`@00000
N@3oool006l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`<00000O@3o
ool00700oooo0P0000090?ooo`030000003oool0oooo01h0oooo100000200?ooo`00LP3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo100000240?ooo`00L`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo100000280?ooo`00M03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0180oooo1000002<0?ooo`00M@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo1000002@0?ooo`00MP3oool2000000<0oooo00<00000
0?ooo`3oool02P3oool4000009@0oooo001h0?ooo`040000003oool0oooo000000T0oooo0`00002H
0?ooo`00N@3oool00`000000oooo000000050?ooo`@00000V`3oool007X0oooo0P0000000`3oool0
000000000002000009l0oooo001k0?ooo`800000X`3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0821172, -0.00989707, \
0.00372703, 0.00372703}}]
}, Open  ]],

Cell["\<\
Since the signal has a peak value of 1, the signal to noise ratio, \
S/N, is about 10. Note that the signal is no longer very clear. Nevertheless, \
the eye+brain is very good at recognising the pattern from the noise.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Change the ",
  StyleBox["PlotRange", "InlineInputTraditionalForm"],
  " to see if you can eliminate the effect of the noise (this is a crude form \
of filtering)."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell["Filter", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The following code produces a Gaussian (low-pass) filter suitable \
for smoothing the signal:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Sigma](k_) := 
        Table[N[\[ExponentialE]\^\(\(-k\)\ \((\((j\/m)\)\^2 + \
\((i\/n)\)\^2)\)\)], {i, n}, {j, m}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "  Modifying the factor ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " leads to different (width) filters. "
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["What can you say about the ",
    FontSlant->"Plain"],
  "\[OpenCurlyDoubleQuote]",
  StyleBox["sharpness",
    FontSlant->"Plain"],
  "\[CloseCurlyDoubleQuote]",
  StyleBox[" of this filter as ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  StyleBox[" increases? Use ",
    FontSlant->"Plain"],
  StyleBox["ListPlot3D", "InlineInputTraditionalForm",
    FontSlant->"Plain"],
  StyleBox[" to visualize ",
    FontSlant->"Plain"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Sigma](k)\)], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  StyleBox[".",
    FontSlant->"Plain"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`ListDensityPlot[\[Sigma](3)]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFCF6EEE4D8CBBDAE9E8F807164564A3F352C251E18130F0C
FCF8F2EAE0D5C8BAAB9C8D7E706255493E352C241D18130F0C
F6F2EDE5DBD0C3B5A7988A7B6D6053473D332B231D17120E0B
EEEAE5DDD4C9BDAFA2938577695D50453B3229221C16120E0B
E4E0DBD4CBC0B5A89B8D7F7265594D42382F27211B15110D0A
D8D5D0C9C0B6AB9F9386796C6054493F352D251F1914100D0A
CBC8C3BDB5ABA1958A7E71655A4F443B322A231D18130F0C09
BDBAB5AFA89F958B8075695E544940372E27211B16120E0B08
AEABA7A29B938A80766C61574D433B322B241E1914100D0A08
9E9C98938D867E756C62594F463D352E27211B16120F0C0907
8F8D8A857F797169615950473F373029231D1814100D0A0806
807E7B77726C655E574F474039322B251F1A16120E0C090705
71706D6965605A544D463F39322C26211C1713100D0A080605
6462605D59544F49433D37322C26211C1814110E0B09070504
565553504D4944403B35302B26211D1915110E0C0907060403
4A494745423F3B37322E2925211C1915120F0C0A0806050403
3F3E3D3B3835322E2B27231F1C1815120F0D0A080705040302
353533322F2D2A2724211D1A1714110F0D0A09070504030202
2C2C2B29272523211E1B181613110E0C0A0907060403020201
25242322211F1D1B19161412100E0C0A080706040303020101
1E1D1D1C1B1918161412100E0D0B0908070504030302010100
1818171615141312100F0D0C0A090706050403030201010000
1313121211100F0E0D0C0A0908070605040302020101000000
0F0F0E0E0D0D0C0B0A09080706050404030202010100000000
0C0C0B0B0A0A09080807060505040303020201010000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0
[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/0
7QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH
303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe
2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^
k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:
BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;
0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;
06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`6
0?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?
S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C
4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0
[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/0
7QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH
303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe
2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^
k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:
BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`00403oool;
0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;
06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C4`/03`l?2`0<30`6
0?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0[Zj^2`2NWYh;08n?
S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/07QhN2`0H61P;01<C
4`/03`l?2`0<30`60?ooo`00403oool;0?clo0/0m_Kf2`3^k^h;0>CTi0/0f=SH303;bl/;0;fm_@/0
[Zj^2`2NWYh;08n?S`/0P8202`1aLG4;06ATI0/0EUIF2`1:BTX;03lo?`/0=CDe2`0/;2`<02DU9@/0
7QhN2`0H61P;01<C4`/03`l?2`0<30`60?ooo`001@3oool;0?clo0/0n?Sh2`3bl_8;0>[ZjP/0h>3P
2`3EeMD<0<S8b0/0^[Zj2`2[Zj/;09bLW0/0SHf=2`1nOWh;071`L0/0HV9R2`1EEED;04U9B@/0?Shn
2`0e=CD;02`/;0`092@T2`0M7Ad;01PH60/04a<C2`0?3`l;00`<30H0oooo00050?ooo`/0o?cl2`3h
n?P;0?;blP/0j^[Z2`3Ph>0;0=GEe@`0b<S82`2j^[X;0:^[Z`/0W9bL2`2=SHd;07inOP/0L71`2`1R
HV8;05EEE@/0BDU92`0n?Sh;03De=@/0;2`/300T92@;01dM7@/061PH2`0C4a<;00l?3`/030`<1P3o
ool000D0oooo2`3lo?`;0?Shn0/0l_;b2`3Zj^X;0>3Ph0/0eMGE3038b<P;0;Zj^P/0Zj^[2`2LW9`;
08f=S@/0OWin2`1`L70;069RHP/0EEEE2`19BDT;03hn?P/0=CDe2`0/;2`<02@T90/07AdM2`0H61P;
01<C4`/03`l?2`0<30`60?ooo`001@3oool;0?clo0/0n?Sh2`3bl_8;0>[ZjP/0h>3P2`3EeMD<0<S8
b0/0^[Zj2`2[Zj/;09bLW0/0SHf=2`1nOWh;071`L0/0HV9R2`1EEED;04U9B@/0?Shn2`0e=CD;02`/
;0`092@T2`0M7Ad;01PH60/04a<C2`0?3`l;00`<30H0oooo00050?ooo`/0o?cl2`3hn?P;0?;blP/0
j^[Z2`3Ph>0;0=GEe@`0b<S82`2j^[X;0:^[Z`/0W9bL2`2=SHd;07inOP/0L71`2`1RHV8;05EEE@/0
BDU92`0n?Sh;03De=@/0;2`/300T92@;01dM7@/061PH2`0C4a<;00l?3`/030`<1P3oool000D0oooo
2`3lo?`;0?Shn0/0l_;b2`3Zj^X;0>3Ph0/0eMGE3038b<P;0;Zj^P/0Zj^[2`2LW9`;08f=S@/0OWin
2`1`L70;069RHP/0EEEE2`19BDT;03hn?P/0=CDe2`0/;2`<02@T90/07AdM2`0H61P;01<C4`/03`l?
2`0<30`60?ooo`001@3oool;0?clo0/0n?Sh2`3bl_8;0>[ZjP/0h>3P2`3EeMD<0<S8b0/0^[Zj2`2[
Zj/;09bLW0/0SHf=2`1nOWh;071`L0/0HV9R2`1EEED;04U9B@/0?Shn2`0e=CD;02`/;0`092@T2`0M
7Ad;01PH60/04a<C2`0?3`l;00`<30H0oooo00050?ooo`/0o?cl2`3hn?P;0?;blP/0j^[Z2`3Ph>0;
0=GEe@`0b<S82`2j^[X;0:^[Z`/0W9bL2`2=SHd;07inOP/0L71`2`1RHV8;05EEE@/0BDU92`0n?Sh;
03De=@/0;2`/300T92@;01dM7@/061PH2`0C4a<;00l?3`/030`<1P3oool000D0oooo2`3lo?`;0?Sh
n0/0l_;b2`3Zj^X;0>3Ph0/0eMGE3038b<P;0;Zj^P/0Zj^[2`2LW9`;08f=S@/0OWin2`1`L70;069R
HP/0EEEE2`19BDT;03hn?P/0=CDe2`0/;2`<02@T90/07AdM2`0H61P;01<C4`/03`l?2`0<30`60?oo
o`001@3oool;0?clo0/0n?Sh2`3bl_8;0>[ZjP/0h>3P2`3EeMD<0<S8b0/0^[Zj2`2[Zj/;09bLW0/0
SHf=2`1nOWh;071`L0/0HV9R2`1EEED;04U9B@/0?Shn2`0e=CD;02`/;0`092@T2`0M7Ad;01PH60/0
4a<C2`0?3`l;00`<30H0oooo00050?ooo`/0o?cl2`3hn?P;0?;blP/0j^[Z2`3Ph>0;0=GEe@`0b<S8
2`2j^[X;0:^[Z`/0W9bL2`2=SHd;07inOP/0L71`2`1RHV8;05EEE@/0BDU92`0n?Sh;03De=@/0;2`/
300T92@;01dM7@/061PH2`0C4a<;00l?3`/030`<1P3oool000D0oooo2`3fm_H;0?;blP/0kNg]2`3U
iND;0=_Kf`/0d=3@3033`l<;0;Fe]@/0YjNW2`2HV9P;08Z:RP/0Ng]k2`1]KFd;061PH0/0De=C2`17
AdL;03dm?@/0<c<c2`0[:b/<02<S8`/07AdM2`0G5aL;018B4P/03Ph>2`0;2`/60?ooo`001@3oool;
0?KfmP/0l_;b2`3]kNd;0>GUi@/0fm_K2`3@d=0<0<?3``/0]KFe2`2WYjL;09RHV0/0RXZ:2`1kNg/;
06e]K@/0H61P2`1CDe<;04M7A`/0?Cdm2`0c<c<;02/[:``08b<S2`0M7Ad;01LG5`/04Q8B2`0>3Ph;
00/;2`H0oooo00050?ooo`/0m_Kf2`3bl_8;0>g]k@/0iNGU2`3Kfm/;0=3@d0`0`l?32`2e]KD;0:NW
Y`/0V9RH2`2:RXX;07]kN`/0KFe]2`1PH60;05=CD`/0AdM72`0m?Cd;03<c<`/0:b/[300S8b<;01dM
7@/05aLG2`0B4Q8;00h>3P/02`/;1P3oool000D0oooo2`3fm_H;0?;blP/0kNg]2`3UiND;0=_Kf`/0
d=3@3033`l<;0;Fe]@/0YjNW2`2HV9P;08Z:RP/0Ng]k2`1]KFd;061PH0/0De=C2`17AdL;03dm?@/0
<c<c2`0[:b/<02<S8`/07AdM2`0G5aL;018B4P/03Ph>2`0;2`/60?ooo`001@3oool;0?KfmP/0l_;b
2`3]kNd;0>GUi@/0fm_K2`3@d=0<0<?3``/0]KFe2`2WYjL;09RHV0/0RXZ:2`1kNg/;06e]K@/0H61P
2`1CDe<;04M7A`/0?Cdm2`0c<c<;02/[:``08b<S2`0M7Ad;01LG5`/04Q8B2`0>3Ph;00/;2`H0oooo
00050?ooo`/0m_Kf2`3bl_8;0>g]k@/0iNGU2`3Kfm/;0=3@d0`0`l?32`2e]KD;0:NWY`/0V9RH2`2:
RXX;07]kN`/0KFe]2`1PH60;05=CD`/0AdM72`0m?Cd;03<c<`/0:b/[300S8b<;01dM7@/05aLG2`0B
4Q8;00h>3P/02`/;1P3oool000D0oooo2`3fm_H;0?;blP/0kNg]2`3UiND;0=_Kf`/0d=3@3033`l<;
0;Fe]@/0YjNW2`2HV9P;08Z:RP/0Ng]k2`1]KFd;061PH0/0De=C2`17AdL;03dm?@/0<c<c2`0[:b/<
02<S8`/07AdM2`0G5aL;018B4P/03Ph>2`0;2`/60?ooo`001@3oool;0?KfmP/0l_;b2`3]kNd;0>GU
i@/0fm_K2`3@d=0<0<?3``/0]KFe2`2WYjL;09RHV0/0RXZ:2`1kNg/;06e]K@/0H61P2`1CDe<;04M7
A`/0?Cdm2`0c<c<;02/[:``08b<S2`0M7Ad;01LG5`/04Q8B2`0>3Ph;00/;2`H0oooo00050?ooo`/0
m_Kf2`3bl_8;0>g]k@/0iNGU2`3Kfm/;0=3@d0`0`l?32`2e]KD;0:NWY`/0V9RH2`2:RXX;07]kN`/0
KFe]2`1PH60;05=CD`/0AdM72`0m?Cd;03<c<`/0:b/[300S8b<;01dM7@/05aLG2`0B4Q8;00h>3P/0
2`/;1P3oool000D0oooo2`3fm_H;0?;blP/0kNg]2`3UiND;0=_Kf`/0d=3@3033`l<;0;Fe]@/0YjNW
2`2HV9P;08Z:RP/0Ng]k2`1]KFd;061PH0/0De=C2`17AdL;03dm?@/0<c<c2`0[:b/<02<S8`/07AdM
2`0G5aL;018B4P/03Ph>2`0;2`/60?ooo`001@3oool;0?KfmP/0l_;b2`3]kNd;0>GUi@/0fm_K2`3@
d=0<0<?3``/0]KFe2`2WYjL;09RHV0/0RXZ:2`1kNg/;06e]K@/0H61P2`1CDe<;04M7A`/0?Cdm2`0c
<c<;02/[:``08b<S2`0M7Ad;01LG5`/04Q8B2`0>3Ph;00/;2`H0oooo00050?ooo`/0k^k^2`3Zj^X;
0>GUi@/0gMgM2`3De=@;0<W9b@`0_Kfm2`2_[jl;0::RXP/0Ti>C2`25QHD;07MgM`/0JFUY2`1MGEd;
051@D0/0ADE52`0k>c/;038b<P/0:BTY300R8R8;01`L70/05QHF2`0B4Q8;00h>3P/02`/;1P3oool0
00D0oooo2`3^k^h;0>[ZjP/0iNGU2`3MgMd;0=CDe0/0bLW9302m_Kd;0:n_[`/0XZ:R2`2CTi<;08F5
Q@/0MgMg2`1YJFT;05eMG@/0D51@2`15ADD;03/k>`/0<S8b2`0Y:BT<028R8P/071`L2`0F5QH;018B
4P/03Ph>2`0;2`/60?ooo`001@3oool;0>k^kP/0j^[Z2`3UiND;0=gMg@/0e=CD2`39bLT<0;fm_@/0
[jn_2`2RXZ8;09>CT`/0QHF52`1gMgL;06UYJ@/0GEeM2`1@D50;04E5A@/0>c/k2`0b<S8;02TY:@`0
8R8R2`0L71`;01HF5P/04Q8B2`0>3Ph;00/;2`H0oooo00050?ooo`/0k^k^2`3Zj^X;0>GUi@/0gMgM
2`3De=@;0<W9b@`0_Kfm2`2_[jl;0::RXP/0Ti>C2`25QHD;07MgM`/0JFUY2`1MGEd;051@D0/0ADE5
2`0k>c/;038b<P/0:BTY300R8R8;01`L70/05QHF2`0B4Q8;00h>3P/02`/;1P3oool000D0oooo2`3^
k^h;0>[ZjP/0iNGU2`3MgMd;0=CDe0/0bLW9302m_Kd;0:n_[`/0XZ:R2`2CTi<;08F5Q@/0MgMg2`1Y
JFT;05eMG@/0D51@2`15ADD;03/k>`/0<S8b2`0Y:BT<028R8P/071`L2`0F5QH;018B4P/03Ph>2`0;
2`/60?ooo`001@3oool;0>k^kP/0j^[Z2`3UiND;0=gMg@/0e=CD2`39bLT<0;fm_@/0[jn_2`2RXZ8;
09>CT`/0QHF52`1gMgL;06UYJ@/0GEeM2`1@D50;04E5A@/0>c/k2`0b<S8;02TY:@`08R8R2`0L71`;
01HF5P/04Q8B2`0>3Ph;00/;2`H0oooo00050?ooo`/0k^k^2`3Zj^X;0>GUi@/0gMgM2`3De=@;0<W9
b@`0_Kfm2`2_[jl;0::RXP/0Ti>C2`25QHD;07MgM`/0JFUY2`1MGEd;051@D0/0ADE52`0k>c/;038b
<P/0:BTY300R8R8;01`L70/05QHF2`0B4Q8;00h>3P/02`/;1P3oool000D0oooo2`3^k^h;0>[ZjP/0
iNGU2`3MgMd;0=CDe0/0bLW9302m_Kd;0:n_[`/0XZ:R2`2CTi<;08F5Q@/0MgMg2`1YJFT;05eMG@/0
D51@2`15ADD;03/k>`/0<S8b2`0Y:BT<028R8P/071`L2`0F5QH;018B4P/03Ph>2`0;2`/60?ooo`00
1@3oool;0>k^kP/0j^[Z2`3UiND;0=gMg@/0e=CD2`39bLT<0;fm_@/0[jn_2`2RXZ8;09>CT`/0QHF5
2`1gMgL;06UYJ@/0GEeM2`1@D50;04E5A@/0>c/k2`0b<S8;02TY:@`08R8R2`0L71`;01HF5P/04Q8B
2`0>3Ph;00/;2`H0oooo00050?ooo`/0k^k^2`3Zj^X;0>GUi@/0gMgM2`3De=@;0<W9b@`0_Kfm2`2_
[jl;0::RXP/0Ti>C2`25QHD;07MgM`/0JFUY2`1MGEd;051@D0/0ADE52`0k>c/;038b<P/0:BTY300R
8R8;01`L70/05QHF2`0B4Q8;00h>3P/02`/;1P3oool000D0oooo2`3^k^h;0>[ZjP/0iNGU2`3MgMd;
0=CDe0/0bLW9302m_Kd;0:n_[`/0XZ:R2`2CTi<;08F5Q@/0MgMg2`1YJFT;05eMG@/0D51@2`15ADD;
03/k>`/0<S8b2`0Y:BT<028R8P/071`L2`0F5QH;018B4P/03Ph>2`0;2`/60?ooo`001@3oool;0>CT
i0/0h>3P2`3Kfm/;0=CDe0/0bl_;2`30`<0<0;Fe]@/0Z:RX2`2KVi/;08f=S@/0Ogmo2`1bLW8;06EU
I@/0FEUI2`1=CDd;0492@P/0>3Ph2`0_;bl;02LW9``08B4Q2`0K6a/;01DE5@/04A4A2`0=3@d;00X:
2PH0oooo00050?ooo`/0i>CT2`3Ph>0;0=_Kf`/0e=CD2`3;bl/;0<30`0`0]KFe2`2XZ:P;09^KV`/0
SHf=2`1oOgl;079bLP/0IFEU2`1IFET;04e=C@/0@T922`0h>3P;02l_;`/09bLW300Q8B4;01/K6`/0
5ADE2`0A4A4;00d=3@/02PX:1P3oool000D0oooo2`3Ti>@;0>3Ph0/0fm_K2`3De=@;0<_;b`/0`<30
302e]KD;0:RXZ0/0Vi^K2`2=SHd;07moO`/0LW9b2`1UIFD;05UIF@/0CDe=2`12@T8;03Ph>0/0;bl_
2`0W9bL<024Q8@/06a/K2`0E5AD;014A4@/03@d=2`0:2PX60?ooo`001@3oool;0>CTi0/0h>3P2`3K
fm/;0=CDe0/0bl_;2`30`<0<0;Fe]@/0Z:RX2`2KVi/;08f=S@/0Ogmo2`1bLW8;06EUI@/0FEUI2`1=
CDd;0492@P/0>3Ph2`0_;bl;02LW9``08B4Q2`0K6a/;01DE5@/04A4A2`0=3@d;00X:2PH0oooo0005
0?ooo`/0i>CT2`3Ph>0;0=_Kf`/0e=CD2`3;bl/;0<30`0`0]KFe2`2XZ:P;09^KV`/0SHf=2`1oOgl;
079bLP/0IFEU2`1IFET;04e=C@/0@T922`0h>3P;02l_;`/09bLW300Q8B4;01/K6`/05ADE2`0A4A4;
00d=3@/02PX:1P3oool000D0oooo2`3Ti>@;0>3Ph0/0fm_K2`3De=@;0<_;b`/0`<30302e]KD;0:RX
Z0/0Vi^K2`2=SHd;07moO`/0LW9b2`1UIFD;05UIF@/0CDe=2`12@T8;03Ph>0/0;bl_2`0W9bL<024Q
8@/06a/K2`0E5AD;014A4@/03@d=2`0:2PX60?ooo`001@3oool;0>CTi0/0h>3P2`3Kfm/;0=CDe0/0
bl_;2`30`<0<0;Fe]@/0Z:RX2`2KVi/;08f=S@/0Ogmo2`1bLW8;06EUI@/0FEUI2`1=CDd;0492@P/0
>3Ph2`0_;bl;02LW9``08B4Q2`0K6a/;01DE5@/04A4A2`0=3@d;00X:2PH0oooo00050?ooo`/0i>CT
2`3Ph>0;0=_Kf`/0e=CD2`3;bl/;0<30`0`0]KFe2`2XZ:P;09^KV`/0SHf=2`1oOgl;079bLP/0IFEU
2`1IFET;04e=C@/0@T922`0h>3P;02l_;`/09bLW300Q8B4;01/K6`/05ADE2`0A4A4;00d=3@/02PX:
1P3oool000D0oooo2`3Ti>@;0>3Ph0/0fm_K2`3De=@;0<_;b`/0`<30302e]KD;0:RXZ0/0Vi^K2`2=
SHd;07moO`/0LW9b2`1UIFD;05UIF@/0CDe=2`12@T8;03Ph>0/0;bl_2`0W9bL<024Q8@/06a/K2`0E
5AD;014A4@/03@d=2`0:2PX60?ooo`001@3oool;0>CTi0/0h>3P2`3Kfm/;0=CDe0/0bl_;2`30`<0<
0;Fe]@/0Z:RX2`2KVi/;08f=S@/0Ogmo2`1bLW8;06EUI@/0FEUI2`1=CDd;0492@P/0>3Ph2`0_;bl;
02LW9``08B4Q2`0K6a/;01DE5@/04A4A2`0=3@d;00X:2PH0oooo00050?ooo`/0i>CT2`3Ph>0;0=_K
f`/0e=CD2`3;bl/;0<30`0`0]KFe2`2XZ:P;09^KV`/0SHf=2`1oOgl;079bLP/0IFEU2`1IFET;04e=
C@/0@T922`0h>3P;02l_;`/09bLW300Q8B4;01/K6`/05ADE2`0A4A4;00d=3@/02PX:1P3oool000D0
oooo2`3Hf=P;0=GEe@/0d=3@2`39bLT;0<30`0/0][Jf302[Zj/;09nOW`/0Ti>C2`26QXH;07UiN@/0
K6a/2`1PH60;05ADE0/0BDU92`0o?cl;03De=@/0;Bd]2`0U9BD<01lO7`/06ATI2`0D51@;010@40/0
3@d=2`0:2PX60?ooo`001@3oool;0=SHf0/0eMGE2`3@d=0;0<W9b@/0`<302`2f][H<0:^[Z`/0WinO
2`2CTi<;08J6QP/0NGUi2`1/K6`;061PH0/0E5AD2`19BDT;03lo?`/0=CDe2`0];Bd;02DU9@`07alO
2`0I6AT;01@D50/0410@2`0=3@d;00X:2PH0oooo00050?ooo`/0f=SH2`3EeMD;0=3@d0/0bLW92`30
`<0;0;Jf]P`0Zj^[2`2OWil;09>CT`/0QXJ62`1iNGT;06a/K0/0H61P2`1DE5@;04U9B@/0?clo2`0e
=CD;02d];@/09BDU300O7al;01TI6@/051@D2`0@410;00d=3@/02PX:1P3oool000D0oooo2`3Hf=P;
0=GEe@/0d=3@2`39bLT;0<30`0/0][Jf302[Zj/;09nOW`/0Ti>C2`26QXH;07UiN@/0K6a/2`1PH60;
05ADE0/0BDU92`0o?cl;03De=@/0;Bd]2`0U9BD<01lO7`/06ATI2`0D51@;010@40/03@d=2`0:2PX6
0?ooo`001@3oool;0=SHf0/0eMGE2`3@d=0;0<W9b@/0`<302`2f][H<0:^[Z`/0WinO2`2CTi<;08J6
QP/0NGUi2`1/K6`;061PH0/0E5AD2`19BDT;03lo?`/0=CDe2`0];Bd;02DU9@`07alO2`0I6AT;01@D
50/0410@2`0=3@d;00X:2PH0oooo00050?ooo`/0f=SH2`3EeMD;0=3@d0/0bLW92`30`<0;0;Jf]P`0
Zj^[2`2OWil;09>CT`/0QXJ62`1iNGT;06a/K0/0H61P2`1DE5@;04U9B@/0?clo2`0e=CD;02d];@/0
9BDU300O7al;01TI6@/051@D2`0@410;00d=3@/02PX:1P3oool000D0oooo2`3Hf=P;0=GEe@/0d=3@
2`39bLT;0<30`0/0][Jf302[Zj/;09nOW`/0Ti>C2`26QXH;07UiN@/0K6a/2`1PH60;05ADE0/0BDU9
2`0o?cl;03De=@/0;Bd]2`0U9BD<01lO7`/06ATI2`0D51@;010@40/03@d=2`0:2PX60?ooo`001@3o
ool;0=SHf0/0eMGE2`3@d=0;0<W9b@/0`<302`2f][H<0:^[Z`/0WinO2`2CTi<;08J6QP/0NGUi2`1/
K6`;061PH0/0E5AD2`19BDT;03lo?`/0=CDe2`0];Bd;02DU9@`07alO2`0I6AT;01@D50/0410@2`0=
3@d;00X:2PH0oooo00050?ooo`/0f=SH2`3EeMD;0=3@d0/0bLW92`30`<0;0;Jf]P`0Zj^[2`2OWil;
09>CT`/0QXJ62`1iNGT;06a/K0/0H61P2`1DE5@;04U9B@/0?clo2`0e=CD;02d];@/09BDU300O7al;
01TI6@/051@D2`0@410;00d=3@/02PX:1P3oool000D0oooo2`3Hf=P;0=GEe@/0d=3@2`39bLT;0<30
`0/0][Jf302[Zj/;09nOW`/0Ti>C2`26QXH;07UiN@/0K6a/2`1PH60;05ADE0/0BDU92`0o?cl;03De
=@/0;Bd]2`0U9BD<01lO7`/06ATI2`0D51@;010@40/03@d=2`0:2PX60?ooo`001@3oool;0=SHf0/0
eMGE2`3@d=0;0<W9b@/0`<302`2f][H<0:^[Z`/0WinO2`2CTi<;08J6QP/0NGUi2`1/K6`;061PH0/0
E5AD2`19BDT;03lo?`/0=CDe2`0];Bd;02DU9@`07alO2`0I6AT;01@D50/0410@2`0=3@d;00X:2PH0
oooo00050?ooo`/0bl_;2`38b<P;0<?3``/0_Kfm2`2e]KD;0:^[Z``0XJ6Q2`2EUID;08Z:RP/0OWin
2`1aLG4;06EUI@/0FUYJ2`1?Cdl;04A4A0/0>c/k2`0b<S8;02XZ:P/08b<S300M7Ad;01PH60/04a<C
2`0?3`l;00`<30/02@T91P3oool000D0oooo2`3;bl/;0<S8b0/0`l?32`2m_Kd;0;Fe]@/0Zj^[302Q
XJ4;09FEU@/0RXZ:2`1nOWh;075aL@/0IFEU2`1JFUX;04m?C`/0A4A42`0k>c/;038b<P/0:RXZ2`0S
8b<<01dM7@/061PH2`0C4a<;00l?3`/030`<2`092@T60?ooo`001@3oool;0<_;b`/0b<S82`33`l<;
0;fm_@/0]KFe2`2[Zj/<0:6QX@/0UIFE2`2:RXX;07inOP/0LG5a2`1UIFD;05YJFP/0Cdm?2`14A4@;
03/k>`/0<S8b2`0Z:RX;02<S8``07AdM2`0H61P;01<C4`/03`l?2`0<30`;00T92@H0oooo00050?oo
o`/0bl_;2`38b<P;0<?3``/0_Kfm2`2e]KD;0:^[Z``0XJ6Q2`2EUID;08Z:RP/0OWin2`1aLG4;06EU
I@/0FUYJ2`1?Cdl;04A4A0/0>c/k2`0b<S8;02XZ:P/08b<S300M7Ad;01PH60/04a<C2`0?3`l;00`<
30/02@T91P3oool000D0oooo2`3;bl/;0<S8b0/0`l?32`2m_Kd;0;Fe]@/0Zj^[302QXJ4;09FEU@/0
RXZ:2`1nOWh;075aL@/0IFEU2`1JFUX;04m?C`/0A4A42`0k>c/;038b<P/0:RXZ2`0S8b<<01dM7@/0
61PH2`0C4a<;00l?3`/030`<2`092@T60?ooo`001@3oool;0<_;b`/0b<S82`33`l<;0;fm_@/0]KFe
2`2[Zj/<0:6QX@/0UIFE2`2:RXX;07inOP/0LG5a2`1UIFD;05YJFP/0Cdm?2`14A4@;03/k>`/0<S8b
2`0Z:RX;02<S8``07AdM2`0H61P;01<C4`/03`l?2`0<30`;00T92@H0oooo00050?ooo`/0bl_;2`38
b<P;0<?3``/0_Kfm2`2e]KD;0:^[Z``0XJ6Q2`2EUID;08Z:RP/0OWin2`1aLG4;06EUI@/0FUYJ2`1?
Cdl;04A4A0/0>c/k2`0b<S8;02XZ:P/08b<S300M7Ad;01PH60/04a<C2`0?3`l;00`<30/02@T91P3o
ool000D0oooo2`3;bl/;0<S8b0/0`l?32`2m_Kd;0;Fe]@/0Zj^[302QXJ4;09FEU@/0RXZ:2`1nOWh;
075aL@/0IFEU2`1JFUX;04m?C`/0A4A42`0k>c/;038b<P/0:RXZ2`0S8b<<01dM7@/061PH2`0C4a<;
00l?3`/030`<2`092@T60?ooo`001@3oool;0<_;b`/0b<S82`33`l<;0;fm_@/0]KFe2`2[Zj/<0:6Q
X@/0UIFE2`2:RXX;07inOP/0LG5a2`1UIFD;05YJFP/0Cdm?2`14A4@;03/k>`/0<S8b2`0Z:RX;02<S
8``07AdM2`0H61P;01<C4`/03`l?2`0<30`;00T92@H0oooo00050?ooo`/0bl_;2`38b<P;0<?3``/0
_Kfm2`2e]KD;0:^[Z``0XJ6Q2`2EUID;08Z:RP/0OWin2`1aLG4;06EUI@/0FUYJ2`1?Cdl;04A4A0/0
>c/k2`0b<S8;02XZ:P/08b<S300M7Ad;01PH60/04a<C2`0?3`l;00`<30/02@T91P3oool000D0oooo
2`3;bl/;0<S8b0/0`l?32`2m_Kd;0;Fe]@/0Zj^[302QXJ4;09FEU@/0RXZ:2`1nOWh;075aL@/0IFEU
2`1JFUX;04m?C`/0A4A42`0k>c/;038b<P/0:RXZ2`0S8b<<01dM7@/061PH2`0C4a<;00l?3`/030`<
2`092@T60?ooo`001@3oool;0;fm_@/0^[Zj2`2e]KD;0:n_[`/0Z:RX2`2OWil<09FEU@/0Rh^;2`20
P80;07EeM@/0JFUY2`1NGUh;05ADE0/0BDU92`10@40;03Lg=`/0;Rh^2`0W9bL;024Q8@`06a/K2`0F
5QH;018B4P/03Ph>2`0;2`/;00P820H0oooo00050?ooo`/0_Kfm2`2j^[X;0;Fe]@/0[jn_2`2XZ:P;
09nOW``0UIFE2`2;Rh/;0820P0/0MGEe2`1YJFT;05iNGP/0E5AD2`19BDT;0410@0/0=cLg2`0^;Rh;
02LW9`/08B4Q300K6a/;01HF5P/04Q8B2`0>3Ph;00/;2`/020P81P3oool000D0oooo2`2m_Kd;0;Zj
^P/0]KFe2`2_[jl;0:RXZ0/0WinO302EUID;08^;R`/0P8202`1eMGD;06UYJ@/0GUiN2`1DE5@;04U9
B@/0@4102`0g=cL;02h^;P/09bLW2`0Q8B4<01/K6`/05QHF2`0B4Q8;00h>3P/02`/;2`0820P60?oo
o`001@3oool;0;fm_@/0^[Zj2`2e]KD;0:n_[`/0Z:RX2`2OWil<09FEU@/0Rh^;2`20P80;07EeM@/0
JFUY2`1NGUh;05ADE0/0BDU92`10@40;03Lg=`/0;Rh^2`0W9bL;024Q8@`06a/K2`0F5QH;018B4P/0
3Ph>2`0;2`/;00P820H0oooo00050?ooo`/0_Kfm2`2j^[X;0;Fe]@/0[jn_2`2XZ:P;09nOW``0UIFE
2`2;Rh/;0820P0/0MGEe2`1YJFT;05iNGP/0E5AD2`19BDT;0410@0/0=cLg2`0^;Rh;02LW9`/08B4Q
300K6a/;01HF5P/04Q8B2`0>3Ph;00/;2`/020P81P3oool000D0oooo2`2m_Kd;0;Zj^P/0]KFe2`2_
[jl;0:RXZ0/0WinO302EUID;08^;R`/0P8202`1eMGD;06UYJ@/0GUiN2`1DE5@;04U9B@/0@4102`0g
=cL;02h^;P/09bLW2`0Q8B4<01/K6`/05QHF2`0B4Q8;00h>3P/02`/;2`0820P60?ooo`001@3oool;
0;fm_@/0^[Zj2`2e]KD;0:n_[`/0Z:RX2`2OWil<09FEU@/0Rh^;2`20P80;07EeM@/0JFUY2`1NGUh;
05ADE0/0BDU92`10@40;03Lg=`/0;Rh^2`0W9bL;024Q8@`06a/K2`0F5QH;018B4P/03Ph>2`0;2`/;
00P820H0oooo00050?ooo`/0_Kfm2`2j^[X;0;Fe]@/0[jn_2`2XZ:P;09nOW``0UIFE2`2;Rh/;0820
P0/0MGEe2`1YJFT;05iNGP/0E5AD2`19BDT;0410@0/0=cLg2`0^;Rh;02LW9`/08B4Q300K6a/;01HF
5P/04Q8B2`0>3Ph;00/;2`/020P81P3oool000D0oooo2`2m_Kd;0;Zj^P/0]KFe2`2_[jl;0:RXZ0/0
WinO302EUID;08^;R`/0P8202`1eMGD;06UYJ@/0GUiN2`1DE5@;04U9B@/0@4102`0g=cL;02h^;P/0
9bLW2`0Q8B4<01/K6`/05QHF2`0B4Q8;00h>3P/02`/;2`0820P60?ooo`001@3oool;0;fm_@/0^[Zj
2`2e]KD;0:n_[`/0Z:RX2`2OWil<09FEU@/0Rh^;2`20P80;07EeM@/0JFUY2`1NGUh;05ADE0/0BDU9
2`10@40;03Lg=`/0;Rh^2`0W9bL;024Q8@`06a/K2`0F5QH;018B4P/03Ph>2`0;2`/;00P820H0oooo
00050?ooo`/0_Kfm2`2j^[X;0;Fe]@/0[jn_2`2XZ:P;09nOW``0UIFE2`2;Rh/;0820P0/0MGEe2`1Y
JFT;05iNGP/0E5AD2`19BDT;0410@0/0=cLg2`0^;Rh;02LW9`/08B4Q300K6a/;01HF5P/04Q8B2`0>
3Ph;00/;2`/020P81P3oool000D0oooo2`2^[Zh;0:^[Z`/0YjNW2`2RXZ8;09^KV`/0Ti>C302:RXX;
0820P0/0MWIf2`1/K6`;065QH@/0EeMG2`1=CDd;04=3@`/0>c/k2`0b<S8;02/[:`/092@T2`0N7Qh<
01TI6@/051@D2`0@410;00d=3@/02PX:2`0820P60?ooo`001@3oool;0:j^[P/0Zj^[2`2WYjL;0::R
XP/0Vi^K2`2CTi<<08Z:RP/0P8202`1fMWH;06a/K0/0HF5Q2`1GEeL;04e=C@/0@d=32`0k>c/;038b
<P/0:b/[2`0T92@;01hN7P`06ATI2`0D51@;010@40/03@d=2`0:2PX;00P820H0oooo00050?ooo`/0
[Zj^2`2[Zj/;0:NWY`/0XZ:R2`2KVi/;09>CT``0RXZ:2`20P80;07IfMP/0K6a/2`1QHF4;05MGE`/0
CDe=2`13@d<;03/k>`/0<S8b2`0[:b/;02@T90/07QhN300I6AT;01@D50/0410@2`0=3@d;00X:2P/0
20P81P3oool000D0oooo2`2^[Zh;0:^[Z`/0YjNW2`2RXZ8;09^KV`/0Ti>C302:RXX;0820P0/0MWIf
2`1/K6`;065QH@/0EeMG2`1=CDd;04=3@`/0>c/k2`0b<S8;02/[:`/092@T2`0N7Qh<01TI6@/051@D
2`0@410;00d=3@/02PX:2`0820P60?ooo`001@3oool;0:j^[P/0Zj^[2`2WYjL;0::RXP/0Vi^K2`2C
Ti<<08Z:RP/0P8202`1fMWH;06a/K0/0HF5Q2`1GEeL;04e=C@/0@d=32`0k>c/;038b<P/0:b/[2`0T
92@;01hN7P`06ATI2`0D51@;010@40/03@d=2`0:2PX;00P820H0oooo00050?ooo`/0[Zj^2`2[Zj/;
0:NWY`/0XZ:R2`2KVi/;09>CT``0RXZ:2`20P80;07IfMP/0K6a/2`1QHF4;05MGE`/0CDe=2`13@d<;
03/k>`/0<S8b2`0[:b/;02@T90/07QhN300I6AT;01@D50/0410@2`0=3@d;00X:2P/020P81P3oool0
00D0oooo2`2^[Zh;0:^[Z`/0YjNW2`2RXZ8;09^KV`/0Ti>C302:RXX;0820P0/0MWIf2`1/K6`;065Q
H@/0EeMG2`1=CDd;04=3@`/0>c/k2`0b<S8;02/[:`/092@T2`0N7Qh<01TI6@/051@D2`0@410;00d=
3@/02PX:2`0820P60?ooo`001@3oool;0:j^[P/0Zj^[2`2WYjL;0::RXP/0Vi^K2`2CTi<<08Z:RP/0
P8202`1fMWH;06a/K0/0HF5Q2`1GEeL;04e=C@/0@d=32`0k>c/;038b<P/0:b/[2`0T92@;01hN7P`0
6ATI2`0D51@;010@40/03@d=2`0:2PX;00P820H0oooo00050?ooo`/0[Zj^2`2[Zj/;0:NWY`/0XZ:R
2`2KVi/;09>CT``0RXZ:2`20P80;07IfMP/0K6a/2`1QHF4;05MGE`/0CDe=2`13@d<;03/k>`/0<S8b
2`0[:b/;02@T90/07QhN300I6AT;01@D50/0410@2`0=3@d;00X:2P/020P81P3oool000D0oooo2`2^
[Zh;0:^[Z`/0YjNW2`2RXZ8;09^KV`/0Ti>C302:RXX;0820P0/0MWIf2`1/K6`;065QH@/0EeMG2`1=
CDd;04=3@`/0>c/k2`0b<S8;02/[:`/092@T2`0N7Qh<01TI6@/051@D2`0@410;00d=3@/02PX:2`08
20P60?ooo`001@3oool;0:j^[P/0Zj^[2`2WYjL;0::RXP/0Vi^K2`2CTi<<08Z:RP/0P8202`1fMWH;
06a/K0/0HF5Q2`1GEeL;04e=C@/0@d=32`0k>c/;038b<P/0:b/[2`0T92@;01hN7P`06ATI2`0D51@;
010@40/03@d=2`0:2PX;00P820H0oooo00050?ooo`/0WYjN2`2LW9`;09RHV0/0Ti>C2`2=SHd;08J6
QP`0OWin2`1eMGD;06a/K0/0HV9R2`1IFET;04m?C`/0ATI62`0m?Cd;03De=@/0;Rh^2`0W9bL;024Q
8@/06a/K300F5QH;018B4P/03`l?2`0<30`;00T92@/01`L71P3oool000D0oooo2`2NWYh;09bLW0/0
V9RH2`2CTi<;08f=S@/0QXJ6301nOWh;07EeM@/0K6a/2`1RHV8;05UIF@/0Cdm?2`16ATH;03dm?@/0
=CDe2`0^;Rh;02LW9`/08B4Q2`0K6a/<01HF5P/04Q8B2`0?3`l;00`<30/02@T92`071`L60?ooo`00
1@3oool;09jNWP/0W9bL2`2HV9P;09>CT`/0SHf=2`26QXH<07inOP/0MGEe2`1/K6`;069RHP/0FEUI
2`1?Cdl;04I6AP/0?Cdm2`0e=CD;02h^;P/09bLW2`0Q8B4;01/K6``05QHF2`0B4Q8;00l?3`/030`<
2`092@T;00L71`H0oooo00050?ooo`/0WYjN2`2LW9`;09RHV0/0Ti>C2`2=SHd;08J6QP`0OWin2`1e
MGD;06a/K0/0HV9R2`1IFET;04m?C`/0ATI62`0m?Cd;03De=@/0;Rh^2`0W9bL;024Q8@/06a/K300F
5QH;018B4P/03`l?2`0<30`;00T92@/01`L71P3oool000D0oooo2`2NWYh;09bLW0/0V9RH2`2CTi<;
08f=S@/0QXJ6301nOWh;07EeM@/0K6a/2`1RHV8;05UIF@/0Cdm?2`16ATH;03dm?@/0=CDe2`0^;Rh;
02LW9`/08B4Q2`0K6a/<01HF5P/04Q8B2`0?3`l;00`<30/02@T92`071`L60?ooo`001@3oool;09jN
WP/0W9bL2`2HV9P;09>CT`/0SHf=2`26QXH<07inOP/0MGEe2`1/K6`;069RHP/0FEUI2`1?Cdl;04I6
AP/0?Cdm2`0e=CD;02h^;P/09bLW2`0Q8B4;01/K6``05QHF2`0B4Q8;00l?3`/030`<2`092@T;00L7
1`H0oooo00050?ooo`/0WYjN2`2LW9`;09RHV0/0Ti>C2`2=SHd;08J6QP`0OWin2`1eMGD;06a/K0/0
HV9R2`1IFET;04m?C`/0ATI62`0m?Cd;03De=@/0;Rh^2`0W9bL;024Q8@/06a/K300F5QH;018B4P/0
3`l?2`0<30`;00T92@/01`L71P3oool000D0oooo2`2NWYh;09bLW0/0V9RH2`2CTi<;08f=S@/0QXJ6
301nOWh;07EeM@/0K6a/2`1RHV8;05UIF@/0Cdm?2`16ATH;03dm?@/0=CDe2`0^;Rh;02LW9`/08B4Q
2`0K6a/<01HF5P/04Q8B2`0?3`l;00`<30/02@T92`071`L60?ooo`001@3oool;09jNWP/0W9bL2`2H
V9P;09>CT`/0SHf=2`26QXH<07inOP/0MGEe2`1/K6`;069RHP/0FEUI2`1?Cdl;04I6AP/0?Cdm2`0e
=CD;02h^;P/09bLW2`0Q8B4;01/K6``05QHF2`0B4Q8;00l?3`/030`<2`092@T;00L71`H0oooo0005
0?ooo`/0WYjN2`2LW9`;09RHV0/0Ti>C2`2=SHd;08J6QP`0OWin2`1eMGD;06a/K0/0HV9R2`1IFET;
04m?C`/0ATI62`0m?Cd;03De=@/0;Rh^2`0W9bL;024Q8@/06a/K300F5QH;018B4P/03`l?2`0<30`;
00T92@/01`L71P3oool000D0oooo2`2NWYh;09bLW0/0V9RH2`2CTi<;08f=S@/0QXJ6301nOWh;07Ee
M@/0K6a/2`1RHV8;05UIF@/0Cdm?2`16ATH;03dm?@/0=CDe2`0^;Rh;02LW9`/08B4Q2`0K6a/<01HF
5P/04Q8B2`0?3`l;00`<30/02@T92`071`L60?ooo`001@3oool;08n?S`/0SHf=2`2:RXX;08F5Q@/0
Ogmo2`1iNGT<075aL@/0JFUY2`1QHF4;05UIF@/0D51@2`17AdL;03lo?`/0=cLg2`0`<30;02TY:@/0
8b<S2`0M7Ad;01PH60`051@D2`0@410;00d=3@/02PX:2`0820P;00H61PH0oooo00050?ooo`/0Shn?
2`2=SHd;08Z:RP/0QHF52`1oOgl;07UiN@`0LG5a2`1YJFT;065QH@/0FEUI2`1@D50;04M7A`/0?clo
2`0g=cL;030`<0/0:BTY2`0S8b<;01dM7@/061PH300D51@;010@40/03@d=2`0:2PX;00P820/01PH6
1P3oool000D0oooo2`2?Shl;08f=S@/0RXZ:2`25QHD;07moO`/0NGUi301aLG4;06UYJ@/0HF5Q2`1I
FET;051@D0/0AdM72`0o?cl;03Lg=`/0<30`2`0Y:BT;02<S8`/07AdM2`0H61P<01@D50/0410@2`0=
3@d;00X:2P/020P82`061PH60?ooo`001@3oool;08n?S`/0SHf=2`2:RXX;08F5Q@/0Ogmo2`1iNGT<
075aL@/0JFUY2`1QHF4;05UIF@/0D51@2`17AdL;03lo?`/0=cLg2`0`<30;02TY:@/08b<S2`0M7Ad;
01PH60`051@D2`0@410;00d=3@/02PX:2`0820P;00H61PH0oooo00050?ooo`/0Shn?2`2=SHd;08Z:
RP/0QHF52`1oOgl;07UiN@`0LG5a2`1YJFT;065QH@/0FEUI2`1@D50;04M7A`/0?clo2`0g=cL;030`
<0/0:BTY2`0S8b<;01dM7@/061PH300D51@;010@40/03@d=2`0:2PX;00P820/01PH61P3oool000D0
oooo2`2?Shl;08f=S@/0RXZ:2`25QHD;07moO`/0NGUi301aLG4;06UYJ@/0HF5Q2`1IFET;051@D0/0
AdM72`0o?cl;03Lg=`/0<30`2`0Y:BT;02<S8`/07AdM2`0H61P<01@D50/0410@2`0=3@d;00X:2P/0
20P82`061PH60?ooo`001@3oool;08n?S`/0SHf=2`2:RXX;08F5Q@/0Ogmo2`1iNGT<075aL@/0JFUY
2`1QHF4;05UIF@/0D51@2`17AdL;03lo?`/0=cLg2`0`<30;02TY:@/08b<S2`0M7Ad;01PH60`051@D
2`0@410;00d=3@/02PX:2`0820P;00H61PH0oooo00050?ooo`/0Shn?2`2=SHd;08Z:RP/0QHF52`1o
Ogl;07UiN@`0LG5a2`1YJFT;065QH@/0FEUI2`1@D50;04M7A`/0?clo2`0g=cL;030`<0/0:BTY2`0S
8b<;01dM7@/061PH300D51@;010@40/03@d=2`0:2PX;00P820/01PH61P3oool000D0oooo2`2?Shl;
08f=S@/0RXZ:2`25QHD;07moO`/0NGUi301aLG4;06UYJ@/0HF5Q2`1IFET;051@D0/0AdM72`0o?cl;
03Lg=`/0<30`2`0Y:BT;02<S8`/07AdM2`0H61P<01@D50/0410@2`0=3@d;00X:2P/020P82`061PH6
0?ooo`001@3oool;08n?S`/0SHf=2`2:RXX;08F5Q@/0Ogmo2`1iNGT<075aL@/0JFUY2`1QHF4;05UI
F@/0D51@2`17AdL;03lo?`/0=cLg2`0`<30;02TY:@/08b<S2`0M7Ad;01PH60`051@D2`0@410;00d=
3@/02PX:2`0820P;00H61PH0oooo00050?ooo`/0Shn?2`2=SHd;08Z:RP/0QHF52`1oOgl;07UiN@`0
LG5a2`1YJFT;065QH@/0FEUI2`1@D50;04M7A`/0?clo2`0g=cL;030`<0/0:BTY2`0S8b<;01dM7@/0
61PH300D51@;010@40/03@d=2`0:2PX;00P820/01PH61P3oool000D0oooo2`20P80;07inOP/0Ng]k
2`1gMgL;079bLP/0K6a/301UIFD;05iNGP/0EeMG2`1?Cdl;04M7A`/0@4102`0i>CT;038b<P/0:b/[
2`0U9BD;01lO7`/06QXJ2`0F5QH<018B4P/03Ph>2`0<30`;00T92@/01`L72`051@D60?ooo`001@3o
ool;0820P0/0OWin2`1kNg/;07MgM`/0LW9b2`1/K6`<06EUI@/0GUiN2`1GEeL;04m?C`/0AdM72`10
@40;03Ti>@/0<S8b2`0[:b/;02DU9@/07alO2`0J6QX;01HF5P`04Q8B2`0>3Ph;00`<30/02@T92`07
1`L;00D51@H0oooo00050?ooo`/0P8202`1nOWh;07]kN`/0MgMg2`1bLW8;06a/K0`0IFEU2`1NGUh;
05MGE`/0Cdm?2`17AdL;0410@0/0>CTi2`0b<S8;02/[:`/09BDU2`0O7al;01XJ6P/05QHF300B4Q8;
00h>3P/030`<2`092@T;00L71`/01@D51P3oool000D0oooo2`20P80;07inOP/0Ng]k2`1gMgL;079b
LP/0K6a/301UIFD;05iNGP/0EeMG2`1?Cdl;04M7A`/0@4102`0i>CT;038b<P/0:b/[2`0U9BD;01lO
7`/06QXJ2`0F5QH<018B4P/03Ph>2`0<30`;00T92@/01`L72`051@D60?ooo`001@3oool;0820P0/0
OWin2`1kNg/;07MgM`/0LW9b2`1/K6`<06EUI@/0GUiN2`1GEeL;04m?C`/0AdM72`10@40;03Ti>@/0
<S8b2`0[:b/;02DU9@/07alO2`0J6QX;01HF5P`04Q8B2`0>3Ph;00`<30/02@T92`071`L;00D51@H0
oooo00050?ooo`/0P8202`1nOWh;07]kN`/0MgMg2`1bLW8;06a/K0`0IFEU2`1NGUh;05MGE`/0Cdm?
2`17AdL;0410@0/0>CTi2`0b<S8;02/[:`/09BDU2`0O7al;01XJ6P/05QHF300B4Q8;00h>3P/030`<
2`092@T;00L71`/01@D51P3oool000D0oooo2`20P80;07inOP/0Ng]k2`1gMgL;079bLP/0K6a/301U
IFD;05iNGP/0EeMG2`1?Cdl;04M7A`/0@4102`0i>CT;038b<P/0:b/[2`0U9BD;01lO7`/06QXJ2`0F
5QH<018B4P/03Ph>2`0<30`;00T92@/01`L72`051@D60?ooo`001@3oool;0820P0/0OWin2`1kNg/;
07MgM`/0LW9b2`1/K6`<06EUI@/0GUiN2`1GEeL;04m?C`/0AdM72`10@40;03Ti>@/0<S8b2`0[:b/;
02DU9@/07alO2`0J6QX;01HF5P`04Q8B2`0>3Ph;00`<30/02@T92`071`L;00D51@H0oooo00050?oo
o`/0P8202`1nOWh;07]kN`/0MgMg2`1bLW8;06a/K0`0IFEU2`1NGUh;05MGE`/0Cdm?2`17AdL;0410
@0/0>CTi2`0b<S8;02/[:`/09BDU2`0O7al;01XJ6P/05QHF300B4Q8;00h>3P/030`<2`092@T;00L7
1`/01@D51P3oool000D0oooo2`20P80;07inOP/0Ng]k2`1gMgL;079bLP/0K6a/301UIFD;05iNGP/0
EeMG2`1?Cdl;04M7A`/0@4102`0i>CT;038b<P/0:b/[2`0U9BD;01lO7`/06QXJ2`0F5QH<018B4P/0
3Ph>2`0<30`;00T92@/01`L72`051@D60?ooo`001@3oool;0820P0/0OWin2`1kNg/;07MgM`/0LW9b
2`1/K6`<06EUI@/0GUiN2`1GEeL;04m?C`/0AdM72`10@40;03Ti>@/0<S8b2`0[:b/;02DU9@/07alO
2`0J6QX;01HF5P`04Q8B2`0>3Ph;00`<30/02@T92`071`L;00D51@H0oooo00050?ooo`/0LG5a2`1`
L70;06e]K@/0JFUY2`1UIFD;061PH0`0FUYJ2`1DE5@;04e=C@/0ATI62`0o?cl;03Ti>@/0<S8b2`0/
;2`;02HV9P/08B4Q2`0L71`;01LG5`/04a<C300@410;00d=3@/02PX:2`0820P;00H61P/01@D51P3o
ool000D0oooo2`1aLG4;071`L0/0KFe]2`1YJFT;06EUI@/0H61P301JFUX;05ADE0/0CDe=2`16ATH;
03lo?`/0>CTi2`0b<S8;02`/;0/09RHV2`0Q8B4;01`L70/05aLG2`0C4a<<010@40/03@d=2`0:2PX;
00P820/01PH62`051@D60?ooo`001@3oool;075aL@/0L71`2`1]KFd;06UYJ@/0IFEU2`1PH60<05YJ
FP/0E5AD2`1=CDd;04I6AP/0?clo2`0i>CT;038b<P/0;2`/2`0V9RH;024Q8@/071`L2`0G5aL;01<C
4``0410@2`0=3@d;00X:2P/020P82`061PH;00D51@H0oooo00050?ooo`/0LG5a2`1`L70;06e]K@/0
JFUY2`1UIFD;061PH0`0FUYJ2`1DE5@;04e=C@/0ATI62`0o?cl;03Ti>@/0<S8b2`0/;2`;02HV9P/0
8B4Q2`0L71`;01LG5`/04a<C300@410;00d=3@/02PX:2`0820P;00H61P/01@D51P3oool000D0oooo
2`1aLG4;071`L0/0KFe]2`1YJFT;06EUI@/0H61P301JFUX;05ADE0/0CDe=2`16ATH;03lo?`/0>CTi
2`0b<S8;02`/;0/09RHV2`0Q8B4;01`L70/05aLG2`0C4a<<010@40/03@d=2`0:2PX;00P820/01PH6
2`051@D60?ooo`001@3oool;075aL@/0L71`2`1]KFd;06UYJ@/0IFEU2`1PH60<05YJFP/0E5AD2`1=
CDd;04I6AP/0?clo2`0i>CT;038b<P/0;2`/2`0V9RH;024Q8@/071`L2`0G5aL;01<C4``0410@2`0=
3@d;00X:2P/020P82`061PH;00D51@H0oooo00050?ooo`/0LG5a2`1`L70;06e]K@/0JFUY2`1UIFD;
061PH0`0FUYJ2`1DE5@;04e=C@/0ATI62`0o?cl;03Ti>@/0<S8b2`0/;2`;02HV9P/08B4Q2`0L71`;
01LG5`/04a<C300@410;00d=3@/02PX:2`0820P;00H61P/01@D51P3oool000D0oooo2`1aLG4;071`
L0/0KFe]2`1YJFT;06EUI@/0H61P301JFUX;05ADE0/0CDe=2`16ATH;03lo?`/0>CTi2`0b<S8;02`/
;0/09RHV2`0Q8B4;01`L70/05aLG2`0C4a<<010@40/03@d=2`0:2PX;00P820/01PH62`051@D60?oo
o`001@3oool;075aL@/0L71`2`1]KFd;06UYJ@/0IFEU2`1PH60<05YJFP/0E5AD2`1=CDd;04I6AP/0
?clo2`0i>CT;038b<P/0;2`/2`0V9RH;024Q8@/071`L2`0G5aL;01<C4``0410@2`0=3@d;00X:2P/0
20P82`061PH;00D51@H0oooo00050?ooo`/0LG5a2`1`L70;06e]K@/0JFUY2`1UIFD;061PH0`0FUYJ
2`1DE5@;04e=C@/0ATI62`0o?cl;03Ti>@/0<S8b2`0/;2`;02HV9P/08B4Q2`0L71`;01LG5`/04a<C
300@410;00d=3@/02PX:2`0820P;00H61P/01@D51P3oool000D0oooo2`1aLG4;071`L0/0KFe]2`1Y
JFT;06EUI@/0H61P301JFUX;05ADE0/0CDe=2`16ATH;03lo?`/0>CTi2`0b<S8;02`/;0/09RHV2`0Q
8B4;01`L70/05aLG2`0C4a<<010@40/03@d=2`0:2PX;00P820/01PH62`051@D60?ooo`001@3oool;
06ATI0/0HV9R2`1PH60;05eMG@/0FEUI2`1DE5@<04m?C`/0BDU92`13@d<;03dm?@/0=cLg2`0b<S8;
02`/;0/09RHV2`0Q8B4;01`L70/061PH2`0D51@;014A4@`03Ph>2`0;2`/;00T92@/01`L72`051@D;
00@410H0oooo00050?ooo`/0I6AT2`1RHV8;061PH0/0GEeM2`1IFET;05ADE0`0Cdm?2`19BDT;04=3
@`/0?Cdm2`0g=cL;038b<P/0;2`/2`0V9RH;024Q8@/071`L2`0H61P;01@D50/04A4A300>3Ph;00/;
2`/02@T92`071`L;00D51@/010@41P3oool000D0oooo2`1TI6@;069RHP/0H61P2`1MGEd;05UIF@/0
E5AD301?Cdl;04U9B@/0@d=32`0m?Cd;03Lg=`/0<S8b2`0/;2`;02HV9P/08B4Q2`0L71`;01PH60/0
51@D2`0A4A4<00h>3P/02`/;2`092@T;00L71`/01@D52`0410@60?ooo`001@3oool;06ATI0/0HV9R
2`1PH60;05eMG@/0FEUI2`1DE5@<04m?C`/0BDU92`13@d<;03dm?@/0=cLg2`0b<S8;02`/;0/09RHV
2`0Q8B4;01`L70/061PH2`0D51@;014A4@`03Ph>2`0;2`/;00T92@/01`L72`051@D;00@410H0oooo
00050?ooo`/0I6AT2`1RHV8;061PH0/0GEeM2`1IFET;05ADE0`0Cdm?2`19BDT;04=3@`/0?Cdm2`0g
=cL;038b<P/0;2`/2`0V9RH;024Q8@/071`L2`0H61P;01@D50/04A4A300>3Ph;00/;2`/02@T92`07
1`L;00D51@/010@41P3oool000D0oooo2`1TI6@;069RHP/0H61P2`1MGEd;05UIF@/0E5AD301?Cdl;
04U9B@/0@d=32`0m?Cd;03Lg=`/0<S8b2`0/;2`;02HV9P/08B4Q2`0L71`;01PH60/051@D2`0A4A4<
00h>3P/02`/;2`092@T;00L71`/01@D52`0410@60?ooo`001@3oool;06ATI0/0HV9R2`1PH60;05eM
G@/0FEUI2`1DE5@<04m?C`/0BDU92`13@d<;03dm?@/0=cLg2`0b<S8;02`/;0/09RHV2`0Q8B4;01`L
70/061PH2`0D51@;014A4@`03Ph>2`0;2`/;00T92@/01`L72`051@D;00@410H0oooo00050?ooo`/0
I6AT2`1RHV8;061PH0/0GEeM2`1IFET;05ADE0`0Cdm?2`19BDT;04=3@`/0?Cdm2`0g=cL;038b<P/0
;2`/2`0V9RH;024Q8@/071`L2`0H61P;01@D50/04A4A300>3Ph;00/;2`/02@T92`071`L;00D51@/0
10@41P3oool000D0oooo2`1TI6@;069RHP/0H61P2`1MGEd;05UIF@/0E5AD301?Cdl;04U9B@/0@d=3
2`0m?Cd;03Lg=`/0<S8b2`0/;2`;02HV9P/08B4Q2`0L71`;01PH60/051@D2`0A4A4<00h>3P/02`/;
2`092@T;00L71`/01@D52`0410@60?ooo`001@3oool;06ATI0/0HV9R2`1PH60;05eMG@/0FEUI2`1D
E5@<04m?C`/0BDU92`13@d<;03dm?@/0=cLg2`0b<S8;02`/;0/09RHV2`0Q8B4;01`L70/061PH2`0D
51@;014A4@`03Ph>2`0;2`/;00T92@/01`L72`051@D;00@410H0oooo00050?ooo`/0I6AT2`1RHV8;
061PH0/0GEeM2`1IFET;05ADE0`0Cdm?2`19BDT;04=3@`/0?Cdm2`0g=cL;038b<P/0;2`/2`0V9RH;
024Q8@/071`L2`0H61P;01@D50/04A4A300>3Ph;00/;2`/02@T92`071`L;00D51@/010@41P3oool0
00D0oooo2`1FEUH;05EEE@/0De=C2`1@D50;04e=C@/0BDU93014A4@;0410@0/0>c/k2`0e=CD;030`
<0/0:b/[2`0V9RH;024Q8@/07AdM2`0I6AT;01DE5@/04A4A2`0>3Ph<00`<30/02@T92`071`L;00H6
1P/010@42`030`<60?ooo`001@3oool;05IFEP/0EEEE2`1CDe<;051@D0/0CDe=2`19BDT<04A4A0/0
@4102`0k>c/;03De=@/0<30`2`0[:b/;02HV9P/08B4Q2`0M7Ad;01TI6@/05ADE2`0A4A4;00h>3P`0
30`<2`092@T;00L71`/01PH62`0410@;00<30`H0oooo00050?ooo`/0EUIF2`1EEED;05=CD`/0D51@
2`1=CDd;04U9B@`0A4A42`10@40;03/k>`/0=CDe2`0`<30;02/[:`/09RHV2`0Q8B4;01dM7@/06ATI
2`0E5AD;014A4@/03Ph>300<30`;00T92@/01`L72`061PH;00@410/00`<31P3oool000D0oooo2`1F
EUH;05EEE@/0De=C2`1@D50;04e=C@/0BDU93014A4@;0410@0/0>c/k2`0e=CD;030`<0/0:b/[2`0V
9RH;024Q8@/07AdM2`0I6AT;01DE5@/04A4A2`0>3Ph<00`<30/02@T92`071`L;00H61P/010@42`03
0`<60?ooo`001@3oool;05IFEP/0EEEE2`1CDe<;051@D0/0CDe=2`19BDT<04A4A0/0@4102`0k>c/;
03De=@/0<30`2`0[:b/;02HV9P/08B4Q2`0M7Ad;01TI6@/05ADE2`0A4A4;00h>3P`030`<2`092@T;
00L71`/01PH62`0410@;00<30`H0oooo00050?ooo`/0EUIF2`1EEED;05=CD`/0D51@2`1=CDd;04U9
B@`0A4A42`10@40;03/k>`/0=CDe2`0`<30;02/[:`/09RHV2`0Q8B4;01dM7@/06ATI2`0E5AD;014A
4@/03Ph>300<30`;00T92@/01`L72`061PH;00@410/00`<31P3oool000D0oooo2`1FEUH;05EEE@/0
De=C2`1@D50;04e=C@/0BDU93014A4@;0410@0/0>c/k2`0e=CD;030`<0/0:b/[2`0V9RH;024Q8@/0
7AdM2`0I6AT;01DE5@/04A4A2`0>3Ph<00`<30/02@T92`071`L;00H61P/010@42`030`<60?ooo`00
1@3oool;05IFEP/0EEEE2`1CDe<;051@D0/0CDe=2`19BDT<04A4A0/0@4102`0k>c/;03De=@/0<30`
2`0[:b/;02HV9P/08B4Q2`0M7Ad;01TI6@/05ADE2`0A4A4;00h>3P`030`<2`092@T;00L71`/01PH6
2`0410@;00<30`H0oooo00050?ooo`/0EUIF2`1EEED;05=CD`/0D51@2`1=CDd;04U9B@`0A4A42`10
@40;03/k>`/0=CDe2`0`<30;02/[:`/09RHV2`0Q8B4;01dM7@/06ATI2`0E5AD;014A4@/03Ph>300<
30`;00T92@/01`L72`061PH;00@410/00`<31P3oool000D0oooo2`1FEUH;05EEE@/0De=C2`1@D50;
04e=C@/0BDU93014A4@;0410@0/0>c/k2`0e=CD;030`<0/0:b/[2`0V9RH;024Q8@/07AdM2`0I6AT;
01DE5@/04A4A2`0>3Ph<00`<30/02@T92`071`L;00H61P/010@42`030`<60?ooo`001@3oool;05IF
EP/0EEEE2`1CDe<;051@D0/0CDe=2`19BDT<04A4A0/0@4102`0k>c/;03De=@/0<30`2`0[:b/;02HV
9P/08B4Q2`0M7Ad;01TI6@/05ADE2`0A4A4;00h>3P`030`<2`092@T;00L71`/01PH62`0410@;00<3
0`H0oooo00050?ooo`/0BTY:2`19BDT;04M7A`/0ADE52`12@T8;03lo?``0>c/k2`0g=cL;038b<P/0
;Rh^2`0Y:BT;02DU9@/08B4Q2`0L71`;01TI6@/05ADE2`0B4Q8;00l?3`/030`<300:2PX;00P820/0
1PH62`051@D;00@410/00`<31P3oool000D0oooo2`1:BTX;04U9B@/0AdM72`15ADD;0492@P/0?clo
300k>c/;03Lg=`/0<S8b2`0^;Rh;02TY:@/09BDU2`0Q8B4;01`L70/06ATI2`0E5AD;018B4P/03`l?
2`0<30`<00X:2P/020P82`061PH;00D51@/010@42`030`<60?ooo`001@3oool;04Y:BP/0BDU92`17
AdL;04E5A@/0@T922`0o?cl<03/k>`/0=cLg2`0b<S8;02h^;P/0:BTY2`0U9BD;024Q8@/071`L2`0I
6AT;01DE5@/04Q8B2`0?3`l;00`<30`02PX:2`0820P;00H61P/01@D52`0410@;00<30`H0oooo0005
0?ooo`/0BTY:2`19BDT;04M7A`/0ADE52`12@T8;03lo?``0>c/k2`0g=cL;038b<P/0;Rh^2`0Y:BT;
02DU9@/08B4Q2`0L71`;01TI6@/05ADE2`0B4Q8;00l?3`/030`<300:2PX;00P820/01PH62`051@D;
00@410/00`<31P3oool000D0oooo2`1:BTX;04U9B@/0AdM72`15ADD;0492@P/0?clo300k>c/;03Lg
=`/0<S8b2`0^;Rh;02TY:@/09BDU2`0Q8B4;01`L70/06ATI2`0E5AD;018B4P/03`l?2`0<30`<00X:
2P/020P82`061PH;00D51@/010@42`030`<60?ooo`001@3oool;04Y:BP/0BDU92`17AdL;04E5A@/0
@T922`0o?cl<03/k>`/0=cLg2`0b<S8;02h^;P/0:BTY2`0U9BD;024Q8@/071`L2`0I6AT;01DE5@/0
4Q8B2`0?3`l;00`<30`02PX:2`0820P;00H61P/01@D52`0410@;00<30`H0oooo00050?ooo`/0BTY:
2`19BDT;04M7A`/0ADE52`12@T8;03lo?``0>c/k2`0g=cL;038b<P/0;Rh^2`0Y:BT;02DU9@/08B4Q
2`0L71`;01TI6@/05ADE2`0B4Q8;00l?3`/030`<300:2PX;00P820/01PH62`051@D;00@410/00`<3
1P3oool000D0oooo2`1:BTX;04U9B@/0AdM72`15ADD;0492@P/0?clo300k>c/;03Lg=`/0<S8b2`0^
;Rh;02TY:@/09BDU2`0Q8B4;01`L70/06ATI2`0E5AD;018B4P/03`l?2`0<30`<00X:2P/020P82`06
1PH;00D51@/010@42`030`<60?ooo`001@3oool;04Y:BP/0BDU92`17AdL;04E5A@/0@T922`0o?cl<
03/k>`/0=cLg2`0b<S8;02h^;P/0:BTY2`0U9BD;024Q8@/071`L2`0I6AT;01DE5@/04Q8B2`0?3`l;
00`<30`02PX:2`0820P;00H61P/01@D52`0410@;00<30`H0oooo00050?ooo`/0BTY:2`19BDT;04M7
A`/0ADE52`12@T8;03lo?``0>c/k2`0g=cL;038b<P/0;Rh^2`0Y:BT;02DU9@/08B4Q2`0L71`;01TI
6@/05ADE2`0B4Q8;00l?3`/030`<300:2PX;00P820/01PH62`051@D;00@410/00`<31P3oool000D0
oooo2`1:BTX;04U9B@/0AdM72`15ADD;0492@P/0?clo300k>c/;03Lg=`/0<S8b2`0^;Rh;02TY:@/0
9BDU2`0Q8B4;01`L70/06ATI2`0E5AD;018B4P/03`l?2`0<30`<00X:2P/020P82`061PH;00D51@/0
10@42`030`<60?ooo`001@3oool;03lo?`/0?Shn2`0m?Cd;03/k>`/0>3Ph2`0e=CD<038b<P/0;Rh^
2`0[:b/;02LW9`/08b<S2`0O7al;01`L70/061PH2`0E5AD;018B4P/03`l?2`0=3@d;00X:2P`020P8
2`071`L;00D51@/010@42`030`<;00820PH0oooo00050?ooo`/0?clo2`0n?Sh;03dm?@/0>c/k2`0h
>3P;03De=@`0<S8b2`0^;Rh;02/[:`/09bLW2`0S8b<;01lO7`/071`L2`0H61P;01DE5@/04Q8B2`0?
3`l;00d=3@/02PX:300820P;00L71`/01@D52`0410@;00<30`/00P821P3oool000D0oooo2`0o?cl;
03hn?P/0?Cdm2`0k>c/;03Ph>0/0=CDe300b<S8;02h^;P/0:b/[2`0W9bL;02<S8`/07alO2`0L71`;
01PH60/05ADE2`0B4Q8;00l?3`/03@d=2`0:2PX<00P820/01`L72`051@D;00@410/00`<32`020P86
0?ooo`001@3oool;03lo?`/0?Shn2`0m?Cd;03/k>`/0>3Ph2`0e=CD<038b<P/0;Rh^2`0[:b/;02LW
9`/08b<S2`0O7al;01`L70/061PH2`0E5AD;018B4P/03`l?2`0=3@d;00X:2P`020P82`071`L;00D5
1@/010@42`030`<;00820PH0oooo00050?ooo`/0?clo2`0n?Sh;03dm?@/0>c/k2`0h>3P;03De=@`0
<S8b2`0^;Rh;02/[:`/09bLW2`0S8b<;01lO7`/071`L2`0H61P;01DE5@/04Q8B2`0?3`l;00d=3@/0
2PX:300820P;00L71`/01@D52`0410@;00<30`/00P821P3oool000D0oooo2`0o?cl;03hn?P/0?Cdm
2`0k>c/;03Ph>0/0=CDe300b<S8;02h^;P/0:b/[2`0W9bL;02<S8`/07alO2`0L71`;01PH60/05ADE
2`0B4Q8;00l?3`/03@d=2`0:2PX<00P820/01`L72`051@D;00@410/00`<32`020P860?ooo`001@3o
ool;03lo?`/0?Shn2`0m?Cd;03/k>`/0>3Ph2`0e=CD<038b<P/0;Rh^2`0[:b/;02LW9`/08b<S2`0O
7al;01`L70/061PH2`0E5AD;018B4P/03`l?2`0=3@d;00X:2P`020P82`071`L;00D51@/010@42`03
0`<;00820PH0oooo00050?ooo`/0?clo2`0n?Sh;03dm?@/0>c/k2`0h>3P;03De=@`0<S8b2`0^;Rh;
02/[:`/09bLW2`0S8b<;01lO7`/071`L2`0H61P;01DE5@/04Q8B2`0?3`l;00d=3@/02PX:300820P;
00L71`/01@D52`0410@;00<30`/00P821P3oool000D0oooo2`0o?cl;03hn?P/0?Cdm2`0k>c/;03Ph
>0/0=CDe300b<S8;02h^;P/0:b/[2`0W9bL;02<S8`/07alO2`0L71`;01PH60/05ADE2`0B4Q8;00l?
3`/03@d=2`0:2PX<00P820/01`L72`051@D;00@410/00`<32`020P860?ooo`001@3oool;03lo?`/0
?Shn2`0m?Cd;03/k>`/0>3Ph2`0e=CD<038b<P/0;Rh^2`0[:b/;02LW9`/08b<S2`0O7al;01`L70/0
61PH2`0E5AD;018B4P/03`l?2`0=3@d;00X:2P`020P82`071`L;00D51@/010@42`030`<;00820PH0
oooo00050?ooo`/0?clo2`0n?Sh;03dm?@/0>c/k2`0h>3P;03De=@`0<S8b2`0^;Rh;02/[:`/09bLW
2`0S8b<;01lO7`/071`L2`0H61P;01DE5@/04Q8B2`0?3`l;00d=3@/02PX:300820P;00L71`/01@D5
2`0410@;00<30`/00P821P3oool000D0oooo5P0e=CD;03<c<`/0<S8b2`0_;bl;02d];@`0:RXZ2`0W
9bL;02@T90/08B4Q2`0M7Ad;01XJ6P/05aLG2`0D51@;014A4@/03`l?2`0=3@d;00X:2P/02@T93007
1`L;00D51@/010@42`030`<F00820PH0oooo00050?oooaH0=CDe2`0c<c<;038b<P/0;bl_2`0];Bd<
02XZ:P/09bLW2`0T92@;024Q8@/07AdM2`0J6QX;01LG5`/051@D2`0A4A4;00l?3`/03@d=2`0:2PX;
00T92@`01`L72`051@D;00@410/00`<35P020P860?ooo`001@3ooolF03De=@/0<c<c2`0b<S8;02l_
;`/0;Bd]300Z:RX;02LW9`/092@T2`0Q8B4;01dM7@/06QXJ2`0G5aL;01@D50/04A4A2`0?3`l;00d=
3@/02PX:2`092@T<00L71`/01@D52`0410@;00<30aH00P821P3oool000D0oooo5P0e=CD;03<c<`/0
<S8b2`0_;bl;02d];@`0:RXZ2`0W9bL;02@T90/08B4Q2`0M7Ad;01XJ6P/05aLG2`0D51@;014A4@/0
3`l?2`0=3@d;00X:2P/02@T930071`L;00D51@/010@42`030`<F00820PH0oooo00050?oooaH0=CDe
2`0c<c<;038b<P/0;bl_2`0];Bd<02XZ:P/09bLW2`0T92@;024Q8@/07AdM2`0J6QX;01LG5`/051@D
2`0A4A4;00l?3`/03@d=2`0:2PX;00T92@`01`L72`051@D;00@410/00`<35P020P860?ooo`001@3o
oolF03De=@/0<c<c2`0b<S8;02l_;`/0;Bd]300Z:RX;02LW9`/092@T2`0Q8B4;01dM7@/06QXJ2`0G
5aL;01@D50/04A4A2`0?3`l;00d=3@/02PX:2`092@T<00L71`/01@D52`0410@;00<30aH00P821P3o
ool000D0oooo5P0e=CD;03<c<`/0<S8b2`0_;bl;02d];@`0:RXZ2`0W9bL;02@T90/08B4Q2`0M7Ad;
01XJ6P/05aLG2`0D51@;014A4@/03`l?2`0=3@d;00X:2P/02@T930071`L;00D51@/010@42`030`<F
00820PH0oooo00050?oooaH0=CDe2`0c<c<;038b<P/0;bl_2`0];Bd<02XZ:P/09bLW2`0T92@;024Q
8@/07AdM2`0J6QX;01LG5`/051@D2`0A4A4;00l?3`/03@d=2`0:2PX;00T92@`01`L72`051@D;00@4
10/00`<35P020P860?ooo`001@3ooolF03De=@/0<c<c2`0b<S8;02l_;`/0;Bd]300Z:RX;02LW9`/0
92@T2`0Q8B4;01dM7@/06QXJ2`0G5aL;01@D50/04A4A2`0?3`l;00d=3@/02PX:2`092@T<00L71`/0
1@D52`0410@;00<30aH00P821P3oool000D0oooo5P0e=CD;03<c<`/0<S8b2`0_;bl;02d];@`0:RXZ
2`0W9bL;02@T90/08B4Q2`0M7Ad;01XJ6P/05aLG2`0D51@;014A4@/03`l?2`0=3@d;00X:2P/02@T9
30071`L;00D51@/010@42`030`<F00820PH0oooo00050?oooaH0=CDe2`0c<c<;038b<P/0;bl_2`0]
;Bd<02XZ:P/09bLW2`0T92@;024Q8@/07AdM2`0J6QX;01LG5`/051@D2`0A4A4;00l?3`/03@d=2`0:
2PX;00T92@`01`L72`051@D;00@410/00`<35P020P860?ooo`001@3ooolF02`/;0/0:b/[2`0Y:BT;
02LW9`/09BDU300S8b<;024Q8@/07QhN2`0K6a/;01PH60/05QHF2`0C4a<;014A4@/03Ph>2`0<30`;
00X:2P/02@T92`071`L<00H61P/010@42`030`<F00820P/00@411P3oool000D0oooo5P0/;2`;02/[
:`/0:BTY2`0W9bL;02DU9@`08b<S2`0Q8B4;01hN7P/06a/K2`0H61P;01HF5P/04a<C2`0A4A4;00h>
3P/030`<2`0:2PX;00T92@/01`L730061PH;00@410/00`<35P020P8;00410@H0oooo00050?oooaH0
;2`/2`0[:b/;02TY:@/09bLW2`0U9BD<02<S8`/08B4Q2`0N7Qh;01/K6`/061PH2`0F5QH;01<C4`/0
4A4A2`0>3Ph;00`<30/02PX:2`092@T;00L71``01PH62`0410@;00<30aH00P822`010@460?ooo`00
1@3ooolF02`/;0/0:b/[2`0Y:BT;02LW9`/09BDU300S8b<;024Q8@/07QhN2`0K6a/;01PH60/05QHF
2`0C4a<;014A4@/03Ph>2`0<30`;00X:2P/02@T92`071`L<00H61P/010@42`030`<F00820P/00@41
1P3oool000D0oooo5P0/;2`;02/[:`/0:BTY2`0W9bL;02DU9@`08b<S2`0Q8B4;01hN7P/06a/K2`0H
61P;01HF5P/04a<C2`0A4A4;00h>3P/030`<2`0:2PX;00T92@/01`L730061PH;00@410/00`<35P02
0P8;00410@H0oooo00050?oooaH0;2`/2`0[:b/;02TY:@/09bLW2`0U9BD<02<S8`/08B4Q2`0N7Qh;
01/K6`/061PH2`0F5QH;01<C4`/04A4A2`0>3Ph;00`<30/02PX:2`092@T;00L71``01PH62`0410@;
00<30aH00P822`010@460?ooo`001@3ooolF02`/;0/0:b/[2`0Y:BT;02LW9`/09BDU300S8b<;024Q
8@/07QhN2`0K6a/;01PH60/05QHF2`0C4a<;014A4@/03Ph>2`0<30`;00X:2P/02@T92`071`L<00H6
1P/010@42`030`<F00820P/00@411P3oool000D0oooo5P0/;2`;02/[:`/0:BTY2`0W9bL;02DU9@`0
8b<S2`0Q8B4;01hN7P/06a/K2`0H61P;01HF5P/04a<C2`0A4A4;00h>3P/030`<2`0:2PX;00T92@/0
1`L730061PH;00@410/00`<35P020P8;00410@H0oooo00050?oooaH0;2`/2`0[:b/;02TY:@/09bLW
2`0U9BD<02<S8`/08B4Q2`0N7Qh;01/K6`/061PH2`0F5QH;01<C4`/04A4A2`0>3Ph;00`<30/02PX:
2`092@T;00L71``01PH62`0410@;00<30aH00P822`010@460?ooo`001@3ooolF02`/;0/0:b/[2`0Y
:BT;02LW9`/09BDU300S8b<;024Q8@/07QhN2`0K6a/;01PH60/05QHF2`0C4a<;014A4@/03Ph>2`0<
30`;00X:2P/02@T92`071`L<00H61P/010@42`030`<F00820P/00@411P3oool000D0oooo5P0/;2`;
02/[:`/0:BTY2`0W9bL;02DU9@`08b<S2`0Q8B4;01hN7P/06a/K2`0H61P;01HF5P/04a<C2`0A4A4;
00h>3P/030`<2`0:2PX;00T92@/01`L730061PH;00@410/00`<35P020P8;00410@H0oooo00050?oo
o`/09BDU2`0T92@;02<S8`/08R8R2`0Q8B4;01lO7``07AdM2`0K6a/;01TI6@/05QHF2`0D51@;018B
4P/0410@2`0>3Ph;00`<30/02PX:2`0820P;00L71`/01PH6300410@F00<30`/00P825P010@460?oo
o`001@3oool;02DU9@/092@T2`0S8b<;028R8P/08B4Q2`0O7al<01dM7@/06a/K2`0I6AT;01HF5P/0
51@D2`0B4Q8;010@40/03Ph>2`0<30`;00X:2P/020P82`071`L;00H61P`010@45P030`<;00820QH0
0@411P3oool000D0oooo2`0U9BD;02@T90/08b<S2`0R8R8;024Q8@/07alO300M7Ad;01/K6`/06ATI
2`0F5QH;01@D50/04Q8B2`0@410;00h>3P/030`<2`0:2PX;00P820/01`L72`061PH<00@411H00`<3
2`020P8F00410@H0oooo00050?ooo`/09BDU2`0T92@;02<S8`/08R8R2`0Q8B4;01lO7``07AdM2`0K
6a/;01TI6@/05QHF2`0D51@;018B4P/0410@2`0>3Ph;00`<30/02PX:2`0820P;00L71`/01PH63004
10@F00<30`/00P825P010@460?ooo`001@3oool;02DU9@/092@T2`0S8b<;028R8P/08B4Q2`0O7al<
01dM7@/06a/K2`0I6AT;01HF5P/051@D2`0B4Q8;010@40/03Ph>2`0<30`;00X:2P/020P82`071`L;
00H61P`010@45P030`<;00820QH00@411P3oool000D0oooo2`0U9BD;02@T90/08b<S2`0R8R8;024Q
8@/07alO300M7Ad;01/K6`/06ATI2`0F5QH;01@D50/04Q8B2`0@410;00h>3P/030`<2`0:2PX;00P8
20/01`L72`061PH<00@411H00`<32`020P8F00410@H0oooo00050?ooo`/09BDU2`0T92@;02<S8`/0
8R8R2`0Q8B4;01lO7``07AdM2`0K6a/;01TI6@/05QHF2`0D51@;018B4P/0410@2`0>3Ph;00`<30/0
2PX:2`0820P;00L71`/01PH6300410@F00<30`/00P825P010@460?ooo`001@3oool;02DU9@/092@T
2`0S8b<;028R8P/08B4Q2`0O7al<01dM7@/06a/K2`0I6AT;01HF5P/051@D2`0B4Q8;010@40/03Ph>
2`0<30`;00X:2P/020P82`071`L;00H61P`010@45P030`<;00820QH00@411P3oool000D0oooo2`0U
9BD;02@T90/08b<S2`0R8R8;024Q8@/07alO300M7Ad;01/K6`/06ATI2`0F5QH;01@D50/04Q8B2`0@
410;00h>3P/030`<2`0:2PX;00P820/01`L72`061PH<00@411H00`<32`020P8F00410@H0oooo0005
0?ooo`/09BDU2`0T92@;02<S8`/08R8R2`0Q8B4;01lO7``07AdM2`0K6a/;01TI6@/05QHF2`0D51@;
018B4P/0410@2`0>3Ph;00`<30/02PX:2`0820P;00L71`/01PH6300410@F00<30`/00P825P010@46
0?ooo`001@3oool;02DU9@/092@T2`0S8b<;028R8P/08B4Q2`0O7al<01dM7@/06a/K2`0I6AT;01HF
5P/051@D2`0B4Q8;010@40/03Ph>2`0<30`;00X:2P/020P82`071`L;00H61P`010@45P030`<;0082
0QH00@411P3oool000D0oooo2`0N7QhF01dM7@/071`L2`0K6a/;01TI6@`061PH2`0F5QH;01@D50/0
4Q8B2`0@410;00h>3P/03@d=2`0;2`/;00T92@/020P82`071`L;00D51@/010@45`030`<;00820QH0
0@412`0000060?ooo`001@3oool;01hN7QH07AdM2`0L71`;01/K6`/06ATI300H61P;01HF5P/051@D
2`0B4Q8;010@40/03Ph>2`0=3@d;00/;2`/02@T92`0820P;00L71`/01@D52`0410@G00<30`/00P82
5P010@4;000000H0oooo00050?ooo`/07QhN5P0M7Ad;01`L70/06a/K2`0I6AT<01PH60/05QHF2`0D
51@;018B4P/0410@2`0>3Ph;00d=3@/02`/;2`092@T;00P820/01`L72`051@D;00@411L00`<32`02
0P8F00410@/000001P3oool000D0oooo2`0N7QhF01dM7@/071`L2`0K6a/;01TI6@`061PH2`0F5QH;
01@D50/04Q8B2`0@410;00h>3P/03@d=2`0;2`/;00T92@/020P82`071`L;00D51@/010@45`030`<;
00820QH00@412`0000060?ooo`001@3oool;01hN7QH07AdM2`0L71`;01/K6`/06ATI300H61P;01HF
5P/051@D2`0B4Q8;010@40/03Ph>2`0=3@d;00/;2`/02@T92`0820P;00L71`/01@D52`0410@G00<3
0`/00P825P010@4;000000H0oooo00050?ooo`/07QhN5P0M7Ad;01`L70/06a/K2`0I6AT<01PH60/0
5QHF2`0D51@;018B4P/0410@2`0>3Ph;00d=3@/02`/;2`092@T;00P820/01`L72`051@D;00@411L0
0`<32`020P8F00410@/000001P3oool000D0oooo2`0N7QhF01dM7@/071`L2`0K6a/;01TI6@`061PH
2`0F5QH;01@D50/04Q8B2`0@410;00h>3P/03@d=2`0;2`/;00T92@/020P82`071`L;00D51@/010@4
5`030`<;00820QH00@412`0000060?ooo`001@3oool;01hN7QH07AdM2`0L71`;01/K6`/06ATI300H
61P;01HF5P/051@D2`0B4Q8;010@40/03Ph>2`0=3@d;00/;2`/02@T92`0820P;00L71`/01@D52`04
10@G00<30`/00P825P010@4;000000H0oooo00050?ooo`/07QhN5P0M7Ad;01`L70/06a/K2`0I6AT<
01PH60/05QHF2`0D51@;018B4P/0410@2`0>3Ph;00d=3@/02`/;2`092@T;00P820/01`L72`051@D;
00@411L00`<32`020P8F00410@/000001P3oool000D0oooo2`0N7QhF01dM7@/071`L2`0K6a/;01TI
6@`061PH2`0F5QH;01@D50/04Q8B2`0@410;00h>3P/03@d=2`0;2`/;00T92@/020P82`071`L;00D5
1@/010@45`030`<;00820QH00@412`0000060?ooo`001@3oool;01hN7QH07AdM2`0L71`;01/K6`/0
6ATI300H61P;01HF5P/051@D2`0B4Q8;010@40/03Ph>2`0=3@d;00/;2`/02@T92`0820P;00L71`/0
1@D52`0410@G00<30`/00P825P010@4;000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE
2`0D51@<01<C4`/04Q8B2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D5
2`0410@G00<30`/00P825P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D
51@<01<C4`/04Q8B2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`04
10@G00<30`/00P825P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<
01<C4`/04Q8B2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G
00<30`/00P825P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C
4`/04Q8B2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<3
0`/00P825P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/0
4Q8B2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/0
0P825P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B
2`0@410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P82
5P010@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B2`0@
410;00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P825P01
0@4F000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B2`0@410;
00l?3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P825P010@4F
000000H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B2`0@410;00l?
3`/03@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P825P010@4F0000
00H0oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B2`0@410;00l?3`/0
3@d=2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P825P010@4F000000H0
oooo00050?oooaH061PH2`0G5aL;01HF5P/05ADE2`0D51@<01<C4`/04Q8B2`0@410;00l?3`/03@d=
2`0<30`;00X:2P/02@T92`071`L;00H61P/01@D52`0410@G00<30`/00P825P010@4F000000H0oooo
00050?oooaH04a<C5P0B4Q8;014A4@/0410@300?3`l;00h>3P/03@d=2`0<30`;00X:2P/02@T92`08
20P;00L71`/01PH62`051@D;00@410/00`<35`020P8F00410B4000001P3oool000D0oooo5P0C4a<F
018B4P/04A4A2`0@410<00l?3`/03Ph>2`0=3@d;00`<30/02PX:2`092@T;00P820/01`L72`061PH;
00D51@/010@42`030`<G00820QH00@418@0000060?ooo`001@3ooolF01<C4aH04Q8B2`0A4A4;010@
40`03`l?2`0>3Ph;00d=3@/030`<2`0:2PX;00T92@/020P82`071`L;00H61P/01@D52`0410@;00<3
0aL00P825P010@4Q000000H0oooo00050?oooaH04a<C5P0B4Q8;014A4@/0410@300?3`l;00h>3P/0
3@d=2`0<30`;00X:2P/02@T92`0820P;00L71`/01PH62`051@D;00@410/00`<35`020P8F00410B40
00001P3oool000D0oooo5P0C4a<F018B4P/04A4A2`0@410<00l?3`/03Ph>2`0=3@d;00`<30/02PX:
2`092@T;00P820/01`L72`061PH;00D51@/010@42`030`<G00820QH00@418@0000060?ooo`001@3o
oolF01<C4aH04Q8B2`0A4A4;010@40`03`l?2`0>3Ph;00d=3@/030`<2`0:2PX;00T92@/020P82`07
1`L;00H61P/01@D52`0410@;00<30aL00P825P010@4Q000000H0oooo00050?oooaH04a<C5P0B4Q8;
014A4@/0410@300?3`l;00h>3P/03@d=2`0<30`;00X:2P/02@T92`0820P;00L71`/01PH62`051@D;
00@410/00`<35`020P8F00410B4000001P3oool000D0oooo5P0C4a<F018B4P/04A4A2`0@410<00l?
3`/03Ph>2`0=3@d;00`<30/02PX:2`092@T;00P820/01`L72`061PH;00D51@/010@42`030`<G0082
0QH00@418@0000060?ooo`001@3ooolF01<C4aH04Q8B2`0A4A4;010@40`03`l?2`0>3Ph;00d=3@/0
30`<2`0:2PX;00T92@/020P82`071`L;00H61P/01@D52`0410@;00<30aL00P825P010@4Q000000H0
oooo00050?oooaH04a<C5P0B4Q8;014A4@/0410@300?3`l;00h>3P/03@d=2`0<30`;00X:2P/02@T9
2`0820P;00L71`/01PH62`051@D;00@410/00`<35`020P8F00410B4000001P3oool000D0oooo5P0C
4a<F018B4P/04A4A2`0@410<00l?3`/03Ph>2`0=3@d;00`<30/02PX:2`092@T;00P820/01`L72`06
1PH;00D51@/010@42`030`<G00820QH00@418@0000060?ooo`001@3ooolF00l?3aH03Ph>5P0=3@d<
00`<30/02`/;2`0:2PX;00T92@/020P82`071`L;00H61P/01@D55P0410@;00<30aH00P825`010@4/
000000H0oooo00050?oooaH03`l?5P0>3PhF00d=3@`030`<2`0;2`/;00X:2P/02@T92`0820P;00L7
1`/01PH62`051@DF00@410/00`<35P020P8G00410B`000001P3oool000D0oooo5P0?3`lF00h>3QH0
3@d=300<30`;00/;2`/02PX:2`092@T;00P820/01`L72`061PH;00D51AH010@42`030`<F00820QL0
0@41;00000060?ooo`001@3ooolF00l?3aH03Ph>5P0=3@d<00`<30/02`/;2`0:2PX;00T92@/020P8
2`071`L;00H61P/01@D55P0410@;00<30aH00P825`010@4/000000H0oooo00050?oooaH03`l?5P0>
3PhF00d=3@`030`<2`0;2`/;00X:2P/02@T92`0820P;00L71`/01PH62`051@DF00@410/00`<35P02
0P8G00410B`000001P3oool000D0oooo5P0?3`lF00h>3QH03@d=300<30`;00/;2`/02PX:2`092@T;
00P820/01`L72`061PH;00D51AH010@42`030`<F00820QL00@41;00000060?ooo`001@3ooolF00l?
3aH03Ph>5P0=3@d<00`<30/02`/;2`0:2PX;00T92@/020P82`071`L;00H61P/01@D55P0410@;00<3
0aH00P825`010@4/000000H0oooo00050?oooaH03`l?5P0>3PhF00d=3@`030`<2`0;2`/;00X:2P/0
2@T92`0820P;00L71`/01PH62`051@DF00@410/00`<35P020P8G00410B`000001P3oool000D0oooo
5P0?3`lF00h>3QH03@d=300<30`;00/;2`/02PX:2`092@T;00P820/01`L72`061PH;00D51AH010@4
2`030`<F00820QL00@41;00000060?ooo`001@3ooolF00l?3aH03Ph>5P0=3@d<00`<30/02`/;2`0:
2PX;00T92@/020P82`071`L;00H61P/01@D55P0410@;00<30aH00P825`010@4/000000H0oooo0005
0?oooaH03`l?5P0>3PhF00d=3@`030`<2`0;2`/;00X:2P/02@T92`0820P;00L71`/01PH62`051@DF
00@410/00`<35P020P8G00410B`000001P3oool000D0oooo5P0<30`F00/;2aH02PX:30092@TF00P8
20/01`L72`061PHF00D51@/010@45P030`<F00820QL00@41=`0000060?ooo`001@3ooolF00`<31H0
2`/;5P0:2PX<00T92AH020P82`071`L;00H61QH01@D52`0410@F00<30aH00P825`010@4g000000H0
oooo00050?oooaH030`<5P0;2`/F00X:2P`02@T95P0820P;00L71`/01PH65P051@D;00@411H00`<3
5P020P8G00410CL000001P3oool000D0oooo5P0<30`F00/;2aH02PX:30092@TF00P820/01`L72`06
1PHF00D51@/010@45P030`<F00820QL00@41=`0000060?ooo`001@3ooolF00`<31H02`/;5P0:2PX<
00T92AH020P82`071`L;00H61QH01@D52`0410@F00<30aH00P825`010@4g000000H0oooo00050?oo
oaH030`<5P0;2`/F00X:2P`02@T95P0820P;00L71`/01PH65P051@D;00@411H00`<35P020P8G0041
0CL000001P3oool000D0oooo5P0<30`F00/;2aH02PX:30092@TF00P820/01`L72`061PHF00D51@/0
10@45P030`<F00820QL00@41=`0000060?ooo`001@3ooolF00`<31H02`/;5P0:2PX<00T92AH020P8
2`071`L;00H61QH01@D52`0410@F00<30aH00P825`010@4g000000H0oooo00050?oooaH030`<5P0;
2`/F00X:2P`02@T95P0820P;00L71`/01PH65P051@D;00@411H00`<35P020P8G00410CL000001P3o
ool000D0oooo5P0<30`F00/;2aH02PX:30092@TF00P820/01`L72`061PHF00D51@/010@45P030`<F
00820QL00@41=`0000060?ooo`001@3ooolF00`<31H02`/;5P0:2PX<00T92AH020P82`071`L;00H6
1QH01@D52`0410@F00<30aH00P825`010@4g000000H0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.500131, -0.500131, 0.0905933, \
0.0905933}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  DensityGraphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell["", "Answer"],

Cell[CellGroupData[{

Cell["Convolution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A common and important application of the FT is doing ",
  StyleBox["convolutions",
    FontSlant->"Italic"],
  ". The basic idea is that integrals of the form ",
  Cell[BoxData[
      \(TraditionalForm\`g(
          x) = \[Integral]\(\(f(y)\)\ \(k(y - x)\)\) \[DifferentialD]y\)]],
  " can be evaluated simply by multiplying the FTs of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  Convolutions are used extensively, for example, in smoothing data. "
}], "Text"],

Cell[TextData[{
  "The following code takes the product of the FTs, removes the small \
imaginary components using ",
  StyleBox["Chop", "InlineInputTraditionalForm"],
  " and then applies ",
  StyleBox["InverseFourier", "InlineInputTraditionalForm"],
  " to the result:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalSigma](k_) := 
        InverseFourier[
          Chop[Fourier[\[ScriptN]\[ScriptCapitalE]]\ Fourier[\[Sigma](
                  k)]]];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  " In effect this performs the integral convolution, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(\(f(y)\)\ \(k(
              y - x)\)\) \[DifferentialD]y\)]],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Visualize ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma](k)\)], "InlineInputTraditionalForm"],
     "InlineInputTraditionalForm"],
  " for various values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " using ",
  StyleBox["ListPlot3D", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["ListDensityPlot", "InlineInputTraditionalForm"],
  ". Describe the general trends that you observe."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(ListDensityPlot[\[LeftBracketingBar]\[CapitalSigma](
            1000)\[RightBracketingBar]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
1415160B06150D060707130609110C04050A0E0E0C0D0D1409
0F0D0E131104020A02080E160711040414140406100A011408
020A1002100A10110E01110D0913090A0C0114111514110E00
0C0B05061411000101160B0F04091614140C0F16171215000D
0F070F0F0A0F05060A130D1403130A150D13091511150D0B0A
041404020C03150E080713050513140E0A0D15130C170D0D0F
14050B0500060308F6F2D3FCFCF5F9EF0C0E0E03090416030C
160C140B08070605ECE1F2E8F9E7D4F4140504160305160B02
1013161200030500DAF5DBF3F6F4E7F20E11030A00110F0E08
140F090E05010D15F9E4E9090E151011160001021207091110
0E16090C060D0A05DDE0EA0A0800020D0E141108010C160109
0C090C0602031005D7D5F0D3EEEEE4DB0A0B120B010A06000C
02030F0D10020207F6FDE5D3DBEADAE100040410090C13060B
061210040D060E03F8DEDBE5E2D6FAFF1608160A0F0B06160E
070005151508150EF5D9F0130B080A14150A030A0A13041205
030C1003120A080DFED7FA100903141304160C0D0004070E13
0E010415120C0E16FEFEF4DFEBFEEFF9050B10041503080810
141207140F0A0714DCEDD4E9DFFDD9FD02140B141206020E10
09120B15170C090BE5F5DDE9EAEFE0FF001006111204010A0E
080C0B0E011316050F1202130C040402070D07081208140004
120D08130E0E090A150702120411160C0D03091001000D0B05
09000E0D110D120F020C0E03080B150C11140F09040F131312
080A0916110E01020715150C03160E07010E12140912150F05
0F0A0F0A070A0913080C140607020A0E00070D110508140B02
03120112080E010D130A0E0206160614080C0B08160A001104
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001@3oool;01@D50/05ADE2`0F5QH;00/;2`/01PH62`0E5AD<00d=3@/0
1PH65P071`L;01<C4`/01PH62`092@T;014A4@/030`<2`0410@;00D51@/02PX:5`0>3Ph;00`<31H0
3@d=2`0D51@;00T92@H0oooo00050?ooo`/051@D2`0E5AD;01HF5P/02`/;2`061PH;01DE5@`03@d=
2`061PHF00L71`/04a<C2`061PH;00T92@/04A4A2`0<30`;00@410/01@D52`0:2PXG00h>3P/030`<
5P0=3@d;01@D50/02@T91P3oool000D0oooo2`0D51@;01DE5@/05QHF2`0;2`/;00H61P/05ADE300=
3@d;00H61QH01`L72`0C4a<;00H61P/02@T92`0A4A4;00`<30/010@42`051@D;00X:2QL03Ph>2`0<
30`F00d=3@/051@D2`092@T60?ooo`001@3oool;01@D50/05ADE2`0F5QH;00/;2`/01PH62`0E5AD<
00d=3@/01PH65P071`L;01<C4`/01PH62`092@T;014A4@/030`<2`0410@;00D51@/02PX:5`0>3Ph;
00`<31H03@d=2`0D51@;00T92@H0oooo00050?ooo`/051@D2`0E5AD;01HF5P/02`/;2`061PH;01DE
5@`03@d=2`061PHF00L71`/04a<C2`061PH;00T92@/04A4A2`0<30`;00@410/01@D52`0:2PXG00h>
3P/030`<5P0=3@d;01@D50/02@T91P3oool000D0oooo2`0D51@;01DE5@/05QHF2`0;2`/;00H61P/0
5ADE300=3@d;00H61QH01`L72`0C4a<;00H61P/02@T92`0A4A4;00`<30/010@42`051@D;00X:2QL0
3Ph>2`0<30`F00d=3@/051@D2`092@T60?ooo`001@3oool;01@D50/05ADE2`0F5QH;00/;2`/01PH6
2`0E5AD<00d=3@/01PH65P071`L;01<C4`/01PH62`092@T;014A4@/030`<2`0410@;00D51@/02PX:
5`0>3Ph;00`<31H03@d=2`0D51@;00T92@H0oooo00050?ooo`/051@D2`0E5AD;01HF5P/02`/;2`06
1PH;01DE5@`03@d=2`061PHF00L71`/04a<C2`061PH;00T92@/04A4A2`0<30`;00@410/01@D52`0:
2PXG00h>3P/030`<5P0=3@d;01@D50/02@T91P3oool000D0oooo2`0D51@;01DE5@/05QHF2`0;2`/;
00H61P/05ADE300=3@d;00H61QH01`L72`0C4a<;00H61P/02@T92`0A4A4;00`<30/010@42`051@D;
00X:2QL03Ph>2`0<30`F00d=3@/051@D2`092@T60?ooo`001@3oool;01@D50/05ADE2`0F5QH;00/;
2`/01PH62`0E5AD<00d=3@/01PH65P071`L;01<C4`/01PH62`092@T;014A4@/030`<2`0410@;00D5
1@/02PX:5`0>3Ph;00`<31H03@d=2`0D51@;00T92@H0oooo00050?ooo`/051@D2`0E5AD;01HF5P/0
2`/;2`061PH;01DE5@`03@d=2`061PHF00L71`/04a<C2`061PH;00T92@/04A4A2`0<30`;00@410/0
1@D52`0:2PXG00h>3P/030`<5P0=3@d;01@D50/02@T91P3oool000D0oooo2`0?3`l;00d=3@/03Ph>
2`0C4a<;014A4@/010@430020P8;00X:2P/00P822`0820P;00h>3P/05QHF2`071`L;014A4AH010@4
5P0D51@;00@410`01PH62`0@410;00X:2P/00@412`0D51@;00P820H0oooo00050?ooo`/03`l?2`0=
3@d;00h>3P/04a<C2`0A4A4;00@410`00P822`0:2PX;00820P/020P82`0>3Ph;01HF5P/01`L72`0A
4A4F00@411H051@D2`0410@<00H61P/0410@2`0:2PX;00410@/051@D2`0820P60?ooo`001@3oool;
00l?3`/03@d=2`0>3Ph;01<C4`/04A4A2`0410@<00820P/02PX:2`020P8;00P820/03Ph>2`0F5QH;
00L71`/04A4A5P0410@F01@D50/010@430061PH;010@40/02PX:2`010@4;01@D50/020P81P3oool0
00D0oooo2`0?3`l;00d=3@/03Ph>2`0C4a<;014A4@/010@430020P8;00X:2P/00P822`0820P;00h>
3P/05QHF2`071`L;014A4AH010@45P0D51@;00@410`01PH62`0@410;00X:2P/00@412`0D51@;00P8
20H0oooo00050?ooo`/03`l?2`0=3@d;00h>3P/04a<C2`0A4A4;00@410`00P822`0:2PX;00820P/0
20P82`0>3Ph;01HF5P/01`L72`0A4A4F00@411H051@D2`0410@<00H61P/0410@2`0:2PX;00410@/0
51@D2`0820P60?ooo`001@3oool;00l?3`/03@d=2`0>3Ph;01<C4`/04A4A2`0410@<00820P/02PX:
2`020P8;00P820/03Ph>2`0F5QH;00L71`/04A4A5P0410@F01@D50/010@430061PH;010@40/02PX:
2`010@4;01@D50/020P81P3oool000D0oooo2`0?3`l;00d=3@/03Ph>2`0C4a<;014A4@/010@43002
0P8;00X:2P/00P822`0820P;00h>3P/05QHF2`071`L;014A4AH010@45P0D51@;00@410`01PH62`0@
410;00X:2P/00@412`0D51@;00P820H0oooo00050?ooo`/03`l?2`0=3@d;00h>3P/04a<C2`0A4A4;
00@410`00P822`0:2PX;00820P/020P82`0>3Ph;01HF5P/01`L72`0A4A4F00@411H051@D2`0410@<
00H61P/0410@2`0:2PX;00410@/051@D2`0820P60?ooo`001@3oool;00l?3`/03@d=2`0>3Ph;01<C
4`/04A4A2`0410@<00820P/02PX:2`020P8;00P820/03Ph>2`0F5QH;00L71`/04A4A5P0410@F01@D
50/010@430061PH;010@40/02PX:2`010@4;01@D50/020P81P3oool000D0oooo2`0?3`l;00d=3@/0
3Ph>2`0C4a<;014A4@/010@430020P8;00X:2P/00P822`0820P;00h>3P/05QHF2`071`L;014A4AH0
10@45P0D51@;00@410`01PH62`0@410;00X:2P/00@412`0D51@;00P820H0oooo00050?ooo`/03`l?
2`0=3@d;00h>3P/04a<C2`0A4A4;00@410`00P822`0:2PX;00820P/020P82`0>3Ph;01HF5P/01`L7
2`0A4A4F00@411H051@D2`0410@<00H61P/0410@2`0:2PX;00410@/051@D2`0820P60?ooo`001@3o
ool;00820P/02PX:2`0@410;00820P/0410@2`0:2PX<010@40/04A4A2`0>3Ph;00410@/04A4A2`0=
3@d;00T92@/04a<C2`092@T;00X:2P/030`<2`010@4;01@D50`04A4A2`0E5AD;01@D50/04A4A2`0>
3Ph;000000H0oooo00050?ooo`/00P822`0:2PX;010@40/00P822`0@410;00X:2P`0410@2`0A4A4;
00h>3P/00@412`0A4A4;00d=3@/02@T92`0C4a<;00T92@/02PX:2`0<30`;00410@/051@D300A4A4;
01DE5@/051@D2`0A4A4;00h>3P/000001P3oool000D0oooo2`020P8;00X:2P/0410@2`020P8;010@
40/02PX:300@410;014A4@/03Ph>2`010@4;014A4@/03@d=2`092@T;01<C4`/02@T92`0:2PX;00`<
30/00@412`0D51@<014A4@/05ADE2`0D51@;014A4@/03Ph>2`0000060?ooo`001@3oool;00820P/0
2PX:2`0@410;00820P/0410@2`0:2PX<010@40/04A4A2`0>3Ph;00410@/04A4A2`0=3@d;00T92@/0
4a<C2`092@T;00X:2P/030`<2`010@4;01@D50`04A4A2`0E5AD;01@D50/04A4A2`0>3Ph;000000H0
oooo00050?ooo`/00P822`0:2PX;010@40/00P822`0@410;00X:2P`0410@2`0A4A4;00h>3P/00@41
2`0A4A4;00d=3@/02@T92`0C4a<;00T92@/02PX:2`0<30`;00410@/051@D300A4A4;01DE5@/051@D
2`0A4A4;00h>3P/000001P3oool000D0oooo2`020P8;00X:2P/0410@2`020P8;010@40/02PX:300@
410;014A4@/03Ph>2`010@4;014A4@/03@d=2`092@T;01<C4`/02@T92`0:2PX;00`<30/00@412`0D
51@<014A4@/05ADE2`0D51@;014A4@/03Ph>2`0000060?ooo`001@3oool;00820P/02PX:2`0@410;
00820P/0410@2`0:2PX<010@40/04A4A2`0>3Ph;00410@/04A4A2`0=3@d;00T92@/04a<C2`092@T;
00X:2P/030`<2`010@4;01@D50`04A4A2`0E5AD;01@D50/04A4A2`0>3Ph;000000H0oooo00050?oo
o`/00P822`0:2PX;010@40/00P822`0@410;00X:2P`0410@2`0A4A4;00h>3P/00@412`0A4A4;00d=
3@/02@T92`0C4a<;00T92@/02PX:2`0<30`;00410@/051@D300A4A4;01DE5@/051@D2`0A4A4;00h>
3P/000001P3oool000D0oooo2`020P8;00X:2P/0410@2`020P8;010@40/02PX:300@410;014A4@/0
3Ph>2`010@4;014A4@/03@d=2`092@T;01<C4`/02@T92`0:2PX;00`<30/00@412`0D51@<014A4@/0
5ADE2`0D51@;014A4@/03Ph>2`0000060?ooo`001@3oool;00820P/02PX:2`0@410;00820P/0410@
2`0:2PX<010@40/04A4A2`0>3Ph;00410@/04A4A2`0=3@d;00T92@/04a<C2`092@T;00X:2P/030`<
2`010@4;01@D50`04A4A2`0E5AD;01@D50/04A4A2`0>3Ph;000000H0oooo00050?ooo`/00P822`0:
2PX;010@40/00P822`0@410;00X:2P`0410@2`0A4A4;00h>3P/00@412`0A4A4;00d=3@/02@T92`0C
4a<;00T92@/02PX:2`0<30`;00410@/051@D300A4A4;01DE5@/051@D2`0A4A4;00h>3P/000001P3o
ool000D0oooo2`0<30`;00/;2`/01@D52`061PH;01@D50/04A4A3000000F00410@/05QHF2`0;2`/;
00l?3`/010@42`092@T;01HF5QH051@D2`0<30`;00l?3``05QHF2`0G5aL;018B4P/05ADE2`00000;
00d=3@H0oooo00050?ooo`/030`<2`0;2`/;00D51@/01PH62`0D51@;014A4@`000005P010@4;01HF
5P/02`/;2`0?3`l;00@410/02@T92`0F5QHF01@D50/030`<2`0?3`l<01HF5P/05aLG2`0B4Q8;01DE
5@/000002`0=3@d60?ooo`001@3oool;00`<30/02`/;2`051@D;00H61P/051@D2`0A4A4<000001H0
0@412`0F5QH;00/;2`/03`l?2`0410@;00T92@/05QHF5P0D51@;00`<30/03`l?300F5QH;01LG5`/0
4Q8B2`0E5AD;000000/03@d=1P3oool000D0oooo2`0<30`;00/;2`/01@D52`061PH;01@D50/04A4A
3000000F00410@/05QHF2`0;2`/;00l?3`/010@42`092@T;01HF5QH051@D2`0<30`;00l?3``05QHF
2`0G5aL;018B4P/05ADE2`00000;00d=3@H0oooo00050?ooo`/030`<2`0;2`/;00D51@/01PH62`0D
51@;014A4@`000005P010@4;01HF5P/02`/;2`0?3`l;00@410/02@T92`0F5QHF01@D50/030`<2`0?
3`l<01HF5P/05aLG2`0B4Q8;01DE5@/000002`0=3@d60?ooo`001@3oool;00`<30/02`/;2`051@D;
00H61P/051@D2`0A4A4<000001H00@412`0F5QH;00/;2`/03`l?2`0410@;00T92@/05QHF5P0D51@;
00`<30/03`l?300F5QH;01LG5`/04Q8B2`0E5AD;000000/03@d=1P3oool000D0oooo2`0<30`;00/;
2`/01@D52`061PH;01@D50/04A4A3000000F00410@/05QHF2`0;2`/;00l?3`/010@42`092@T;01HF
5QH051@D2`0<30`;00l?3``05QHF2`0G5aL;018B4P/05ADE2`00000;00d=3@H0oooo00050?ooo`/0
30`<2`0;2`/;00D51@/01PH62`0D51@;014A4@`000005P010@4;01HF5P/02`/;2`0?3`l;00@410/0
2@T92`0F5QHF01@D50/030`<2`0?3`l<01HF5P/05aLG2`0B4Q8;01DE5@/000002`0=3@d60?ooo`00
1@3oool;00`<30/02`/;2`051@D;00H61P/051@D2`0A4A4<000001H00@412`0F5QH;00/;2`/03`l?
2`0410@;00T92@/05QHF5P0D51@;00`<30/03`l?300F5QH;01LG5`/04Q8B2`0E5AD;000000/03@d=
1P3oool000D0oooo2`0<30`;00/;2`/01@D52`061PH;01@D50/04A4A3000000F00410@/05QHF2`0;
2`/;00l?3`/010@42`092@T;01HF5QH051@D2`0<30`;00l?3``05QHF2`0G5aL;018B4P/05ADE2`00
000;00d=3@H0oooo00050?ooo`/030`<2`0;2`/;00D51@/01PH62`0D51@;014A4@`000005P010@4;
01HF5P/02`/;2`0?3`l;00@410/02@T92`0F5QHF01@D50/030`<2`0?3`l<01HF5P/05aLG2`0B4Q8;
01DE5@/000002`0=3@d60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H6
1P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE
5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/0
3`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/0
4a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L7
5P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:
2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3o
ool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`03
0`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:
2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;
00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;
00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H6
1P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE
5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/0
3`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/0
4a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L7
5P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:
2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3o
ool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;00d=3@/051@D2`03
0`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;00d=3@/02`/;2`0:
2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H61P/02PX:2`0C4a<;
00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE5@/04A4A2`0E5AD;
00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00l?3`/01`L75P0?3`l;00X:2P/03`l?30051@D;00H6
1P/02PX:2`0C4a<;00d=3@/051@D2`030`<;01<C4`/02PX:2`0E5AD;00d=3@/04a<C2`092@T<01DE
5@/04A4A2`0E5AD;00d=3@/02`/;2`0:2PX60?ooo`001@3oool;00@410/051@D2`0410@;00820P/0
30`<2`030`<<01DE5@/03Ph>2`0820P;00L71`/04a<C5P051@D;01<C4`/051@D2`0>3Ph;00X:2P/0
3@d=2`0E5AD<01<C4`/030`<2`0G5aLF00d=3@/03`l?1P3oool000D0oooo2`0410@;01@D50/010@4
2`020P8;00`<30/00`<3300E5AD;00h>3P/020P82`071`L;01<C4aH01@D52`0C4a<;01@D50/03Ph>
2`0:2PX;00d=3@/05ADE300C4a<;00`<30/05aLG5P0=3@d;00l?3`H0oooo00050?ooo`/010@42`0D
51@;00@410/00P822`0<30`;00<30``05ADE2`0>3Ph;00P820/01`L72`0C4a<F00D51@/04a<C2`0D
51@;00h>3P/02PX:2`0=3@d;01DE5@`04a<C2`0<30`;01LG5aH03@d=2`0?3`l60?ooo`001@3oool;
00@410/051@D2`0410@;00820P/030`<2`030`<<01DE5@/03Ph>2`0820P;00L71`/04a<C5P051@D;
01<C4`/051@D2`0>3Ph;00X:2P/03@d=2`0E5AD<01<C4`/030`<2`0G5aLF00d=3@/03`l?1P3oool0
00D0oooo2`0410@;01@D50/010@42`020P8;00`<30/00`<3300E5AD;00h>3P/020P82`071`L;01<C
4aH01@D52`0C4a<;01@D50/03Ph>2`0:2PX;00d=3@/05ADE300C4a<;00`<30/05aLG5P0=3@d;00l?
3`H0oooo00050?ooo`/010@42`0D51@;00@410/00P822`0<30`;00<30``05ADE2`0>3Ph;00P820/0
1`L72`0C4a<F00D51@/04a<C2`0D51@;00h>3P/02PX:2`0=3@d;01DE5@`04a<C2`0<30`;01LG5aH0
3@d=2`0?3`l60?ooo`001@3oool;00@410/051@D2`0410@;00820P/030`<2`030`<<01DE5@/03Ph>
2`0820P;00L71`/04a<C5P051@D;01<C4`/051@D2`0>3Ph;00X:2P/03@d=2`0E5AD<01<C4`/030`<
2`0G5aLF00d=3@/03`l?1P3oool000D0oooo2`0410@;01@D50/010@42`020P8;00`<30/00`<3300E
5AD;00h>3P/020P82`071`L;01<C4aH01@D52`0C4a<;01@D50/03Ph>2`0:2PX;00d=3@/05ADE300C
4a<;00`<30/05aLG5P0=3@d;00l?3`H0oooo00050?ooo`/010@42`0D51@;00@410/00P822`0<30`;
00<30``05ADE2`0>3Ph;00P820/01`L72`0C4a<F00D51@/04a<C2`0D51@;00h>3P/02PX:2`0=3@d;
01DE5@`04a<C2`0<30`;01LG5aH03@d=2`0?3`l60?ooo`001@3oool;00@410/051@D2`0410@;0082
0P/030`<2`030`<<01DE5@/03Ph>2`0820P;00L71`/04a<C5P051@D;01<C4`/051@D2`0>3Ph;00X:
2P/03@d=2`0E5AD<01<C4`/030`<2`0G5aLF00d=3@/03`l?1P3oool000D0oooo2`0410@;01@D50/0
10@42`020P8;00`<30/00`<3300E5AD;00h>3P/020P82`071`L;01<C4aH01@D52`0C4a<;01@D50/0
3Ph>2`0:2PX;00d=3@/05ADE300C4a<;00`<30/05aLG5P0=3@d;00l?3`H0oooo00050?ooo`/051@D
2`051@D;00/;2`/01@D52`00000;00H61P`00`<32`0820P;0?KfmP/0l_;b2`3Cdm<F0?clo0/0mOGe
2`3inOT;0>o_k`/030`<5P0>3Ph<00<30`/02@T92`0410@;01HF5P/00`<32`0<30`60?ooo`001@3o
ool;01@D50/01@D52`0;2`/;00D51@/000002`061PH<00<30`/020P82`3fm_H;0?;blP/0dm?C5P3l
o?`;0?Gem@/0nOWi2`3_knl;00`<31H03Ph>30030`<;00T92@/010@42`0F5QH;00<30`/030`<1P3o
ool000D0oooo2`0D51@;00D51@/02`/;2`051@D;000000/01PH630030`<;00P820/0m_Kf2`3bl_8;
0=?CdaH0o?cl2`3emOD;0?Win@/0kno_2`0<30`F00h>3P`00`<32`092@T;00@410/05QHF2`030`<;
00`<30H0oooo00050?ooo`/051@D2`051@D;00/;2`/01@D52`00000;00H61P`00`<32`0820P;0?Kf
mP/0l_;b2`3Cdm<F0?clo0/0mOGe2`3inOT;0>o_k`/030`<5P0>3Ph<00<30`/02@T92`0410@;01HF
5P/00`<32`0<30`60?ooo`001@3oool;01@D50/01@D52`0;2`/;00D51@/000002`061PH<00<30`/0
20P82`3fm_H;0?;blP/0dm?C5P3lo?`;0?Gem@/0nOWi2`3_knl;00`<31H03Ph>30030`<;00T92@/0
10@42`0F5QH;00<30`/030`<1P3oool000D0oooo2`0D51@;00D51@/02`/;2`051@D;000000/01PH6
30030`<;00P820/0m_Kf2`3bl_8;0=?CdaH0o?cl2`3emOD;0?Win@/0kno_2`0<30`F00h>3P`00`<3
2`092@T;00@410/05QHF2`030`<;00`<30H0oooo00050?ooo`/051@D2`051@D;00/;2`/01@D52`00
000;00H61P`00`<32`0820P;0?KfmP/0l_;b2`3Cdm<F0?clo0/0mOGe2`3inOT;0>o_k`/030`<5P0>
3Ph<00<30`/02@T92`0410@;01HF5P/00`<32`0<30`60?ooo`001@3oool;01@D50/01@D52`0;2`/;
00D51@/000002`061PH<00<30`/020P82`3fm_H;0?;blP/0dm?C5P3lo?`;0?Gem@/0nOWi2`3_knl;
00`<31H03Ph>30030`<;00T92@/010@42`0F5QH;00<30`/030`<1P3oool000D0oooo2`0D51@;00D5
1@/02`/;2`051@D;000000/01PH630030`<;00P820/0m_Kf2`3bl_8;0=?CdaH0o?cl2`3emOD;0?Wi
n@/0kno_2`0<30`F00h>3P`00`<32`092@T;00@410/05QHF2`030`<;00`<30H0oooo00050?ooo`/0
51@D2`051@D;00/;2`/01@D52`00000;00H61P`00`<32`0820P;0?KfmP/0l_;b2`3Cdm<F0?clo0/0
mOGe2`3inOT;0>o_k`/030`<5P0>3Ph<00<30`/02@T92`0410@;01HF5P/00`<32`0<30`60?ooo`00
1@3oool;01@D50/01@D52`0;2`/;00D51@/000002`061PH<00<30`/020P82`3fm_H;0?;blP/0dm?C
5P3lo?`;0?Gem@/0nOWi2`3_knl;00`<31H03Ph>30030`<;00T92@/010@42`0F5QH;00<30`/030`<
1P3oool000D0oooo2`0F5QH;00`<30/051@D2`0;2`/;00P820/01`L730061PH;00D51@/0k>c/2`3Q
hN4;0?;blP/0j>SX2`3inOT;0>OWi`/0e=CD2`3dm?@;01@D50/01@D52`0410@<01HF5P/00`<32`05
1@D;01HF5P/02`/;2`020P860?ooo`001@3oool;01HF5P/030`<2`0D51@;00/;2`/020P82`071`L<
00H61P/01@D52`3/k>`;0>7Qh@/0l_;b2`3Xj>P;0?Win@/0inOW2`3De=@;0?Cdm0/051@D2`051@D;
00@410`05QHF2`030`<;00D51@/05QHF2`0;2`/;00820PH0oooo00050?ooo`/05QHF2`0<30`;01@D
50/02`/;2`0820P;00L71``01PH62`051@D;0>c/k0/0hN7Q2`3bl_8;0>SXj0/0nOWi2`3WinL;0=CD
e0/0m?Cd2`0D51@;00D51@/010@4300F5QH;00<30`/01@D52`0F5QH;00/;2`/00P821P3oool000D0
oooo2`0F5QH;00`<30/051@D2`0;2`/;00P820/01`L730061PH;00D51@/0k>c/2`3QhN4;0?;blP/0
j>SX2`3inOT;0>OWi`/0e=CD2`3dm?@;01@D50/01@D52`0410@<01HF5P/00`<32`051@D;01HF5P/0
2`/;2`020P860?ooo`001@3oool;01HF5P/030`<2`0D51@;00/;2`/020P82`071`L<00H61P/01@D5
2`3/k>`;0>7Qh@/0l_;b2`3Xj>P;0?Win@/0inOW2`3De=@;0?Cdm0/051@D2`051@D;00@410`05QHF
2`030`<;00D51@/05QHF2`0;2`/;00820PH0oooo00050?ooo`/05QHF2`0<30`;01@D50/02`/;2`08
20P;00L71``01PH62`051@D;0>c/k0/0hN7Q2`3bl_8;0>SXj0/0nOWi2`3WinL;0=CDe0/0m?Cd2`0D
51@;00D51@/010@4300F5QH;00<30`/01@D52`0F5QH;00/;2`/00P821P3oool000D0oooo2`0F5QH;
00`<30/051@D2`0;2`/;00P820/01`L730061PH;00D51@/0k>c/2`3QhN4;0?;blP/0j>SX2`3inOT;
0>OWi`/0e=CD2`3dm?@;01@D50/01@D52`0410@<01HF5P/00`<32`051@D;01HF5P/02`/;2`020P86
0?ooo`001@3oool;01HF5P/030`<2`0D51@;00/;2`/020P82`071`L<00H61P/01@D52`3/k>`;0>7Q
h@/0l_;b2`3Xj>P;0?Win@/0inOW2`3De=@;0?Cdm0/051@D2`051@D;00@410`05QHF2`030`<;00D5
1@/05QHF2`0;2`/;00820PH0oooo00050?ooo`/05QHF2`0<30`;01@D50/02`/;2`0820P;00L71``0
1PH62`051@D;0>c/k0/0hN7Q2`3bl_8;0>SXj0/0nOWi2`3WinL;0=CDe0/0m?Cd2`0D51@;00D51@/0
10@4300F5QH;00<30`/01@D52`0F5QH;00/;2`/00P821P3oool000D0oooo2`0F5QH;00`<30/051@D
2`0;2`/;00P820/01`L730061PH;00D51@/0k>c/2`3QhN4;0?;blP/0j>SX2`3inOT;0>OWi`/0e=CD
2`3dm?@;01@D50/01@D52`0410@<01HF5P/00`<32`051@D;01HF5P/02`/;2`020P860?ooo`001@3o
ool;01HF5P/030`<2`0D51@;00/;2`/020P82`071`L<00H61P/01@D52`3/k>`;0>7Qh@/0l_;b2`3X
j>P;0?Win@/0inOW2`3De=@;0?Cdm0/051@D2`051@D;00@410`05QHF2`030`<;00D51@/05QHF2`0;
2`/;00820PH0oooo00050?ooo`/0410@2`0C4a<;01HF5P/04Q8B2`00000;00<30``01@D52`00000;
0=[JfP/0mOGe2`3Kfm/;0??cl`/0m_Kf2`3dm?@;0>OWi`/0l_;b2`0>3Ph;014A4@/00`<3300:2PX;
000000/04A4A2`0?3`l;00h>3P/020P81P3oool000D0oooo2`0@410;01<C4`/05QHF2`0B4Q8;0000
00/00`<330051@D;000000/0f][J2`3emOD;0=_Kf`/0lo?c2`3fm_H;0?Cdm0/0inOW2`3bl_8;00h>
3P/04A4A2`030`<<00X:2P/000002`0A4A4;00l?3`/03Ph>2`0820P60?ooo`001@3oool;010@40/0
4a<C2`0F5QH;018B4P/000002`030`<<00D51@/000002`3Jf]X;0?Gem@/0fm_K2`3clo<;0?KfmP/0
m?Cd2`3WinL;0?;blP/03Ph>2`0A4A4;00<30``02PX:2`00000;014A4@/03`l?2`0>3Ph;00P820H0
oooo00050?ooo`/0410@2`0C4a<;01HF5P/04Q8B2`00000;00<30``01@D52`00000;0=[JfP/0mOGe
2`3Kfm/;0??cl`/0m_Kf2`3dm?@;0>OWi`/0l_;b2`0>3Ph;014A4@/00`<3300:2PX;000000/04A4A
2`0?3`l;00h>3P/020P81P3oool000D0oooo2`0@410;01<C4`/05QHF2`0B4Q8;000000/00`<33005
1@D;000000/0f][J2`3emOD;0=_Kf`/0lo?c2`3fm_H;0?Cdm0/0inOW2`3bl_8;00h>3P/04A4A2`03
0`<<00X:2P/000002`0A4A4;00l?3`/03Ph>2`0820P60?ooo`001@3oool;010@40/04a<C2`0F5QH;
018B4P/000002`030`<<00D51@/000002`3Jf]X;0?Gem@/0fm_K2`3clo<;0?KfmP/0m?Cd2`3WinL;
0?;blP/03Ph>2`0A4A4;00<30``02PX:2`00000;014A4@/03`l?2`0>3Ph;00P820H0oooo00050?oo
o`/0410@2`0C4a<;01HF5P/04Q8B2`00000;00<30``01@D52`00000;0=[JfP/0mOGe2`3Kfm/;0??c
l`/0m_Kf2`3dm?@;0>OWi`/0l_;b2`0>3Ph;014A4@/00`<3300:2PX;000000/04A4A2`0?3`l;00h>
3P/020P81P3oool000D0oooo2`0@410;01<C4`/05QHF2`0B4Q8;000000/00`<330051@D;000000/0
f][J2`3emOD;0=_Kf`/0lo?c2`3fm_H;0?Cdm0/0inOW2`3bl_8;00h>3P/04A4A2`030`<<00X:2P/0
00002`0A4A4;00l?3`/03Ph>2`0820P60?ooo`001@3oool;010@40/04a<C2`0F5QH;018B4P/00000
2`030`<<00D51@/000002`3Jf]X;0?Gem@/0fm_K2`3clo<;0?KfmP/0m?Cd2`3WinL;0?;blP/03Ph>
2`0A4A4;00<30``02PX:2`00000;014A4@/03`l?2`0>3Ph;00P820H0oooo00050?ooo`/0410@2`0C
4a<;01HF5P/04Q8B2`00000;00<30``01@D52`00000;0=[JfP/0mOGe2`3Kfm/;0??cl`/0m_Kf2`3d
m?@;0>OWi`/0l_;b2`0>3Ph;014A4@/00`<3300:2PX;000000/04A4A2`0?3`l;00h>3P/020P81P3o
ool000D0oooo2`0@410;01<C4`/05QHF2`0B4Q8;000000/00`<330051@D;000000/0f][J2`3emOD;
0=_Kf`/0lo?c2`3fm_H;0?Cdm0/0inOW2`3bl_8;00h>3P/04A4A2`030`<<00X:2P/000002`0A4A4;
00l?3`/03Ph>2`0820P60?ooo`001@3oool;01@D50/03`l?2`092@T;00h>3P/01@D52`010@4<00d=
3@/05ADE2`3inOT;0>CTi0/0jNWY2`092@T;00h>3P/05ADE2`0@410;014A4@/05QHF2`00000;0041
0@`00P822`0B4Q8;00L71`/02@T92`0A4A4;010@40H0oooo00050?ooo`/051@D2`0?3`l;00T92@/0
3Ph>2`051@D;00410@`03@d=2`0E5AD;0?Win@/0i>CT2`3YjNT;00T92@/03Ph>2`0E5AD;010@40/0
4A4A2`0F5QH;000000/00@4130020P8;018B4P/01`L72`092@T;014A4@/0410@1P3oool000D0oooo
2`0D51@;00l?3`/02@T92`0>3Ph;00D51@/00@41300=3@d;01DE5@/0nOWi2`3Ti>@;0>WYj@/02@T9
2`0>3Ph;01DE5@/0410@2`0A4A4;01HF5P/000002`010@4<00820P/04Q8B2`071`L;00T92@/04A4A
2`0@41060?ooo`001@3oool;01@D50/03`l?2`092@T;00h>3P/01@D52`010@4<00d=3@/05ADE2`3i
nOT;0>CTi0/0jNWY2`092@T;00h>3P/05ADE2`0@410;014A4@/05QHF2`00000;00410@`00P822`0B
4Q8;00L71`/02@T92`0A4A4;010@40H0oooo00050?ooo`/051@D2`0?3`l;00T92@/03Ph>2`051@D;
00410@`03@d=2`0E5AD;0?Win@/0i>CT2`3YjNT;00T92@/03Ph>2`0E5AD;010@40/04A4A2`0F5QH;
000000/00@4130020P8;018B4P/01`L72`092@T;014A4@/0410@1P3oool000D0oooo2`0D51@;00l?
3`/02@T92`0>3Ph;00D51@/00@41300=3@d;01DE5@/0nOWi2`3Ti>@;0>WYj@/02@T92`0>3Ph;01DE
5@/0410@2`0A4A4;01HF5P/000002`010@4<00820P/04Q8B2`071`L;00T92@/04A4A2`0@41060?oo
o`001@3oool;01@D50/03`l?2`092@T;00h>3P/01@D52`010@4<00d=3@/05ADE2`3inOT;0>CTi0/0
jNWY2`092@T;00h>3P/05ADE2`0@410;014A4@/05QHF2`00000;00410@`00P822`0B4Q8;00L71`/0
2@T92`0A4A4;010@40H0oooo00050?ooo`/051@D2`0?3`l;00T92@/03Ph>2`051@D;00410@`03@d=
2`0E5AD;0?Win@/0i>CT2`3YjNT;00T92@/03Ph>2`0E5AD;010@40/04A4A2`0F5QH;000000/00@41
30020P8;018B4P/01`L72`092@T;014A4@/0410@1P3oool000D0oooo2`0D51@;00l?3`/02@T92`0>
3Ph;00D51@/00@41300=3@d;01DE5@/0nOWi2`3Ti>@;0>WYj@/02@T92`0>3Ph;01DE5@/0410@2`0A
4A4;01HF5P/000002`010@4<00820P/04Q8B2`071`L;00T92@/04A4A2`0@41060?ooo`001@3oool;
01@D50/03`l?2`092@T;00h>3P/01@D52`010@4<00d=3@/05ADE2`3inOT;0>CTi0/0jNWY2`092@T;
00h>3P/05ADE2`0@410;014A4@/05QHF2`00000;00410@`00P822`0B4Q8;00L71`/02@T92`0A4A4;
010@40H0oooo00050?ooo`/051@D2`0?3`l;00T92@/03Ph>2`051@D;00410@`03@d=2`0E5AD;0?Wi
n@/0i>CT2`3YjNT;00T92@/03Ph>2`0E5AD;010@40/04A4A2`0F5QH;000000/00@4130020P8;018B
4P/01`L72`092@T;014A4@/0410@1P3oool000D0oooo2`0>3Ph;01HF5P/02@T92`0<30`;00H61P/0
3@d=300:2PX;00D51@/0gMgM2`3Ph>0;0>[ZjP/02PX:2`0820P;000000/00P822`0=3@d;00h>3P/0
51@D2`0A4A4<00P820/00@412`0<30`;01HF5P/00@412`092@T60?ooo`001@3oool;00h>3P/05QHF
2`092@T;00`<30/01PH62`0=3@d<00X:2P/01@D52`3MgMd;0>3Ph0/0j^[Z2`0:2PX;00P820/00000
2`020P8;00d=3@/03Ph>2`0D51@;014A4@`020P82`010@4;00`<30/05QHF2`010@4;00T92@H0oooo
00050?ooo`/03Ph>2`0F5QH;00T92@/030`<2`061PH;00d=3@`02PX:2`051@D;0=gMg@/0h>3P2`3Z
j^X;00X:2P/020P82`00000;00820P/03@d=2`0>3Ph;01@D50/04A4A300820P;00410@/030`<2`0F
5QH;00410@/02@T91P3oool000D0oooo2`0>3Ph;01HF5P/02@T92`0<30`;00H61P/03@d=300:2PX;
00D51@/0gMgM2`3Ph>0;0>[ZjP/02PX:2`0820P;000000/00P822`0=3@d;00h>3P/051@D2`0A4A4<
00P820/00@412`0<30`;01HF5P/00@412`092@T60?ooo`001@3oool;00h>3P/05QHF2`092@T;00`<
30/01PH62`0=3@d<00X:2P/01@D52`3MgMd;0>3Ph0/0j^[Z2`0:2PX;00P820/000002`020P8;00d=
3@/03Ph>2`0D51@;014A4@`020P82`010@4;00`<30/05QHF2`010@4;00T92@H0oooo00050?ooo`/0
3Ph>2`0F5QH;00T92@/030`<2`061PH;00d=3@`02PX:2`051@D;0=gMg@/0h>3P2`3Zj^X;00X:2P/0
20P82`00000;00820P/03@d=2`0>3Ph;01@D50/04A4A300820P;00410@/030`<2`0F5QH;00410@/0
2@T91P3oool000D0oooo2`0>3Ph;01HF5P/02@T92`0<30`;00H61P/03@d=300:2PX;00D51@/0gMgM
2`3Ph>0;0>[ZjP/02PX:2`0820P;000000/00P822`0=3@d;00h>3P/051@D2`0A4A4<00P820/00@41
2`0<30`;01HF5P/00@412`092@T60?ooo`001@3oool;00h>3P/05QHF2`092@T;00`<30/01PH62`0=
3@d<00X:2P/01@D52`3MgMd;0>3Ph0/0j^[Z2`0:2PX;00P820/000002`020P8;00d=3@/03Ph>2`0D
51@;014A4@`020P82`010@4;00`<30/05QHF2`010@4;00T92@H0oooo00050?ooo`/03Ph>2`0F5QH;
00T92@/030`<2`061PH;00d=3@`02PX:2`051@D;0=gMg@/0h>3P2`3Zj^X;00X:2P/020P82`00000;
00820P/03@d=2`0>3Ph;01@D50/04A4A300820P;00410@/030`<2`0F5QH;00410@/02@T91P3oool0
00D0oooo2`0>3Ph;01HF5P/02@T92`0<30`;00H61P/03@d=300:2PX;00D51@/0gMgM2`3Ph>0;0>[Z
jP/02PX:2`0820P;000000/00P822`0=3@d;00h>3P/051@D2`0A4A4<00P820/00@412`0<30`;01HF
5P/00@412`092@T60?ooo`001@3oool;00h>3P/05QHF2`092@T;00`<30/01PH62`0=3@d<00X:2P/0
1@D52`3MgMd;0>3Ph0/0j^[Z2`0:2PX;00P820/000002`020P8;00d=3@/03Ph>2`0D51@;014A4@`0
20P82`010@4;00`<30/05QHF2`010@4;00T92@H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH6
2`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:
2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`09
2@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3T
i>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo0005
0?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;
0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;
00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OG
e`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:
2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0
410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`0
2`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH6
2`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:
2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`09
2@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3T
i>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo0005
0?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;
0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;
00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0410@2`051@D;0=OG
e`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`02`/;2`010@4;00X:
2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH62`020P8;00<30``0
410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:2`0;2`/;018B4P`0
2`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo00050?ooo`/030`<2`092@T;00`<30/01PH6
2`020P8;00<30``0410@2`051@D;0=OGe`/0eMGE2`3`l?0;0=?CdaH0k^k^2`3Ti>@;0=_Kf`/02PX:
2`0;2`/;018B4P`02`/;2`010@4;00X:2P/01PH62`00000;00`<30H0oooo00050?ooo`/00P822`03
0`<;00l?3`/03@d=2`0@410G00820P/01`L72`3fm_H;0?gmo@/0iNGU2`3Cdm<;0=_Kf`/0j^[Z2`3J
f]X;0>7Qh@/000005P0410@<010@40/02@T92`0<30`;01<C4`/01PH62`0;2`/60?ooo`001@3oool;
00820P/00`<32`0?3`l;00d=3@/0410@5`020P8;00L71`/0m_Kf2`3moOd;0>GUi@/0dm?C2`3Kfm/;
0>[ZjP/0f][J2`3QhN4;000001H010@4300@410;00T92@/030`<2`0C4a<;00H61P/02`/;1P3oool0
00D0oooo2`020P8;00<30`/03`l?2`0=3@d;010@41L00P822`071`L;0?KfmP/0oOgm2`3UiND;0=?C
d`/0fm_K2`3Zj^X;0=[JfP/0hN7Q2`00000F00@410`0410@2`092@T;00`<30/04a<C2`061PH;00/;
2`H0oooo00050?ooo`/00P822`030`<;00l?3`/03@d=2`0@410G00820P/01`L72`3fm_H;0?gmo@/0
iNGU2`3Cdm<;0=_Kf`/0j^[Z2`3Jf]X;0>7Qh@/000005P0410@<010@40/02@T92`0<30`;01<C4`/0
1PH62`0;2`/60?ooo`001@3oool;00820P/00`<32`0?3`l;00d=3@/0410@5`020P8;00L71`/0m_Kf
2`3moOd;0>GUi@/0dm?C2`3Kfm/;0>[ZjP/0f][J2`3QhN4;000001H010@4300@410;00T92@/030`<
2`0C4a<;00H61P/02`/;1P3oool000D0oooo2`020P8;00<30`/03`l?2`0=3@d;010@41L00P822`07
1`L;0?KfmP/0oOgm2`3UiND;0=?Cd`/0fm_K2`3Zj^X;0=[JfP/0hN7Q2`00000F00@410`0410@2`09
2@T;00`<30/04a<C2`061PH;00/;2`H0oooo00050?ooo`/00P822`030`<;00l?3`/03@d=2`0@410G
00820P/01`L72`3fm_H;0?gmo@/0iNGU2`3Cdm<;0=_Kf`/0j^[Z2`3Jf]X;0>7Qh@/000005P0410@<
010@40/02@T92`0<30`;01<C4`/01PH62`0;2`/60?ooo`001@3oool;00820P/00`<32`0?3`l;00d=
3@/0410@5`020P8;00L71`/0m_Kf2`3moOd;0>GUi@/0dm?C2`3Kfm/;0>[ZjP/0f][J2`3QhN4;0000
01H010@4300@410;00T92@/030`<2`0C4a<;00H61P/02`/;1P3oool000D0oooo2`020P8;00<30`/0
3`l?2`0=3@d;010@41L00P822`071`L;0?KfmP/0oOgm2`3UiND;0=?Cd`/0fm_K2`3Zj^X;0=[JfP/0
hN7Q2`00000F00@410`0410@2`092@T;00`<30/04a<C2`061PH;00/;2`H0oooo00050?ooo`/00P82
2`030`<;00l?3`/03@d=2`0@410G00820P/01`L72`3fm_H;0?gmo@/0iNGU2`3Cdm<;0=_Kf`/0j^[Z
2`3Jf]X;0>7Qh@/000005P0410@<010@40/02@T92`0<30`;01<C4`/01PH62`0;2`/60?ooo`001@3o
ool;00820P/00`<32`0?3`l;00d=3@/0410@5`020P8;00L71`/0m_Kf2`3moOd;0>GUi@/0dm?C2`3K
fm/;0>[ZjP/0f][J2`3QhN4;000001H010@4300@410;00T92@/030`<2`0C4a<;00H61P/02`/;1P3o
ool000D0oooo2`061PH;018B4P/0410@2`0410@;00d=3@/01PH6300>3Ph;00<30`/0n?Sh2`3Ng]h;
0=_Kf`/0iNGU2`3Rh^8;0=KFeP/0n_[j2`3oool;01HF5P/020P82`0F5QH<00X:2P/03`l?2`0;2`/;
00H61P/05QHF2`0>3Ph60?ooo`001@3oool;00H61P/04Q8B2`0@410;00@410/03@d=2`061PH<00h>
3P/00`<32`3hn?P;0=kNgP/0fm_K2`3UiND;0>;RhP/0e]KF2`3jn_X;0?ooo`/05QHF2`0820P;01HF
5P`02PX:2`0?3`l;00/;2`/01PH62`0F5QH;00h>3PH0oooo00050?ooo`/01PH62`0B4Q8;010@40/0
10@42`0=3@d;00H61P`03Ph>2`030`<;0?Shn0/0g]kN2`3Kfm/;0>GUi@/0h^;R2`3Fe]H;0?[jnP/0
oooo2`0F5QH;00P820/05QHF300:2PX;00l?3`/02`/;2`061PH;01HF5P/03Ph>1P3oool000D0oooo
2`061PH;018B4P/0410@2`0410@;00d=3@/01PH6300>3Ph;00<30`/0n?Sh2`3Ng]h;0=_Kf`/0iNGU
2`3Rh^8;0=KFeP/0n_[j2`3oool;01HF5P/020P82`0F5QH<00X:2P/03`l?2`0;2`/;00H61P/05QHF
2`0>3Ph60?ooo`001@3oool;00H61P/04Q8B2`0@410;00@410/03@d=2`061PH<00h>3P/00`<32`3h
n?P;0=kNgP/0fm_K2`3UiND;0>;RhP/0e]KF2`3jn_X;0?ooo`/05QHF2`0820P;01HF5P`02PX:2`0?
3`l;00/;2`/01PH62`0F5QH;00h>3PH0oooo00050?ooo`/01PH62`0B4Q8;010@40/010@42`0=3@d;
00H61P`03Ph>2`030`<;0?Shn0/0g]kN2`3Kfm/;0>GUi@/0h^;R2`3Fe]H;0?[jnP/0oooo2`0F5QH;
00P820/05QHF300:2PX;00l?3`/02`/;2`061PH;01HF5P/03Ph>1P3oool000D0oooo2`061PH;018B
4P/0410@2`0410@;00d=3@/01PH6300>3Ph;00<30`/0n?Sh2`3Ng]h;0=_Kf`/0iNGU2`3Rh^8;0=KF
eP/0n_[j2`3oool;01HF5P/020P82`0F5QH<00X:2P/03`l?2`0;2`/;00H61P/05QHF2`0>3Ph60?oo
o`001@3oool;00H61P/04Q8B2`0@410;00@410/03@d=2`061PH<00h>3P/00`<32`3hn?P;0=kNgP/0
fm_K2`3UiND;0>;RhP/0e]KF2`3jn_X;0?ooo`/05QHF2`0820P;01HF5P`02PX:2`0?3`l;00/;2`/0
1PH62`0F5QH;00h>3PH0oooo00050?ooo`/01PH62`0B4Q8;010@40/010@42`0=3@d;00H61P`03Ph>
2`030`<;0?Shn0/0g]kN2`3Kfm/;0>GUi@/0h^;R2`3Fe]H;0?[jnP/0oooo2`0F5QH;00P820/05QHF
300:2PX;00l?3`/02`/;2`061PH;01HF5P/03Ph>1P3oool000D0oooo2`061PH;018B4P/0410@2`04
10@;00d=3@/01PH6300>3Ph;00<30`/0n?Sh2`3Ng]h;0=_Kf`/0iNGU2`3Rh^8;0=KFeP/0n_[j2`3o
ool;01HF5P/020P82`0F5QH<00X:2P/03`l?2`0;2`/;00H61P/05QHF2`0>3Ph60?ooo`001@3oool;
00H61P/04Q8B2`0@410;00@410/03@d=2`061PH<00h>3P/00`<32`3hn?P;0=kNgP/0fm_K2`3UiND;
0>;RhP/0e]KF2`3jn_X;0?ooo`/05QHF2`0820P;01HF5P`02PX:2`0?3`l;00/;2`/01PH62`0F5QH;
00h>3PH0oooo00050?ooo`/01`L72`00000;00D51AH05ADE2`0820P<01DE5@/03Ph>2`3emOD;0=WI
f@/0l?3`2`0C4a<;00/;2`/020P82`0:2PX;01@D50/05ADE2`0:2PX;00<30aL02PX:2`0C4a<;00@4
10/04Q8B2`051@D60?ooo`001@3oool;00L71`/000002`051@DF01DE5@/020P8300E5AD;00h>3P/0
mOGe2`3IfMT;0?3`l0/04a<C2`0;2`/;00P820/02PX:2`0D51@;01DE5@/02PX:2`030`<G00X:2P/0
4a<C2`0410@;018B4P/01@D51P3oool000D0oooo2`071`L;000000/01@D55P0E5AD;00P820`05ADE
2`0>3Ph;0?Gem@/0fMWI2`3`l?0;01<C4`/02`/;2`0820P;00X:2P/051@D2`0E5AD;00X:2P/00`<3
5`0:2PX;01<C4`/010@42`0B4Q8;00D51@H0oooo00050?ooo`/01`L72`00000;00D51AH05ADE2`08
20P<01DE5@/03Ph>2`3emOD;0=WIf@/0l?3`2`0C4a<;00/;2`/020P82`0:2PX;01@D50/05ADE2`0:
2PX;00<30aL02PX:2`0C4a<;00@410/04Q8B2`051@D60?ooo`001@3oool;00L71`/000002`051@DF
01DE5@/020P8300E5AD;00h>3P/0mOGe2`3IfMT;0?3`l0/04a<C2`0;2`/;00P820/02PX:2`0D51@;
01DE5@/02PX:2`030`<G00X:2P/04a<C2`0410@;018B4P/01@D51P3oool000D0oooo2`071`L;0000
00/01@D55P0E5AD;00P820`05ADE2`0>3Ph;0?Gem@/0fMWI2`3`l?0;01<C4`/02`/;2`0820P;00X:
2P/051@D2`0E5AD;00X:2P/00`<35`0:2PX;01<C4`/010@42`0B4Q8;00D51@H0oooo00050?ooo`/0
1`L72`00000;00D51AH05ADE2`0820P<01DE5@/03Ph>2`3emOD;0=WIf@/0l?3`2`0C4a<;00/;2`/0
20P82`0:2PX;01@D50/05ADE2`0:2PX;00<30aL02PX:2`0C4a<;00@410/04Q8B2`051@D60?ooo`00
1@3oool;00L71`/000002`051@DF01DE5@/020P8300E5AD;00h>3P/0mOGe2`3IfMT;0?3`l0/04a<C
2`0;2`/;00P820/02PX:2`0D51@;01DE5@/02PX:2`030`<G00X:2P/04a<C2`0410@;018B4P/01@D5
1P3oool000D0oooo2`071`L;000000/01@D55P0E5AD;00P820`05ADE2`0>3Ph;0?Gem@/0fMWI2`3`
l?0;01<C4`/02`/;2`0820P;00X:2P/051@D2`0E5AD;00X:2P/00`<35`0:2PX;01<C4`/010@42`0B
4Q8;00D51@H0oooo00050?ooo`/01`L72`00000;00D51AH05ADE2`0820P<01DE5@/03Ph>2`3emOD;
0=WIf@/0l?3`2`0C4a<;00/;2`/020P82`0:2PX;01@D50/05ADE2`0:2PX;00<30aL02PX:2`0C4a<;
00@410/04Q8B2`051@D60?ooo`001@3oool;00L71`/000002`051@DF01DE5@/020P8300E5AD;00h>
3P/0mOGe2`3IfMT;0?3`l0/04a<C2`0;2`/;00P820/02PX:2`0D51@;01DE5@/02PX:2`030`<G00X:
2P/04a<C2`0410@;018B4P/01@D51P3oool000D0oooo2`030`<;00`<30/0410@2`030`<;018B4P/0
2PX:300820P;00d=3@/0o_kn2`3GemL;0?[jnP/0410@2`092@T;00<30`/051@D2`0C4a<;00@410/0
5QHF2`0<30`<00d=3@/000002`0410@;00L71`/03Ph>2`0C4a<60?ooo`001@3oool;00<30`/030`<
2`0@410;00<30`/04Q8B2`0:2PX<00P820/03@d=2`3no_h;0=OGe`/0n_[j2`0@410;00T92@/00`<3
2`0D51@;01<C4`/010@42`0F5QH;00`<30`03@d=2`00000;00@410/01`L72`0>3Ph;01<C4`H0oooo
00050?ooo`/00`<32`0<30`;010@40/00`<32`0B4Q8;00X:2P`020P82`0=3@d;0?knoP/0emOG2`3j
n_X;010@40/02@T92`030`<;01@D50/04a<C2`0410@;01HF5P/030`<300=3@d;000000/010@42`07
1`L;00h>3P/04a<C1P3oool000D0oooo2`030`<;00`<30/0410@2`030`<;018B4P/02PX:300820P;
00d=3@/0o_kn2`3GemL;0?[jnP/0410@2`092@T;00<30`/051@D2`0C4a<;00@410/05QHF2`0<30`<
00d=3@/000002`0410@;00L71`/03Ph>2`0C4a<60?ooo`001@3oool;00<30`/030`<2`0@410;00<3
0`/04Q8B2`0:2PX<00P820/03@d=2`3no_h;0=OGe`/0n_[j2`0@410;00T92@/00`<32`0D51@;01<C
4`/010@42`0F5QH;00`<30`03@d=2`00000;00@410/01`L72`0>3Ph;01<C4`H0oooo00050?ooo`/0
0`<32`0<30`;010@40/00`<32`0B4Q8;00X:2P`020P82`0=3@d;0?knoP/0emOG2`3jn_X;010@40/0
2@T92`030`<;01@D50/04a<C2`0410@;01HF5P/030`<300=3@d;000000/010@42`071`L;00h>3P/0
4a<C1P3oool000D0oooo2`030`<;00`<30/0410@2`030`<;018B4P/02PX:300820P;00d=3@/0o_kn
2`3GemL;0?[jnP/0410@2`092@T;00<30`/051@D2`0C4a<;00@410/05QHF2`0<30`<00d=3@/00000
2`0410@;00L71`/03Ph>2`0C4a<60?ooo`001@3oool;00<30`/030`<2`0@410;00<30`/04Q8B2`0:
2PX<00P820/03@d=2`3no_h;0=OGe`/0n_[j2`0@410;00T92@/00`<32`0D51@;01<C4`/010@42`0F
5QH;00`<30`03@d=2`00000;00@410/01`L72`0>3Ph;01<C4`H0oooo00050?ooo`/00`<32`0<30`;
010@40/00`<32`0B4Q8;00X:2P`020P82`0=3@d;0?knoP/0emOG2`3jn_X;010@40/02@T92`030`<;
01@D50/04a<C2`0410@;01HF5P/030`<300=3@d;000000/010@42`071`L;00h>3P/04a<C1P3oool0
00D0oooo2`030`<;00`<30/0410@2`030`<;018B4P/02PX:300820P;00d=3@/0o_kn2`3GemL;0?[j
nP/0410@2`092@T;00<30`/051@D2`0C4a<;00@410/05QHF2`0<30`<00d=3@/000002`0410@;00L7
1`/03Ph>2`0C4a<60?ooo`001@3oool;00<30`/030`<2`0@410;00<30`/04Q8B2`0:2PX<00P820/0
3@d=2`3no_h;0=OGe`/0n_[j2`0@410;00T92@/00`<32`0D51@;01<C4`/010@42`0F5QH;00`<30`0
3@d=2`00000;00@410/01`L72`0>3Ph;01<C4`H0oooo00050?ooo`/03Ph>2`010@4;00@410/05ADE
2`0B4Q8;00`<30`03Ph>2`0F5QHF0?knoP/0m?Cd2`3Ogml;0>_[j`/0o_kn2`3_knl;0?Win@/01@D5
2`0;2`/;010@40`010@42`0E5AD;00<30aH020P82`0@41060?ooo`001@3oool;00h>3P/00@412`04
10@;01DE5@/04Q8B2`0<30`<00h>3P/05QHF5P3no_h;0?Cdm0/0gmoO2`3[jn/;0?knoP/0kno_2`3i
nOT;00D51@/02`/;2`0@410<00@410/05ADE2`030`<F00P820/0410@1P3oool000D0oooo2`0>3Ph;
00410@/010@42`0E5AD;018B4P/030`<300>3Ph;01HF5QH0o_kn2`3dm?@;0=oOg`/0jn_[2`3no_h;
0>o_k`/0nOWi2`051@D;00/;2`/0410@300410@;01DE5@/00`<35P0820P;010@40H0oooo00050?oo
o`/03Ph>2`010@4;00@410/05ADE2`0B4Q8;00`<30`03Ph>2`0F5QHF0?knoP/0m?Cd2`3Ogml;0>_[
j`/0o_kn2`3_knl;0?Win@/01@D52`0;2`/;010@40`010@42`0E5AD;00<30aH020P82`0@41060?oo
o`001@3oool;00h>3P/00@412`0410@;01DE5@/04Q8B2`0<30`<00h>3P/05QHF5P3no_h;0?Cdm0/0
gmoO2`3[jn/;0?knoP/0kno_2`3inOT;00D51@/02`/;2`0@410<00@410/05ADE2`030`<F00P820/0
410@1P3oool000D0oooo2`0>3Ph;00410@/010@42`0E5AD;018B4P/030`<300>3Ph;01HF5QH0o_kn
2`3dm?@;0=oOg`/0jn_[2`3no_h;0>o_k`/0nOWi2`051@D;00/;2`/0410@300410@;01DE5@/00`<3
5P0820P;010@40H0oooo00050?ooo`/03Ph>2`010@4;00@410/05ADE2`0B4Q8;00`<30`03Ph>2`0F
5QHF0?knoP/0m?Cd2`3Ogml;0>_[j`/0o_kn2`3_knl;0?Win@/01@D52`0;2`/;010@40`010@42`0E
5AD;00<30aH020P82`0@41060?ooo`001@3oool;00h>3P/00@412`0410@;01DE5@/04Q8B2`0<30`<
00h>3P/05QHF5P3no_h;0?Cdm0/0gmoO2`3[jn/;0?knoP/0kno_2`3inOT;00D51@/02`/;2`0@410<
00@410/05ADE2`030`<F00P820/0410@1P3oool000D0oooo2`0>3Ph;00410@/010@42`0E5AD;018B
4P/030`<300>3Ph;01HF5QH0o_kn2`3dm?@;0=oOg`/0jn_[2`3no_h;0>o_k`/0nOWi2`051@D;00/;
2`/0410@300410@;01DE5@/00`<35P0820P;010@40H0oooo00050?ooo`/03Ph>2`010@4;00@410/0
5ADE2`0B4Q8;00`<30`03Ph>2`0F5QHF0?knoP/0m?Cd2`3Ogml;0>_[j`/0o_kn2`3_knl;0?Win@/0
1@D52`0;2`/;010@40`010@42`0E5AD;00<30aH020P82`0@41060?ooo`001@3oool;00h>3P/00@41
2`0410@;01DE5@/04Q8B2`0<30`<00h>3P/05QHF5P3no_h;0?Cdm0/0gmoO2`3[jn/;0?knoP/0kno_
2`3inOT;00D51@/02`/;2`0@410<00@410/05ADE2`030`<F00P820/0410@1P3oool000D0oooo2`0D
51@;018B4P/01`L72`0D51@;00l?3`/02PX:30071`L;01@D50/0g=cL2`3]kNd;0=CDe0/0jNWY2`3O
gml;0?gmo@/0fMWI2`3moOd;00820P/051@D2`0;2`/<01@D50/04Q8B2`061PH;00820P/03Ph>2`0@
41060?ooo`001@3oool;01@D50/04Q8B2`071`L;01@D50/03`l?2`0:2PX<00L71`/051@D2`3Lg=`;
0>g]k@/0e=CD2`3YjNT;0=oOg`/0oOgm2`3IfMT;0?gmo@/00P822`0D51@;00/;2``051@D2`0B4Q8;
00H61P/00P822`0>3Ph;010@40H0oooo00050?ooo`/051@D2`0B4Q8;00L71`/051@D2`0?3`l;00X:
2P`01`L72`0D51@;0=cLg0/0kNg]2`3De=@;0>WYj@/0gmoO2`3moOd;0=WIf@/0oOgm2`020P8;01@D
50/02`/;300D51@;018B4P/01PH62`020P8;00h>3P/0410@1P3oool000D0oooo2`0D51@;018B4P/0
1`L72`0D51@;00l?3`/02PX:30071`L;01@D50/0g=cL2`3]kNd;0=CDe0/0jNWY2`3Ogml;0?gmo@/0
fMWI2`3moOd;00820P/051@D2`0;2`/<01@D50/04Q8B2`061PH;00820P/03Ph>2`0@41060?ooo`00
1@3oool;01@D50/04Q8B2`071`L;01@D50/03`l?2`0:2PX<00L71`/051@D2`3Lg=`;0>g]k@/0e=CD
2`3YjNT;0=oOg`/0oOgm2`3IfMT;0?gmo@/00P822`0D51@;00/;2``051@D2`0B4Q8;00H61P/00P82
2`0>3Ph;010@40H0oooo00050?ooo`/051@D2`0B4Q8;00L71`/051@D2`0?3`l;00X:2P`01`L72`0D
51@;0=cLg0/0kNg]2`3De=@;0>WYj@/0gmoO2`3moOd;0=WIf@/0oOgm2`020P8;01@D50/02`/;300D
51@;018B4P/01PH62`020P8;00h>3P/0410@1P3oool000D0oooo2`0D51@;018B4P/01`L72`0D51@;
00l?3`/02PX:30071`L;01@D50/0g=cL2`3]kNd;0=CDe0/0jNWY2`3Ogml;0?gmo@/0fMWI2`3moOd;
00820P/051@D2`0;2`/<01@D50/04Q8B2`061PH;00820P/03Ph>2`0@41060?ooo`001@3oool;01@D
50/04Q8B2`071`L;01@D50/03`l?2`0:2PX<00L71`/051@D2`3Lg=`;0>g]k@/0e=CD2`3YjNT;0=oO
g`/0oOgm2`3IfMT;0?gmo@/00P822`0D51@;00/;2``051@D2`0B4Q8;00H61P/00P822`0>3Ph;010@
40H0oooo00050?ooo`/051@D2`0B4Q8;00L71`/051@D2`0?3`l;00X:2P`01`L72`0D51@;0=cLg0/0
kNg]2`3De=@;0>WYj@/0gmoO2`3moOd;0=WIf@/0oOgm2`020P8;01@D50/02`/;300D51@;018B4P/0
1PH62`020P8;00h>3P/0410@1P3oool000D0oooo2`0D51@;018B4P/01`L72`0D51@;00l?3`/02PX:
30071`L;01@D50/0g=cL2`3]kNd;0=CDe0/0jNWY2`3Ogml;0?gmo@/0fMWI2`3moOd;00820P/051@D
2`0;2`/<01@D50/04Q8B2`061PH;00820P/03Ph>2`0@41060?ooo`001@3oool;01@D50/04Q8B2`07
1`L;01@D50/03`l?2`0:2PX<00L71`/051@D2`3Lg=`;0>g]k@/0e=CD2`3YjNT;0=oOg`/0oOgm2`3I
fMT;0?gmo@/00P822`0D51@;00/;2``051@D2`0B4Q8;00H61P/00P822`0>3Ph;010@40H0oooo0005
0?ooo`/02@T92`0B4Q8;00/;2`/05ADE2`0G5aL;00`<30`02@T92`0;2`/;0>GUi@/0mOGe2`3MgMd;
0>WYj@/0j^[Z2`3_knl;0>3Ph0/0oooo2`00000;010@40/01PH6300A4A4;018B4P/010@42`010@4;
00X:2P/03Ph>1P3oool000D0oooo2`092@T;018B4P/02`/;2`0E5AD;01LG5`/030`<30092@T;00/;
2`/0iNGU2`3emOD;0=gMg@/0jNWY2`3Zj^X;0>o_k`/0h>3P2`3oool;000000/0410@2`061PH<014A
4@/04Q8B2`0410@;00410@/02PX:2`0>3Ph60?ooo`001@3oool;00T92@/04Q8B2`0;2`/;01DE5@/0
5aLG2`0<30`<00T92@/02`/;2`3UiND;0?Gem@/0gMgM2`3YjNT;0>[ZjP/0kno_2`3Ph>0;0?ooo`/0
00002`0@410;00H61P`04A4A2`0B4Q8;00@410/00@412`0:2PX;00h>3PH0oooo00050?ooo`/02@T9
2`0B4Q8;00/;2`/05ADE2`0G5aL;00`<30`02@T92`0;2`/;0>GUi@/0mOGe2`3MgMd;0>WYj@/0j^[Z
2`3_knl;0>3Ph0/0oooo2`00000;010@40/01PH6300A4A4;018B4P/010@42`010@4;00X:2P/03Ph>
1P3oool000D0oooo2`092@T;018B4P/02`/;2`0E5AD;01LG5`/030`<30092@T;00/;2`/0iNGU2`3e
mOD;0=gMg@/0jNWY2`3Zj^X;0>o_k`/0h>3P2`3oool;000000/0410@2`061PH<014A4@/04Q8B2`04
10@;00410@/02PX:2`0>3Ph60?ooo`001@3oool;00T92@/04Q8B2`0;2`/;01DE5@/05aLG2`0<30`<
00T92@/02`/;2`3UiND;0?Gem@/0gMgM2`3YjNT;0>[ZjP/0kno_2`3Ph>0;0?ooo`/000002`0@410;
00H61P`04A4A2`0B4Q8;00@410/00@412`0:2PX;00h>3PH0oooo00050?ooo`/02@T92`0B4Q8;00/;
2`/05ADE2`0G5aL;00`<30`02@T92`0;2`/;0>GUi@/0mOGe2`3MgMd;0>WYj@/0j^[Z2`3_knl;0>3P
h0/0oooo2`00000;010@40/01PH6300A4A4;018B4P/010@42`010@4;00X:2P/03Ph>1P3oool000D0
oooo2`092@T;018B4P/02`/;2`0E5AD;01LG5`/030`<30092@T;00/;2`/0iNGU2`3emOD;0=gMg@/0
jNWY2`3Zj^X;0>o_k`/0h>3P2`3oool;000000/0410@2`061PH<014A4@/04Q8B2`0410@;00410@/0
2PX:2`0>3Ph60?ooo`001@3oool;00T92@/04Q8B2`0;2`/;01DE5@/05aLG2`0<30`<00T92@/02`/;
2`3UiND;0?Gem@/0gMgM2`3YjNT;0>[ZjP/0kno_2`3Ph>0;0?ooo`/000002`0@410;00H61P`04A4A
2`0B4Q8;00@410/00@412`0:2PX;00h>3PH0oooo00050?ooo`/02@T92`0B4Q8;00/;2`/05ADE2`0G
5aL;00`<30`02@T92`0;2`/;0>GUi@/0mOGe2`3MgMd;0>WYj@/0j^[Z2`3_knl;0>3Ph0/0oooo2`00
000;010@40/01PH6300A4A4;018B4P/010@42`010@4;00X:2P/03Ph>1P3oool000D0oooo2`092@T;
018B4P/02`/;2`0E5AD;01LG5`/030`<30092@T;00/;2`/0iNGU2`3emOD;0=gMg@/0jNWY2`3Zj^X;
0>o_k`/0h>3P2`3oool;000000/0410@2`061PH<014A4@/04Q8B2`0410@;00410@/02PX:2`0>3Ph6
0?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B
4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D
50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/0
1@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/0
4Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@41
2`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=
2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;
2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`02
0P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;
00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;
00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@6
0?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B
4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D
50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/0
1@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/0
4Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@41
2`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=
2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;00P820/030`<2`0;
2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;00`<31H010@42`02
0P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@60?ooo`001@3oool;
00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B4P/00P822`0C4a<;
00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D50/000002`0410@6
0?ooo`001@3oool;00P820/030`<2`0;2`/;00h>3P/00@412`0C4a<<01HF5P/01@D52`0?3`l;018B
4P/00P822`0C4a<;00`<31H010@42`020P8;00L71`/03@d=2`071`L<00P820/04Q8B2`0820P;01@D
50/000002`0410@60?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/0
5ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/0
0@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>
30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<3
2`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`08
20P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<
30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;
018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;
014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D6
0?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;0082
0P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=
3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/0
5ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/0
0@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>
30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<3
2`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`08
20P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<
30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;
018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;00820P/04Q8B2`0410@;
014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=3@/02`/;2`051@D6
0?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/05ADE2`071`L;0082
0P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/00@412`00000;00d=
3@/02`/;2`051@D60?ooo`001@3oool;018B4P/03@d=2`0820P;01<C4aH03Ph>30092@T;00X:2P/0
5ADE2`071`L;00820P/04Q8B2`0410@;014A4@/05QHF2`0<30`;00d=3@/00`<32`092@T<010@40/0
0@412`00000;00d=3@/02`/;2`051@D60?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A
2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A
2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>
3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E
5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;
00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;
00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q86
0?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<
30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?
3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/0
3`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``0
2@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A
2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A
2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>
3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E
5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;
00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;
00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q86
0?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/03`l?2`020P8;00`<
30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``02@T92`0410@;00l?
3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A2`0=3@d<018B4P/0
3`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A2`0D51@;00l?3``0
2@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;00T92@/000002`0>3Ph;00d=3@/04A4A
2`0=3@d<018B4P/03`l?2`020P8;00`<30/03Ph>2`030`<;00P820/02`/;2`0E5AD;00`<30/04A4A
2`0D51@;00l?3``02@T92`0410@;00l?3aH04a<C2`0B4Q860?ooo`001@3oool;00P820/02PX:2`09
2@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`07
1`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;
00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;
01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D6
0?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE
5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE
5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/0
0P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/0
2@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A
2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>
2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`09
2@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`07
1`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;
00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;
01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D6
0?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE
5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE
5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A2`0>3Ph<00410@/0
0P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>2`0B4Q8<01@D50/0
2@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`092@T;01HF5P/04A4A
2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`071`L;00410@/03Ph>
2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;00P820/02PX:2`09
2@T;01HF5P/04A4A2`0>3Ph<00410@/00P822`071`LF01DE5@/030`<2`030`<;01HF5P/03Ph>2`07
1`L;00410@/03Ph>2`0B4Q8<01@D50/02@T92`0B4Q8;01DE5@/03`l?2`051@D60?ooo`001@3oool;
00l?3`/02PX:2`0?3`l;00X:2P/01`L72`0:2PX<00T92@/04a<C2`0820P;00`<30/051@D2`061PH;
00L71`/00P822`0:2PX;00h>3P/000002`071`L;00d=3@`04A4A2`051@D;00P820/051@D2`0;2`/;
00820PH0oooo00050?ooo`/03`l?2`0:2PX;00l?3`/02PX:2`071`L;00X:2P`02@T92`0C4a<;00P8
20/030`<2`0D51@;00H61P/01`L72`020P8;00X:2P/03Ph>2`00000;00L71`/03@d=300A4A4;00D5
1@/020P82`0D51@;00/;2`/00P821P3oool000D0oooo2`0?3`l;00X:2P/03`l?2`0:2PX;00L71`/0
2PX:30092@T;01<C4`/020P82`0<30`;01@D50/01PH62`071`L;00820P/02PX:2`0>3Ph;000000/0
1`L72`0=3@d<014A4@/01@D52`0820P;01@D50/02`/;2`020P860?ooo`001@3oool;00l?3`/02PX:
2`0?3`l;00X:2P/01`L72`0:2PX<00T92@/04a<C2`0820P;00`<30/051@D2`061PH;00L71`/00P82
2`0:2PX;00h>3P/000002`071`L;00d=3@`04A4A2`051@D;00P820/051@D2`0;2`/;00820PH0oooo
00050?ooo`/03`l?2`0:2PX;00l?3`/02PX:2`071`L;00X:2P`02@T92`0C4a<;00P820/030`<2`0D
51@;00H61P/01`L72`020P8;00X:2P/03Ph>2`00000;00L71`/03@d=300A4A4;00D51@/020P82`0D
51@;00/;2`/00P821P3oool000D0oooo2`0?3`l;00X:2P/03`l?2`0:2PX;00L71`/02PX:30092@T;
01<C4`/020P82`0<30`;01@D50/01PH62`071`L;00820P/02PX:2`0>3Ph;000000/01`L72`0=3@d<
014A4@/01@D52`0820P;01@D50/02`/;2`020P860?ooo`001@3oool;00l?3`/02PX:2`0?3`l;00X:
2P/01`L72`0:2PX<00T92@/04a<C2`0820P;00`<30/051@D2`061PH;00L71`/00P822`0:2PX;00h>
3P/000002`071`L;00d=3@`04A4A2`051@D;00P820/051@D2`0;2`/;00820PH0oooo00050?ooo`/0
3`l?2`0:2PX;00l?3`/02PX:2`071`L;00X:2P`02@T92`0C4a<;00P820/030`<2`0D51@;00H61P/0
1`L72`020P8;00X:2P/03Ph>2`00000;00L71`/03@d=300A4A4;00D51@/020P82`0D51@;00/;2`/0
0P821P3oool000D0oooo2`0?3`l;00X:2P/03`l?2`0:2PX;00L71`/02PX:30092@T;01<C4`/020P8
2`0<30`;01@D50/01PH62`071`L;00820P/02PX:2`0>3Ph;000000/01`L72`0=3@d<014A4@/01@D5
2`0820P;01@D50/02`/;2`020P860?ooo`001@3oool;00l?3`/02PX:2`0?3`l;00X:2P/01`L72`0:
2PX<00T92@/04a<C2`0820P;00`<30/051@D2`061PH;00L71`/00P822`0:2PX;00h>3P/000002`07
1`L;00d=3@`04A4A2`051@D;00P820/051@D2`0;2`/;00820PH0oooo00050?ooo`/03`l?2`0:2PX;
00l?3`/02PX:2`071`L;00X:2P`02@T92`0C4a<;00P820/030`<2`0D51@;00H61P/01`L72`020P8;
00X:2P/03Ph>2`00000;00L71`/03@d=300A4A4;00D51@/020P82`0D51@;00/;2`/00P821P3oool0
00D0oooo2`030`<;018B4P/00@412`0B4Q8;00P820/03Ph>30010@4;00d=3@/04a<C2`0:2PX;00h>
3P/00P822`061PH;01HF5P/01PH62`0D51@;00P820/030`<2`0;2`/<00P820/05QHF2`0:2PX;0000
00/04A4A2`0410@60?ooo`001@3oool;00<30`/04Q8B2`010@4;018B4P/020P82`0>3Ph<00410@/0
3@d=2`0C4a<;00X:2P/03Ph>2`020P8;00H61P/05QHF2`061PH;01@D50/020P82`0<30`;00/;2``0
20P82`0F5QH;00X:2P/000002`0A4A4;00@410H0oooo00050?ooo`/00`<32`0B4Q8;00410@/04Q8B
2`0820P;00h>3P`00@412`0=3@d;01<C4`/02PX:2`0>3Ph;00820P/01PH62`0F5QH;00H61P/051@D
2`0820P;00`<30/02`/;300820P;01HF5P/02PX:2`00000;014A4@/010@41P3oool000D0oooo2`03
0`<;018B4P/00@412`0B4Q8;00P820/03Ph>30010@4;00d=3@/04a<C2`0:2PX;00h>3P/00P822`06
1PH;01HF5P/01PH62`0D51@;00P820/030`<2`0;2`/<00P820/05QHF2`0:2PX;000000/04A4A2`04
10@60?ooo`001@3oool;00<30`/04Q8B2`010@4;018B4P/020P82`0>3Ph<00410@/03@d=2`0C4a<;
00X:2P/03Ph>2`020P8;00H61P/05QHF2`061PH;01@D50/020P82`0<30`;00/;2``020P82`0F5QH;
00X:2P/000002`0A4A4;00@410H0oooo00050?ooo`/00`<32`0B4Q8;00410@/04Q8B2`0820P;00h>
3P`00@412`0=3@d;01<C4`/02PX:2`0>3Ph;00820P/01PH62`0F5QH;00H61P/051@D2`0820P;00`<
30/02`/;300820P;01HF5P/02PX:2`00000;014A4@/010@41P3oool000D0oooo2`030`<;018B4P/0
0@412`0B4Q8;00P820/03Ph>30010@4;00d=3@/04a<C2`0:2PX;00h>3P/00P822`061PH;01HF5P/0
1PH62`0D51@;00P820/030`<2`0;2`/<00P820/05QHF2`0:2PX;000000/04A4A2`0410@60?ooo`00
1@3oool;00<30`/04Q8B2`010@4;018B4P/020P82`0>3Ph<00410@/03@d=2`0C4a<;00X:2P/03Ph>
2`020P8;00H61P/05QHF2`061PH;01@D50/020P82`0<30`;00/;2``020P82`0F5QH;00X:2P/00000
2`0A4A4;00@410H0oooo00050?ooo`/00`<32`0B4Q8;00410@/04Q8B2`0820P;00h>3P`00@412`0=
3@d;01<C4`/02PX:2`0>3Ph;00820P/01PH62`0F5QH;00H61P/051@D2`0820P;00`<30/02`/;3008
20P;01HF5P/02PX:2`00000;014A4@/010@41P3oool000D0oooo2`030`<;018B4P/00@412`0B4Q8;
00P820/03Ph>30010@4;00d=3@/04a<C2`0:2PX;00h>3P/00P822`061PH;01HF5P/01PH62`0D51@;
00P820/030`<2`0;2`/<00P820/05QHF2`0:2PX;000000/04A4A2`0410@60?ooo`001@3oool;00<3
0`/04Q8B2`010@4;018B4P/020P82`0>3Ph<00410@/03@d=2`0C4a<;00X:2P/03Ph>2`020P8;00H6
1P/05QHF2`061PH;01@D50/020P82`0<30`;00/;2``020P82`0F5QH;00X:2P/000002`0A4A4;00@4
10H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.500131, -0.500131, 0.0905933, \
0.0905933}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ListPlot3D", "[", 
          
          StyleBox[\(\[LeftBracketingBar]\[CapitalSigma](
                1000)\[RightBracketingBar]\),
            "InlineInputTraditionalForm"], 
          StyleBox["]",
            "InlineInputTraditionalForm"]}], 
        StyleBox[";",
          "InlineInputTraditionalForm"]}], TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -9 -11.9926 ]
[.12586 .2075 0 .00736 ]
[.25429 .15697 -13.4005 -12 ]
[.25429 .15697 .5995 0 ]
[.38935 .10384 -12.7924 -12 ]
[.38935 .10384 1.2076 0 ]
[.53158 .04793 -12.1843 -12 ]
[.53158 .04793 1.81571 0 ]
[.68156 -0.01098 -11.5762 -12 ]
[.68156 -0.01098 2.42381 0 ]
[.75679 .08071 0 -8.23703 ]
[.75679 .08071 9 3.76297 ]
[.82083 .17876 0 -8.11081 ]
[.82083 .17876 14 3.88919 ]
[.87924 .26821 0 -7.99808 ]
[.87924 .26821 14 4.00192 ]
[.93273 .35014 0 -7.89677 ]
[.93273 .35014 14 4.10323 ]
[.98191 .42546 0 -7.80525 ]
[.98191 .42546 14 4.19475 ]
[.02412 .2651 -9 -3.65641 ]
[.02412 .2651 0 8.34359 ]
[.01479 .32353 -31.5 -3.7223 ]
[.01479 .32353 0 8.2777 ]
[.00511 .38423 -26.5 -3.791 ]
[.00511 .38423 0 8.209 ]
[-0.00496 .44733 -31.5 -3.86269 ]
[-0.00496 .44733 0 8.13731 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
gsave
.75679 .08071 -61 -12.237 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.80845 .18312 m
.80226 .18529 L
s
gsave
.82083 .17876 -61 -12.1108 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.86679 .27235 m
.86056 .27443 L
s
gsave
.87924 .26821 -61 -11.9981 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.92022 .35409 m
.91397 .35607 L
s
gsave
.93273 .35014 -61 -11.8968 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -11.8052 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.75778 .10561 m
.75408 .10697 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.87784 .28927 m
.87411 .2905 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.93037 .36962 m
.92662 .3708 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
.73096 .06459 m
.72728 .06598 L
s
.71716 .04348 m
.71349 .04489 L
s
.70309 .02196 m
.69942 .02338 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25794 L
s
gsave
.02412 .2651 -70 -7.65641 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02706 .31888 m
.03319 .31655 L
s
gsave
.01479 .32353 -92.5 -7.7223 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
1.000 setlinewidth
grestore
.01742 .3797 m
.02358 .37743 L
s
gsave
.00511 .38423 -87.5 -7.791 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
1.000 setlinewidth
grestore
.0074 .44292 m
.01358 .44072 L
s
gsave
-0.00496 .44733 -92.5 -7.86269 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0015) show
1.000 setlinewidth
grestore
.125 Mabswid
.03451 .27186 m
.03818 .27043 L
s
.03267 .28348 m
.03634 .28206 L
s
.03081 .29519 m
.03449 .29378 L
s
.02894 .30699 m
.03262 .30558 L
s
.02516 .33086 m
.02884 .32947 L
s
.02325 .34293 m
.02693 .34154 L
s
.02132 .35509 m
.02501 .35371 L
s
.01938 .36735 m
.02307 .36598 L
s
.01545 .39215 m
.01915 .39079 L
s
.01346 .40469 m
.01716 .40335 L
s
.01146 .41734 m
.01516 .416 L
s
.00944 .43008 m
.01314 .42875 L
s
.00535 .45587 m
.00906 .45455 L
s
.00328 .46892 m
.007 .46761 L
s
.0012 .48207 m
.00492 .48077 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.699 .913 .969 r
.39191 .60332 .40503 .60643 .42612 .61092 .41359 .59326 Mtetra
.6 .643 .864 r
.41359 .59326 .42612 .61092 .44804 .59175 .4352 .59077 Mtetra
.676 .947 .959 r
.4352 .59077 .44804 .59175 .46957 .59821 .4572 .57997 Mtetra
.683 .67 .831 r
.4572 .57997 .46957 .59821 .49163 .58451 .4793 .57112 Mtetra
.626 .713 .908 r
.4793 .57112 .49163 .58451 .51374 .58177 .50152 .56659 Mtetra
.67 .703 .872 r
.50152 .56659 .51374 .58177 .53604 .56581 .52395 .55926 Mtetra
.324 .719 .981 r
.52395 .55926 .53604 .56581 .55858 .56764 .54661 .56035 Mtetra
.794 .853 .895 r
.54661 .56035 .55858 .56764 .58136 .56597 .56934 .54445 Mtetra
.618 .618 .828 r
.56934 .54445 .58136 .56597 .60411 .55237 .59238 .54064 Mtetra
.527 .71 .955 r
.59238 .54064 .60411 .55237 .62725 .54831 .61574 .53979 Mtetra
.802 .84 .88 r
.61574 .53979 .62725 .54831 .65018 .53211 .63882 .52257 Mtetra
.642 .796 .957 r
.63882 .52257 .65018 .53211 .6737 .52796 .6624 .5161 Mtetra
.718 .777 .899 r
.6624 .5161 .6737 .52796 .69795 .53339 .68598 .5052 Mtetra
.589 .558 .788 r
.68598 .5052 .69795 .53339 .72112 .51376 .71024 .50391 Mtetra
.587 .777 .97 r
.71024 .50391 .72112 .51376 .74585 .51738 .73462 .4997 Mtetra
.765 .721 .812 r
.73462 .4997 .74585 .51738 .76949 .50131 .75826 .48158 Mtetra
.59 .63 .859 r
.75826 .48158 .76949 .50131 .79418 .4972 .78321 .4795 Mtetra
.603 .66 .879 r
.78321 .4795 .79418 .4972 .81876 .48883 .80837 .47627 Mtetra
.602 .738 .94 r
.80837 .47627 .81876 .48883 .8434 .47893 .83371 .47202 Mtetra
.8 .902 .914 r
.83371 .47202 .8434 .47893 .86963 .48261 .85802 .4549 Mtetra
.625 .586 .79 r
.85802 .4549 .86963 .48261 .89391 .46536 .88372 .44977 Mtetra
.501 .643 .919 r
.88372 .44977 .89391 .46536 .9185 .45004 .91051 .45151 Mtetra
.552 .927 .8 r
.91051 .45151 .9185 .45004 .9459 .45578 .93558 .43657 Mtetra
.732 .709 .829 r
.93558 .43657 .9459 .45578 .97046 .43739 .96078 .4217 Mtetra
.637 .662 .858 r
.37914 .58605 .39191 .60332 .41359 .59326 .40071 .58113 Mtetra
.672 .744 .905 r
.40071 .58113 .41359 .59326 .4352 .59077 .42256 .57392 Mtetra
.473 .601 .898 r
.42256 .57392 .4352 .59077 .4572 .57997 .44432 .57709 Mtetra
.693 .923 .969 r
.44432 .57709 .4572 .57997 .4793 .57112 .46663 .56664 Mtetra
.677 .894 .976 r
.46663 .56664 .4793 .57112 .50152 .56659 .48906 .55744 Mtetra
.795 .816 .868 r
.48906 .55744 .50152 .56659 .52395 .55926 .51167 .54059 Mtetra
.651 .659 .845 r
.51167 .54059 .52395 .55926 .54661 .56035 .53437 .53429 Mtetra
.608 .579 .796 r
.53437 .53429 .54661 .56035 .56934 .54445 .55729 .53124 Mtetra
.399 .626 .945 r
.55729 .53124 .56934 .54445 .59238 .54064 .58058 .53521 Mtetra
.625 .873 .988 r
.58058 .53521 .59238 .54064 .61574 .53979 .60394 .52779 Mtetra
.753 .781 .876 r
.60394 .52779 .61574 .53979 .63882 .52257 .62731 .51391 Mtetra
.77 .842 .906 r
.62731 .51391 .63882 .52257 .6624 .5161 .65075 .49951 Mtetra
.36 .55 .904 r
.65075 .49951 .6624 .5161 .68598 .5052 .6753 .50708 Mtetra
.603 .953 .854 r
.6753 .50708 .68598 .5052 .71024 .50391 .69913 .49311 Mtetra
.74 .808 .906 r
.69913 .49311 .71024 .50391 .73462 .4997 .72316 .48051 Mtetra
.706 .688 .83 r
.72316 .48051 .73462 .4997 .75826 .48158 .74737 .4686 Mtetra
.449 .659 .951 r
.74737 .4686 .75826 .48158 .78321 .4795 .7728 .47096 Mtetra
.568 .804 .988 r
.7728 .47096 .78321 .4795 .80837 .47627 .79804 .46643 Mtetra
.621 .8 .968 r
.79804 .46643 .80837 .47627 .83371 .47202 .8234 .46026 Mtetra
.777 .814 .882 r
.8234 .46026 .83371 .47202 .85802 .4549 .848 .44391 Mtetra
.49 .722 .974 r
.848 .44391 .85802 .4549 .88372 .44977 .8744 .4435 Mtetra
.533 .844 .999 r
.8744 .4435 .88372 .44977 .91051 .45151 .9006 .43823 Mtetra
.734 .788 .895 r
.9006 .43823 .91051 .45151 .93558 .43657 .92611 .42508 Mtetra
.769 .83 .899 r
.92611 .42508 .93558 .43657 .96078 .4217 .95143 .40942 Mtetra
.753 .769 .866 r
.36593 .57463 .37914 .58605 .40071 .58113 .38795 .56124 Mtetra
.482 .568 .866 r
.38795 .56124 .40071 .58113 .42256 .57392 .40948 .56498 Mtetra
.672 .804 .946 r
.40948 .56498 .42256 .57392 .44432 .57709 .43164 .55742 Mtetra
.611 .633 .848 r
.43164 .55742 .44432 .57709 .46663 .56664 .45388 .554 Mtetra
.711 .754 .886 r
.45388 .554 .46663 .56664 .48906 .55744 .47645 .5438 Mtetra
.595 .706 .921 r
.47645 .5438 .48906 .55744 .51167 .54059 .49911 .54058 Mtetra
.562 .928 .933 r
.49911 .54058 .51167 .54059 .53437 .53429 .52201 .53113 Mtetra
.808 .931 .914 r
.52201 .53113 .53437 .53429 .55729 .53124 .54503 .51413 Mtetra
.526 .629 .896 r
.54503 .51413 .55729 .53124 .58058 .53521 .56834 .51499 Mtetra
.645 .648 .838 r
.56834 .51499 .58058 .53521 .60394 .52779 .59181 .5088 Mtetra
.738 .696 .811 r
.59181 .5088 .60394 .52779 .62731 .51391 .61525 .49338 Mtetra
.614 .633 .846 r
.61525 .49338 .62731 .51391 .65075 .49951 .63918 .48949 Mtetra
.598 .781 .968 r
.63918 .48949 .65075 .49951 .6753 .50708 .66332 .48472 Mtetra
.554 .589 .843 r
.66332 .48472 .6753 .50708 .69913 .49311 .68798 .48525 Mtetra
.768 .869 .923 r
.68798 .48525 .69913 .49311 .72316 .48051 .71211 .47071 Mtetra
.562 .776 .979 r
.71211 .47071 .72316 .48051 .74737 .4686 .73705 .46707 Mtetra
.359 .824 .912 r
.73705 .46707 .74737 .4686 .7728 .47096 .76217 .46196 Mtetra
.73 .85 .938 r
.76217 .46196 .7728 .47096 .79804 .46643 .78699 .44975 Mtetra
.716 .728 .86 r
.78699 .44975 .79804 .46643 .8234 .46026 .81195 .43747 Mtetra
.691 .658 .812 r
.81195 .43747 .8234 .46026 .848 .44391 .83714 .42582 Mtetra
.533 .631 .894 r
.83714 .42582 .848 .44391 .8744 .4435 .86377 .42646 Mtetra
.621 .689 .892 r
.86377 .42646 .8744 .4435 .9006 .43823 .89015 .42142 Mtetra
.664 .713 .885 r
.89015 .42142 .9006 .43823 .92611 .42508 .91644 .41327 Mtetra
.666 .794 .943 r
.91644 .41327 .92611 .42508 .95143 .40942 .94292 .40465 Mtetra
.716 .872 .955 r
.3522 .56906 .36593 .57463 .38795 .56124 .37427 .55874 Mtetra
.696 .927 .967 r
.37427 .55874 .38795 .56124 .40948 .56498 .39648 .54805 Mtetra
.508 .622 .899 r
.39648 .54805 .40948 .56498 .43164 .55742 .41844 .54952 Mtetra
.722 .836 .935 r
.41844 .54952 .43164 .55742 .45388 .554 .44099 .53887 Mtetra
.667 .71 .88 r
.44099 .53887 .45388 .554 .47645 .5438 .46362 .53151 Mtetra
.72 .765 .888 r
.46362 .53151 .47645 .5438 .49911 .54058 .48648 .5205 Mtetra
.648 .65 .838 r
.48648 .5205 .49911 .54058 .52201 .53113 .50946 .51407 Mtetra
.506 .623 .902 r
.50946 .51407 .52201 .53113 .54503 .51413 .53265 .51565 Mtetra
.766 .991 .886 r
.53265 .51565 .54503 .51413 .56834 .51499 .55599 .49788 Mtetra
.707 .706 .847 r
.55599 .49788 .56834 .51499 .59181 .5088 .57949 .48668 Mtetra
.481 .553 .853 r
.57949 .48668 .59181 .5088 .61525 .49338 .60351 .49125 Mtetra
.809 .961 .909 r
.60351 .49125 .61525 .49338 .63918 .48949 .6272 .47306 Mtetra
.471 .619 .914 r
.6272 .47306 .63918 .48949 .66332 .48472 .65175 .47588 Mtetra
.564 .797 .986 r
.65175 .47588 .66332 .48472 .68798 .48525 .67635 .47167 Mtetra
.759 .775 .867 r
.67635 .47167 .68798 .48525 .71211 .47071 .70062 .45641 Mtetra
.643 .731 .913 r
.70062 .45641 .71211 .47071 .73705 .46707 .72553 .44997 Mtetra
.754 .734 .834 r
.72553 .44997 .73705 .46707 .76217 .46196 .75001 .43363 Mtetra
.597 .571 .795 r
.75001 .43363 .76217 .46196 .78699 .44975 .77563 .43096 Mtetra
.585 .65 .881 r
.77563 .43096 .78699 .44975 .81195 .43747 .80158 .42853 Mtetra
.824 .874 .882 r
.80158 .42853 .81195 .43747 .83714 .42582 .8262 .40842 Mtetra
.672 .708 .875 r
.8262 .40842 .83714 .42582 .86377 .42646 .85201 .39958 Mtetra
.539 .552 .817 r
.85201 .39958 .86377 .42646 .89015 .42142 .87926 .40182 Mtetra
.678 .689 .853 r
.87926 .40182 .89015 .42142 .91644 .41327 .90551 .39202 Mtetra
.705 .686 .829 r
.90551 .39202 .91644 .41327 .94292 .40465 .93158 .3791 Mtetra
.62 .636 .845 r
.33899 .54923 .3522 .56906 .37427 .55874 .36083 .54509 Mtetra
.672 .73 .894 r
.36083 .54509 .37427 .55874 .39648 .54805 .38303 .53757 Mtetra
.61 .767 .955 r
.38303 .53757 .39648 .54805 .41844 .54952 .4053 .53286 Mtetra
.759 .717 .813 r
.4053 .53286 .41844 .54952 .44099 .53887 .42814 .51594 Mtetra
.438 .521 .846 r
.42814 .51594 .44099 .53887 .46362 .53151 .45052 .52236 Mtetra
.591 .791 .975 r
.45052 .52236 .46362 .53151 .48648 .5205 .47344 .51775 Mtetra
.847 .927 .882 r
.47344 .51775 .48648 .5205 .50946 .51407 .49673 .49706 Mtetra
.533 .64 .901 r
.49673 .49706 .50946 .51407 .53265 .51565 .52 .49723 Mtetra
.621 .662 .868 r
.52 .49723 .53265 .51565 .55599 .49788 .54355 .49263 Mtetra
.832 .9 .888 r
.54355 .49263 .55599 .49788 .57949 .48668 .56715 .47302 Mtetra
.355 .607 .944 r
.56715 .47302 .57949 .48668 .60351 .49125 .59127 .47801 Mtetra
.732 .77 .883 r
.59127 .47801 .60351 .49125 .6272 .47306 .6153 .46541 Mtetra
.759 .87 .929 r
.6153 .46541 .6272 .47306 .65175 .47588 .63942 .45149 Mtetra
.654 .625 .809 r
.63942 .45149 .65175 .47588 .67635 .47167 .66392 .44352 Mtetra
.66 .604 .781 r
.66392 .44352 .67635 .47167 .70062 .45641 .68855 .43403 Mtetra
.599 .618 .842 r
.68855 .43403 .70062 .45641 .72553 .44997 .71375 .43087 Mtetra
.604 .656 .874 r
.71375 .43087 .72553 .44997 .75001 .43363 .7392 .4271 Mtetra
.715 .9 .962 r
.7392 .4271 .75001 .43363 .77563 .43096 .76433 .41492 Mtetra
.659 .721 .894 r
.76433 .41492 .77563 .43096 .80158 .42853 .78999 .40716 Mtetra
.547 .606 .864 r
.78999 .40716 .80158 .42853 .8262 .40842 .81661 .40739 Mtetra
.709 .982 .899 r
.81661 .40739 .8262 .40842 .85201 .39958 .84194 .39075 Mtetra
.354 .705 .985 r
.84194 .39075 .85201 .39958 .87926 .40182 .86935 .39245 Mtetra
.86 .883 .853 r
.86935 .39245 .87926 .40182 .90551 .39202 .89413 .36792 Mtetra
.616 .62 .832 r
.89413 .36792 .90551 .39202 .93158 .3791 .92134 .36311 Mtetra
.502 .701 .959 r
.32517 .53714 .33899 .54923 .36083 .54509 .3469 .53677 Mtetra
.744 .829 .917 r
.3469 .53677 .36083 .54509 .38303 .53757 .36946 .52463 Mtetra
.475 .677 .953 r
.36946 .52463 .38303 .53757 .4053 .53286 .39161 .5254 Mtetra
.622 .831 .981 r
.39161 .5254 .4053 .53286 .42814 .51594 .4143 .51906 Mtetra
.681 .978 .875 r
.4143 .51906 .42814 .51594 .45052 .52236 .43742 .50381 Mtetra
.689 .684 .84 r
.43742 .50381 .45052 .52236 .47344 .51775 .46052 .49386 Mtetra
.635 .616 .814 r
.46052 .49386 .47344 .51775 .49673 .49706 .48374 .4879 Mtetra
.95 .633 .395 r
.48374 .4879 .49673 .49706 .52 .49723 .50621 .6595 Mtetra
.567 .321 .503 r
.50621 .6595 .52 .49723 .54355 .49263 .53117 .66683 Mtetra
.498 .266 .493 r
.53117 .66683 .54355 .49263 .56715 .47302 .55623 .6383 Mtetra
.56 .315 .502 r
.55623 .6383 .56715 .47302 .59127 .47801 .58174 .64182 Mtetra
.542 .3 .498 r
.58174 .64182 .59127 .47801 .6153 .46541 .60741 .63572 Mtetra
.548 .306 .501 r
.60741 .63572 .6153 .46541 .63942 .45149 .63343 .63239 Mtetra
.519 .285 .499 r
.63343 .63239 .63942 .45149 .66392 .44352 .6591 .61234 Mtetra
.587 .337 .505 r
.6591 .61234 .66392 .44352 .68855 .43403 .6867 .63245 Mtetra
0 0 .353 r
.6867 .63245 .68855 .43403 .71375 .43087 .70173 .41014 Mtetra
.466 .57 .876 r
.70173 .41014 .71375 .43087 .7392 .4271 .72781 .41466 Mtetra
.764 .808 .888 r
.72781 .41466 .7392 .4271 .76433 .41492 .75289 .39908 Mtetra
.512 .661 .928 r
.75289 .39908 .76433 .41492 .78999 .40716 .77935 .39938 Mtetra
.605 .85 .99 r
.77935 .39938 .78999 .40716 .81661 .40739 .80553 .39216 Mtetra
.793 .783 .844 r
.80553 .39216 .81661 .40739 .84194 .39075 .83076 .37221 Mtetra
.686 .709 .865 r
.83076 .37221 .84194 .39075 .86935 .39245 .85702 .36176 Mtetra
.577 .554 .792 r
.85702 .36176 .86935 .39245 .89413 .36792 .88455 .36054 Mtetra
.54 .839 .999 r
.88455 .36054 .89413 .36792 .92134 .36311 .91192 .35492 Mtetra
.654 .888 .982 r
.31063 .5326 .32517 .53714 .3469 .53677 .33296 .52415 Mtetra
.768 .766 .851 r
.33296 .52415 .3469 .53677 .36946 .52463 .35584 .5083 Mtetra
.454 .616 .919 r
.35584 .5083 .36946 .52463 .39161 .5254 .37796 .51101 Mtetra
.714 .739 .872 r
.37796 .51101 .39161 .5254 .4143 .51906 .40093 .49992 Mtetra
.705 .685 .828 r
.40093 .49992 .4143 .51906 .43742 .50381 .42406 .4882 Mtetra
.687 .72 .875 r
.42406 .4882 .43742 .50381 .46052 .49386 .44726 .47896 Mtetra
.441 .635 .938 r
.44726 .47896 .46052 .49386 .48374 .4879 .47045 .48152 Mtetra
.945 .623 .393 r
.47045 .48152 .48374 .4879 .50621 .6595 .49253 .63864 Mtetra
.37 .528 .883 r
.49253 .63864 .50621 .6595 .53117 .66683 .51752 .64654 Mtetra
.81 .721 .767 r
.51752 .64654 .53117 .66683 .55623 .6383 .54276 .61751 Mtetra
.296 .488 .877 r
.54276 .61751 .55623 .6383 .58174 .64182 .56842 .62826 Mtetra
.763 .788 .873 r
.56842 .62826 .58174 .64182 .60741 .63572 .59404 .61195 Mtetra
.126 .348 .812 r
.59404 .61195 .60741 .63572 .63343 .63239 .62077 .63135 Mtetra
.941 .927 .764 r
.62077 .63135 .63343 .63239 .6591 .61234 .64607 .59228 Mtetra
0 .237 .754 r
.64607 .59228 .6591 .61234 .6867 .63245 .67387 .61621 Mtetra
.967 .721 .513 r
.67387 .61621 .6867 .63245 .70173 .41014 .68996 .39708 Mtetra
.3 .596 .947 r
.68996 .39708 .70173 .41014 .72781 .41466 .71627 .40316 Mtetra
.764 .826 .9 r
.71627 .40316 .72781 .41466 .75289 .39908 .74159 .3877 Mtetra
.483 .728 .979 r
.74159 .3877 .75289 .39908 .77935 .39938 .76814 .38686 Mtetra
.693 .797 .929 r
.76814 .38686 .77935 .39938 .80553 .39216 .79425 .37639 Mtetra
.774 .775 .854 r
.79425 .37639 .80553 .39216 .83076 .37221 .81986 .35834 Mtetra
.705 .783 .912 r
.81986 .35834 .83076 .37221 .85702 .36176 .84624 .34689 Mtetra
.488 .672 .946 r
.84624 .34689 .85702 .36176 .88455 .36054 .87415 .34756 Mtetra
.63 .774 .95 r
.87415 .34756 .88455 .36054 .91192 .35492 .90157 .3405 Mtetra
.759 .709 .805 r
.29668 .51489 .31063 .5326 .33296 .52415 .31967 .49723 Mtetra
.617 .585 .795 r
.31967 .49723 .33296 .52415 .35584 .5083 .34198 .49256 Mtetra
.321 .562 .924 r
.34198 .49256 .35584 .5083 .37796 .51101 .364 .49862 Mtetra
.699 .768 .905 r
.364 .49862 .37796 .51101 .40093 .49992 .38705 .48888 Mtetra
.734 .796 .902 r
.38705 .48888 .40093 .49992 .42406 .4882 .41035 .47672 Mtetra
.643 .773 .942 r
.41035 .47672 .42406 .4882 .44726 .47896 .43363 .47011 Mtetra
.444 .75 .993 r
.43363 .47011 .44726 .47896 .47045 .48152 .457 .46924 Mtetra
.954 .64 .395 r
.457 .46924 .47045 .48152 .49253 .63864 .47816 .65581 Mtetra
.246 0 0 r
.47816 .65581 .49253 .63864 .51752 .64654 .50355 .64781 Mtetra
.688 .977 .901 r
.50355 .64781 .51752 .64654 .54276 .61751 .52916 .63176 Mtetra
0 0 0 r
.52916 .63176 .54276 .61751 .56842 .62826 .5548 .60573 Mtetra
.483 .576 .872 r
.5548 .60573 .56842 .62826 .59404 .61195 .58087 .60918 Mtetra
.298 0 0 r
.58087 .60918 .59404 .61195 .62077 .63135 .60749 .61815 Mtetra
.8 .807 .857 r
.60749 .61815 .62077 .63135 .64607 .59228 .63368 .59747 Mtetra
.276 0 0 r
.63368 .59747 .64607 .59228 .67387 .61621 .6608 .59898 Mtetra
.966 .721 .515 r
.6608 .59898 .67387 .61621 .68996 .39708 .67799 .38392 Mtetra
.569 .736 .954 r
.67799 .38392 .68996 .39708 .71627 .40316 .7039 .3804 Mtetra
.601 .627 .849 r
.7039 .3804 .71627 .40316 .74159 .3877 .73009 .37653 Mtetra
.792 .842 .889 r
.73009 .37653 .74159 .3877 .76814 .38686 .75558 .35846 Mtetra
.496 .526 .817 r
.75558 .35846 .76814 .38686 .79425 .37639 .783 .36323 Mtetra
.826 .824 .846 r
.783 .36323 .79425 .37639 .81986 .35834 .80842 .34033 Mtetra
.607 .688 .9 r
.80842 .34033 .81986 .35834 .84624 .34689 .83563 .33546 Mtetra
.649 .811 .961 r
.83563 .33546 .84624 .34689 .87415 .34756 .86277 .327 Mtetra
.572 .643 .882 r
.86277 .327 .87415 .34756 .90157 .3405 .89089 .32465 Mtetra
.553 .598 .853 r
.28284 .49309 .29668 .51489 .31967 .49723 .30478 .49262 Mtetra
.484 .84 .994 r
.30478 .49262 .31967 .49723 .34198 .49256 .32722 .48842 Mtetra
.813 .903 .904 r
.32722 .48842 .34198 .49256 .364 .49862 .35062 .47068 Mtetra
.496 .519 .81 r
.35062 .47068 .364 .49862 .38705 .48888 .37307 .47459 Mtetra
.739 .753 .864 r
.37307 .47459 .38705 .48888 .41035 .47672 .39656 .46101 Mtetra
.687 .725 .879 r
.39656 .46101 .41035 .47672 .43363 .47011 .42004 .45155 Mtetra
.598 .66 .881 r
.42004 .45155 .43363 .47011 .457 .46924 .44355 .44792 Mtetra
.964 .651 .377 r
.44355 .44792 .457 .46924 .47816 .65581 .46384 .64173 Mtetra
.88 .775 .742 r
.46384 .64173 .47816 .65581 .50355 .64781 .48973 .60022 Mtetra
.324 .328 .71 r
.48973 .60022 .50355 .64781 .52916 .63176 .51517 .62329 Mtetra
.962 .73 .541 r
.51517 .62329 .52916 .63176 .5548 .60573 .54023 .41882 Mtetra
.585 .395 .59 r
.54023 .41882 .5548 .60573 .58087 .60918 .56488 .40463 Mtetra
.579 .388 .586 r
.56488 .40463 .58087 .60918 .60749 .61815 .5897 .39232 Mtetra
.549 .362 .581 r
.5897 .39232 .60749 .61815 .63368 .59747 .61518 .3978 Mtetra
.574 .385 .587 r
.61518 .3978 .63368 .59747 .6608 .59898 .64058 .38869 Mtetra
.592 .396 .586 r
.64058 .38869 .6608 .59898 .67799 .38392 .66568 .36763 Mtetra
.338 .571 .926 r
.66568 .36763 .67799 .38392 .7039 .3804 .69226 .37429 Mtetra
.779 .925 .932 r
.69226 .37429 .7039 .3804 .73009 .37653 .71791 .3575 Mtetra
.655 .696 .876 r
.71791 .3575 .73009 .37653 .75558 .35846 .74427 .34937 Mtetra
.808 .885 .9 r
.74427 .34937 .75558 .35846 .783 .36323 .77002 .33016 Mtetra
.606 .561 .778 r
.77002 .33016 .783 .36323 .80842 .34033 .79708 .32524 Mtetra
.625 .741 .93 r
.79708 .32524 .80842 .34033 .83563 .33546 .82431 .31871 Mtetra
.575 .696 .924 r
.82431 .31871 .83563 .33546 .86277 .327 .85218 .31529 Mtetra
.574 .78 .977 r
.85218 .31529 .86277 .327 .89089 .32465 .88022 .31021 Mtetra
.749 .797 .892 r
.26797 .48234 .28284 .49309 .30478 .49262 .29091 .46909 Mtetra
.595 .605 .832 r
.29091 .46909 .30478 .49262 .32722 .48842 .31332 .46593 Mtetra
.446 .544 .862 r
.31332 .46593 .32722 .48842 .35062 .47068 .33553 .47052 Mtetra
.457 .879 .924 r
.33553 .47052 .35062 .47068 .37307 .47459 .3587 .46337 Mtetra
.792 .802 .86 r
.3587 .46337 .37307 .47459 .39656 .46101 .38256 .44532 Mtetra
.447 .636 .936 r
.38256 .44532 .39656 .46101 .42004 .45155 .40573 .44742 Mtetra
.729 .922 .957 r
.40573 .44742 .42004 .45155 .44355 .44792 .42969 .43452 Mtetra
.955 .64 .392 r
.42969 .43452 .44355 .44792 .46384 .64173 .44944 .62011 Mtetra
.818 .717 .754 r
.44944 .62011 .46384 .64173 .48973 .60022 .47544 .58766 Mtetra
0 .38 .821 r
.47544 .58766 .48973 .60022 .51517 .62329 .50098 .60051 Mtetra
.943 .709 .556 r
.50098 .60051 .51517 .62329 .54023 .41882 .52695 .40583 Mtetra
.747 .792 .889 r
.52695 .40583 .54023 .41882 .56488 .40463 .55179 .39152 Mtetra
.699 .782 .915 r
.55179 .39152 .56488 .40463 .5897 .39232 .57682 .38086 Mtetra
.633 .792 .958 r
.57682 .38086 .5897 .39232 .61518 .3978 .60213 .3738 Mtetra
.546 .591 .85 r
.60213 .3738 .61518 .3978 .64058 .38869 .62791 .37357 Mtetra
.65 .744 .918 r
.62791 .37357 .64058 .38869 .66568 .36763 .65376 .36583 Mtetra
.753 .978 .917 r
.65376 .36583 .66568 .36763 .69226 .37429 .67939 .34834 Mtetra
.697 .651 .8 r
.67939 .34834 .69226 .37429 .71791 .3575 .70533 .33455 Mtetra
.593 .628 .856 r
.70533 .33455 .71791 .3575 .74427 .34937 .7321 .33085 Mtetra
.658 .708 .885 r
.7321 .33085 .74427 .34937 .77002 .33016 .75884 .32225 Mtetra
.411 .77 .995 r
.75884 .32225 .77002 .33016 .79708 .32524 .78643 .32061 Mtetra
.819 .965 .9 r
.78643 .32061 .79708 .32524 .82431 .31871 .8126 .2994 Mtetra
.483 .617 .907 r
.8126 .2994 .82431 .31871 .85218 .31529 .84118 .30153 Mtetra
.797 .829 .877 r
.84118 .30153 .85218 .31529 .88022 .31021 .86782 .28173 Mtetra
.43 .649 .95 r
.25312 .46797 .26797 .48234 .29091 .46909 .27505 .46981 Mtetra
.565 .93 .931 r
.27505 .46981 .29091 .46909 .31332 .46593 .2981 .45997 Mtetra
.794 .88 .909 r
.2981 .45997 .31332 .46593 .33553 .47052 .32174 .44347 Mtetra
.565 .567 .814 r
.32174 .44347 .33553 .47052 .3587 .46337 .34461 .4423 Mtetra
.71 .679 .818 r
.34461 .4423 .3587 .46337 .38256 .44532 .36834 .42917 Mtetra
.554 .68 .922 r
.36834 .42917 .38256 .44532 .40573 .44742 .39176 .42714 Mtetra
.738 .698 .813 r
.39176 .42714 .40573 .44742 .42969 .43452 .41594 .41097 Mtetra
.965 .654 .376 r
.41594 .41097 .42969 .43452 .44944 .62011 .43457 .60926 Mtetra
.866 .821 .802 r
.43457 .60926 .44944 .62011 .47544 .58766 .46082 .5781 Mtetra
.69 .843 .956 r
.46082 .5781 .47544 .58766 .50098 .60051 .48673 .56738 Mtetra
.54 .531 .793 r
.48673 .56738 .50098 .60051 .52695 .40583 .51281 .56841 Mtetra
.516 .266 .474 r
.51281 .56841 .52695 .40583 .55179 .39152 .53922 .55835 Mtetra
.498 .252 .472 r
.53922 .55835 .55179 .39152 .57682 .38086 .56576 .53935 Mtetra
.584 .322 .485 r
.56576 .53935 .57682 .38086 .60213 .3738 .59324 .56345 Mtetra
.534 .286 .485 r
.59324 .56345 .60213 .3738 .62791 .37357 .62074 .56004 Mtetra
0 0 .293 r
.62074 .56004 .62791 .37357 .65376 .36583 .64104 .35064 Mtetra
.791 .788 .85 r
.64104 .35064 .65376 .36583 .67939 .34834 .66677 .33068 Mtetra
.443 .618 .925 r
.66677 .33068 .67939 .34834 .70533 .33455 .69379 .33365 Mtetra
.75 .988 .893 r
.69379 .33365 .70533 .33455 .7321 .33085 .7199 .31466 Mtetra
.601 .719 .928 r
.7199 .31466 .7321 .33085 .75884 .32225 .74708 .30948 Mtetra
.703 .813 .933 r
.74708 .30948 .75884 .32225 .78643 .32061 .77405 .2977 Mtetra
.702 .688 .833 r
.77405 .2977 .78643 .32061 .8126 .2994 .80108 .2841 Mtetra
.389 .628 .949 r
.80108 .2841 .8126 .2994 .84118 .30153 .83003 .28808 Mtetra
.753 .827 .909 r
.83003 .28808 .84118 .30153 .86782 .28173 .85737 .27229 Mtetra
.649 .696 .88 r
.23826 .45078 .25312 .46797 .27505 .46981 .26094 .44385 Mtetra
.526 .556 .829 r
.26094 .44385 .27505 .46981 .2981 .45997 .28323 .44489 Mtetra
.681 .736 .892 r
.28323 .44489 .2981 .45997 .32174 .44347 .30652 .43579 Mtetra
.563 .825 .995 r
.30652 .43579 .32174 .44347 .34461 .4423 .32976 .43069 Mtetra
.797 .802 .855 r
.32976 .43069 .34461 .4423 .36834 .42917 .35397 .41161 Mtetra
.67 .706 .875 r
.35397 .41161 .36834 .42917 .39176 .42714 .37777 .40291 Mtetra
.602 .613 .835 r
.37777 .40291 .39176 .42714 .41594 .41097 .40159 .39875 Mtetra
.953 .64 .399 r
.40159 .39875 .41594 .41097 .43457 .60926 .41957 .5927 Mtetra
.516 .679 .939 r
.41957 .5927 .43457 .60926 .46082 .5781 .44536 .59176 Mtetra
.66 .914 .601 r
.44536 .59176 .46082 .5781 .48673 .56738 .47195 .56213 Mtetra
.852 .915 .875 r
.47195 .56213 .48673 .56738 .51281 .56841 .49842 .53792 Mtetra
.561 .561 .811 r
.49842 .53792 .51281 .56841 .53922 .55835 .52489 .53672 Mtetra
.407 .561 .895 r
.52489 .53672 .53922 .55835 .56576 .53935 .55178 .5423 Mtetra
.76 .996 .839 r
.55178 .5423 .56576 .53935 .59324 .56345 .5787 .51965 Mtetra
.571 .505 .742 r
.5787 .51965 .59324 .56345 .62074 .56004 .60616 .51764 Mtetra
.934 .687 .542 r
.60616 .51764 .62074 .56004 .64104 .35064 .62751 .31727 Mtetra
.615 .567 .777 r
.62751 .31727 .64104 .35064 .66677 .33068 .65388 .31094 Mtetra
.653 .695 .877 r
.65388 .31094 .66677 .33068 .69379 .33365 .68043 .30251 Mtetra
.54 .542 .805 r
.68043 .30251 .69379 .33365 .7199 .31466 .70778 .30313 Mtetra
.753 .847 .921 r
.70778 .30313 .7199 .31466 .74708 .30948 .73449 .28781 Mtetra
.625 .667 .87 r
.73449 .28781 .74708 .30948 .77405 .2977 .76202 .28121 Mtetra
.564 .705 .936 r
.76202 .28121 .77405 .2977 .80108 .2841 .79014 .27776 Mtetra
.804 .948 .916 r
.79014 .27776 .80108 .2841 .83003 .28808 .81707 .2577 Mtetra
.607 .588 .806 r
.81707 .2577 .83003 .28808 .85737 .27229 .84558 .25209 Mtetra
.7 .866 .96 r
.22221 .44396 .23826 .45078 .26094 .44385 .24534 .43357 Mtetra
.592 .788 .974 r
.24534 .43357 .26094 .44385 .28323 .44489 .26821 .42848 Mtetra
.722 .732 .859 r
.26821 .42848 .28323 .44489 .30652 .43579 .29187 .4157 Mtetra
.691 .685 .84 r
.29187 .4157 .30652 .43579 .32976 .43069 .31555 .40477 Mtetra
.642 .618 .81 r
.31555 .40477 .32976 .43069 .35397 .41161 .3392 .39712 Mtetra
.406 .647 .956 r
.3392 .39712 .35397 .41161 .37777 .40291 .36258 .39933 Mtetra
.791 .933 .925 r
.36258 .39933 .37777 .40291 .40159 .39875 .38715 .38219 Mtetra
.957 .637 .374 r
.38715 .38219 .40159 .39875 .41957 .5927 .40523 .55035 Mtetra
.628 .54 .735 r
.40523 .55035 .41957 .5927 .44536 .59176 .43116 .54104 Mtetra
.404 .375 .712 r
.43116 .54104 .44536 .59176 .47195 .56213 .45682 .55657 Mtetra
.902 .889 .808 r
.45682 .55657 .47195 .56213 .49842 .53792 .48372 .52277 Mtetra
0 .315 .788 r
.48372 .52277 .49842 .53792 .52489 .53672 .51024 .53887 Mtetra
.335 .817 .804 r
.51024 .53887 .52489 .53672 .55178 .5423 .53734 .53013 Mtetra
.767 .833 .903 r
.53734 .53013 .55178 .5423 .5787 .51965 .56459 .51303 Mtetra
.754 .918 .946 r
.56459 .51303 .5787 .51965 .60616 .51764 .59199 .4968 Mtetra
.961 .722 .531 r
.59199 .4968 .60616 .51764 .62751 .31727 .61462 .30876 Mtetra
.625 .857 .987 r
.61462 .30876 .62751 .31727 .65388 .31094 .64113 .30023 Mtetra
.524 .781 .991 r
.64113 .30023 .65388 .31094 .68043 .30251 .66812 .29644 Mtetra
.717 .928 .961 r
.66812 .29644 .68043 .30251 .70778 .30313 .69491 .28231 Mtetra
.746 .727 .834 r
.69491 .28231 .70778 .30313 .73449 .28781 .72165 .26468 Mtetra
.557 .621 .872 r
.72165 .26468 .73449 .28781 .76202 .28121 .74965 .26278 Mtetra
.709 .745 .88 r
.74965 .26278 .76202 .28121 .79014 .27776 .77714 .24958 Mtetra
.689 .647 .802 r
.77714 .24958 .79014 .27776 .81707 .2577 .80476 .2355 Mtetra
.521 .616 .888 r
.80476 .2355 .81707 .2577 .84558 .25209 .83401 .23555 Mtetra
.509 .724 .97 r
.20637 .43145 .22221 .44396 .24534 .43357 .22884 .42975 Mtetra
.814 .911 .906 r
.22884 .42975 .24534 .43357 .26821 .42848 .253 .4113 Mtetra
.629 .7 .896 r
.253 .4113 .26821 .42848 .29187 .4157 .27626 .40528 Mtetra
.736 .82 .917 r
.27626 .40528 .29187 .4157 .31555 .40477 .30023 .3925 Mtetra
.517 .736 .974 r
.30023 .3925 .31555 .40477 .3392 .39712 .32369 .39028 Mtetra
.701 .88 .964 r
.32369 .39028 .3392 .39712 .36258 .39933 .34793 .37913 Mtetra
.7 .695 .842 r
.34793 .37913 .36258 .39933 .38715 .38219 .3724 .36708 Mtetra
.956 .637 .382 r
.3724 .36708 .38715 .38219 .40523 .55035 .38953 .54122 Mtetra
.546 .815 .996 r
.38953 .54122 .40523 .55035 .43116 .54104 .41553 .53605 Mtetra
.186 .687 .911 r
.41553 .53605 .43116 .54104 .45682 .55657 .44169 .53665 Mtetra
.949 .716 .552 r
.44169 .53665 .45682 .55657 .48372 .52277 .47163 .33673 Mtetra
.567 .376 .581 r
.47163 .33673 .48372 .52277 .51024 .53887 .49708 .32573 Mtetra
.571 .374 .575 r
.49708 .32573 .51024 .53887 .53734 .53013 .52274 .31062 Mtetra
.556 .362 .573 r
.52274 .31062 .53734 .53013 .56459 .51303 .5486 .30366 Mtetra
.544 .355 .574 r
.5486 .30366 .56459 .51303 .59199 .4968 .57485 .30317 Mtetra
.561 .37 .579 r
.57485 .30317 .59199 .4968 .61462 .30876 .60129 .29475 Mtetra
.555 .741 .963 r
.60129 .29475 .61462 .30876 .64113 .30023 .62816 .2909 Mtetra
.692 .869 .965 r
.62816 .2909 .64113 .30023 .66812 .29644 .65505 .27913 Mtetra
.754 .77 .866 r
.65505 .27913 .66812 .29644 .69491 .28231 .68189 .26212 Mtetra
.727 .73 .854 r
.68189 .26212 .69491 .28231 .72165 .26468 .70897 .24682 Mtetra
.506 .664 .933 r
.70897 .24682 .72165 .26468 .74965 .26278 .73723 .24624 Mtetra
.501 .683 .948 r
.73723 .24624 .74965 .26278 .77714 .24958 .76591 .24538 Mtetra
.868 .974 .853 r
.76591 .24538 .77714 .24958 .80476 .2355 .79273 .21823 Mtetra
.556 .702 .937 r
.79273 .21823 .80476 .2355 .83401 .23555 .82183 .2148 Mtetra
.724 .819 .924 r
.18998 .42125 .20637 .43145 .22884 .42975 .21353 .40944 Mtetra
.712 .693 .83 r
.21353 .40944 .22884 .42975 .253 .4113 .23735 .39626 Mtetra
.579 .716 .936 r
.23735 .39626 .253 .4113 .27626 .40528 .26054 .39239 Mtetra
.765 .79 .873 r
.26054 .39239 .27626 .40528 .30023 .3925 .28491 .37629 Mtetra
.699 .739 .882 r
.28491 .37629 .30023 .3925 .32369 .39028 .30904 .36527 Mtetra
.509 .569 .852 r
.30904 .36527 .32369 .39028 .34793 .37913 .33262 .36637 Mtetra
.509 .731 .973 r
.33262 .36637 .34793 .37913 .3724 .36708 .35673 .36428 Mtetra
.941 .625 .412 r
.35673 .36428 .3724 .36708 .38953 .54122 .37263 .55118 Mtetra
.734 .975 .731 r
.37263 .55118 .38953 .54122 .41553 .53605 .39978 .5241 Mtetra
.523 .766 .985 r
.39978 .5241 .41553 .53605 .44169 .53665 .4262 .52061 Mtetra
.954 .722 .549 r
.4262 .52061 .44169 .53665 .47163 .33673 .45722 .31926 Mtetra
.592 .7 .918 r
.45722 .31926 .47163 .33673 .49708 .32573 .48275 .31459 Mtetra
.506 .765 .989 r
.48275 .31459 .49708 .32573 .52274 .31062 .50857 .3116 Mtetra
.589 .947 .891 r
.50857 .3116 .52274 .31062 .5486 .30366 .53471 .29796 Mtetra
.579 .887 .991 r
.53471 .29796 .5486 .30366 .57485 .30317 .56108 .28956 Mtetra
.573 .757 .965 r
.56108 .28956 .57485 .30317 .60129 .29475 .5878 .28469 Mtetra
.867 .871 .838 r
.5878 .28469 .60129 .29475 .62816 .2909 .61419 .25699 Mtetra
.625 .577 .78 r
.61419 .25699 .62816 .2909 .65505 .27913 .64125 .24879 Mtetra
.639 .607 .802 r
.64125 .24879 .65505 .27913 .68189 .26212 .66857 .23967 Mtetra
.45 .579 .891 r
.66857 .23967 .68189 .26212 .70897 .24682 .69687 .24318 Mtetra
.766 .975 .919 r
.69687 .24318 .70897 .24682 .73723 .24624 .72422 .22408 Mtetra
.632 .678 .875 r
.72422 .22408 .73723 .24624 .76591 .24538 .75252 .2163 Mtetra
.575 .588 .829 r
.75252 .2163 .76591 .24538 .79273 .21823 .78152 .21299 Mtetra
.594 .917 .974 r
.78152 .21299 .79273 .21823 .82183 .2148 .81023 .20198 Mtetra
.612 .682 .892 r
.17415 .40277 .18998 .42125 .21353 .40944 .19713 .39753 Mtetra
.612 .777 .96 r
.19713 .39753 .21353 .40944 .23735 .39626 .22043 .39156 Mtetra
.71 .91 .965 r
.22043 .39156 .23735 .39626 .26054 .39239 .24451 .37943 Mtetra
.814 .791 .83 r
.24451 .37943 .26054 .39239 .28491 .37629 .2696 .35669 Mtetra
.623 .678 .881 r
.2696 .35669 .28491 .37629 .30904 .36527 .29347 .3506 Mtetra
.63 .746 .931 r
.29347 .3506 .30904 .36527 .33262 .36637 .31764 .3439 Mtetra
.697 .679 .829 r
.31764 .3439 .33262 .36637 .35673 .36428 .3424 .33134 Mtetra
.97 .655 .339 r
.3424 .33134 .35673 .36428 .37263 .55118 .35784 .50784 Mtetra
.334 .362 .741 r
.35784 .50784 .37263 .55118 .39978 .5241 .3832 .52394 Mtetra
.903 .951 .823 r
.3832 .52394 .39978 .5241 .4262 .52061 .41087 .49139 Mtetra
.267 .416 .826 r
.41087 .49139 .4262 .52061 .45722 .31926 .43722 .50481 Mtetra
.51 .252 .459 r
.43722 .50481 .45722 .31926 .48275 .31459 .46455 .49926 Mtetra
.5 .243 .456 r
.46455 .49926 .48275 .31459 .50857 .3116 .49225 .4888 Mtetra
.473 .219 .448 r
.49225 .4888 .50857 .3116 .53471 .29796 .52022 .46746 Mtetra
.524 .26 .456 r
.52022 .46746 .53471 .29796 .56108 .28956 .54843 .46933 Mtetra
0 0 .21 r
.54843 .46933 .56108 .28956 .5878 .28469 .57378 .26095 Mtetra
.633 .658 .857 r
.57378 .26095 .5878 .28469 .61419 .25699 .60087 .25321 Mtetra
.802 .968 .909 r
.60087 .25321 .61419 .25699 .64125 .24879 .62781 .2325 Mtetra
.558 .718 .947 r
.62781 .2325 .64125 .24879 .66857 .23967 .65555 .22863 Mtetra
.779 .873 .916 r
.65555 .22863 .66857 .23967 .69687 .24318 .68294 .21062 Mtetra
.483 .512 .812 r
.68294 .21062 .69687 .24318 .72422 .22408 .71181 .21469 Mtetra
.675 .881 .975 r
.71181 .21469 .72422 .22408 .75252 .2163 .74011 .20278 Mtetra
.667 .815 .954 r
.74011 .20278 .75252 .2163 .78152 .21299 .76876 .19216 Mtetra
.725 .741 .864 r
.76876 .19216 .78152 .21299 .81023 .20198 .79723 .17637 Mtetra
.772 .822 .892 r
.15714 .39236 .17415 .40277 .19713 .39753 .1814 .37639 Mtetra
.546 .63 .886 r
.1814 .37639 .19713 .39753 .22043 .39156 .20433 .37463 Mtetra
.749 .743 .847 r
.20433 .37463 .22043 .39156 .24451 .37943 .2289 .35855 Mtetra
.688 .689 .845 r
.2289 .35855 .24451 .37943 .2696 .35669 .25316 .34726 Mtetra
.669 .838 .964 r
.25316 .34726 .2696 .35669 .29347 .3506 .27745 .33785 Mtetra
.679 .791 .934 r
.27745 .33785 .29347 .3506 .31764 .3439 .30197 .32814 Mtetra
.672 .749 .908 r
.30197 .32814 .31764 .3439 .3424 .33134 .32669 .31872 Mtetra
.952 .637 .396 r
.32669 .31872 .3424 .33134 .35784 .50784 .34057 .50894 Mtetra
.748 .985 .904 r
.34057 .50894 .35784 .50784 .3832 .52394 .36776 .48968 Mtetra
.428 .475 .806 r
.36776 .48968 .3832 .52394 .41087 .49139 .39402 .49674 Mtetra
.601 .948 .809 r
.39402 .49674 .41087 .49139 .43722 .50481 .42158 .47868 Mtetra
.386 .521 .87 r
.42158 .47868 .43722 .50481 .46455 .49926 .4487 .48532 Mtetra
.825 .823 .847 r
.4487 .48532 .46455 .49926 .49225 .4888 .47682 .46009 Mtetra
.77 .685 .769 r
.47682 .46009 .49225 .4888 .52022 .46746 .50496 .43344 Mtetra
.172 .321 .775 r
.50496 .43344 .52022 .46746 .54843 .46933 .53321 .45431 Mtetra
.971 .731 .517 r
.53321 .45431 .54843 .46933 .57378 .26095 .5597 .24778 Mtetra
.811 .838 .87 r
.5597 .24778 .57378 .26095 .60087 .25321 .58671 .22604 Mtetra
.66 .645 .824 r
.58671 .22604 .60087 .25321 .62781 .2325 .6141 .21523 Mtetra
.348 .599 .941 r
.6141 .21523 .62781 .2325 .65555 .22863 .64234 .21997 Mtetra
.854 .913 .873 r
.64234 .21997 .65555 .22863 .68294 .21062 .6697 .19468 Mtetra
.645 .768 .938 r
.6697 .19468 .68294 .21062 .71181 .21469 .69799 .18568 Mtetra
.466 .533 .843 r
.69799 .18568 .71181 .21469 .74011 .20278 .72747 .18971 Mtetra
.785 .86 .905 r
.72747 .18971 .74011 .20278 .76876 .19216 .75573 .17039 Mtetra
.741 .74 .851 r
.75573 .17039 .76876 .19216 .79723 .17637 .78424 .15263 Mtetra
.787 .751 .82 r
.14048 .37599 .15714 .39236 .1814 .37639 .16546 .35495 Mtetra
.578 .643 .879 r
.16546 .35495 .1814 .37639 .20433 .37463 .1886 .35141 Mtetra
.702 .674 .82 r
.1886 .35141 .20433 .37463 .2289 .35855 .21301 .338 Mtetra
.704 .7 .843 r
.21301 .338 .2289 .35855 .25316 .34726 .23751 .32521 Mtetra
.58 .641 .876 r
.23751 .32521 .25316 .34726 .27745 .33785 .26141 .32143 Mtetra
.705 .75 .887 r
.26141 .32143 .27745 .33785 .30197 .32814 .28623 .30949 Mtetra
.596 .69 .908 r
.28623 .30949 .30197 .32814 .32669 .31872 .31075 .3045 Mtetra
.954 .641 .397 r
.31075 .3045 .32669 .31872 .34057 .50894 .32328 .5022 Mtetra
.684 .9 .974 r
.32328 .5022 .34057 .50894 .36776 .48968 .35039 .48987 Mtetra
.924 .938 .794 r
.35039 .48987 .36776 .48968 .39402 .49674 .37886 .45208 Mtetra
.093 .203 .687 r
.37886 .45208 .39402 .49674 .42158 .47868 .40468 .48129 Mtetra
.349 .825 .807 r
.40468 .48129 .42158 .47868 .4487 .48532 .4325 .47191 Mtetra
.738 .827 .919 r
.4325 .47191 .4487 .48532 .47682 .46009 .46072 .45644 Mtetra
.383 .826 .947 r
.46072 .45644 .47682 .46009 .50496 .43344 .48901 .45102 Mtetra
0 0 0 r
.48901 .45102 .50496 .43344 .53321 .45431 .51769 .43259 Mtetra
.964 .721 .522 r
.51769 .43259 .53321 .45431 .5597 .24778 .54524 .22289 Mtetra
.633 .654 .853 r
.54524 .22289 .5597 .24778 .58671 .22604 .57264 .21469 Mtetra
.648 .837 .973 r
.57264 .21469 .58671 .22604 .6141 .21523 .6003 .20492 Mtetra
.79 .888 .915 r
.6003 .20492 .6141 .21523 .64234 .21997 .62793 .18583 Mtetra
.586 .565 .797 r
.62793 .18583 .64234 .21997 .6697 .19468 .6563 .18085 Mtetra
.732 .833 .927 r
.6563 .18085 .6697 .19468 .69799 .18568 .68452 .16587 Mtetra
.376 .586 .925 r
.68452 .16587 .69799 .18568 .72747 .18971 .71419 .17068 Mtetra
.821 .794 .827 r
.71419 .17068 .72747 .18971 .75573 .17039 .7422 .14444 Mtetra
.563 .621 .868 r
.7422 .14444 .75573 .17039 .78424 .15263 .7721 .14104 Mtetra
.438 .505 .831 r
.12509 .34715 .14048 .37599 .16546 .35495 .14714 .35138 Mtetra
.84 .911 .884 r
.14714 .35138 .16546 .35495 .1886 .35141 .17252 .32938 Mtetra
.676 .678 .845 r
.17252 .32938 .1886 .35141 .21301 .338 .19673 .31881 Mtetra
.489 .638 .921 r
.19673 .31881 .21301 .338 .23751 .32521 .22011 .31867 Mtetra
.782 .894 .923 r
.22011 .31867 .23751 .32521 .26141 .32143 .24535 .3018 Mtetra
.308 .543 .914 r
.24535 .3018 .26141 .32143 .28623 .30949 .26883 .30765 Mtetra
.708 .955 .95 r
.26883 .30765 .28623 .30949 .31075 .3045 .29427 .29326 Mtetra
.742 .835 .922 r
.29427 .29326 .31075 .3045 .32328 .5022 .31986 .27897 Mtetra
.548 .347 .56 r
.31986 .27897 .32328 .5022 .35039 .48987 .34539 .26841 Mtetra
.524 .329 .558 r
.34539 .26841 .35039 .48987 .37886 .45208 .37057 .26921 Mtetra
.577 .377 .573 r
.37057 .26921 .37886 .45208 .40468 .48129 .39708 .24793 Mtetra
.543 .342 .558 r
.39708 .24793 .40468 .48129 .4325 .47191 .42324 .23884 Mtetra
.522 .326 .556 r
.42324 .23884 .4325 .47191 .46072 .45644 .4494 .24057 Mtetra
.545 .346 .562 r
.4494 .24057 .46072 .45644 .48901 .45102 .47619 .23166 Mtetra
.556 .354 .563 r
.47619 .23166 .48901 .45102 .51769 .43259 .5033 .21668 Mtetra
.554 .353 .563 r
.5033 .21668 .51769 .43259 .54524 .22289 .53059 .20283 Mtetra
.618 .703 .906 r
.53059 .20283 .54524 .22289 .57264 .21469 .55816 .19569 Mtetra
.547 .687 .931 r
.55816 .19569 .57264 .21469 .6003 .20492 .58613 .19232 Mtetra
.684 .836 .956 r
.58613 .19232 .6003 .20492 .62793 .18583 .61427 .18047 Mtetra
.727 .952 .949 r
.61427 .18047 .62793 .18583 .6563 .18085 .64249 .1639 Mtetra
.492 .694 .958 r
.64249 .1639 .6563 .18085 .68452 .16587 .67161 .16233 Mtetra
.732 .976 .923 r
.67161 .16233 .68452 .16587 .71419 .17068 .70021 .1437 Mtetra
.652 .659 .844 r
.70021 .1437 .71419 .17068 .7422 .14444 .7295 .13296 Mtetra
.603 .837 .988 r
.7295 .13296 .7422 .14444 .7721 .14104 .75926 .12423 Mtetra
.77 .877 .925 r
.10665 .34005 .12509 .34715 .14714 .35138 .13127 .32443 Mtetra
.547 .582 .841 r
.13127 .32443 .14714 .35138 .17252 .32938 .15439 .32254 Mtetra
.638 .874 .985 r
.15439 .32254 .17252 .32938 .19673 .31881 .17862 .31352 Mtetra
.731 .911 .956 r
.17862 .31352 .19673 .31881 .22011 .31867 .20356 .29976 Mtetra
.592 .69 .91 r
.20356 .29976 .22011 .31867 .24535 .3018 .22781 .29476 Mtetra
.785 .892 .921 r
.22781 .29476 .24535 .3018 .26883 .30765 .25344 .2774 Mtetra
.631 .603 .803 r
.25344 .2774 .26883 .30765 .29427 .29326 .27846 .26897 Mtetra
.606 .641 .859 r
.27846 .26897 .29427 .29326 .31986 .27897 .30356 .26305 Mtetra
.509 .704 .958 r
.30356 .26305 .31986 .27897 .34539 .26841 .3287 .26089 Mtetra
.74 .898 .95 r
.3287 .26089 .34539 .26841 .37057 .26921 .35492 .24613 Mtetra
.558 .637 .885 r
.35492 .24613 .37057 .26921 .39708 .24793 .38075 .24298 Mtetra
.851 .931 .879 r
.38075 .24298 .39708 .24793 .42324 .23884 .40776 .21848 Mtetra
.378 .581 .921 r
.40776 .21848 .42324 .23884 .4494 .24057 .43393 .22248 Mtetra
.752 .769 .866 r
.43393 .22248 .4494 .24057 .47619 .23166 .46106 .20506 Mtetra
.523 .59 .863 r
.46106 .20506 .47619 .23166 .5033 .21668 .48812 .20417 Mtetra
.765 .849 .914 r
.48812 .20417 .5033 .21668 .53059 .20283 .51567 .18688 Mtetra
.568 .742 .959 r
.51567 .18688 .53059 .20283 .55816 .19569 .54344 .18168 Mtetra
.771 .836 .902 r
.54344 .18168 .55816 .19569 .58613 .19232 .57139 .16348 Mtetra
.521 .574 .849 r
.57139 .16348 .58613 .19232 .61427 .18047 .59992 .16289 Mtetra
.709 .78 .908 r
.59992 .16289 .61427 .18047 .64249 .1639 .62848 .14905 Mtetra
.613 .786 .964 r
.62848 .14905 .64249 .1639 .67161 .16233 .65753 .14099 Mtetra
.731 .749 .867 r
.65753 .14099 .67161 .16233 .70021 .1437 .68646 .12423 Mtetra
.688 .757 .904 r
.68646 .12423 .70021 .1437 .7295 .13296 .71585 .11152 Mtetra
.675 .731 .892 r
.71585 .11152 .7295 .13296 .75926 .12423 .74557 .0995 Mtetra
.681 .72 .879 r
.08934 .32153 .10665 .34005 .13127 .32443 .11342 .31108 Mtetra
.73 .794 .903 r
.11342 .31108 .13127 .32443 .15439 .32254 .13806 .29762 Mtetra
.64 .645 .84 r
.13806 .29762 .15439 .32254 .17862 .31352 .16226 .28927 Mtetra
.448 .566 .881 r
.16226 .28927 .17862 .31352 .20356 .29976 .18555 .29148 Mtetra
.696 .871 .964 r
.18555 .29148 .20356 .29976 .22781 .29476 .21063 .27984 Mtetra
.808 .79 .835 r
.21063 .27984 .22781 .29476 .25344 .2774 .23698 .2568 Mtetra
.648 .697 .882 r
.23698 .2568 .25344 .2774 .27846 .26897 .26212 .24813 Mtetra
.666 .703 .874 r
.26212 .24813 .27846 .26897 .30356 .26305 .28762 .23805 Mtetra
.298 .48 .87 r
.28762 .23805 .30356 .26305 .3287 .26089 .3121 .24618 Mtetra
.785 .805 .869 r
.3121 .24618 .3287 .26089 .35492 .24613 .3388 .22654 Mtetra
.608 .702 .911 r
.3388 .22654 .35492 .24613 .38075 .24298 .36491 .22005 Mtetra
.745 .716 .825 r
.36491 .22005 .38075 .24298 .40776 .21848 .39186 .20133 Mtetra
.59 .73 .941 r
.39186 .20133 .40776 .21848 .43393 .22248 .41848 .19545 Mtetra
.497 .575 .864 r
.41848 .19545 .43393 .22248 .46106 .20506 .44526 .19582 Mtetra
.671 .878 .976 r
.44526 .19582 .46106 .20506 .48812 .20417 .47272 .18417 Mtetra
.665 .729 .898 r
.47272 .18417 .48812 .20417 .51567 .18688 .50042 .17358 Mtetra
.753 .843 .919 r
.50042 .17358 .51567 .18688 .54344 .18168 .52839 .15697 Mtetra
.623 .665 .87 r
.52839 .15697 .54344 .18168 .57139 .16348 .55663 .14894 Mtetra
.545 .762 .978 r
.55663 .14894 .57139 .16348 .59992 .16289 .58527 .14392 Mtetra
.653 .747 .919 r
.58527 .14392 .59992 .16289 .62848 .14905 .61416 .13382 Mtetra
.719 .822 .929 r
.61416 .13382 .62848 .14905 .65753 .14099 .64319 .11913 Mtetra
.626 .705 .903 r
.64319 .11913 .65753 .14099 .68646 .12423 .67277 .11063 Mtetra
.863 .874 .845 r
.67277 .11063 .68646 .12423 .71585 .11152 .70146 .08159 Mtetra
.518 .573 .85 r
.70146 .08159 .71585 .11152 .74557 .0995 .73213 .08087 Mtetra
.549 .603 .86 r
.07271 .29614 .08934 .32153 .11342 .31108 .09574 .29367 Mtetra
.561 .701 .935 r
.09574 .29367 .11342 .31108 .13806 .29762 .11926 .28978 Mtetra
.816 .87 .886 r
.11926 .28978 .13806 .29762 .16226 .28927 .14515 .26908 Mtetra
.423 .607 .924 r
.14515 .26908 .16226 .28927 .18555 .29148 .16851 .27083 Mtetra
.717 .718 .85 r
.16851 .27083 .18555 .29148 .21063 .27984 .19401 .25636 Mtetra
.578 .642 .878 r
.19401 .25636 .21063 .27984 .23698 .2568 .21867 .25189 Mtetra
.566 .889 .988 r
.21867 .25189 .23698 .2568 .26212 .24813 .24401 .24353 Mtetra
.674 .924 .973 r
.24401 .24353 .26212 .24813 .28762 .23805 .26994 .23114 Mtetra
.816 .905 .903 r
.26994 .23114 .28762 .23805 .3121 .24618 .29672 .2103 Mtetra
.463 .485 .796 r
.29672 .2103 .3121 .24618 .3388 .22654 .32193 .2138 Mtetra
.724 .83 .931 r
.32193 .2138 .3388 .22654 .36491 .22005 .34865 .19991 Mtetra
.698 .733 .878 r
.34865 .19991 .36491 .22005 .39186 .20133 .37551 .18692 Mtetra
.458 .718 .98 r
.37551 .18692 .39186 .20133 .41848 .19545 .40212 .18534 Mtetra
.784 .883 .918 r
.40212 .18534 .41848 .19545 .44526 .19582 .4297 .16659 Mtetra
.643 .634 .826 r
.4297 .16659 .44526 .19582 .47272 .18417 .45721 .15637 Mtetra
.622 .637 .844 r
.45721 .15637 .47272 .18417 .50042 .17358 .48498 .14813 Mtetra
.746 .709 .818 r
.48498 .14813 .50042 .17358 .52839 .15697 .51313 .12804 Mtetra
.418 .522 .856 r
.51313 .12804 .52839 .15697 .55663 .14894 .54152 .1328 Mtetra
.702 .803 .928 r
.54152 .1328 .55663 .14894 .58527 .14392 .57024 .11935 Mtetra
.609 .668 .882 r
.57024 .11935 .58527 .14392 .61416 .13382 .59936 .11196 Mtetra
.673 .727 .891 r
.59936 .11196 .61416 .13382 .64319 .11913 .6287 .09994 Mtetra
.697 .77 .909 r
.6287 .09994 .64319 .11913 .67277 .11063 .65826 .0863 Mtetra
.686 .711 .868 r
.65826 .0863 .67277 .11063 .70146 .08159 .68809 .07258 Mtetra
.823 .941 .903 r
.68809 .07258 .70146 .08159 .73213 .08087 .71752 .04885 Mtetra
.66 .886 .981 r
.05295 .28976 .07271 .29614 .09574 .29367 .07723 .27957 Mtetra
.652 .778 .941 r
.07723 .27957 .09574 .29367 .11926 .28978 .10151 .27087 Mtetra
.585 .697 .919 r
.10151 .27087 .11926 .28978 .14515 .26908 .12555 .26576 Mtetra
.659 .928 .972 r
.12555 .26576 .14515 .26908 .16851 .27083 .1507 .25399 Mtetra
.781 .771 .844 r
.1507 .25399 .16851 .27083 .19401 .25636 .17703 .23366 Mtetra
.674 .69 .857 r
.17703 .23366 .19401 .25636 .21867 .25189 .20245 .2225 Mtetra
.554 .581 .836 r
.20245 .2225 .21867 .25189 .24401 .24353 .2273 .21938 Mtetra
.725 .697 .824 r
.2273 .21938 .24401 .24353 .26994 .23114 .25373 .20257 Mtetra
.583 .605 .839 r
.25373 .20257 .26994 .23114 .29672 .2103 .27935 .19741 Mtetra
.546 .779 .985 r
.27935 .19741 .29672 .2103 .32193 .2138 .3053 .1923 Mtetra
.548 .663 .912 r
.3053 .1923 .32193 .2138 .34865 .19991 .3315 .18877 Mtetra
.818 .864 .881 r
.3315 .18877 .34865 .19991 .37551 .18692 .35912 .1663 Mtetra
.508 .659 .928 r
.35912 .1663 .37551 .18692 .40212 .18534 .38585 .16441 Mtetra
.778 .755 .833 r
.38585 .16441 .40212 .18534 .4297 .16659 .41375 .14243 Mtetra
.656 .686 .867 r
.41375 .14243 .4297 .16659 .45721 .15637 .4414 .13181 Mtetra
.419 .57 .897 r
.4414 .13181 .45721 .15637 .48498 .14813 .46908 .13479 Mtetra
.665 .829 .962 r
.46908 .13479 .48498 .14813 .51313 .12804 .49744 .12356 Mtetra
.828 .967 .893 r
.49744 .12356 .51313 .12804 .54152 .1328 .52608 .09931 Mtetra
.619 .6 .81 r
.52608 .09931 .54152 .1328 .57024 .11935 .55492 .09016 Mtetra
.547 .597 .856 r
.55492 .09016 .57024 .11935 .59936 .11196 .58423 .08694 Mtetra
.706 .712 .853 r
.58423 .08694 .59936 .11196 .6287 .09994 .61363 .07117 Mtetra
.725 .69 .816 r
.61363 .07117 .6287 .09994 .65826 .0863 .64311 .05193 Mtetra
.446 .503 .824 r
.64311 .05193 .65826 .0863 .68809 .07258 .67397 .05616 Mtetra
.794 .845 .89 r
.67397 .05616 .68809 .07258 .71752 .04885 .70386 .03427 Mtetra
.653 .801 .954 r
.03367 .27713 .05295 .28976 .07723 .27957 .0579 .26823 Mtetra
.632 .817 .971 r
.0579 .26823 .07723 .27957 .10151 .27087 .08225 .25999 Mtetra
.791 .839 .888 r
.08225 .25999 .10151 .27087 .12555 .26576 .10832 .24096 Mtetra
.694 .678 .83 r
.10832 .24096 .12555 .26576 .1507 .25399 .13378 .2274 Mtetra
.439 .55 .872 r
.13378 .2274 .1507 .25399 .17703 .23366 .15751 .22963 Mtetra
.75 .937 .947 r
.15751 .22963 .17703 .23366 .20245 .2225 .18374 .21342 Mtetra
.754 .877 .935 r
.18374 .21342 .20245 .2225 .2273 .21938 .21007 .1976 Mtetra
.647 .698 .883 r
.21007 .1976 .2273 .21938 .25373 .20257 .23593 .18834 Mtetra
.658 .797 .949 r
.23593 .18834 .25373 .20257 .27935 .19741 .26211 .17845 Mtetra
.46 .658 .946 r
.26211 .17845 .27935 .19741 .3053 .1923 .28781 .17793 Mtetra
.795 .823 .874 r
.28781 .17793 .3053 .1923 .3315 .18877 .31538 .15689 Mtetra
.616 .603 .815 r
.31538 .15689 .3315 .18877 .35912 .1663 .34225 .14855 Mtetra
.536 .714 .954 r
.34225 .14855 .35912 .1663 .38585 .16441 .36921 .14457 Mtetra
.711 .754 .886 r
.36921 .14457 .38585 .16441 .41375 .14243 .39702 .13011 Mtetra
.764 .862 .921 r
.39702 .13011 .41375 .14243 .4414 .13181 .42515 .11238 Mtetra
.658 .746 .915 r
.42515 .11238 .4414 .13181 .46908 .13479 .45327 .10178 Mtetra
.594 .591 .819 r
.45327 .10178 .46908 .13479 .49744 .12356 .48163 .09486 Mtetra
.6 .63 .852 r
.48163 .09486 .49744 .12356 .52608 .09931 .51037 .08763 Mtetra
.656 .859 .977 r
.51037 .08763 .52608 .09931 .55492 .09016 .53948 .07605 Mtetra
.694 .84 .953 r
.53948 .07605 .55492 .09016 .58423 .08694 .56886 .06259 Mtetra
.64 .696 .886 r
.56886 .06259 .58423 .08694 .61363 .07117 .59861 .05241 Mtetra
.662 .772 .931 r
.59861 .05241 .61363 .07117 .64311 .05193 .62866 .04089 Mtetra
.511 .82 1 r
.62866 .04089 .64311 .05193 .67397 .05616 .65928 .03451 Mtetra
.765 .781 .866 r
.65928 .03451 .67397 .05616 .70386 .03427 .68953 .01368 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
gsave
.12586 .2075 -70 -15.9926 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.26314 .16665 m
.26757 .17149 L
s
gsave
.25429 .15697 -74.4005 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.39772 .11395 m
.4019 .11901 L
s
gsave
.38935 .10384 -73.7924 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.53939 .05848 m
.54329 .06375 L
s
gsave
.53158 .04793 -73.1843 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.16024 .20694 m
.163 .20975 L
s
.18558 .19702 m
.18832 .19985 L
s
.21118 .187 m
.21389 .18985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.31615 .14589 m
.31875 .14885 L
s
.34306 .13535 m
.34564 .13834 L
s
.37025 .12471 m
.37279 .12772 L
s
.42547 .10309 m
.42794 .10615 L
s
.4535 .09211 m
.45595 .0952 L
s
.48183 .08102 m
.48425 .08413 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.59817 .03546 m
.60044 .03868 L
s
.62804 .02377 m
.63027 .02701 L
s
.65822 .01195 m
.66042 .01522 L
s
.11029 .2265 m
.1131 .22926 L
s
.08568 .23614 m
.08851 .23887 L
s
.0613 .24568 m
.06416 .24839 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00_@3oool400000080oooo0P00
001K0?ooo`00_@3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
F03oool00;h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1H0?ooo`00_`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo05P0oooo00300?ooo`030000003oool00000
00800000F`3oool00;d0oooo00H000000?ooo`3oool000000?ooo`00001M0?ooo`00_P3oool20000
0080oooo1000001J0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00b03oool2
000005H0oooo00350?ooo`<0000000<0oooo0000003oool0E@3oool00<<0oooo0P0000040?ooo`80
0000E@3oool00<00oooo0`0000060?ooo`030000003oool0000005@0oooo002H0?ooo`@000000P3o
ool2000001h0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000E03o
ool009P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo01P0oooo
0`00000:0?ooo`050<?7g@000000oooo0?ooo`000000D`3oool009T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo01D0oooo0`00000<0?ooo`80`lOM00<000000?ooo`00
00000P00001B0?ooo`00VP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0
oooo0P0000020?ooo`030000003oool0oooo00P0oooo1033amd01@000000`lOM0?ooo`3oool00000
0580oooo002K0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0403oool3000000h0
oooo1@33amd00`000000`lOM0?ooo`020?ooo`030000003oool0oooo04l0oooo002H0?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0>0?ooo`<000003`3oool60<?7
g@0300000033amd0`lOM00<0oooo00<000000?ooo`3oool0CP3oool009T0oooo0P0000030?ooo`80
00003P3oool300000080oooo00<000000?ooo`3oool0203oool408;Ao`L0`lOM00<000000<?7g@3;
f><00P3;f><00`3oool000000?ooo`1?0?ooo`00[03oool2000000/0oooo0`2YaNh708;Ao`L0`lOM
00<000000<_Hh`3;f><00P3;f><2000004l0oooo002Y0?ooo`<000002P3oool70:W5kPL0P]7o1033
amd20<_Hh`030000003;f><0bmSS00<0bmSS00<000000?ooo`3oool0C@3oool00:L0oooo0P000003
0?ooo`030000003oool0oooo00D0oooo2P2YaNh608;Ao`<0`lOM0`3;f><00`000000bmSS0<_Hh`02
0<_Hh`030=;`i`3oool0000004h0oooo002T0?ooo`<000002`3oool00`2S/^80ZLG^0:W5kP080:W5
kP030;V`d01bP=80LX3B00<0LX3B0P22dOl00`33amd0bmSS0<_Hh`020<_Hh`040000003;f><0bmSS
0<_Hh`<0d_3W00<0oooo0000003oool0C03oool00:80oooo0`00000:0?ooo`D0Xk;R202YaNh30;V`
d0L0LX3B103;f><00`000000bmSS0<_Hh`040=;`i`030?ooo`000000oooo04`0oooo002O0?ooo`<0
00000`3oool00`000000oooo0?ooo`040?ooo`T0Xk;R1@2YaNh50;V`d0P0LX3B0`3;f><00`000000
bmSS0=;`i`040=;`i`030?ooo`000000000000P0oooo0P0000120?ooo`00W@3oool2000000/0oooo
00<0/MOc0:>bhP2S/^80202S/^830:W5kPL0^K3@2@1bP=820<_Hh`030000003Bl>L0d_3W00D0d_3W
0P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000440oooo001f0?ooo`<00000
0P3oool2000001d0oooo0`0000000`3oool000000?ooo`070?ooo`D0/MOc2P2S/^800`2YaNh0^K3@
0;V`d0070;V`d0T0LX3B00<0bmSS0000003Bl>L01P3Bl>L20?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0?`3oool007L0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0G0?ooo`<000002`3oool80;7Gl`P0Xk;R00<0];KJ0;V`d02i/=00202i/=0807:0dP80[kKN
00<000000=;`i`3Bl>L01@3Bl>L30?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
?`3oool007L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`800000303o
ool30:OKnPL0/MOc1P2S/^840;BffPT0^K3@1@1bP=850:nfgP030000002_]]h0d_3W00H0d_3W0`3o
ool00`000000oooo0?ooo`020?ooo`<00000@P3oool007L0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0B0?ooo`<000000P3oool00`000000oooo0?ooo`060?ooo`L0Ym_j1`2aeo<4
0:>bhPD0];KJ2P2i/=000`1bP=80[kKN0:nfgP060:nfgP030000002_]]h0Q9;I00H0Q9;I0`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo001g0?ooo`030000003oool0oooo
00<000004`3oool2000000`0oooo2P2WfoX70;7Gl`030:>bhP2d]]X0];KJ00H0];KJ202i/=000`2b
aNP0[kKN0:nfgP070:nfgP030000003LgmP0g=oH00L0Q9;I00@0oooo0000003oool000000`3oool4
00000440oooo001f0?ooo`8000000P3oool00`000000oooo0?ooo`0@0?ooo`<000002`3oool409VQ
fPP0Ym_j00<0WYW?08bHf`2<V=/01@2<V=/:0;BffPD0^K3@102baNP80:nfgP030000003LgmP0g=oH
00P0Q9;I0`3oool00`000000oooo0?ooo`150?ooo`00M`3oool00`000000oooo0?ooo`04000000d0
oooo0P0000030?ooo`030000003oool0oooo00D0oooo202IXMX40:OKnPD0WYW?1`2<V=/90;BffP@0
^K3@1P2baNP60:nfgP040=cOf0000000g=oH0=cOf0T0Q9;I0P3oool00`000000oooo0?ooo`150?oo
o`00R03oool3000000P0oooo0`2HUm4;09VQfP030:OKnP2NVLl0WYW?00D0WYW?202<V=/90;BffP03
0;V`d02baNP0//GX00H0//GX1@2_]]h20=cOf0040000003LgmP0g=oH0=cOf0T0Q9;I0P3oool00`00
0000oooo0?ooo`140?ooo`00QP3oool4000000@0oooo00<0Z;kZ09RGd@2HUm401P2HUm4909VQfP03
0=?gi02NVLl0WYW?00L0WYW?1`2<V=/80;BffP80[;[T2@2baNP30:nfgP<0g=oH00@000000=cOf03L
gmP0g=oH2024T]T00`2/^n@0oooo0?ooo`02000004D0oooo00230?ooo`<000001@3oool50:RnjPL0
V9OA202IXMX30=?gi0P0WYW?202<V=/40;BffPH0[;[T2@2baNP00`2_]]h0g=oH0=cOf0020=cOf004
0000003LgmP0g=oH0=cOf0D0Q9;I1@2/^n@20?ooo`030000003oool0oooo04<0oooo00210?ooo`80
00001P3oool70:RnjPP0V9OA1P2IXMX40=?gi0T0WYW?202<V=/00`2d]]X0[;[T0:bji0070:bji0H0
//GX0P2P]>L50=cOf0030000003LgmP0g=oH0080g=oH00<0Q9;I0:bki02/^n@01P2/^n@30?ooo`03
0000003oool0oooo0480oooo001n0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0`mc[00T0
Z;kZ202HUm4409VQfPH0doOT202NVLl608bHf`80Vj_Q2`2/^^@20;;5j0H0X;CW103LgmP01@000000
g=oH0=cOf03LgmP0/<7W00X0[;_T0P3oool00`000000oooo0?ooo`120?ooo`00O03oool2000000L0
oooo1033g>/80:RnjPP0V9OA0`2IXMX70=?gi0T0WYW?0P2<V=/609^[h@T0[;[T00<0^=;]0:2di`2P
]>L01`2P]>L30=cOf0030000002``NL0/<7W00<0/<7W2@2/^n@30?ooo`030000003oool0oooo0440
oooo001D0?ooo`<000000P3oool2000001h0oooo0`0000080?ooo`H0`mc[202X_^X809RGd@0309VQ
fP3Cmn@0doOT00L0doOT1`2NVLl00`2ccNd0Vj_Q09^[h@0709^[h@H0[;[T102hd^d90:2di`040=cO
f02``NL0/<7W000000D0/<7W2@2/^n@20?ooo`800000@P3oool005D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0H0?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`T0
`mc[1`2X_^X609RGd@D0Z]Cf1`3Cmn@409jIc`D0/lg]2@2KZn440:bji0D0^=;]202P]>L20;^og@80
/<7W00<000000;31i`2``NL0102``NL60:bki080V]Kl0`3oool00`000000oooo0?ooo`100?ooo`00
E@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01H0oooo0P00000:0?ooo`<0
]/7R2@33g>/70:RnjP80V9OA202Ze?H00`2n]M40JhGK06^5f`0306^5f`80doOT00<0WYW?0;?=k@2c
cNd01@2ccNd:09^[h@030:bji02hd^d0^=;]00H0^=;]1@2P]>L50;^og@030;31i`000000/<7W00H0
/<7W0P2/^n@609[Fo0<0oooo00<000000?ooo`3oool0?`3oool005D0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0C0?ooo`<0000000<0oooo0000003oool0203oool50;K1hPH0
`mc[0P2W[md806^Ai@P0Z]Cf0`2n]M4606^5f`T0/lg]202KZn400`2W_n/0^=;]0;SBk@070;SBk@@0
X;CW1`2k_md00`000000/<7W0;31i`030;31i`<0YZSH202Je_`30?ooo`030000003oool0oooo03h0
oooo001E0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool2000000`0
oooo202f`N820<?Lj`H0YjoM201[TND50:[DmPD0_[GA1`1[QM/80;?=k@D0Vj_Q1@2W_n/90;SBk@03
0:2di`2k_md0^koM00L0^koM00<000000;31i`2``NL01`2VZ=P809[Fo080oooo00<000000?ooo`3o
ool0?P3oool005@0oooo0P0000020?ooo`040000003oool0oooo00000100oooo0`00000=0?ooo`T0
]/7R2@2W[md806^Ai@<0Z]Cf1`2n]M4706^5f`P0/lg]00<0Vj_Q0:Noj`2W_n/01`2W_n/60;SBk@80
W<Wf2P2k_md00`000000YZSH0:JXf0080:JXf0@0V]Kl102@W]h00`3oool000000000000o0?ooo`00
E@3oool010000000oooo0?ooo`3oool2000000l0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo0`29]_@90;K1hP80al7E202W[md906^Ai@030:[DmP2n]M40_[GA00L0_[GA1`1[QM/40;?=k@@0
Rl?j2P2W_n/20;SBk@H0W<Wf202k_md00`2knN`000000;_ik0080:JXf0030=;;d`2@W]h0T9kN00L0
T9kN0P3oool00`000000oooo0?ooo`0l0?ooo`00I`3oool3000000P0oooo0`2MV]0708Vfm0L0]/7R
1037`MD80:N_g@H0Ji7U0P2OXmP:0;jed@H0JhGK0`2OZ]h708_3nPP0Yko[0P2eanP809c9mPD0^koM
0`2knN`00`000000^oW/0:JXf0060:JXf0<0d/_C2@2@W]h00`3oool000000?ooo`0m0?ooo`00I@3o
ool4000000H0oooo1`2MV]0708Vfm0D0]/7R1@37`MD90:N_g@80Ji7U1P2OXmP:0;jed@80JhGK1`2O
Z]h708_3nP@0Yko[1P2eanP809c9mP<0^koM102knN`00`000000^oW/0;_ik0050:JXf0@0d/_C202@
W]h0102m_MT0oooo0?ooo`00000m0?ooo`00HP3oool3000000L0oooo00<0bm;O09fJd02MV]00202M
V]0708Vfm0<0]/7R1`37`MD60:N_g@80Y:;C2@2OXmP80;jed@030<3Gj`2OZ]h0Wj[N00P0Wj[N1`2;
`oX00`2W_n/0]LOX0;G7j0070;G7j0P0W<Wf00<0^koM0;_ik02knN`00`2knN`00`000000^oW/0;_i
k0040:JXf0H0d/_C1@2@W]h40;fmf@80oooo00<000000?ooo`3oool01P3oool300000080oooo0P00
000]0?ooo`00H03oool2000000T0oooo0`3;d]l:09fJd0L0RKKd00<0]/7R0<O1e@37`MD01`37`MD2
0:N_g@H0Y:;C202OXmP60;jed@@0`=O[202OZ]h00`35e^H0QI;I08FBf@0608FBf@P0]LOX00<0^_?b
07fam@1m/OD02@1m/OD30;_ik0030000002knN`0^oW/00<0YZSH1`3Bbm<4092NgPH0_KgI0P000009
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:P3oool005d0oooo0`000002
0?ooo`030000003oool0oooo00D0oooo103;d]l909fJd0030=7Mh@22Z>d0PZS]00D0PZS]2@37`MD0
0`38h^/0Y:;C0:BRd`070:BRd`P0Wj?H102n]M450<3Gj`L0Wj[N0`35e^H808FBf@H0]LOX0`2jlo89
07fam@060;_Ek@1PU^`0H9K/062Fk0000000H9K/0P2knN`00`2VZ=P0d/_C0=;;d`070=;;d`03092N
gP2m_MT0_KgI00H0_KgI0P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0:P3oool003T0oooo0P00000P0?ooo`800000303oool60<_Bg`L0WI[@
0`3AgN4708:Xk@L0al7E0`38h^/80:BRd`T0Wj?H00<0_[GA0<3Gj`30en/01P30en/409nZgPD0aMKV
2@25T]T30;G7j0H0^_?b1P1m/OD40;_Ek@80H9K/00@00000062Fk01PU^`0H9K/2@3Bbm<00`38g>L0
_KgI0;fmf@080;fmf@80oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02X0oooo000h0?ooo`040000003oool0oooo000001`0oooo1000000<0?oo
o`L0bm;O1P2MV]050=7Mh@L0PZS]1@37`MD40<SRj`T0Y:;C1P2OXmP30:Zji@P0`=O[0`2OZ]h70<GF
iPT0QI;I00<0]LOX0;[clP2jlo801P2jlo8407fam@H0^mG]00<0H9K/0000001PU^`00`1PU^`70=;;
d`<0b=cW202m_MT0102i_Md0oooo0?ooo`0000070?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0:P3oool003/0oooo00<000000?ooo`3oool05`3oool3000000L0oooo0P2Xc?88
07FXlPL0bm;O102MV]070=7Mh@L0PZS]0`37`MD60<SRj`T0Y:;C0P2OXmP70:Zji@P0`=O[00<0Wj[N
0<GFiP35e^H01`35e^H708FBf@<0[mKd202jlo800`1m/OD0^mG]0;_Ek@060;_Ek@03062Fk0000000
H9K/00@0H9K/103Bbm<60<SLi`D0_KgI102i_Md20?ooo`030000003oool0oooo00<0oooo0P000002
0?ooo`040000003oool0oooo000002`0oooo000k0?ooo`030000003oool0oooo01D0oooo0P000007
0?ooo`H0Z<cb201eZ?860<_Bg`<0WI[@2@3AgN4708:Xk@030<O1e@38h^/0b>;[00H0b>;[1`2TX]<0
0`2[h?T0Z[[U0:Zji@080:Zji@@0`=O[1@2A_OD80<GFiP@0QI;I1`2_e_@40;[clP@0UY3<2@2keNd0
0`000000H9K/062Fk003062Fk0<0d/_C1`38g>L40;fmf@D0^KgM00<0oooo0000000000001P3oool0
10000000oooo0?ooo`3oool2000002d0oooo000h0?ooo`<000005@3oool300000080oooo00@00000
0?ooo`3oool0oooo0P2U/^880:S<lPP0MJSb1P3;d]l00`2MV]00dMgQ0=7Mh@070=7Mh@80/[_P201e
]oX70<SRj`@0Y:;C1@2[h?T80:Zji@80`mWY2@2A_OD80<GFiP0308FBf@2_e_@0[mKd00H0[mKd00<0
b^?Z09J@c02FT<`01`2FT<`60;_Ek@80YLC`00<0000007N8e`1gR=L00P1gR=L2062Fk0030=;;d`38
g>L0b=cW00L0b=cW00<0_KgI0;Vmg@2i_Md01P2i_Md20?ooo`030000003oool0oooo03H0oooo000h
0?ooo`030000003oool0oooo01<0oooo0P0000070?ooo`D0YK;R202Xc?8607FXlP0308_7o02<ZNT0
S:WY00H0S:WY1P3AgN450;:kh0T0MKOj1P38h^/00`2TX]<0Zn3i0:_Pn@060:_Pn@H0Z[[U1033fNT9
096mm@@0aMKV102<[nh60:oFm0@0b^?Z2@2FT<`20;_Ek@D0YLC`00<0000007N8e`1gR=L01@1gR=L8
0<SLi`030:[@m02i_Md0^KgM00L0^KgM0`3oool00`000000oooo0?ooo`0e0?ooo`00>03oool40000
00l0oooo100000060?ooo`P0YK;R202Xc?8207FXlPD0RlOl2P2<ZNT00`3AgN40/[_P0;:kh0060;:k
h0H0MKOj0P2G^_0807nCg@P0Zn3i0`2Z^^D70<?Ij@H0TKge0P2N/nL908b_kP@0[mKd1@3:hnX809J@
c0030=[Yg`2Ua?00YLC`00D0YLC`00<0000007N8e`1gR=L01P1gR=L40<SLi`D0Z]3d202i_Md30?oo
o`030000003oool0oooo03D0oooo00190?ooo`800000203oool00`31h>l0YK;R0:FbhP080:FbhP@0
Z<cb1@2EV]H608_7o0P0S:WY00<0^MC^0;:kh02b^n00202b^n0207FgnPH0Uk[`2@1oTmd70:_Pn@03
0:Zji@33fNT0`mWY00L0`mWY0P2A_OD609jci`T0S:o^00<0[mKd0<[SjP3:hnX01@3:hnX709J@c0<0
f^WO1P2Ua?000`000000YLC`07N8e`0707N8e`030<SLi`2Zd?@0Z]3d00H0Z]3d202i_Md20?ooo`80
0000=P3oool004H0oooo0`0000080?ooo`@0`N3_202U/^800`2i/]80UI[F09FJeP0809FJePD0RlOl
1P2<ZNT40;WDkPP0/[_P0P2n]m<709Njl0P0Oi?M00<0`<CM08FGg025Um`01P25Um`80<?Ij@0308eJ
T02N/nL0W[?W00L0W[?W1`2<[nh20:GFn@P0b^?Z1@2FT<`50=[Yg`H0YLC`00<0000007N8e`1gR=L0
1@1gR=L20:cQn@P0Z]3d1P2i_Md309SZn@<0oooo00<000000?ooo`3oool0<`3oool004@0oooo0P00
00020?ooo`030000003oool0oooo00D0oooo1P31h>l60:FbhP<0^K;B2P2EV]H508_7o0@0S:WY1P2i
e>h60;:kh0@0_[OC1`2G^_0607nCg@<0`<CM2025Um`40<?Ij@D0SEZ@202N/nL408b_kPH0YMKi1`3:
hnX409J@c0L0f^WO1@2Ua?000`000000MhSG07N8e`0207N8e`H0[>7i202Zd?@20;Vmg@L0V>[i0P3o
ool00`000000oooo0?ooo`0c0?ooo`00@@3oool3000000X0oooo2@31h>l30:FbhPD0^K;B2@2EV]H0
0`3@inL0MWc;07Ilb`0207Ilb`80RlOl00<0S:WY0;WDkP2ie>h01`2ie>h30;:kh0L0_[OC1P2G^_04
07nCg@D0`<CM2@25Um`00`33fNT0SEZ@08eJT00608eJT0P0W[?W00<0S:o^0:GFn@2Ue_T01`2Ue_T6
0<[SjP<0UY3<1`3JjMl00`37gnX0Nh??07^3c`0307^3c`030000002Ua?00MhSG00T0[>7i102Zd?@5
09>Fe0P0V>[i0P3oool00`000000oooo0?ooo`0b0?ooo`00?`3oool2000000030?ooo`000000oooo
00P0oooo0`2oko890<7Pk`030:FbhP2i/]80^K;B00D0^K;B1`2EV]H30=3Wi`L0MWc;2@2ie>h00`2b
^n00_[OC0;jgd`070;jgd`D0Uk[`0`1oTmd70<34g@L0QIOL00<0SUZ@08eJT02=FY00202=FY0609jc
i`<0XZOJ1`2Ue_T20:RUdP@0FIW`0P3:hnX00`2FT<`0f^WO0=[Yg`050=[Yg`<0amoZ101kPll01000
0000Nh??07^3c`1kPll60:cQn@80XJgO2P2CU]@409SZn@<0S[?_0P3oool2000003<0oooo000l0?oo
o`<00000303oool70;o_lP<0`N3_0`2=U=H90;VbdP@0UI[F1@3@inL807Ilb`H0^MC^0P2K/nT90;jg
d`030=W^h@1PU>/0H9C[0080H9C[0P2G^_000`1oTmd0`<CM0<34g@070<34g@D0QIOL0P2>FY0;08eJ
T080W[?W1`2RYmX40:GFn@D0Z:GB1`1IVO040=[Yg`D0amoZ101kPll00`000000Nh??07^3c`0207^3
c`80[>7i1P2Q[Ml909>Fe0P0S[?_0P3oool00`000000oooo0?ooo`0a0?ooo`00>P3oool3000000`0
oooo202oko800`2//=/0SICF08fDeP0508fDePP0^K;B0`2EV]H70=3Wi`P0MWc;0P2ie>h609^cj@L0
_[OC0`3Ik^46062Dj`T0`<CM0`25Um`408iJT0/0SEZ@2P2RYmX00`2Ue_T0Z:GB0:RUdP060:RUdPP0
FIW`00<0f^WO0<OOjP37gnX01@37gnX307^3c`050000001kPll0Nh??07^3c`34nN/0202Q[Ml809>F
e080g_WJ202>/nl20?ooo`030000003oool0oooo0300oooo000g0?ooo`<000001P3oool00`2a[M@0
L8cO072<g`02072<g`<0oooo1P2oko850:b`f`L0SICF202i/]800`2EV]H0d>OW0=3Wi`060=3Wi`L0
MWc;00<0b<kN09^cj@2K/nT01P2K/nT60;jgd`D0fNkQ1P1PU>/90<34g@0308FGg02>FY00SUZ@00<0
SUZ@2`2=FY000`3f^8D0XZOJ0::WfP060::WfP030<oFgP2XYM80Z:GB00P0Z:GB101IVO0408jglPL0
amoZ0`1kPll00`000000Nh??07^3c`030<Cij`P0XJgO1P2CU]@40=kifPL0S[?_0`3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool3000000L0oooo102a[M@9072<g`030<O5f02//=/0[;3K00D0[;3K
1`2=U=H70;VbdP<0[>ci1`3@inL607Ilb`<0b<kN202K/nT40;jgd`L0fNkQ1P1PU>/60<34g@80ReR?
1P2>FY0;08eJT0030?JhQ@2RYmX0XZOJ00D0XZOJ0`3?e]h80:RUdP030<ggj02>]o80S[Ob00L0S[Ob
1`37gnX207^3c`030000001kPll0a?W[00@0a?W[202Q[Ml409>Fe0H0g_WJ1`2>/nl20?ooo`800000
<03oool00380oooo0P0000020?ooo`030000003oool0oooo00<0oooo1`2a[M@7072<g`<0alGH1`2/
/=/708fDeP@0^K;B202/k?T50=3Wi`@0MWc;1@38c]h709^cj@<0_[OC2@3Ik^46062Dj`80`<CM1@2;
F8l608iJT0/0SEZ@0P3f^8D40::WfPD0cmKN1`2XYM830<ggj0T0S[Ob1P37gnX207^3c`0300000034
nN/0a?W[00@0a?W[202Q[Ml309>Fe0H0g_WJ00<0/:G=08FMh`25WN<01@25WN<20?ooo`800000<03o
ool002l0oooo0`0000080?ooo`030<[Fh`2a[M@0/JgD00H0/JgD1@1`S=l60<O5f0L0[;3K1`2=U=H0
0`2i/]80[>ci0:c/n@060:c/n@80Z[?O0`1<N]h20=3Wi`<0MWc;1`38c]h709^cj@030;jgd`3Ik^40
fNkQ00H0fNkQ0P2;Ehh608ECSPL0ReR?1P2>FY0;08eJT080m[R50`2RYmX70<oFgP@0Z:GB1P3=mnP6
08jglP80Xi_=1@1cU>@20<OOjP8000001`34nN/80:6]g`0309>Fe03NnMX0g_WJ0080g_WJ1@2`YLd7
08FMh`<0oooo00<000000?ooo`3oool0;@3oool002d0oooo0P0000000`3oool000000?ooo`070?oo
o`<0b]KS202a[M@3072<g`L0alGH1`2//=/608fDeP@0T>?l0`2/k?T60:Zcg`D0C7[N00<0MWc;0<S>
gP38c]h01`38c]h309^cj@H0SZ?R0`3Ik^4508]GSPH0QE>>1`2;F8l708iJT0T0SEZ@103f^8D00`2R
YmX0cmKN0<oFgP060<oFgP<0Z:GB203=mnP208jglPH0Xi_=0`1cU>@30000000307>Di0000000LiCT
00L0a?W[102Q[Ml5082^lP030=kifP2`YLd0/:G=00H0/:G=1`25WN<20?ooo`030000003oool0oooo
02d0oooo000Z0?ooo`<000002P3oool60<[Fh`P0/JgD00<0L8cO0<O5f037aMP01`37aMP70:b`f`80
SICF1`2@ho`00`2U/^40Z[?O0:Zcg`070:Zcg`H0C7[N1`38c]h00`2miO<0SZ?R08jShP0708jShP03
09=PTP2;Ehh0ReN>00D0ReN>1P25Dhh708]HS`L0SUZ@2@2=FY040?JhQ@80n;^4203?e]h00`2XYM80
cOOX0<ggj0060<ggj00309nCa`2SVld0Xi_=00H0Xi_=0`00000507>Di00300000021ZNh0PJW^00D0
PJW^2020[_800`2e_^40/:G=0;2Uc@070;2Uc@P0QIgS0P3oool00`000000oooo0?ooo`060?ooo`<0
00000P3oool2000001l0oooo000Y0?ooo`<000002P3oool70<[Fh`L0/JgD00<0Z>gh0<O5f037aMP0
2@37aMP30:b`f`H0TjCP0`2@ho`50:Fbh@P0Z[?O1`1<N]h40<S>gP@0_NGc1`2>Xn8209=PTPL0ReN>
1P25Dhh708]HS`L0SUZ@2@2=FY040?JhQ@<0n;^41P3?e]h40::Xf`<0cOOX1@2OTlL40:>Kc@<00000
00<0Xi_=07>Di01cU>@00P1cU>@40;ZjfP0300000021ZNh0PJW^00D0PJW^1P20[_830;Fnh@T0/:G=
1025WN<309^FcP80oooo0P0000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0703oool002T0oooo00<000000?ooo`0000002@3oool90<[Fh`@0/JgD102XkOP90<O5f0030;Ng
f@2CY>00TjCP00P0TjCP202U/^480:Zcg`L0C7[N00<0b<kN0;gUl`2miO<01@2miO<508jShP<0Tf2B
1`2;Ehh608ECSPL0ReR?1`2>FY0908eJT0@0m[R5103h^h@20<oFgPP0XZSK1`2OTlL0102SVld00000
0000000000050:>Kc@0307>Di02j^]X0^[[J00D0^[[J00<00000086YkP21ZNh01@21ZNh3082^lPD0
]KkQ202`YLd00`3=l^X0ViK>09^FcP0609^FcP80oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo000Y0?ooo`040000003oool0oooo000000H0
oooo0`2QdOP90<[Fh`030;6]e02XkOP0Z>gh00D0Z>gh1P37aMP40;Ngf@P0TjCP0P3>b]D80:Fbh@P0
Z[?O0`1<N]h508:dm@L0_NGc0`2>Xn8409=PTPL0ReN>1P25Dhh708]HS`L0SUZ@2@2=FY040?JhQ@@0
n;^42@2RZ=/20=gNeP@0Wi?70`0000070:>Kc@030<75g@2j^]X0^[[J00H0^[[J00<000000;ZjfP21
ZNh01P21ZNh00`20[_80]KkQ0;Fnh@050;Fnh@H0/:G=0`3=l^X809^FcP80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo000P0?ooo`800000
1`3oool200000080oooo00<000000?ooo`3oool0202QdOP60<[Fh`D0UK;[1@2XkOP40<O5f0H0]kOI
1P2CY>040<k:e@P0YK;Q102Z/ml309^Tf`X0P[Ce1P2miO<00`2>Xn80Tf2B09=PTP0309=PTPL0ReN>
1P25Dhh708]HS`L0SUZ@2@2=FY040?JhQ@@0n;^400<0000e0::Xf`2RZ=/01@2RZ=/30=gNeP0409nC
a`0000000000000000<0Wi?71P2SVld30<75g@P0^[[J00<0000008jNg`2>W]l01@2>W]l90;Fnh@@0
/:G=103=l^X809^FcP80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03000001l0
oooo000O0?ooo`040000003oool0oooo000000D0oooo0P0000030?ooo`<0Ylgd2@2QdOP20<[Fh`P0
UK;[00<0d=kR06bKk01/Vn`00P1/Vn`00`2XkOP0alGH0;Ngf@070;Ngf@D0TjCP1P3>b]D60:Fbh@03
0:6Jc@2KY=/0VjCK00H0VjCK2022]?D00`2<F8l0QUB>08IDSP0408IDSPH0Tf2B1`2;Ehh608ECSPP0
ReR?1P2>FY0908eJT0<0m[R51@3h^h@00`0003D0XZSK0::Xf`040::Xf`80gMkF0`00000709nCa`@0
Xi_=1@31aMd50;ZjfP<0_[[E00<0000008jNg`2>W]l01@2>W]l80;Fnh@<0/:G=1@3=l^X909^FcP03
0?ooo`000000000000D0oooo0P0000020?ooo`030000003oool0oooo01l0oooo000O0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`2WcO@01`2WcO@60:7An080Y/O`202E/^/30=3NhPD0
K9_/2@2g]mT309>Th0P0c/[E0P2U/^450:6Jc@P0VjCK1022]?D408aHS`H0QUB>1P2CH98708]GSPH0
QE>>202;F8l608iJT0P0SEZ@103f^8D50?RkQ080000e102RZ=/00`3Mg]H00000000000030=gNePL0
Wi?70`2SVld60<75g@@0^[[J102n^]D00`000000SYkO08jNg`0608jNg`P0]KkQ00<0/:G=0<gbjP3=
l^X01@3=l^X709^FcP<0`=?X00<0oooo0000003oool0103oool00`000000oooo0?ooo`04000001h0
oooo000O0?ooo`040000003oool0oooo000000D0oooo0P0000090:O=m080XM7h1P2Vao0509Fbj`H0
d=kR1@1/Vn`90;Ngf@0309>Th03>b]D0c/[E00H0c/[E00<0b>C[0:6Jc@2QV/d01P2QV/d809^Tf`03
08:dm@2<F8l0S5R?00@0S5R?1P26E8h609=PTPL0ReN>1`25Dhh708]HS`H0SUZ@202=FY040?JhQ@D0
n;^40P0003D20::Xf`<000001@3Mg]H809nCa`030:>Kc@31aMd0`LGM00H0`LGM00<0^[[J0;jje@2n
^]D01@2n^]D00`000000SYkO08jNg`0608jNg`@0]KkQ102@]>l70<gbjPD0ViK>1P30dnP00`000000
oooo0?ooo`0X0?ooo`007`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?oo
o`H0Ylgd0`2Xh_/70:K7l0<0UK;[203@g^8506bKk0L0]kOI0`2bg_H60<k:e@<0b>C[1`2QV/d709^T
f`030;gEk02<F8l0S5R?00D0S5R?1P26E8h609=PTPL0ReN>1`25Dhh708]HS`H0SUZ@202=FY040?Jh
Q@@0n;^40P0003D3000000P0gMkF1P2OTlL20;7Nm`P0`LGM00<0]ngf0;jje@2n^]D01`2n^]D00`00
0000SYkO08jNg`0308jNg`80Wj[N2@2@]>l60<gbjP@0ViK>1P30dnP00`3<e>00oooo0000000Y0?oo
o`007`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P2WcO@80:SR
n`H0Y/O`00<0UK;[0=3NhP3@g^80203@g^8506bKk0@0]kOI1P2bg_H30<k:e@D0b>C[202QV/d409^T
f`<0_MG/1`2<F8l608IDSPH0Tf2B1`2;Ehh708ECSPL0ReR?1P2>FY0808eJT0@0m[R50`3h^h@30000
00@0T/7g203Mg]H209nCa`H0/Mkg1P31aMd30;O]mPT0_[[E00<0000008jNg`2OZ]h01@2OZ]h7092d
k`030;>`e@1SX?80Hj3b00<0Hj3b0P3=l^X00`2KU/h0`=?X0<3Cj0050<3Cj0<0c=CP0P00000X0?oo
o`00803oool2000000H0oooo0P0000050?ooo`T0Z>;k0`2Vao0408nck`P0d=kR00<0XjGG07:@h@1b
T>400P1bT>4206bKk0030;Ngf@2bg_H0/]kf00L0/]kf00<0c/[E0<STj`38i>/01@38i>/80:6Jc@03
09^Tf`2meN`0_MG/00<0_MG/1`2<F8l608IDSPH0Tf2B1`2;Ehh708ECSPL0ReR?1P2>FY0808eJT0@0
m[R50`0000000`3h^h@0T/7g09;1m`0509;1m`@0gMkF102>_OH80;7Nm`<0`LGM1P2gkOH70;jje@03
0<3Hj`000000Wj[N00L0Wj[N102@]>l40;>`e@L0Hj3b1@30dnP50<cDh0030?ooo`000000oooo02L0
oooo000W0?ooo`8000002@3oool30:SRn`@0S9[L2@2?/nl20=3NhPD0XjGG1`1bT>470;;NmP<0Uk3X
1P38i>/70:6Jc@<0]OCc102meN`708aHS`H0QUB>1P2CH98708]GSPL0QE>>1`2;F8l608iJT0P0SEZ@
00@0m[R50000000000000000103h^h@609;1m`80SejD202>_OH80;7Nm`030<75g@2gkOH0]ngf00D0
]ngf102n^]D50<3Hj`030000002OZ]h0Wj[N00H0Wj[N00<0T;C_0;>`e@2c/=D01@2c/=D706>PlP<0
`=?X1`3<e>000`3oool000000?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`080?ooo`P0S9[L
1`2?/nl00`2jbnL0XjGG0:>Ue`060:>Ue`P0LY3Q0P2bg_H809N`j0D0b>C[1@2QV/d50;Gdl`<0_MG/
1`2<F8l608IDSPH0Tf2B202;Ehh608ECSPL0ReR?1`2>FY0508eJT0<000000`3f^8D40?RkQ0@0T/7g
1@2?GY@808jmmP@0/Mkg1P26aod60;O]mP030;jje@30f>/0`=S[00H0`=S[00<0000009nZgP2OZ]h0
102OZ]h00`2cd>h0/k3E0;>`e@070;>`e@L0Hj3b00<0`=?X0<cDh03<e>001P3<e>020?ooo`030000
003oool0oooo02@0oooo000W0?ooo`8000002P3oool808bJg0@0Sk?_102jbnL70:>Ue`L0LY3Q0P2k
jO@809N`j0040<STk01>RnT0CX_Y04j;j@80b>C[0`2QV/d80;Gdl`80_MG/1`2<F8l608IDSPH0Tf2B
202;Ehh608ECSPL0ReR?1`2>FY0308eJT080000000<0SEZ@0?JhQ@3f^8D00P3f^8D50?RkQ00309CS
o@2B`OL0SejD00L0SejD1P2>_OH309oKo0H0Q/Om0P2W/N0708Z:cPP0`=S[00@0Wj[N0000002OZ]h0
Wj[N1@2cd>h70;>`e@030=7giP1kWNP0NigX00H0NigX203<e>020?ooo`8000009@3oool002L0oooo
00<000000?ooo`3oool02P3oool808bJg00308nck`2jbnL0^/_W00D0^/_W1`2SYML407:@h@D0^nWd
1P2G/>P30<STk0D0CX_Y00<0XI[=0;Gdl`2em?<0102em?<309R`j080_MG/1`2<F8l608IDSPL0Tf2B
1`2;Ehh608ECSPL0ReR?1`2>FY03000000<0SEZ@103f^8D50?RkQ00308]JTP2?GY@0SejD00P0SejD
0P2>_OH709oKo080Q/Om1P2W/N0708Z:cPP0`=S[00<000000;?@kP2cd>h01@2cd>h60;>`e@<0dOOV
201kWNP80<cDh080oooo00<000000?ooo`3oool08`3oool002L0oooo00<000000?ooo`3oool02P3o
ool708bJg080[[SQ1`2jbnL80:>Ue`0307:@h@2kjO@0^nWd00H0^nWd0`2G/>P60<STk0L0CX_Y00<0
];oS09R`j02H/>P0102H/>P20;gEk0L0S5R?1P26E8h709=PTPL0ReN>1P25Dhh708]HS`@0SUZ@0`00
000608eJT0@0m[R5103h^h@208]JTPX0SejD0P3f^8L609oKo00309fAaP2W/N00Yk7P00H0Yk7P202:
R/h40<3Hj`@0VKS]00<000000;?@kP2cd>h01@2cd>h40;>`e@D0dOOV201kWNP40<cDh0<0T/Oj0`3o
ool00`000000oooo0?ooo`0R0?ooo`009`3oool2000000`0oooo102<V]`50:jhh@L0^/_W1P2SYML4
0:?Oo0L0^nWd00<0Uk3X0<STk038i>`01P38i>`404j;j@@0];oS1@2H/>P20;gEk0L0S5R?1`26E8h6
09=PTPL0ReN>1P25Dhh708]HS`0408iJT00000000000000000<0SUZ@1P2=FY040?JhQ@@0n;^40P2;
FY8:08mNU0<0m[R70P2Ofo`509fAaPL0Yk7P1`2:R/h00`2oo>@0VKS]09Vhk@0709Vhk@030000002c
d>h0/m3^00@0/m3^0`2c/=D70=7giP@0NigX0`2C/^`809;7nP80oooo00<000000?ooo`3oool08P3o
ool002L0oooo00<000000?ooo`3oool0303oool00`2<V]`0[[SQ0:jhh@060:jhh@L0^/_W0P2SYML7
0:?Oo0030:f]f01mXn/0OJ?[00H0OJ?[2038i>`00`1>RnT0];oS0;Boh`050;Boh`@0V;3X0P2meN`7
08aHS`L0QUB>1P2CH98708]GSPH0QE>>1@2;F8l3000000H0SUZ@1P2=FY040?JhQ@@0n;^40P2;FY8:
08mNU0<0m[R7202MTLH70:Nah0D0RX[>0`2oo>@909Vhk@030000002cd>h0/m3^00@0/m3^00<0/k3E
0=7giP3AmnH0103AmnH209nmkPP0Tk;/1`2BaoX20?ooo`8000008`3oool000L0oooo0P0000030?oo
o`030000003oool0oooo008000000`3oool2000000<0oooo0P0000030?ooo`8000001P3oool00`00
0000oooo0?ooo`0=0?ooo`X0[[SQ0`2jbnL508bDe`D0Xmol102][MP907fSj`<0b>C/102DY>080;Bo
h`<0V;3X0P2meN`708aHS`L0QUB>1P2CH98708]GSPH0QE>>0P2;F8l300000080ReR?1`2>FY0608eJ
T0@0m[R5103h^h@208]JTPX0SejD0`3f^8L00`3_[hX0WI7609fAaP0509fAaPL0Yk7P102:R/h50;ol
i0H0VKS]0P2X]N800`000000Z;GR06W5oP0606W5oP80dOOV1P2O_Nh809>bk0L0T/Oj0P3oool00`00
0000oooo0?ooo`0Q0?ooo`001P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0oooo
0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00`3oool2000000l0oooo202^^>400`35h>`0S9CG08bDe`0808bDe`030:?Oo02]
[MP0[JgH00D0[JgH1`1mXn/00`2d/mL0U:CP09BTh00609BTh0P0];oS00@0V;3X0:boj02meN`0_MG/
1`2<F8l708IDSPH0Tf2B1`2;Ehh508ECSP<000001@2;F8l708iJT0H0SEZ@103f^8D40?RkQ080ReZB
2P2?GY@30?JhQ`030>n_RP2MTLH0WI7600H0WI761P2W/N0308Z:cPL0_ocT0P2I^>d60:RehP030000
002X]N80JLGn0080JLGn0`2KSlL909nmkPH0Tk;/00<0Y/of09:Th@2BY>401@2BY>430?ooo`030000
003oool0oooo0200oooo00060?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo1P2^^>430<GPk0P0S9CG00<0enWR0:f]
f02][MP01`2][MP407fSj`@0];?G202DY>060;Boh`<0[L[_0P2meN`708aHS`L0QUB>1P2CH98708]G
SP80QE>>0`0000000`25Dhh0ReR?08]HS`0508]HS`L0SUZ@1@2=FY050?JhQ@@0n;^40`2;FY8808mN
U0@0m[R700<0kjn:09fAaP2MTLH01@2MTLH00`3:bMT0LIk/076Nk003076Nk080Yk7P00<0RX[>0;ol
i02oo>@00`2oo>@309NPf`T0Z;GR00<0000009^?a`2KSlL01@2KSlL909nmkP80Tk;/1@2VcoH709:T
h@<0oooo00<000000?ooo`3oool01@3oool400000080oooo0P00000B0?ooo`001P3oool010000000
oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0@0?ooo`<0[[SQ1P35h>`608bDe`<0enWR2@2][MP00`1mXn/0];?G0;Bce`050;Bce`P0U:CP0P2d
_n<60:g:k`80_MG/1`2<F8l708IDSPH0Tf2B1`2;Ehh2000000@0QE>>1`2;F8l708iJT0D0SEZ@1@3f
^8D40?RkQ0<0ReZB202?GY@40?JhQ`80kjn:1@2MTLH30<[9f@P0LIk/00<0/ZK<09NPf`2GX=/01@2G
X=/70:RehP030<kRiP000000c^;V00L0Vho71P2O_Nh209^`iPP0Y/of1`2BY>420?ooo`8000001P3o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool03`3oool000H0oooo
00@000000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo00000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo00000002000000H0oooo0P00000B0?ooo`030:jhh@35h>`0
aN3/00D0aN3/1@2<U=L50=OYhPL0[JgH00<0/jcA0;Bce`2d/mL01`2d/mL609BTh0<0ZmKf1`2]b^l0
0`2meN`0S5R?08aHS`0508aHS`L0QUB>1P2CH98408]GSP<000001P25Dhh708]HS`L0SUZ@1@2=FY04
0?JhQ@@0n;^4102;FY8808mNU0@0m[R70P3_[hX409fAaPD0b/WI1@1aW^`40;:Vc0L0Uj3K102X]N84
0<kRiP030000002KSlL0Vho700H0Vho70P2O_Nh609^`iPL0Y/of202BY>420?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00l0oooo0006
0?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool000000080oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0E0?ooo`D0
aN3/0`2<U=L70=OYhP@0[JgH102c[=490;Bce`80U:CP1`2[e_H60:g:k`030;gEk02<F8l0S5R?00D0
S5R?1`26E8h609=PTP0408]GSP0000000000000000<0ReN>1P25Dhh808]HS`H0SUZ@1@2=FY040?Jh
Q@@0n;^4102;FY8808mNU0<0m[R70`3_[hX309fAaPH0b/WI101aW^`50;:Vc0L0Uj3K0`2X]N860<kR
iP030000002KSlL0Vho700@0Vho700<0dm;H09^`iP2K/>H01`2K/>H70:K?mP@0TZCQ0`2Qa_<30?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0?
0?ooo`001`3oool2000000H0oooo0P0000030?ooo`8000000`3oool200000080oooo100000040?oo
o`030000003oool0oooo01L0oooo101`PM@00`35h>`0S9CG0=OYhP080=OYhP030:f]f02c[=40/jcA
00D0/jcA1`2d/mL30;2`f0P0ZmKf0P2]b^l30:6nkP030;gEk02<F8l0S5R?00D0S5R?1`26E8h409=P
TP<000001P2;Ehh708ECSPL0ReR?1P2>FY0508eJT0@0m[R5103h^h@408]JTPP0SejD0`3f^8L40>n_
RP0309fAaP3:bMT0b/WI00H0b/WI00<0LIk/0;:Vc02bY/`01P2bY/`709NPf`030:RehP3>h^H0c^;V
00H0c^;V00<0000009^?a`2KSlL00P2KSlL30=?Bf0L0Vk3V00<0]<SY07b/lP1l[?801@1l[?880:76
l`80oooo00<000000?ooo`3oool01P3oool00`000000oooo000000020?ooo`030000003oool0oooo
00l0oooo000U0?ooo`8000006@3oool80721e0@0enWR0P2CY>490;>/d@@0];?G1P2`/=P60:_FmP80
WjgQ102Q_^h00`2meN`0S5R?08aHS`0508aHS`L0QUB>00@0Tf2B00000000000000000P2CH98708]G
SPL0QE>>1`2;F8l708iJT0@0SEZ@103f^8D40?RkQ0@0ReZB202?GY@30?JhQ`@0kjn:203:bMT00`30
n^X0/ZK<0;:Vc0070;:Vc0H0Uj3K0`2W/^070<kRiP040000002KSlL0Vho709^?a`D0dm;H102K/>H4
0;C8j@L0O:cb202Qa_<00`3oool00000000000040?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`0?0?ooo`009@3oool00`000000oooo0?ooo`0H0?ooo`P0L87D00<0
bL3A09>Th@2CY>40102CY>490;>/d@030;Bce`2`/=P0/;3H00L0/;3H0P2[e_H609n]h@<0XKk^00<0
_MG/08aHS`2<F8l01@2<F8l508IDSP<000001@2CH98708]GSPL0QE>>1`2;F8l708iJT0@0SEZ@103f
^8D40?RkQ0@0ReZB202?GY@30?JhQ`@0kjn:00<0001;0<[9f@3:bMT0103:bMT30<3jjPT0/ZK<0P2G
X=/70:Nbh0H0c^;V00<0Vho70000002KSlL01`3Cd]P00`2K/>H0]<SY0;C8j@050;C8j@L0O:cb1P2Q
a_<308[Fo`030?ooo`000000oooo00<0oooo0P0000030?ooo`8000004P3oool002D0oooo00<00000
0?ooo`3oool06@3oool60721e0<0bL3A1P2CY>470;>/d@030;nnf02`/=P0/;3H00L0/;3H0P3@b]@8
09n]h@80XKk^00<0_MG/08aHS`2<F8l01@2<F8l208IDSP<000000P26E8h609=PTPL0ReN>1`25Dhh7
08]HS`L0SUZ@102=FY040?JhQ@@0n;^4102;FY8708mNU0@0m[R7103_[hX20000B`<0b/WI1P30n^X7
0;:Vc0030<O/kP2W/^00Yk;P00H0Yk;P00<0b]OS07j6d@1nQ]400`1nQ]420<kRiP0309^?a`000000
dm;H00D0dm;H0P36a]X80;C8j@L0O:cb0P2Qa_<708[Fo`030000003oool0oooo01/0oooo000U0?oo
o`8000006`3oool40721e0D0bL3A1@2CY>460;>/d@<0_kkH1`2`/=P40=3:e0P0WjgQ00<0XKk^0;gE
k02<F8l01P2<F8l2000000D0QUB>1P2CH98708]GSPL0QE>>1`2;F8l708iJT0<0SEZ@1@3f^8D40?Rk
Q0@0ReZB1`2?GY@40?JhQ`@0kjn:0`0004/00`3:bMT0`?[Z0<3jjP050<3jjPH0/ZK<0`37k>h60:Nb
h0<0b]OS1`1nQ]400`3Cd]P000000=?Bf0030=?Bf0@0a/KJ1P2db>T00`2_]Md0Thg:09>=bP0709>=
bP@0R]Ko0`2MW]@00`3oool000000?ooo`0K0?ooo`009@3oool00`000000oooo0?ooo`0J0?ooo`<0
L87D1`39`=4509>Th@<0/jcA1P2o_]P50;2`f0H0d<[D1P2O[N400`2b_N40PY7J0;gEk00408aHS`<0
00001`26E8h609=PTPL0ReN>1`25Dhh708]HS`L0SUZ@0`2=FY050?JhQ@<0n;^41@2;FY8708mNU0@0
m[R7103_[hX20000B`<0Y[k[00@0UfFF05JBk@1FT^d0EY;]0`30n^X30;:Vc0H0anc^0`2W/^050<[G
h`P0OXKA00<000000=?Bf03Cd]P01`36a]X20;C8j@D0[kGM202CSLX809fNe08000006`3oool002@0
oooo00<000000?ooo`3oool0703oool00`1`PM@0bL3A0<W0d@070<W0d@D0TjCQ00<0/jcA0;nnf02o
_]P01P2o_]P30;2`f0P0d<[D0P2O[N450;:mh@030;gEk02<F8l00000008000000`2<F8l708IDSPH0
Tf2B1`2;Ehh708ECSPL0ReR?1`2>FY0308eJT0@0m[R5103h^h@508]JTPL0SejD103f^8L40>n_RP@0
Y[k[0`2GIIH505JBk@030<3jjP2bY/`0anc^00L0anc^00<0Yk;P0<[Gh`3:en<01@3:en<807j6d@03
00000036a]X0a/KJ00D0a/KJ00<0blSH0:neg@2_]Md01@2_]Md709>=bP80g>;J1`2MW]@00`3oool0
00000?ooo`0J0?ooo`00903oool3000001d0oooo2039`=400`35d^@0Rj7R08^QhP0408^QhPT0_kkH
00<0/;3H0=3:e03@b]@01P3@b]@20<?:g`D0/[gQ0`00000608aHS`L0QUB>1P2CH98708]GSPL0QE>>
1`2;F8l708iJT0<0SEZ@103f^8D40?RkQ0D0ReZB1`2?GY@40?JhQ`<0kjn:102V_^/509MUUPL0EY;]
1037k>h409VPf@L0b]OS1`1nQ]400`2ac>d0a/KJ000000050<K6fP<0blSH1`2_]Md509>=bP<0g>;J
202MW]@00`3oool000000?ooo`0I0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`H0bL3A0`35
d^@608^QhPL0_kkH0`2ej?L60=3:e0@0`l[O00H0/[gQ00000000000000000;:mh@2meN`808aHS`H0
QUB>1P2CH98708]GSPL0QE>>1`2;F8l708iJT0<0SEZ@103f^8D40?RkQ0H0ReZB1P2?GY@40?JhQ`<0
kjn:0`2V_^/709MUUP<0EY;]0`2A_?@909VPf@H0b]OS101nQ]450;7<k@0400000036a]X0a/KJ0<K6
fPD0blSH1`2_]Md409>=bPD0g>;J1P2MW]@0102d[m@0oooo0?ooo`00000I0?ooo`002P3oool20000
00<0oooo00<000000?ooo`3oool00P0000030?ooo`8000000`3oool3000000D0oooo00<000000?oo
o`3oool07`3oool30<W0d@D0aM;T1`2;XN840;nnf0H0]NSg0`3@b]@40<?:g`<00000102b_N400`2m
eN`0S5R?08aHS`0608aHS`H0QUB>1P2CH98708]GSPL0QE>>1`2;F8l708iJT0<0SEZ@103f^8D40?Rk
Q0H0ReZB1P2?GY@30?JhQ`@0kjn:00<0RiOI0:Jnj`2GIIH01`2GIIH00`3g^8<0TKcd096lm004096l
m0T0VJ3I1P3:en<00`1nQ]40/Lc]0;7<k@050;7<k@030<K6fP000000a/KJ00H0blSH1`2_]Md309>=
bPH0g>;J102MW]@40;B_e08000006@3oool000T0oooo00@000000?ooo`3oool00000103oool01P00
0000oooo0?ooo`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000060?ooo`800000
8@3oool00`39`=40aM;T0<GBi0050<GBi0L0Rj7R00<0_kkH0;GXm`2ej?L01`2ej?L00`3@b]@0`l[O
0<?:g`03000000@0`l[O0`2b_N400`2meN`0S5R?08aHS`0608aHS`H0QUB>1P2CH98708]GSPL0QE>>
1`2;F8l708iJT0<0SEZ@103f^8D40?RkQ0H0ReZB1P2?GY@30?JhQ`@0kjn:00<0TV:F09MUUP2GIIH0
1`2GIIH20?NhP`D0TKcd202IX=T00`33dnH0Nk[j07^jnP0507^jnPP0/Lc]00<0a/KJ0000003;b=P0
1P3;b=P70:neg@0309>=bP3Lh]X0g>;J00H0g>;J00<0WIkD0;B_e02d[m@0102d[m@20?ooo`030000
003oool0oooo01H0oooo00090?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0R
0?ooo`H0aM;T1P2;XN8409c6m@@0]NSg0`2D]nl3000000H0`l[O0P2ldNX208Bln@80_MG/1`2<F8l6
08IDSPH0Tf2B1`2;Ehh708ECSPL0ReR?1`2>FY0208eJT0D0m[R5103h^h@608]JTPD0SejD103f^8L4
0>n_RP03099RUP2GIIH0UfFF00L0UfFF0`3g^8<5096lm0D0VJ3I1033dnH707^jnPH0/Lc]00@0V]Wm
0<_8f03;b=P000001@3;b=P30;GkiPD0F[Cl203Lh]X00`2]/=X0]:oD0;B_e0060;B_e0030?ooo`00
0000oooo01L0oooo00090?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool00000
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`0S0?oo
o`H0aM;T0P2;XN8709c6m@80][7D0`2D]nl2000000<0U;O_1033b]l50;cAjP0308Bln@2meN`0_MG/
00L0S5R?1P26E8h609=PTPL0ReN>1`25Dhh708]HS`L0SUZ@0P2=FY050?JhQ@@0n;^41P2;FY8508mN
U0@0m[R7103_[hX00`2BHYH0UfFF09MUUP0709MUUP<0mkR30`1<V?82096lm0@0VJ3I1P33dnH707^j
nP80/Lc]1@2JfOd00`3;b=P000000<_8f0030<_8f0D0]O_V1@1J]?`40=cRfPD0[K3J1`2d[m@20?oo
o`8000005P3oool000T0oooo00@000000?ooo`3oool00000103oool01P000000oooo0?ooo`000000
oooo00000080oooo00D000000?ooo`3oool0oooo000000050?ooo`8000009P3oool30<GBi0@0W:kT
1P2La_D30;Jae0<000001P2D]nl00`33b]l0_=7Z0;cAjP060;cAjP80_MG/1`2<F8l608IDSPH0Tf2B
1`2;Ehh708ECSPL0ReR?1`2>FY0208eJT0D0m[R50`3h^h@708]JTPD0SejD103f^8L40>n_RP03099R
UP2GIIH0UfFF00L0UfFF103g^8<504bHlP0309VPf@33dnH0`m?V00D0`m?V00<0`lkS08>Yk@23ZNd0
1`23ZNd609[Io@030<_8f0000000blSH00D0]O_V0P2/]Ml408V=d@80F[Cl00<0g>;J0:f`fP2]/=X0
1@2]/=X80;B_e080oooo00<000000?ooo`3oool0503oool000T0oooo00@000000?ooo`3oool00000
103oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P0000050?oo
o`030000003oool0oooo02H0oooo1`2L[^@309c6m@80][7D0`0000020;Jae0H0U;O_0`2Q/nD60;cA
jP030;2_e`2TW/l0_MG/00L0S5R?1P26E8h609=PTPL0ReN>1`25Dhh708]HS`P0SUZ@00<0SEZ@0?Jh
Q@3f^8D00P3f^8D40?RkQ0L0ReZB1@2?GY@40?JhQ`@0kjn:00<0TV:F09MUUP2GIIH01`2GIIH50?Nh
P`D0C9Sb1P33dnH30<?>h`T0PjW]1P2JfOd0103;b=P000000;GkiP2ennH60:beg`D0RHgA202]/=X6
0;B_e0<0Z/_a00<0oooo0000003oool05@3oool000X0oooo0P0000060?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`L0W:kT00@0W<Ke0000
0000000000001P2f/M@209Bgk`L0XK?U0`2ldNX40;2_e`030;gEk02<F8l0S5R?00D0S5R?1`26E8h5
09=PTPL0ReN>1`25Dhh708]HS`P0SUZ@00<0SEZ@0?JhQ@3f^8D00P3f^8D40?RkQ0L0ReZB1@2?GY@4
0?JhQ`@0kjn:0P2BHYH809MUUPH0mkR31@1<V?830<?CiPH0`lkS1P23ZNd20:Rhi0L0S9_M00<0d]oQ
0000002/]Ml01P2/]Ml608V=d@P0[K3J0P2d[m@70:[;l@030?ooo`000000oooo00L0oooo10000002
0?ooo`8000001@3oool002<0oooo0P00000Y0?ooo`@0W:kT0`0000080;Jae080d>WW2@2Q/nD00`2l
dNX0/:oG0;2_e`030;2_e`030;gEk02<F8l0S5R?00D0S5R?1`26E8h509=PTPL0ReN>1`25Dhh708]H
S`P0SUZ@00<0SEZ@0?JhQ@3f^8D00P3f^8D40?RkQ0L0ReZB1@2?GY@40?JhQ`@0kjn:0P2BHYH809MU
UPH0mkR3101gTN0204bHlP030<?CiP33c^<0`lkS00H0`lkS0P23ZNd60:Rhi0D0S9_M0P3Bgn400`00
0000[;GO0:beg`060:beg`H0RHgA1P2]/=X20:VfhPL0Z/_a00@0a=CV0?ooo`00000000001`3oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool002<0oooo00<0
00000?ooo`3oool0:@3oool3000000@0^M7/1P2f/M@40=3Yi`L0XK?U00<0^;_K0;2_e`2`[mL0102`
[mL00`2meN`0S5R?08aHS`0508aHS`L0QUB>1@2CH98808]GSPH0QE>>202;F8l708iJT00308eJT03f
^8D0m[R50080m[R5103h^h@708]JTPD0SejD103f^8L30>n_RP<0TV:F1`2GIIH70?NhP`030000FP1g
TN00Mi7P00@0Mi7P1`33c^<00`2gi_H0Z;ST0:Rhi0060:Rhi0@0S9_M103Bgn400`000000[;GO0:be
g`050:beg`L0RHgA0P2]/=X60:VfhP@0Z/_a1034e>H00`3oool000000?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool002<0oooo00<000000?ooo`3oool09P3oool3
00000080oooo1P2idN`30;Jae0L0d>WW102Q/nD40;Rkf`D0/:oG00<0_MG/08aHS`2<F8l01@2<F8l7
08IDSPD0Tf2B202;Ehh708ECSPL0ReR?1`2>FY050?JhQ@@0n;^41`2;FY8508mNU0<0m[R7103_[hX3
099RUPL0UfFF1`3g^8<20000FPH0Mi7P1033c^<40;OVmPL0Z;ST0`2<Vmd60=;Oh@030000002/]Ml0
[;GO00@0[;GO1P29SM400`2N/>@0ZKKR0:VfhP070:VfhP030:[;l@34e>H0a=CV00D0a=CV00<0oooo
0000003oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000R0?oo
o`8000009P3oool2000000H0oooo1P2idN`00`2f/M@0d>WW0=3Yi`070=3Yi`030:6ci@2h^m/0^;_K
00D0^;_K102`[mL00`2meN`0S5R?08aHS`0508aHS`L0QUB>1P2CH98708]GSPL0QE>>1`2;F8l708iJ
T0D0m[R5103h^h@808]JTP<0SejD103f^8L40>n_RP<0TV:F1`2GIIH70?NhP`80001J1`1gTN000`33
c^<0]nKf0;OVmP050;OVmPL0Z;ST00<0S9_M0=;Oh@3Bgn401@3Bgn400`000000[;GO0:beg`050:be
g`80RHgA1@2N/>@70:VfhP030;_9i@34e>H0a=CV00D0a=CV0P2k]M@2000000P0oooo00<000000?oo
o`0000000P0000050?ooo`008P3oool2000002<0oooo0`0000090?ooo`<0^M7/1@22^OP40=3Yi`@0
UlWi1`2h^m/40;2_e`030;gEk02<F8l0S5R?00D0S5R?1`26E8h609=PTPL0ReN>1`25Dhh708]HS`L0
SUZ@1@3f^8D30?RkQ00308iLTP2;FY80ReZB00H0ReZB0`2?GY@40?JhQ`@0kjn:0`2BHYH709MUUPL0
mkR30`0005X307NAh0H0VZOO1P2gi_H30:Rhi0D0UJKQ1P3Bgn400`2`Z<l0000008RQi00508RQi0P0
W[3T1@2Y]^830;_9i@@0a=CV1@2k]M@00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000
003oool000001`3oool00280oooo00<000000?ooo`3oool07`3oool3000000h0oooo1P22^OP30;?M
m@H0UlWi1`2h^m/30;2_e`030;gEk02<F8l0S5R?00D0S5R?1`26E8h609=PTPL0ReN>1`25Dhh708]H
S`H0SUZ@00<000000?JhQ@3f^8D00`3f^8D30?RkQ00308iLTP2;FY80ReZB00H0ReZB0`2?GY@40?Jh
Q`@0kjn:0`2BHYH709MUUPL0mkR30`2IW]L809ZWg`030<6ke@2HT//0V9;;00@0V9;;2@2EY^420=;O
h@D0/:S?00<0000008RQi028XN@01028XN@709j`i0<0ZKKR1P2kbND00`34e>H0^kGD0;^ee0050;^e
e0030000003oool0oooo00@0oooo0P0000020?ooo`@00000103oool00280oooo0`00000L0?ooo`<0
00004P3oool308:in0H0/mge1P2GbOT50;Rkf`<0[[cT00<0T=?n0;gEk02<F8l01P2<F8l708IDSPH0
Tf2B1`2;Ehh708ECSPL0ReR?1@2>FY0202aBaP030000003f^8D0m[R50080m[R50`3h^h@208iLTPL0
ReZB0`2?GY@40?JhQ`@0kjn:0`2BHYH709MUUPL0mkR3102IW]L609ZWg`<0`K_E1P2HT//709FVh@03
0;Njg02`Z<l0/:S?00H0/:S?00<0000008RQi028XN@00`28XN@809j`i0030:VfhP2kbND0^lWU00@0
^lWU00<0SNg<0;^ee02k]M@01P2k]M@00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`0I0?ooo`<000005P3oool00`22^OP0/mge0;?Mm@060;?Mm@H0UlWi00<0^;_K0:jli02^_>@0
1@2^_>@00`2meN`0S5R?08aHS`0508aHS`L0QUB>1P2CH98708]GSPL0QE>>1`2;F8l308iJT080aJo4
100/D/H20?JhQ@@0n;^40P2>G98708]JTP<0SejD103f^8L40>n_RP<0TV:F1`2GIIH70?NhP`D0VIkG
0`2JYml50<6ke@L0V9;;102EY^440;Njg0L0/:S?00<0000008RQi028XN@01028XN@409j`i0<0R=So
1P2kbND308g]c0H0^kGD0P3oool00`000000oooo0?ooo`0?0?ooo`000`3oool2000000<0oooo00<0
00000?ooo`3oool00P0000030?ooo`8000000`3oool300000080oooo0P0000060?ooo`030000003o
ool0oooo01H0oooo0`00000K0?ooo`H0/mge00<0Y[;Q08J>e026S]@01026S]@80:jli0030;gEk02<
F8l0S5R?00D0S5R?1`26E8h609=PTPL0ReN>1`25Dhh708]HS`80SUZ@1035[l@402aBaP030?JhQ@3h
^h@0n;^40080n;^40P2>G98708]JTP<0SejD103f^8L40>n_RP<0TV:F1`2GIIH60?NhP`L0VIkG00<0
VZOO0<6ke@31^mD01@31^mD709RBb`0309FVh@2g^]`0]k[L00@0]k[L1`2`Z<l00`36d>40000007fh
n@0607fhn@H0R=So0`2kbND608g]c0@0^kGD0`3oool00`000000oooo0?ooo`0?0?ooo`000P3oool0
10000000oooo0?ooo`0000040?ooo`060000003oool0oooo0000003oool000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0D
0?ooo`<00000803oool00`2cgOD0Y[;Q0:Jbh@030:Jbh@H0QXkD1P2^_>@00`3;hNP0_MG/08aHS`06
08aHS`L0QUB>1P2CH98708]GSPL0QE>>1`2;F8l00`2>FY00aJo40<F_a0030<F_a0D0;5;6103h^h@2
08iLTPL0ReZB0`2?GY@40?JhQ`@0kjn:0`2BHYH709MUUPH0mkR31P2IW]L00`2T^nT0`K_E0<6ke@06
0<6ke@H0V9;;00<0^]W`0;Njg02g^]`01P2g^]`50;2Xc`<0a]3Q00<0000007fhn@1m^?T00`1m^?T0
0`2OU/X0P:C[082Tj`03082Tj`80R=So00<0^lWU0?ooo`3oool00P3oool308g]c0<0^kGD103oool0
0`000000oooo0?ooo`0?0?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`060000003oool0
oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool00P3oool200000180oooo0`00000S0?ooo`L0Y[;Q1P26S]@30:jli0<0bn7X00<0_MG/08aHS`2<
F8l01@2<F8l708IDSPH0Tf2B1`2;Ehh708ECSP@0ReR?0P1Rdo870<F_a0D0;5;6103h^h@208iLTPL0
ReZB0P2?GY@50?JhQ`@0kjn:102BHYH609MUUPH0mkR300<0Z9[709VNe`2IW]L01@2T^nT70<6ke@@0
V9;;102jfO070;Njg0<0/:S?1P36d>400`000000OKSi09nFbP0409nFbPH0P:C[203oool00`2=kL`0
^kGD0?ooo`040?ooo`030000003oool0oooo00l0oooo00020?ooo`040000003oool0oooo000000@0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo0P00000W0?ooo`H0Y[;Q1`26
S]@00`2^_>@0bn7X0<_Qj0020<_Qj0030;gEk02<F8l0S5R?00D0S5R?1`26E8h00`3/l</0Tf2B09=P
TP0309=PTPL0ReN>1P25Dhh40;cCj`80H]?b2@35[l@502aBaP80n;^40`2>G98708]JTP80SejD1@3f
^8L30>n_RPD0TV:F1P2GIIH60?NhP`030<;6g@2T^nT0Y;_Y00H0Y;_Y1`31^mD00`2HT//0^]W`0;[I
l0050;[Il0L0]k[L00<0/:S?0<K@h@36d>401036d>400`3<i^T0000009nFbP0609nFbP<0P:C[4@3o
ool00`000000oooo0?ooo`0?0?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`060000003o
ool0oooo0000003oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo0`0000050?oo
o`030000003oool0oooo00`0oooo0`00000Z0?ooo`H0Y[;Q1@26S]@4093^kP80bn7X00<0_MG/08aH
S`2<F8l01@2<F8l608IDSP80k?3;00<05c>_09=PTP2CH9800P2CH98708]GSP@0QE>>1P2ldn/00`3C
d]P0aJo40<F_a0080<F_a0H0;5;600@0n;^408iLTP2>G980SUbB1`2;FY8208mNU0@0m[R7103_[hX5
099RUPH0UfFF1P3g^8<20<;6g@L0Y;_Y1P31^mD00`1Kd^T0^]W`0;[Il0070;[Il0<0]k[L0`2Nc?L6
0<K@h@<0c>KY00<0000009nFbP2OU/X01@2OU/X00`20Y>/0oooo0?ooo`0@0?ooo`030000003oool0
oooo00l0oooo00020?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`050?ooo`800000
2P3oool3000002h0oooo1P2V/^400`26S]@0T>k^093^kP03093^kP<0V9[D00<0LX_L0;gEk02<F8l0
1P2<F8l508IDSP<0k?3;0P0G<jl309=PTPL0ReN>0`25Dhh60;cCj`<0dm;H2P35[l@602aBaP<0SUbB
1`2;FY8208mNU0@0m[R7103_[hX5099RUPH0UfFF1P3g^8<20<;6g@P0Y;_Y0P31^mD505_Bj@H0^]W`
0P2AcO`709k<m`<0a]3Q1@3<i^T00`2OU/X0000009nFbP0409nFbQ@0oooo00<000000?ooo`3oool0
3`3oool000<0oooo0P0000060?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool01000
00040?ooo`030000003oool0oooo00H0oooo0`00000c0?ooo`H0KZKc00<0_lcT09RJe02HV]@01@2H
V]@00`1bRm`0S5R?08aHS`0508aHS`@0QUB>1@3/l</201Lc[`80Tf2B1`2;Ehh00`25Dhh0_=?[0;cC
j`050;cCj`@0dm;H2@35[l@4099OT`H0SUbB1`2;FY8208mNU0@0m[R7103_[hX5099RUPD0UfFF1`3g
^8<30<;6g@@0Y;_Y102?a_X20;B`e0<0LZSc0P1Kd^T20;[Il0H0TLgl1`2Nc?L00`36d>40c>KY0<cV
j@050<cVj@0309nFbP000000WiK:0080WiK:5P3oool00`000000oooo0?ooo`0>0?ooo`008@3oool0
0`000000oooo0?ooo`030?ooo`<00000=`3oool306jVl`@0_lcT1P2HV]@00`1bRm`0S5R?08aHS`05
08aHS`<0QUB>1P3/l</301Lc[`0309=PTP2;Ehh0ReN>00<0ReN>101Idlh50;cCj`H0dm;H1`35[l@5
099OT`H0SUbB202;FY800`2?GY@0m[R70?JhQ`020?JhQ`@0kjn:1@2BHYH509MUUPL0mkR30P32a]d3
0<CNk0@0SlKj1@2d/=@607:Xl`L0TLgl0`2Nc?L509Zll0H0c>KY00<0WiK:0000002OU/X0603oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000080oooo0`00000k0?ooo`0306jVl`2oc>@0_lcT
00@0_lcT1P2HV]@708aHS`<0QUB>1P3/l</401Lc[`80ReN>00<05c>_09Wbc`1RQMh00P1RQMh305WC
cP<0_=?[203Cd]P40<F_a0L0TUnC1P2>G98808]JTP0308mNU03f^8L0m[R70080m[R7103_[hX5099R
UPD0UfFF1`3g^8<60<CNk00308o6nP2d/=@0];3D00H0];3D1P1bZ?<3097=o0@0VZSQ202J_?060<cV
j@0309nFbP000000oooo01L0oooo00<000000?ooo`3oool03P3oool00200oooo1000000o0?ooo`H0
_lcT1P2HV]@708aHS`80QUB>203/l</501Lc[`<0VO;?1@1RQMh00`1Idlh0_=?[0=?Bf0080=?Bf0<0
aJo400<0TF2D099OT`2BGi<01@2BGi<608iLTPP0ReZB00<0SejD0?JhQ`3f^8L00P3f^8L40>n_RPD0
TV:F1@2GIIH70?NhP`D0a=k/00<0_LkW0;B`e02d/=@01P2d/=@00`33^<l0Uj7K09NQf`0409NQf`P0
VZSQ1P2J_?090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00200oooo
0P0000120?ooo`H0_lcT1@2HV]@708aHS`0308IDSP3/l</0k?3;00L0k?3;100G<jl409Wbc`P0HXGN
2@3Cd]P00`35[l@0TF2D095PU007099OT`H0SUbB202;FY850?JhQ`@0kjn:1@2BHYH509MUUPL0mkR3
0`34g^`40;g>i`H0];3D0`33^<l609NQf`P0VZSQ0P2J_?0<0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool03P3oool00280oooo00<000000?ooo`3oool0@03oool60;o<i0<0V9[D00<0
NmOn08aHS`2<F8l0102<F8l40:oVn@040;oli`1]NLh0KGW>06eicP<0k?3;0`0G<jl609Wbc`P0HXGN
1P3Cd]P5095PU0L0TUnC1`2>G98708]JTPD0m[R7103_[hX5099RUPD0UfFF1`3g^8<00`34g^`0_LkW
0;g>i`050;g>i`@0];3D1@33^<l609NQf`H0VZSQ403oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00h0oooo000S0?ooo`030000003oool0oooo03l0oooo2@2=VMX0101keoh0S5R?08aH
S`2<F8l60:oVn@<0_ocW1@1]NLh00`3/l</05c>_09Wbc`0206eicP80A6[C0`2Il/l806:5gP80dm;H
0`3b]hd5095PU0L0TUnC1`2>G98708]JTPD0m[R7103_[hX6099RUP@0UfFF1`3g^8<00`2JlmX0_LkW
0;g>i`050;g>i`<0];3D1P33^<l709NQf`80VZSQ503oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00h0oooo000T0?ooo`030000003oool0oooo03l0oooo1`2=VMX00`32]Lh0WIG;08aH
S`070:oVn@@0_ocW2P1]NLh01@3Wlm80A6[C04AZd`14J]<0VO;?00H0HXGN1`3b]hd5095PU0L0TUnC
1`2>G98608]JTP030<7[lP3f^8L0m[R700<0m[R7103_[hX6099RUP@0UfFF1P3g^8<309[cfPL0_LkW
00<0];3D0<>hc`33^<l01P33^<l309NQfaX0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0=0?ooo`009@3oool200000400oooo1@2=VMX30<:ecP80WIG;1@2_i_T60;oli`P0KGW>0P3W
lm8404AZd`040?BhS01RQMh0HXGN0?BhS0T0l[N=1P2AH9@7099OT`H0SUbB102;FY840<7[lP<0m[R7
103_[hX7099RUP@0UfFF1P3g^8<409[cfP<0_LkW0`2Fa_P80<>hcah0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0=0?ooo`009`3oool00`000000oooo0?ooo`0n0?ooo`<0SIWJ1032
]Lh509fEb`030:oVn@2oo>L0_ocW00D0_ocW1`1]NLh40>OcdP<0A6[C0`3d^8`:0?:gS@H0TF2D1`2B
Gi<608iLTP<0ReZB1P31jo820?JhQ`@0kjn:1`2BHYH409MUUPH0mkR31P2FS/T509K6n0H0`kS?803o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo000X0?ooo`030000003oool0
oooo03h0oooo00<0SIWJ0<:ecP32]Lh01032]Lh609fEb`80a<CI0P1EG;d20;oli`H0KGW>1P3Wlm80
0`14J]<0m;R<0?BhS0020?BhS0X0l[N=1P2AH9@7099OT`H0SUbB00<0ReZB0<7[lP31jo801`31jo80
0`3f^8L0kjn:0>n_RP020>n_RPL0TV:F102GIIH60?NhP`L0UXk91@2Fa_P30<>hcb<0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`00:@3oool00`000000oooo0?ooo`0m0?oo
o`P0`[G>102MUL/30<C4f@<0EEbm0P2oo>L406eicPL0io?B00<0A6[C0?BhS03d^8`00P3d^8`:0?:g
S@H0TF2D1`2BGi<508iLTP@0a=GW2031jo840>n_RPL0TV:F102GIIH60?NhP`H0UXk91@3oool209K6
n0030<>hc`3oool0oooo02<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?oo
o`00:P3oool2000003h0oooo1`32]Lh309fEb`D0a<CI101EG;d306eicPT0io?B103d^8`:0?:gS@H0
TF2D1`2BGi<408iLTPD0a=GW00<0`_kF09:1_@2BPKd01@2BPKd40>n_RPL0TV:F102GIIH60?NhP`D0
UXk9;P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo000/0?ooo`030000
003oool0oooo03`0oooo1`32]Lh00`2MUL/0a<CI0<C4f@040<C4f@D0EEbm00<0KGW>0>OcdP3Wlm80
1@3Wlm8308G4o0@0m;R<2P3b]hd2001@b@@0TF2D1`2BGi<208iLTPH0a=GW0P32o]H709:1_@@0kjn:
1`2BHYH309MUUPL0mkR3102FS/T`0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3@3oool002d0oooo00<000000?ooo`3oool0>`3oool60<:ecP80Yn?k1P34a=T805EL_@<0^oVk1P25
a?`30?BhS0X0l[N=00<0i^?>001@b@00D<T00`2AH9@7099OT`0308iLTP34eNL0a=GW00@0a=GW1032
o]H709:1_@<0kjn:00<0S5bD099RUP2BHYH0102BHYH309MUUPL0mkR30`2FS/Tb0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool002h0oooo00<000000?ooo`3oool0>`3oool2
0<:ecPH0Yn?k1034a=T20;kDjPH0EEbm1P2knK/508G4o0030?BhS03b]hd0l[N=00P0l[N=0`3Vhlh3
001@b@03095PU02BGi<0TUnC00<0TUnC0`1EdLd50<CEi`D0`_kF1`2BPKd30>n_RP0308aLU02BHYH0
TV:F00@0TV:F0`2GIIH70?NhP`030;O6iP2FS/T0oooo0380oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0<0?ooo`00;`3oool2000003h0oooo1P2Who/00`34a=T0_]CZ0;kDjP020;kD
jPD0EEbm1P2knK/308_@oP80;joY0P25a?`90?:gS@D0i^?>0`00D<T2099OT`L0EM7=0`34eNL60<;n
ePL0TX6m0`3_[hX00`2<G9@0TV:F099RUP05099RUP80UfFF1`3g^8<f0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0303oool00340oooo00<000000?ooo`3oool0?@3oool6082cm@<0
_]CZ101EG;d40;_i^`P0Rm3n0P0_[nT80?:gS@H0i^?>1`2?Sll406R?i@80EM7=00<0a=GW0<;neP1X
SnD00P2EIIL40<;nePL0TX6m0P3_[hX00`2<G9@0TV:F099RUP05099RUP80UfFF1`3g^8<g0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00380oooo00<000000?ooo`3oool0
?@3oool7082cm@040;kDjP2/^^@0EEbm05EL_@80^oVk0P2/^^@00`2La?@0Rm3n08_@oP0408_@oP80
X8Zl0P1WGkH00`0_[nT0l[N=0?:gS@040?:gS@H0i^?>0P3Jj]l708n?c`L0J8oU102EIIL30<;nePL0
TX6m00<0kjn:08aLU02<G9@01`2BHYH209MUUPL0mkR3>03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo000c0?ooo`030000003oool0oooo03d0oooo0`20/oD409jRf0030:bj
i01EG;d0[;[T00<0[;[T00<0/^gg08:OiP22WnH00P2;d?h50:2:_0<0Ienf00<0;joY0?:gS@3b]hd0
0`3b]hd50>KScP<0f^[O202?Sll406R?i@H0UFFG00<0U6>F0<;neP32o]H01`2BPKd00`3_[hX0S5bD
08aLU007099RUP80UfFF1`3g^8<h0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool003@0oooo00<000000?ooo`3oool0?03oool809jRf0<0[;[T102bkOL00`22WnH0X8Zl0:2:
_0060:2:_0@0Ienf0`3b]hd50>KScPD0f^[O1`2?Sll306R?i@030?JjRP2EIIL0UFFG00@0UFFG0P2D
HiH00`32o]H0TX6m09:1_@0609:1_@80S5bD1`2BHYH209MUUPL0mkR3>@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00`0oooo000e0?ooo`800000?@3oool809jRf0030:bji02bkOL0
/^gg00@0/^gg00<0PYoV0:2:_02PR[`01@2PR[`506MO]P030?:gS@3Vhlh0i^?>00<0i^?>1`3Jj]l7
08n?c`0306R?i@3f^XX0m[Z:00H0UFFG0`2DHiH00`32o]H0TX6m09:1_@0509:1_@80S5bD1`2BHYH2
09MUUPH0mkR3>`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo000g0?oo
o`030000003oool0oooo03/0oooo1P2NX]P40;OOm0@0/^gg00<0PYoV0:2:_02PR[`01@2PR[`806MO
]P80i^?>203Jj]l608n?c`@0m[Z:1P2EIIL409ASUP@0TX6m1@2<G9@7099RUP80UfFF1P3g^8<l0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool003P0oooo00<000000?ooo`3o
ool0>P3oool409jRf0D0]mod00<0`<CM07^Ag@1kTMd00P1kTMd00`2bkOL0X8Zl0:2:_0050:2:_0T0
Ienf0`2XjIT70=[Zg`80Sho?1`3f^XX609EUU`L0U6>F1P2<G9@7099RUP80UfFF1P3g^8<l0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool003T0oooo00<000000?ooo`3oool0
>P3oool00`2NX]P0]mod0;OOm0030;OOm0@0`<CM1@1kTMd70:2:_0L0Ienf0`2XjIT00`2`eo@0RXO;
08Z7b`0308Z7b`@0lKF>1`3f^XX609EUU`L0U6>F1P2<G9@7099RUP80UfFF1P3g^8<m0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool003X0oooo0P00000m0?ooo`80]mod1P30
a=d407^Ag@L0X8Zl1P1WGkH20:SYV@@0/=Od102:Ql/40?6eSPL0m[Z:1P2EIIL709ASUPH0S5bD1`2B
HYH209MUUPH0mkR3?P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo000l
0?ooo`030000003oool0oooo03`0oooo1P30a=d507^Ag@H0X8Zl1@1WGkH00`2XjIT0/=Od0;3Gm004
0;3Gm0@0RXO;0`3a]Hh80?JjRPH0UFFG1`2DHiH708aLU0H0TV:F00<0UfFF0?NhP`3g^8<01@3g^8<n
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool003d0oooo00<000000?oo
o`3oool0?03oool60<34g@80Ni7M0P2/_^L60:2:_0@0Ienf00<0Q:g`0=gBc@3Md/d01P2`eo@308Z7
b`<0lKF>203f^XX609EUU`L0U6>F1`2<G9@7099RUPL0mkR3?`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo000n0?ooo`030000003oool0oooo03`0oooo0`30a=d40:>Yf`80
[;kW1`2PR[`206MO]P80Q:g`103Md/d40;3Gm0<0RXO;0`3a]Hh90?JjRPH0UFFG1P2DHiH708aLU0L0
TV:F1`3g^8=00?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool003l0oooo
0P00000l0?ooo`P0XjWK0P2/_^L60:2:_00306MO]P24[O00Q:g`00D0gM;=00<0dKO1001QdP2`eo@0
0P2`eo@00`2:Ql/0lKF>0?6eSP020?6eSPT0m[Z:1P2EIIL609ASUPL0S5bD1`2BHYH70?NhPd40oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00@@3oool00`000000oooo0?oo
o`0j0?ooo`H0XjWK00@0/^Wh09VTg@2IY=d0VJCM1`24[O060=gBc@80dKO10P00HM800`2`eo@0RXO;
0?6eSP030?6eSPT0m[Z:1P2EIIL709ASUPH0S5bD1`2BHYH70?NhPd40oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0:0?ooo`00@P3oool00`000000oooo0?ooo`0j0?ooo`<0XjWK102b
jOP309VTg@D0Q:g`1P3Md/d40=6g`@<0067B103a]Hh90?JjRPH0UFFG1`2DHiH608aLU0L0TV:F1`3g
^8=20?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool004<0oooo00<00000
0?ooo`3oool0>P3oool00`2SZM/0/^Wh0;;Yn0040;;Yn0<0VJCM0`24[O060=gBc@D0dKO100<0DU>e
001QdP00HM80103a]Hh90?JjRPH0UFFG1`2DHiH508aLU0<0c<kK0`3`kL<2000l`@L0mkR3@`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00140?ooo`800000?@3oool40;;Y
n0<0VJCM00<0oooo08B]l03Md/d01@3Md/d60=6g`@80DU>e0P00HM830?6eSPT0m[Z:1P2EIIL709AS
UP@0S5bD0`3<c]/50?3]``8003c11P3g^8=40?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02P3oool004H0oooo00<000000?ooo`3oool0>P3oool01P000000oooo0?ooo`3oool0/^Wh
09VTg@<0oooo1@3Md/d60=6g`@80hLJm0P1BDkD01000HM80lKF>0?6eSP3a]Hh90?JjRPP0Ni?O1@2D
HiH308aLU0@0c<kK1P3`kL<2000l`@@0mkR3A@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00170?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool3
0=gBc@H0dKO10`3Qa[d3059C]@03001QdP3a]Hh0m[Z:00P0m[Z:0P00000807^Cg`040<?9g`0PFLl0
U6>F09ASUP80S5bD103<c]/60?3]``<0oooo00@003c10?NhP`3g^8<0mkR3AP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00180?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0203oool00`3Md/d0dKO10=6g`@050=6g`@<0hLJm101BDkD00`3a]Hh0m[Z:0?Jj
RP060?JjRP0404]lh00000000000000000D0Ni?O1033bMl2021Ic`0308aLU03<c]/0c<kK00<0c<kK
1@3`kL<50?ooo`<0mkR3A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00190?ooo`800000>03oool00`000000oooo0?ooo`080?ooo`L0dKO1103Qa[d5059C]@L0m[Z:00D0
ckS404]lh01;O>00BgcP0000000407^Cg`D0`lWO0`0PFLl40<c>f`@0l>g3203oool20?NhPdP0oooo
00D000000?ooo`3oool0oooo0000000;0?ooo`00B`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00T0oooo1P3A]l450>76_@H0DU>e103f^XX20<nha0D0BgcP00<0Ni?O0<?9g`33bMl0
1P33bMl3021Ic`80c<kK103`kL<:0?ooo`030?NhP`3oool0oooo04H0oooo00D000000?ooo`3oool0
oooo0000000;0?ooo`00C03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00X0oooo
103A]l460>76_@P0DU>e00<0m[Z:0<nha03?^<@00P3?^<@604]lh0L0`lWO100PFLl0103<c]/0l>g3
0?3]``3`kL=E0?ooo`040000003oool0oooo000000/0oooo001=0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool02`3oool20=6g`@L0hLJm1`1BDkD00`2`n^H0ckS40<nha0030<nha0L0
BgcP1`33bMl3021IceX0oooo00<000000?ooo`0000002`3oool004h0oooo0P00000c0?ooo`030000
003oool0oooo00`0oooo00<0dKO10>76_@3Qa[d01@3Qa[d5059C]@<0/?[V1P3?^<@704]lh0<0`lWO
H03oool00`000000oooo0000000;0?ooo`00D03oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00`0oooo2@3Qa[d3059C]@<0/?[V1`3?^<A[0?ooo`030000003oool0000000X0oooo001A
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03@3oool80>76_@03059C]@2`n^H0
/?[V0080/?[V1`3?^<A]0?ooo`8000002P3oool00580oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0>0?ooo`H0hLJm00<0oooo05j7hP1NQn800P1NQn870<nha6d0oooo0`00000:0?oo
o`00D`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo0P3Qa[d40?ooo`D0
GXOR1@3?^<AZ0?ooo`@000003@3oool005@0oooo0P00000]0?ooo`030000003oool0oooo01H0oooo
1@1NQn830<nha6P0oooo0`00000A0?ooo`00EP3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01X0oooo0P1NQn800`3?^<@0oooo0?ooo`1S0?ooo`@00000503oool005L0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1n0?ooo`@00000603oool005P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`1j0?ooo`@00000703oool005T0oooo0P00000X0?ooo`03
0000003oool0oooo07H0oooo1000000P0?ooo`00F`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo07<0oooo0`00000T0?ooo`00G03oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo06l0oooo1000000W0?ooo`00G@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06/0oooo1000000[0?ooo`00GP3oool2000002<0oooo00<000000?ooo`3oool0I`3oool40000
02l0oooo001P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0I03oool3000003<0
oooo001Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0H03oool4000003H0oooo
001R0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0G03oool4000003X0oooo001S
0?ooo`8000007@3oool00`000000oooo0?ooo`1I0?ooo`@00000?P3oool006D0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1F0?ooo`<00000@P3oool006H0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1B0?ooo`@00000A@3oool006L0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1>0?ooo`@00000B@3oool006P0oooo0P00000H0?ooo`030000003o
ool0oooo04X0oooo1000001=0?ooo`00JP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04H0oooo1000001A0?ooo`00J`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04<0oooo0`00001E0?ooo`00K03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03l0
oooo1000001H0?ooo`00K@3oool2000001<0oooo00<000000?ooo`3oool0>`3oool4000005`0oooo
001_0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool400000600oooo001`
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=03oool3000006@0oooo001a0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool4000006L0oooo001b0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0;03oool4000006/0oooo001c0?ooo`800000
3@3oool00`000000oooo0?ooo`0X0?ooo`@00000K`3oool007D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0U0?ooo`<00000L`3oool007H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0Q0?ooo`@00000MP3oool007L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0M0?ooo`@00000NP3oool007P0oooo0P0000080?ooo`030000003oool0oooo01T0
oooo1000001n0?ooo`00NP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo
100000220?ooo`00N`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0`00
00260?ooo`00O03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo10000029
0?ooo`00O@3oool2000000<0oooo00<000000?ooo`3oool02P3oool4000008d0oooo001o0?ooo`04
0000003oool0oooo000000P0oooo1000002A0?ooo`00P03oool00`000000oooo000000050?ooo`<0
0000U@3oool00840oooo0P0000000`3oool0000000000002000009P0oooo00220?ooo`800000W03o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.12735, -0.0301577, \
0.00389272, 0.00389272}}]
}, Closed]],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ListPlot3D", "[", 
          
          StyleBox[\(\[LeftBracketingBar]\[CapitalSigma](
                10)\[RightBracketingBar]\),
            "InlineInputTraditionalForm"], 
          StyleBox["]",
            "InlineInputTraditionalForm"]}], 
        StyleBox[";",
          "InlineInputTraditionalForm"]}], TraditionalForm]], "Input"],

Cell["", "Answer"],

Cell[BoxData[
    \(TraditionalForm\`Convolve\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Edge detection"
}], "Subsection"],

Cell[TextData[{
  "A straightforward image processing problem is that of edge detection, \
whereby sharp intensity transitions are enhanced relative to slow \
transitions.  An ",
  StyleBox["edge",
    FontSlant->"Italic"],
  " can be approximated by a step-function.  Derivatives of step-functions \
(also called Heaviside functions) lead to the Dirac delta \
\[OpenCurlyDoubleQuote]function\[CloseCurlyDoubleQuote] which will clearly \
reveal sharp transitions."
}], "Text",
  CellTags->{
  "edge detection", "step-function", "Heaviside function", "Dirac delta"}],

Cell[CellGroupData[{

Cell["Approximating a step function", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Enter the following useful approximation to the step \
function:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalH](x_, 
        k_ : 5) = \(2\ \(\(tan\^\(-1\)\)(k\ x)\)\)\/\[Pi]; \)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The syntax ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(k_:  5\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " defines a ",
  StyleBox["default argument",
    FontSlant->"Italic"],
  ".  If no second argument is supplied to ",
  StyleBox["\[ScriptCapitalH]", "InlineInputTraditionalForm"],
  " then it will default to ",
  StyleBox["5", "InlineInputTraditionalForm"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Visualize ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[ScriptCapitalH]",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", and its first two (partial) derivatives",
  StyleBox[" for a range of ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  StyleBox[" values.  ",
    FontSlant->"Plain"],
  StyleBox["NB",
    FontSlant->"Italic"],
  ": you will need to ",
  StyleBox["Evaluate", "InlineInputTraditionalForm"],
  " the argument to ",
  StyleBox["Plot", "InlineInputTraditionalForm"],
  ".  What can you say about the magnitude of the sign-change of the second \
derivative compared to the original step function?"
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The extension of this derivative technique for enhancing edges in two (or \
more) dimensions is to apply the (discrete) ",
  StyleBox["Laplacian operator",
    FontSlant->"Italic"],
  " to the (pixel) image function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  ". In our case ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " corresponds to the matrix of intensity (pixel) values stored in ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  ". ",
  "Note that the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " indices refer to the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " element of the matrix."
}], "Text",
  CellTags->"Laplacian operator"],

Cell[TextData[{
  "Recall that the (continuous) Laplacian operator is defined by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]", "=", 
          RowBox[{
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]x\^2\),
              MultilineFunction->None], "+", 
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]y\^2\),
              MultilineFunction->None]}]}], TraditionalForm]]],
  ", implemented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CapitalDelta]", ":=", 
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\^2 #\), \(\[PartialD]x\^2\),
              MultilineFunction->None], "+", 
            FractionBox[\(\[PartialD]\^2 #\), \(\[PartialD]y\^2\),
              MultilineFunction->None]}], "&"}]}], TraditionalForm]], "Input"],

Cell[TextData[{
  "At this time it might be a good idea to review section ",
  ButtonBox["3.3.1",
    ButtonData:>{"3.Numerics.nb", "numerical derivatives"},
    ButtonStyle->"Hyperlink"],
  " on numerical derivatives. Noting that"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(\[CapitalDelta](f(x, y))\),
          "TraditionalForm"], "-", 
        FractionBox[
          
          FormBox[\(f(x - h, y) + f(h + x, y) + f(x, y - h) + f(x, h + y) - 
              4\ \(f(x, y)\)\),
            "TraditionalForm"], \(h\^2\)], "+", \(O[h]\^3\)}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-\(1\/12\)\), " ", 
                  RowBox[{
                    SuperscriptBox["f", 
                      TagBox[\((0, 4)\),
                        Derivative],
                      MultilineFunction->None], "(", \(x, y\), ")"}]}], "-", 
                RowBox[{\(1\/12\), " ", 
                  RowBox[{
                    SuperscriptBox["f", 
                      TagBox[\((4, 0)\),
                        Derivative],
                      MultilineFunction->None], "(", \(x, y\), ")"}]}]}], 
              ")"}], " ", \(h\^2\)}], "+", 
          InterpretationBox[\(O(h\^3)\),
            SeriesData[ h, 0, {}, 2, 3, 1]]}],
        SeriesData[ h, 0, {
          Plus[ 
            Times[ 
              Rational[ -1, 12], 
              Derivative[ 0, 4][ f][ x, y]], 
            Times[ 
              Rational[ -1, 12], 
              Derivative[ 4, 0][ f][ x, y]]]}, 2, 3, 1]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["we now have a matrix operator:", "Text",
  CellTags->"discrete Laplacian filter"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Delta]", "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"1", \(-4\), "1"},
                {"0", "1", "0"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "which approximates the action of the continuous Laplacian operator.  For \
this operator, the geometrical relation in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane relating the ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, y]\)]],
  " values can be illustrated as follows: take the direct product (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Dot",
          "Input"], TraditionalForm]]],
  " product) between \[CapitalDelta] and the values of ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, y]\)]],
  " discretized on a regular grid"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Delta]\/h\^2\), " ", 
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {\(f(x - h, h + y)\), \(f(x, h + y)\), \(f(h + x, h + y)\)},
              {\(f(x - h, y)\), \(f(x, y)\), \(f(h + x, y)\)},
              {\(f(x - h, y - h)\), \(f(x, y - h)\), \(f(h + x, y - h)\)}
              }], "\[NoBreak]", ")"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(\(f(x, h + y)\)\/h\^2\), "0"},
            {\(\(f(x - h, 
                    y)\)\/h\^2\), \(-\(\(4\ \(f(x, y)\)\)\/h\^2\)\), \(\(f(
                    h + x, y)\)\/h\^2\)},
            {"0", \(\(f(x, y - h)\)\/h\^2\), "0"}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Adding all the elements together we recover the truncated series \
approximation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Together[Plus @@ \(Plus @@ %\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\(-4\)\ \(f(x, y)\) + f(x, y - h) + f(x, h + y) + \
f(x - h, y) + f(h + x, y)\)\/h\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To compute the action of the discrete Laplacian we need to ",
  StyleBox["convolve",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", compute the direct product of) the matrix \[Delta] with ",
  StyleBox["each",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`3\[Times]3\)]],
  " block of the matrix generated by discretizing ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  ". The ",
  StyleBox["Partition", "InlineInputTraditionalForm"],
  " function is useful here:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalM] = 
      Table[f\_\(i, j\), {i, 6}, {j, 5}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(f\_\(1, 1\)\), \(f\_\(1, 2\)\), \(f\_\(1, 3\)\), \(f\_\(1, 
                  4\)\), \(f\_\(1, 5\)\)},
            {\(f\_\(2, 1\)\), \(f\_\(2, 2\)\), \(f\_\(2, 3\)\), \(f\_\(2, 
                  4\)\), \(f\_\(2, 5\)\)},
            {\(f\_\(3, 1\)\), \(f\_\(3, 2\)\), \(f\_\(3, 3\)\), \(f\_\(3, 
                  4\)\), \(f\_\(3, 5\)\)},
            {\(f\_\(4, 1\)\), \(f\_\(4, 2\)\), \(f\_\(4, 3\)\), \(f\_\(4, 
                  4\)\), \(f\_\(4, 5\)\)},
            {\(f\_\(5, 1\)\), \(f\_\(5, 2\)\), \(f\_\(5, 3\)\), \(f\_\(5, 
                  4\)\), \(f\_\(5, 5\)\)},
            {\(f\_\(6, 1\)\), \(f\_\(6, 2\)\), \(f\_\(6, 3\)\), \(f\_\(6, 
                  4\)\), \(f\_\(6, 5\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptP] = 
      Partition[\[ScriptCapitalM], {3, 3}, {1, 1}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(1, 1\)\), \(f\_\(1, 2\)\), \(f\_\(1, 3\)\)},
                      {\(f\_\(2, 1\)\), \(f\_\(2, 2\)\), \(f\_\(2, 3\)\)},
                      {\(f\_\(3, 1\)\), \(f\_\(3, 2\)\), \(f\_\(3, 3\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(1, 2\)\), \(f\_\(1, 3\)\), \(f\_\(1, 4\)\)},
                      {\(f\_\(2, 2\)\), \(f\_\(2, 3\)\), \(f\_\(2, 4\)\)},
                      {\(f\_\(3, 2\)\), \(f\_\(3, 3\)\), \(f\_\(3, 4\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(1, 3\)\), \(f\_\(1, 4\)\), \(f\_\(1, 5\)\)},
                      {\(f\_\(2, 3\)\), \(f\_\(2, 4\)\), \(f\_\(2, 5\)\)},
                      {\(f\_\(3, 3\)\), \(f\_\(3, 4\)\), \(f\_\(3, 5\)\)}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(2, 1\)\), \(f\_\(2, 2\)\), \(f\_\(2, 3\)\)},
                      {\(f\_\(3, 1\)\), \(f\_\(3, 2\)\), \(f\_\(3, 3\)\)},
                      {\(f\_\(4, 1\)\), \(f\_\(4, 2\)\), \(f\_\(4, 3\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(2, 2\)\), \(f\_\(2, 3\)\), \(f\_\(2, 4\)\)},
                      {\(f\_\(3, 2\)\), \(f\_\(3, 3\)\), \(f\_\(3, 4\)\)},
                      {\(f\_\(4, 2\)\), \(f\_\(4, 3\)\), \(f\_\(4, 4\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(2, 3\)\), \(f\_\(2, 4\)\), \(f\_\(2, 5\)\)},
                      {\(f\_\(3, 3\)\), \(f\_\(3, 4\)\), \(f\_\(3, 5\)\)},
                      {\(f\_\(4, 3\)\), \(f\_\(4, 4\)\), \(f\_\(4, 5\)\)}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(3, 1\)\), \(f\_\(3, 2\)\), \(f\_\(3, 3\)\)},
                      {\(f\_\(4, 1\)\), \(f\_\(4, 2\)\), \(f\_\(4, 3\)\)},
                      {\(f\_\(5, 1\)\), \(f\_\(5, 2\)\), \(f\_\(5, 3\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(3, 2\)\), \(f\_\(3, 3\)\), \(f\_\(3, 4\)\)},
                      {\(f\_\(4, 2\)\), \(f\_\(4, 3\)\), \(f\_\(4, 4\)\)},
                      {\(f\_\(5, 2\)\), \(f\_\(5, 3\)\), \(f\_\(5, 4\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(3, 3\)\), \(f\_\(3, 4\)\), \(f\_\(3, 5\)\)},
                      {\(f\_\(4, 3\)\), \(f\_\(4, 4\)\), \(f\_\(4, 5\)\)},
                      {\(f\_\(5, 3\)\), \(f\_\(5, 4\)\), \(f\_\(5, 5\)\)}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(4, 1\)\), \(f\_\(4, 2\)\), \(f\_\(4, 3\)\)},
                      {\(f\_\(5, 1\)\), \(f\_\(5, 2\)\), \(f\_\(5, 3\)\)},
                      {\(f\_\(6, 1\)\), \(f\_\(6, 2\)\), \(f\_\(6, 3\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(4, 2\)\), \(f\_\(4, 3\)\), \(f\_\(4, 4\)\)},
                      {\(f\_\(5, 2\)\), \(f\_\(5, 3\)\), \(f\_\(5, 4\)\)},
                      {\(f\_\(6, 2\)\), \(f\_\(6, 3\)\), \(f\_\(6, 4\)\)}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(f\_\(4, 3\)\), \(f\_\(4, 4\)\), \(f\_\(4, 5\)\)},
                      {\(f\_\(5, 3\)\), \(f\_\(5, 4\)\), \(f\_\(5, 5\)\)},
                      {\(f\_\(6, 3\)\), \(f\_\(6, 4\)\), \(f\_\(6, 5\)\)}
                      }], "\[NoBreak]", ")"}]}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{
          Subscript[ f, 1, 1], 
          Subscript[ f, 1, 2], 
          Subscript[ f, 1, 3]}, {
          Subscript[ f, 2, 1], 
          Subscript[ f, 2, 2], 
          Subscript[ f, 2, 3]}, {
          Subscript[ f, 3, 1], 
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3]}}, {{
          Subscript[ f, 1, 2], 
          Subscript[ f, 1, 3], 
          Subscript[ f, 1, 4]}, {
          Subscript[ f, 2, 2], 
          Subscript[ f, 2, 3], 
          Subscript[ f, 2, 4]}, {
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4]}}, {{
          Subscript[ f, 1, 3], 
          Subscript[ f, 1, 4], 
          Subscript[ f, 1, 5]}, {
          Subscript[ f, 2, 3], 
          Subscript[ f, 2, 4], 
          Subscript[ f, 2, 5]}, {
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4], 
          Subscript[ f, 3, 5]}}}, {{{
          Subscript[ f, 2, 1], 
          Subscript[ f, 2, 2], 
          Subscript[ f, 2, 3]}, {
          Subscript[ f, 3, 1], 
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3]}, {
          Subscript[ f, 4, 1], 
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3]}}, {{
          Subscript[ f, 2, 2], 
          Subscript[ f, 2, 3], 
          Subscript[ f, 2, 4]}, {
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4]}, {
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4]}}, {{
          Subscript[ f, 2, 3], 
          Subscript[ f, 2, 4], 
          Subscript[ f, 2, 5]}, {
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4], 
          Subscript[ f, 3, 5]}, {
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4], 
          Subscript[ f, 4, 5]}}}, {{{
          Subscript[ f, 3, 1], 
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3]}, {
          Subscript[ f, 4, 1], 
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3]}, {
          Subscript[ f, 5, 1], 
          Subscript[ f, 5, 2], 
          Subscript[ f, 5, 3]}}, {{
          Subscript[ f, 3, 2], 
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4]}, {
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4]}, {
          Subscript[ f, 5, 2], 
          Subscript[ f, 5, 3], 
          Subscript[ f, 5, 4]}}, {{
          Subscript[ f, 3, 3], 
          Subscript[ f, 3, 4], 
          Subscript[ f, 3, 5]}, {
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4], 
          Subscript[ f, 4, 5]}, {
          Subscript[ f, 5, 3], 
          Subscript[ f, 5, 4], 
          Subscript[ f, 5, 5]}}}, {{{
          Subscript[ f, 4, 1], 
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3]}, {
          Subscript[ f, 5, 1], 
          Subscript[ f, 5, 2], 
          Subscript[ f, 5, 3]}, {
          Subscript[ f, 6, 1], 
          Subscript[ f, 6, 2], 
          Subscript[ f, 6, 3]}}, {{
          Subscript[ f, 4, 2], 
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4]}, {
          Subscript[ f, 5, 2], 
          Subscript[ f, 5, 3], 
          Subscript[ f, 5, 4]}, {
          Subscript[ f, 6, 2], 
          Subscript[ f, 6, 3], 
          Subscript[ f, 6, 4]}}, {{
          Subscript[ f, 4, 3], 
          Subscript[ f, 4, 4], 
          Subscript[ f, 4, 5]}, {
          Subscript[ f, 5, 3], 
          Subscript[ f, 5, 4], 
          Subscript[ f, 5, 5]}, {
          Subscript[ f, 6, 3], 
          Subscript[ f, 6, 4], 
          Subscript[ f, 6, 5]}}}}, TableDepth -> 2]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
We can now compute the direct product of each block with \[Delta] \
as follows,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Map[\[Delta]\ #\  &, \[ScriptP], {2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(1, 2\)\), "0"},
                      {\(f\_\(2, 1\)\), \(\(-4\)\ f\_\(2, 2\)\), \(f\_\(2, 
                            3\)\)},
                      {"0", \(f\_\(3, 2\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(1, 3\)\), "0"},
                      {\(f\_\(2, 2\)\), \(\(-4\)\ f\_\(2, 3\)\), \(f\_\(2, 
                            4\)\)},
                      {"0", \(f\_\(3, 3\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(1, 4\)\), "0"},
                      {\(f\_\(2, 3\)\), \(\(-4\)\ f\_\(2, 4\)\), \(f\_\(2, 
                            5\)\)},
                      {"0", \(f\_\(3, 4\)\), "0"}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(2, 2\)\), "0"},
                      {\(f\_\(3, 1\)\), \(\(-4\)\ f\_\(3, 2\)\), \(f\_\(3, 
                            3\)\)},
                      {"0", \(f\_\(4, 2\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(2, 3\)\), "0"},
                      {\(f\_\(3, 2\)\), \(\(-4\)\ f\_\(3, 3\)\), \(f\_\(3, 
                            4\)\)},
                      {"0", \(f\_\(4, 3\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(2, 4\)\), "0"},
                      {\(f\_\(3, 3\)\), \(\(-4\)\ f\_\(3, 4\)\), \(f\_\(3, 
                            5\)\)},
                      {"0", \(f\_\(4, 4\)\), "0"}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(3, 2\)\), "0"},
                      {\(f\_\(4, 1\)\), \(\(-4\)\ f\_\(4, 2\)\), \(f\_\(4, 
                            3\)\)},
                      {"0", \(f\_\(5, 2\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(3, 3\)\), "0"},
                      {\(f\_\(4, 2\)\), \(\(-4\)\ f\_\(4, 3\)\), \(f\_\(4, 
                            4\)\)},
                      {"0", \(f\_\(5, 3\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(3, 4\)\), "0"},
                      {\(f\_\(4, 3\)\), \(\(-4\)\ f\_\(4, 4\)\), \(f\_\(4, 
                            5\)\)},
                      {"0", \(f\_\(5, 4\)\), "0"}
                      }], "\[NoBreak]", ")"}]},
              {
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(4, 2\)\), "0"},
                      {\(f\_\(5, 1\)\), \(\(-4\)\ f\_\(5, 2\)\), \(f\_\(5, 
                            3\)\)},
                      {"0", \(f\_\(6, 2\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(4, 3\)\), "0"},
                      {\(f\_\(5, 2\)\), \(\(-4\)\ f\_\(5, 3\)\), \(f\_\(5, 
                            4\)\)},
                      {"0", \(f\_\(6, 3\)\), "0"}
                      }], "\[NoBreak]", ")"}], 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", \(f\_\(4, 4\)\), "0"},
                      {\(f\_\(5, 3\)\), \(\(-4\)\ f\_\(5, 4\)\), \(f\_\(5, 
                            5\)\)},
                      {"0", \(f\_\(6, 4\)\), "0"}
                      }], "\[NoBreak]", ")"}]}
              }], "\[NoBreak]", ")"}],
        MatrixForm[ {{{{0, 
          Subscript[ f, 1, 2], 0}, {
          Subscript[ f, 2, 1], 
          Times[ -4, 
            Subscript[ f, 2, 2]], 
          Subscript[ f, 2, 3]}, {0, 
          Subscript[ f, 3, 2], 0}}, {{0, 
          Subscript[ f, 1, 3], 0}, {
          Subscript[ f, 2, 2], 
          Times[ -4, 
            Subscript[ f, 2, 3]], 
          Subscript[ f, 2, 4]}, {0, 
          Subscript[ f, 3, 3], 0}}, {{0, 
          Subscript[ f, 1, 4], 0}, {
          Subscript[ f, 2, 3], 
          Times[ -4, 
            Subscript[ f, 2, 4]], 
          Subscript[ f, 2, 5]}, {0, 
          Subscript[ f, 3, 4], 0}}}, {{{0, 
          Subscript[ f, 2, 2], 0}, {
          Subscript[ f, 3, 1], 
          Times[ -4, 
            Subscript[ f, 3, 2]], 
          Subscript[ f, 3, 3]}, {0, 
          Subscript[ f, 4, 2], 0}}, {{0, 
          Subscript[ f, 2, 3], 0}, {
          Subscript[ f, 3, 2], 
          Times[ -4, 
            Subscript[ f, 3, 3]], 
          Subscript[ f, 3, 4]}, {0, 
          Subscript[ f, 4, 3], 0}}, {{0, 
          Subscript[ f, 2, 4], 0}, {
          Subscript[ f, 3, 3], 
          Times[ -4, 
            Subscript[ f, 3, 4]], 
          Subscript[ f, 3, 5]}, {0, 
          Subscript[ f, 4, 4], 0}}}, {{{0, 
          Subscript[ f, 3, 2], 0}, {
          Subscript[ f, 4, 1], 
          Times[ -4, 
            Subscript[ f, 4, 2]], 
          Subscript[ f, 4, 3]}, {0, 
          Subscript[ f, 5, 2], 0}}, {{0, 
          Subscript[ f, 3, 3], 0}, {
          Subscript[ f, 4, 2], 
          Times[ -4, 
            Subscript[ f, 4, 3]], 
          Subscript[ f, 4, 4]}, {0, 
          Subscript[ f, 5, 3], 0}}, {{0, 
          Subscript[ f, 3, 4], 0}, {
          Subscript[ f, 4, 3], 
          Times[ -4, 
            Subscript[ f, 4, 4]], 
          Subscript[ f, 4, 5]}, {0, 
          Subscript[ f, 5, 4], 0}}}, {{{0, 
          Subscript[ f, 4, 2], 0}, {
          Subscript[ f, 5, 1], 
          Times[ -4, 
            Subscript[ f, 5, 2]], 
          Subscript[ f, 5, 3]}, {0, 
          Subscript[ f, 6, 2], 0}}, {{0, 
          Subscript[ f, 4, 3], 0}, {
          Subscript[ f, 5, 2], 
          Times[ -4, 
            Subscript[ f, 5, 3]], 
          Subscript[ f, 5, 4]}, {0, 
          Subscript[ f, 6, 3], 0}}, {{0, 
          Subscript[ f, 4, 4], 0}, {
          Subscript[ f, 5, 3], 
          Times[ -4, 
            Subscript[ f, 5, 4]], 
          Subscript[ f, 5, 5]}, {0, 
          Subscript[ f, 6, 4], 0}}}}, TableDepth -> 2]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["and then add up all entries in each sub-matrix.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Apply[Plus, %, {2, 3}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(f\_\(1, 2\) + f\_\(2, 1\) - 4\ f\_\(2, 2\) + f\_\(2, 3\) + 
                f\_\(3, 2\)\), \(f\_\(1, 3\) + f\_\(2, 2\) - 4\ f\_\(2, 3\) + 
                f\_\(2, 4\) + f\_\(3, 3\)\), \(f\_\(1, 4\) + f\_\(2, 3\) - 
                4\ f\_\(2, 4\) + f\_\(2, 5\) + f\_\(3, 4\)\)},
            {\(f\_\(2, 2\) + f\_\(3, 1\) - 4\ f\_\(3, 2\) + f\_\(3, 3\) + 
                f\_\(4, 2\)\), \(f\_\(2, 3\) + f\_\(3, 2\) - 4\ f\_\(3, 3\) + 
                f\_\(3, 4\) + f\_\(4, 3\)\), \(f\_\(2, 4\) + f\_\(3, 3\) - 
                4\ f\_\(3, 4\) + f\_\(3, 5\) + f\_\(4, 4\)\)},
            {\(f\_\(3, 2\) + f\_\(4, 1\) - 4\ f\_\(4, 2\) + f\_\(4, 3\) + 
                f\_\(5, 2\)\), \(f\_\(3, 3\) + f\_\(4, 2\) - 4\ f\_\(4, 3\) + 
                f\_\(4, 4\) + f\_\(5, 3\)\), \(f\_\(3, 4\) + f\_\(4, 3\) - 
                4\ f\_\(4, 4\) + f\_\(4, 5\) + f\_\(5, 4\)\)},
            {\(f\_\(4, 2\) + f\_\(5, 1\) - 4\ f\_\(5, 2\) + f\_\(5, 3\) + 
                f\_\(6, 2\)\), \(f\_\(4, 3\) + f\_\(5, 2\) - 4\ f\_\(5, 3\) + 
                f\_\(5, 4\) + f\_\(6, 3\)\), \(f\_\(4, 4\) + f\_\(5, 3\) - 
                4\ f\_\(5, 4\) + f\_\(5, 5\) + f\_\(6, 4\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 4.0, this operation is built-in as ",
  StyleBox["ListConvolve", "InlineInputTraditionalForm"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`ListConvolve[\[Delta], \ \[ScriptCapitalM]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(f\_\(1, 2\) + f\_\(2, 1\) - 4\ f\_\(2, 2\) + f\_\(2, 3\) + 
                f\_\(3, 2\)\), \(f\_\(1, 3\) + f\_\(2, 2\) - 4\ f\_\(2, 3\) + 
                f\_\(2, 4\) + f\_\(3, 3\)\), \(f\_\(1, 4\) + f\_\(2, 3\) - 
                4\ f\_\(2, 4\) + f\_\(2, 5\) + f\_\(3, 4\)\)},
            {\(f\_\(2, 2\) + f\_\(3, 1\) - 4\ f\_\(3, 2\) + f\_\(3, 3\) + 
                f\_\(4, 2\)\), \(f\_\(2, 3\) + f\_\(3, 2\) - 4\ f\_\(3, 3\) + 
                f\_\(3, 4\) + f\_\(4, 3\)\), \(f\_\(2, 4\) + f\_\(3, 3\) - 
                4\ f\_\(3, 4\) + f\_\(3, 5\) + f\_\(4, 4\)\)},
            {\(f\_\(3, 2\) + f\_\(4, 1\) - 4\ f\_\(4, 2\) + f\_\(4, 3\) + 
                f\_\(5, 2\)\), \(f\_\(3, 3\) + f\_\(4, 2\) - 4\ f\_\(4, 3\) + 
                f\_\(4, 4\) + f\_\(5, 3\)\), \(f\_\(3, 4\) + f\_\(4, 3\) - 
                4\ f\_\(4, 4\) + f\_\(4, 5\) + f\_\(5, 4\)\)},
            {\(f\_\(4, 2\) + f\_\(5, 1\) - 4\ f\_\(5, 2\) + f\_\(5, 3\) + 
                f\_\(6, 2\)\), \(f\_\(4, 3\) + f\_\(5, 2\) - 4\ f\_\(5, 3\) + 
                f\_\(5, 4\) + f\_\(6, 3\)\), \(f\_\(4, 4\) + f\_\(5, 3\) - 
                4\ f\_\(5, 4\) + f\_\(5, 5\) + f\_\(6, 4\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Use ",
  StyleBox["ListConvolve", "InlineInputTraditionalForm"],
  " to compute the action of the discrete Laplacian, ",
  StyleBox["\[Delta]", "InlineInputTraditionalForm"],
  ", on ",
  StyleBox["\[ScriptCapitalE]", "InlineInputTraditionalForm"],
  " and visualize the result. "
}], "BeginEndQuestion"],

Cell["\<\
One should see that the edges of the image have been enhanced. \
\
\>", "Text",
  CellTags->"edge enhancement"],

Cell["\<\
Since the Laplacian also arises in Poisson's equation and Schr\
\[ODoubleDot]dinger's equation, this discretized numerical approximation is \
very useful.  \
\>", "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Sound"
}], "Section"],

Cell[TextData[{
  "And now for some fun \[Ellipsis]",
  StyleBox["  Mathematica",
    FontSlant->"Italic"],
  " has the ability not only to ",
  StyleBox["Plot", "InlineInputTraditionalForm"],
  " functions but to ",
  StyleBox["Play", "InlineInputTraditionalForm"],
  " them as well."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Simple Sounds"
}], "Subsection"],

Cell[TextData[{
  "For those that are curious, the lowest note on the piano is A sounding at \
27.50\[ThinSpace]Hz and the highest is the top C sounding at 4186.009\
\[ThinSpace]Hz. A440 concert pitch refers to tuning the A above middle C to \
440.000\[ThinSpace]Hz. See ",
  ButtonBox["http://www.pianoworld.com/pitch.htm",
    ButtonData:>{
      URL[ "http://www.pianoworld.com/pitch.htm"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Look up ",
  StyleBox["Play", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["Play", "InlineInputTraditionalForm"],
  " a note of frequency 261.626\[ThinSpace]Hz (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", middle-C) for 1 second. Use ",
  StyleBox["Play", "InlineInputTraditionalForm"],
  " to generate a (linear) superposition of two tones, middle-C and A440, and \
play this for 1 second."
}], "BeginEndQuestion",
  CellTags->"C and A"],

Cell[CellGroupData[{

Cell["Consider", "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["Play",
            "InlineInputTraditionalForm"], 
          StyleBox["[",
            "InlineInputTraditionalForm"], 
          RowBox[{
            RowBox[{
              StyleBox["sin",
                "InlineInputTraditionalForm"], 
              StyleBox["(",
                "InlineInputTraditionalForm"], 
              RowBox[{
                StyleBox["2",
                  "InlineInputTraditionalForm"], 
                StyleBox[" ",
                  "InlineInputTraditionalForm"], 
                StyleBox["\[Pi]",
                  "InlineInputTraditionalForm"], 
                StyleBox[" ",
                  "InlineInputTraditionalForm"], "256", 
                StyleBox[\(t\^2\),
                  "InlineInputTraditionalForm"]}], 
              StyleBox[")",
                "InlineInputTraditionalForm"]}], 
            StyleBox[",",
              "InlineInputTraditionalForm"], 
            StyleBox[\({t, 0, 2}\),
              "InlineInputTraditionalForm"]}], 
          StyleBox["]",
            "InlineInputTraditionalForm"]}], 
        StyleBox[";",
          "InlineInputTraditionalForm"]}], TraditionalForm]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  " ",
  Cell[BoxData[Cell[""]]],
  "At what rate is the frequency of this sound increasing (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": think about derivatives)?"
}], "EndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "To make question ",
  
  CounterBox["Exercise"],
  " clearer, consider the following plot:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`f(t_) = 2\ t\^2 - t + 1; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot[sin(f(t)), {t, 0, 5}, 
      PlotStyle \[Rule] RGBColor[1, 0, 0]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.309017 0.294303 [
[.21429 .29652 -4.5 -12 ]
[.21429 .29652 4.5 0 ]
[.40476 .29652 -4.5 -12 ]
[.40476 .29652 4.5 0 ]
[.59524 .29652 -4.5 -12 ]
[.59524 .29652 4.5 0 ]
[.78571 .29652 -4.5 -12 ]
[.78571 .29652 4.5 0 ]
[.97619 .29652 -4.5 -12 ]
[.97619 .29652 4.5 0 ]
[.01131 .01471 -15.9375 -6 ]
[.01131 .01471 0 6 ]
[.01131 .16187 -23.4375 -6 ]
[.01131 .16187 0 6 ]
[.01131 .45617 -16.5 -6 ]
[.01131 .45617 0 6 ]
[.01131 .60332 -9 -6 ]
[.01131 .60332 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
gsave
.21429 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .30902 m
.40476 .31527 L
s
gsave
.40476 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 .30902 m
.59524 .31527 L
s
gsave
.59524 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 .30902 m
.78571 .31527 L
s
gsave
.78571 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
gsave
.01131 .01471 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .16187 m
.03006 .16187 L
s
gsave
.01131 .16187 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -70 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .55666 m
.03279 .54965 L
.04262 .5433 L
.04758 .54071 L
.05288 .53844 L
.05789 .5368 L
.06006 .53625 L
.06244 .53574 L
.06507 .53533 L
.0665 .53516 L
.06719 .53509 L
.06785 .53504 L
.0691 .53496 L
.07025 .53492 L
.07148 .53491 L
.07218 .53491 L
.07283 .53493 L
.07354 .53495 L
.0743 .53499 L
.07503 .53504 L
.07569 .5351 L
.07829 .5354 L
.07964 .53561 L
.08112 .53588 L
.0841 .53657 L
.08922 .53816 L
.09469 .54043 L
.10458 .54591 L
.12582 .56254 L
.14594 .58125 L
.15559 .58971 L
.16088 .59383 L
.16585 .5972 L
.17042 .59976 L
.17461 .60157 L
.17687 .60231 L
.17802 .60261 L
.17926 .60288 L
.1805 .60308 L
.18165 .60322 L
.18236 .60328 L
.18302 .60331 L
.18427 .60331 L
.18542 .60326 L
.18666 .60313 L
.18783 .60294 L
.1889 .6027 L
.19015 .60235 L
.19151 .60188 L
.19399 .60075 L
Mistroke
.19658 .5992 L
.19933 .5971 L
.20428 .59209 L
.20927 .58531 L
.21397 .57723 L
.22274 .55739 L
.23253 .52737 L
.24285 .48634 L
.26134 .38991 L
.29936 .14348 L
.30941 .08687 L
.31891 .04545 L
.32416 .02932 L
.32713 .02268 L
.32854 .02019 L
.32987 .01827 L
.33107 .01688 L
.33217 .0159 L
.33339 .01515 L
.33471 .01475 L
.3359 .01476 L
.33721 .01518 L
.33787 .01556 L
.33857 .01609 L
.33984 .01736 L
.34108 .019 L
.34244 .02126 L
.34519 .02733 L
.34773 .03474 L
.35011 .04322 L
.35547 .06782 L
.36123 .10233 L
.37177 .18482 L
.38139 .27613 L
.39141 .37781 L
.40206 .47954 L
.41116 .5491 L
.41365 .56397 L
.41634 .57759 L
.41886 .58791 L
.42009 .59203 L
.4212 .59524 L
.42228 .59784 L
.42345 .6001 L
.42468 .60185 L
.42585 .60288 L
.42713 .60332 L
.42778 .60326 L
.42849 .60297 L
.42975 .60189 L
Mistroke
.43093 .60022 L
.43225 .59758 L
.43351 .59432 L
.43587 .58624 L
.4384 .57469 L
.44117 .55879 L
.44578 .52515 L
.45068 .48027 L
.4595 .38125 L
.46922 .25829 L
.47949 .13579 L
.48486 .08361 L
.4877 .06097 L
.49075 .04126 L
.49219 .03372 L
.49355 .02768 L
.49488 .02288 L
.4961 .01941 L
.49727 .01699 L
.4985 .01536 L
.49974 .01472 L
.50044 .01481 L
.5011 .01519 L
.50232 .01663 L
.50345 .01885 L
.50469 .02227 L
.50601 .02703 L
.50871 .04033 L
.51117 .05646 L
.51592 .09785 L
.5204 .14783 L
.5305 .28726 L
.54119 .44317 L
.54579 .50147 L
.55073 .55219 L
.55356 .57425 L
.55615 .58926 L
.55739 .59462 L
.55805 .59695 L
.55875 .59903 L
.56003 .60179 L
.56122 .60311 L
.56247 .60319 L
.56362 .60208 L
.56488 .59954 L
.56552 .59774 L
.56621 .59537 L
.56864 .58384 L
.57091 .56865 L
.57514 .52939 L
Mistroke
.57968 .47358 L
.58932 .32315 L
.59954 .15734 L
.60487 .0872 L
.60791 .05631 L
.60937 .04425 L
.61075 .03458 L
.612 .02746 L
.61266 .02432 L
.61336 .02145 L
.61459 .01761 L
.61574 .01547 L
.61644 .01484 L
.61719 .01475 L
.6179 .01521 L
.61856 .01612 L
.6198 .01909 L
.62111 .02402 L
.62238 .03055 L
.62359 .03829 L
.62586 .05676 L
.63095 .1156 L
.64013 .2663 L
.65026 .44882 L
.65538 .52477 L
.65829 .55838 L
.6596 .5707 L
.66103 .58205 L
.6622 .58965 L
.66346 .59596 L
.66415 .59863 L
.66479 .60055 L
.66602 .60285 L
.66715 .60327 L
.66838 .6019 L
.66953 .59885 L
.6706 .59454 L
.67183 .58777 L
.67299 .57975 L
.67562 .55558 L
.67818 .52467 L
.68093 .48429 L
.69048 .30632 L
.69934 .13841 L
.70425 .06808 L
.70566 .05261 L
.70699 .04031 L
.70817 .03128 L
.70947 .02357 L
.71016 .0204 L
Mistroke
.71081 .01807 L
.7115 .01627 L
.71223 .0151 L
.71292 .01472 L
.71356 .01499 L
.71477 .01716 L
.71547 .01937 L
.7162 .02249 L
.71752 .03005 L
.71894 .04096 L
.72051 .05621 L
.7255 .1252 L
.73088 .22622 L
.74061 .43096 L
.74525 .51404 L
.74784 .55076 L
.7502 .57641 L
.75154 .5874 L
.75225 .59207 L
.75299 .59614 L
.75365 .59897 L
.75437 .60127 L
.75563 .60324 L
.75689 .60255 L
.75759 .601 L
.75824 .59886 L
.75949 .59272 L
.76068 .58452 L
.76189 .57386 L
.76322 .55947 L
.76592 .52243 L
.77078 .43382 L
.77614 .31586 L
.78179 .18975 L
.78659 .09893 L
.78932 .05975 L
.79062 .04494 L
.79186 .0335 L
.79298 .02538 L
.7942 .01912 L
.7953 .01578 L
.79632 .01472 L
.79743 .01577 L
.79864 .01959 L
.79991 .02651 L
.8011 .03567 L
.80239 .04841 L
.80379 .06552 L
.80635 .10463 L
.81114 .20049 L
Mistroke
.81671 .33185 L
.82195 .4526 L
.82436 .50075 L
.8269 .5434 L
.82824 .56168 L
.8297 .57817 L
.83103 .58972 L
.83227 .59738 L
.83348 .60187 L
.83463 .60332 L
.83566 .60228 L
.83678 .59863 L
.838 .59172 L
.8393 .58108 L
.8404 .56938 L
.84162 .55381 L
.84683 .45999 L
.85244 .32582 L
.8577 .19511 L
.86027 .138 L
.8626 .09324 L
.86498 .05655 L
.86607 .04327 L
.86723 .03184 L
.86846 .02276 L
.8696 .01736 L
.87083 .01482 L
.87152 .01489 L
.87217 .01597 L
.87282 .018 L
.87353 .0213 L
.87481 .03019 L
.87606 .04232 L
.87722 .05652 L
.87985 .0984 L
.88264 .15572 L
.888 .28913 L
.89364 .43501 L
.89597 .488 L
.89846 .53596 L
.89989 .55844 L
.9012 .57523 L
.90251 .58833 L
.90375 .59704 L
.90499 .60207 L
.90562 .60314 L
.90632 .60319 L
.90754 .60035 L
.90869 .5943 L
.90938 .5891 L
Mistroke
.91004 .58309 L
.91128 .56906 L
.91406 .52524 L
.91682 .46742 L
.91939 .40409 L
.9252 .24574 L
.92762 .18252 L
.93023 .12138 L
.93254 .07671 L
.93379 .05681 L
.93497 .04145 L
.93633 .02789 L
.93704 .02259 L
.93781 .0184 L
.93852 .01594 L
.93918 .01482 L
.94043 .01596 L
.94166 .0212 L
.94281 .02963 L
.94406 .04276 L
.94539 .06097 L
.97619 .57442 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0
oooo103oool00140oooo0`0000060?ooo`030000003oool0oooo0?l0oooo103oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`@00000103oool0
0`000000oooo0?ooo`050?ooo`<00000C`3oool40?l002P0oooo0`3o000M0?ooo`80o`005`3oool2
0?l001D0oooo0P3o000B0?ooo`80o`00403oool20?l00100oooo000B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C`3oool0103o0000oooo0?ooo`3o000X0?ooo`030?l0003oool0
o`0001`0oooo00<0o`000?ooo`3o00005`3oool00`3o0000oooo0?l0000D0?ooo`80o`004P3oool2
0?l00100oooo0P3o000@0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04h0oooo00D0o`000?ooo`3oool0oooo0?l0000X0?ooo`030?l0003oool0o`0001`0oooo00<0o`00
0?ooo`3o00005`3oool00`3o0000oooo0?l0000C0?ooo`030?l0003oool0o`000140oooo00<0o`00
0?ooo`3o0000403oool20?l00100oooo000A0?ooo`8000001`3oool00`000000oooo0?ooo`1=0?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0903oool01@3o0000oooo0?ooo`3oool0
o`0001/0oooo00<0o`000?ooo`3o00005`3oool00`3o0000oooo0?l0000C0?ooo`030?l0003oool0
o`000140oooo00<0o`000?ooo`3o0000403oool20?l00100oooo000B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
02@0oooo00D0o`000?ooo`3oool0oooo0?l0000K0?ooo`040?l0003oool0oooo0?l001H0oooo00<0
o`000?ooo`3o00004`3oool00`3o0000oooo0?l0000A0?ooo`030?l0003oool0o`000100oooo0P3o
000@0?ooo`006P3oool00`000000oooo0?ooo`1=0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01P0oooo00@0o`00
0?ooo`3oool0o`005P3oool00`3o0000oooo0?l0000C0?ooo`030?l0003oool0o`000140oooo00<0
o`000?ooo`3o0000403oool20?l00100oooo000J0?ooo`030000003oool0oooo04`0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0603oool0103o0000oooo0?ooo`3o000E0?ooo`050?l0003oool0oooo0?ooo`3o0000
4P3oool00`3o0000oooo0?l0000A0?ooo`030?l0003oool0o`0000l0oooo00@0o`000?ooo`3oool0
o`003`3oool001X0oooo0P00001=0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01L0oooo00D0o`000?ooo`3oool0
oooo0?l0000E0?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`3o0000oooo0?l0000A0?oo
o`030?l0003oool0o`0000l0oooo00@0o`000?ooo`3oool0o`003`3oool001X0oooo00<000000?oo
o`3oool0C03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo02<0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0G0?ooo`050?l0003oool0oooo0?ooo`3o00005@3oool0
1@3o0000oooo0?ooo`3oool0o`000180oooo00@0o`000?ooo`3oool0o`00403oool00`3o0000oooo
0?l0000?0?ooo`040?l0003oool0oooo0?l000l0oooo000J0?ooo`030000003oool0oooo04`0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo
00D0o`000?ooo`3oool0oooo0?l0000B0?ooo`040?l0003oool0oooo0?l00100oooo00<0o`000?oo
o`3o00003`3oool0103o0000oooo0?ooo`3o000?0?ooo`006P3oool00`000000oooo0?ooo`1<0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool08@3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0B0?oo
o`050?l0003oool0oooo0?ooo`3o00004P3oool0103o0000oooo0?ooo`3o000@0?ooo`040?l0003o
ool0oooo0?l000h0oooo00@0o`000?ooo`3oool0o`003`3oool001X0oooo00<000000?ooo`3oool0
B`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
4P3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00D0o`000?ooo`3oool0oooo0?l0000@0?oo
o`040?l0003oool0oooo0?l000h0oooo00@0o`000?ooo`3oool0o`003`3oool001X0oooo00<00000
0?ooo`3oool0B`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0240oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool04P3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00D0o`000?ooo`3oool0oooo
0?l0000@0?ooo`040?l0003oool0oooo0?l000h0oooo00@0o`000?ooo`3oool0o`003`3oool001X0
oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo0200
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool04P3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00D0o`000?oo
o`3oool0oooo0?l0000@0?ooo`040?l0003oool0oooo0?l000h0oooo00@0o`000?ooo`3oool0o`00
3`3oool001X0oooo00<000000?ooo`3oool0BP3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo0200oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool04P3oool01@3o0000oooo0?ooo`3oool0o`000140oooo
00D0o`000?ooo`3oool0oooo0?l0000@0?ooo`040?l0003oool0oooo0?l000h0oooo00@0o`000?oo
o`3oool0o`003`3oool001X0oooo0P00001;0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool0803oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01L0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`3o00004@3oool0
1@3o0000oooo0?ooo`3oool0o`000100oooo00@0o`000?ooo`3oool0o`003P3oool0103o0000oooo
0?ooo`3o000?0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01H0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`050?l0003oool0oooo0?ooo`3o
00004@3oool01@3o0000oooo0?ooo`3oool0o`000100oooo00@0o`000?ooo`3oool0o`003P3oool0
103o0000oooo0?ooo`3o000?0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`050?l0003oool0
oooo0?ooo`3o00004@3oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00D0o`000?ooo`3oool0
oooo0?l0000>0?ooo`040?l0003oool0oooo0?l000l0oooo000J0?ooo`030000003oool0oooo04T0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0180
oooo00D0o`000?ooo`3oool0oooo0?l0000A0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool0
1@3o0000oooo0?ooo`3oool0o`0000h0oooo00@0o`000?ooo`3oool0o`003`3oool001X0oooo00<0
00000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01h0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool04@3oool01@3o0000oooo0?ooo`3oool0o`000140oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00003P3oool0103o0000
oooo0?ooo`3o000?0?ooo`006P3oool00`000000oooo0?ooo`190?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01D0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0
oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`040?l0003oool0oooo0?l000l0oooo000J0?oo
o`030000003oool0oooo04T0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0N0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool01@3o0000oooo0?ooo`3oool0
o`0000h0oooo00@0o`000?ooo`3oool0o`003`3oool001X0oooo00<000000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00003P3oool01@3o0000oooo0?oo
o`3oool0o`0000h0oooo000J0?ooo`800000BP3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo01h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`050?l0003o
ool0oooo0?ooo`3o00003@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo
000J0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?oo
o`0N0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0>0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool01@3o0000oooo0?oo
o`3oool0o`0000d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`006P3o
ool00`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool07P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00D0o`000?ooo`3oool0oooo
0?l0000=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool001X0oooo00<0
00000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo01d0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o0000
3@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo000J0?ooo`030000003o
ool0oooo04P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`006P3oool0
0`000000oooo0?ooo`180?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0703oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool0
01X0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo
01`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00`0oooo000J0?ooo`030000003oool0oooo04P0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0L0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool04`3oool00`3o0000
oooo0?ooo`050?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0103oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0<0?ooo`006P3oool2000004P0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0L0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`170?ooo`030?l0003oool0oooo00h0oooo00<0
o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01<0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00`0oooo000J0?ooo`030000003oool0oooo04L0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`170?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0180oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool001X0oooo00<000000?ooo`3oool0
A`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00090?ooo`8000000`3o
ool00`000000oooo0?ooo`02000000L0oooo00<000000?ooo`3oool0A`3oool00`3o0000oooo0?oo
o`0?0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00`0oooo00080?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`160?ooo`030?l0003oool0oooo0100oooo
00<0o`000?ooo`3oool06P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0180oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00X0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool0303oool000<0oooo100000001@3oool000000?ooo`3oool0000000L0oooo
00<000000?ooo`3oool0103oool3000004H0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0;0?ooo`00203oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo01X0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo
00080?ooo`040000003oool0oooo000000@0oooo0`0000070?ooo`030000003oool0oooo04H0oooo
00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00T0oooo
00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`00203oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0AP3oool00`3o0000oooo
0?ooo`0A0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00/0oooo00090?ooo`8000001@3oool4000000H0oooo00<0
00000?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo01T0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo000J
0?ooo`030000003oool0oooo04H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0I
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;
0?ooo`006P3oool00`000000oooo0?ooo`150?ooo`030?l0003oool0oooo0180oooo00<0o`000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0140oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool02`3oool001X0oooo00<000000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00/0oooo000J0?ooo`800000AP3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0
003oool0oooo01T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0;0?ooo`006P3oool00`000000oooo0?ooo`150?ooo`030?l0003oool0
oooo0180oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool0A@3oool00`3o
0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo01L0oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo000J0?ooo`030000003oool0oooo04@0
oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`006P3oool00`000000oooo
0?ooo`140?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool001X0oooo00<0
00000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo01L0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo000J
0?ooo`800000A@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo01L0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00/0oooo000J0?oo
o`030000003oool0oooo04@0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0G0?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?oo
o`006P3oool00`000000oooo0?ooo`140?ooo`030?l0003oool0oooo01@0oooo00<0o`000?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool02P3oool001X0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0D0?ooo`030?l0
003oool0oooo01L0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00X0oooo000J0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0:0?ooo`006P3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0
oooo01H0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool02P3oool001X0oooo00<000000?ooo`3oool0@`3oool00`3o
0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo000J0?ooo`030000003oool0oooo04<0
oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`006P3oool2000004@0oooo
00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00`0oooo
00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`006P3oool00`000000oooo0?oo
o`130?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool001X0oooo00<00000
0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo01D0oooo00<0o`00
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo000J0?oo
o`030000003oool0oooo0480oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?oo
o`006P3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool02P3oool001X0oooo00<000000?ooo`3oool0;`3oool300000100oooo00<0o`000?ooo`3oool0
603oool00`3o0000oooo0?ooo`0400000100oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000003o0000oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3oool000001P3oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`8000001`3oool001X0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01P0oooo00@0o`000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool010000000oooo0?l00000000;0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`040?l0003oool0oooo000000H0oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo
000J0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0H0?ooo`050?l0003oool0oooo0?ooo`0000004P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00h0oooo00<0o`000000003oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0103o000000000000000000060?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`00
6P3oool200000340oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<000000?l0003oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`0000060?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`00
6P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l000000000oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00@0o`000000003oool0
00001P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<000001`3oool001X0oooo
00<000000?ooo`3oool0;`3oool200000100oooo00<0o`000?ooo`3oool06@3oool0103o0000oooo
0?ooo`0000020?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0<0?ooo`040000003oool0o`00000000/0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00@0o`000?ooo`00000000001P3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`040?l0003oool0oooo000000T0oooo000J0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0I0?ooo`040?l0003oool0
oooo0?ooo`800000403oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0
00000?l0003oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool0203oool0103o0000oooo0?ooo`0000060?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`0000000`0000060?ooo`006P3oool00`000000oooo0?ooo`110?ooo`030?l0003o
ool0oooo01T0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`0I0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
0440oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00X0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`110?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool001@0oooo
B@0000000`3o000000000000000K000000030?l00000000000000180000000<0o`00000000000000
3P0000000`3o000000000000000=000000030?l000000000000000/0000000<0o`00000000000000
2P0000000`3o0000000000000009000000030?l000000000000000P0000000<0o`00000000000000
200000000`3o0000000000000006000000030?l000000000000000L0000000<0o`00000000000000
1P0000000`3o0000000000000007000000030?l000000000000000T00000000J0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0000000T0oooo00@000000?ooo`3o
ool0o`001P3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0000000T0oooo00<000000?oo
o`3o00001`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<000000?oo
o`3oool0103oool0103o0000oooo0?ooo`0000070?ooo`030?l0003oool0000000P0oooo00<0o`00
0?ooo`0000001P3oool0103o0000oooo0?ooo`0000060?ooo`040?l0003oool0oooo000000D0oooo
00D0o`000?ooo`3oool0oooo000000050?ooo`050?l0003oool0oooo0?ooo`0000001`3oool001X0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01/0
oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00l0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0000000<0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0000000P0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0000000L0oooo000J0?ooo`03
0000003oool0oooo0400oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`100?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo03l0oooo00<0o`000?ooo`3oool0703oool0
0`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0oooo
01`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool001X0oooo0P0000100?ooo`030?l0003oool0oooo01`0
oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0?`3oool00`3o0000oooo
0?ooo`0L0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo03l0oooo00<0
o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0o
0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool0?`3oool00`3o0000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool0403oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo000J0?ooo`03
0000003oool0oooo03h0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo0100oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`00
6P3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo01h0oooo00<0o`000?ooo`3oool0
403oool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool001X0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003o
ool0oooo00l0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo000J0?ooo`800000?`3oool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo000J0?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0oooo01h0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool001X0oooo00<000000?ooo`3oool0?P3oool00`3o0000oooo
0?ooo`0N0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo000J0?ooo`030000003oool0oooo03d0oooo00<0
o`000?ooo`3oool07`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`0m
0?ooo`030?l0003oool0oooo01l0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool001X0oooo00<000000?oo
o`3oool0?@3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo000J0?ooo`03
0000003oool0oooo03d0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`00
6P3oool2000003h0oooo00<0o`000?ooo`3oool0803oool00`3o0000oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030?l0
003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`006P3o
ool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool001X0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo000J0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3oool08@3oool00`3o
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`0l0?ooo`030?l0003oool0oooo0240
oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool001X0oooo00<000000?ooo`3oool0?03oool00`3o0000oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo000J0?ooo`030000003oool0oooo03/0oooo00<0
o`000?ooo`3oool08P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01@0oooo00<0
o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`006P3oool2000003`0oooo00<0o`00
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01@0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`006P3oool00`000000oooo0?ooo`0k0?oo
o`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool01`3oool001X0oooo00<000000?ooo`3o
ool0>`3oool00`3o0000oooo0?ooo`0S0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3o
ool0503oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo000J0?ooo`030000
003oool0oooo03/0oooo00<0o`000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo01@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`006P3o
ool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3o
ool001X0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00L0oooo00090?ooo`8000000`3oool00`000000oooo0?ooo`02000000L0oooo00<000000?oo
o`3oool0>P3oool00`3o0000oooo0?ooo`0T0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool0503oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00080?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0j
0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0D
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool000P0oooo00@000000?oo
o`3oool000001`3oool00`000000oooo0?ooo`040?ooo`<00000>P3oool00`3o0000oooo0?ooo`0T
0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`07
0?ooo`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo02D0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0403oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00h0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0o`00
0?ooo`3oool01`3oool000P0oooo00@000000?ooo`3oool00000103oool3000000L0oooo00<00000
0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo0100oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0i
0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0E
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`05
0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool000T0oooo0P0000050?oo
o`@000001P3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo02H0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0o`000?oo
o`3oool01`3oool001X0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0V0?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00L0oooo000J0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool0
9`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`070?ooo`006P3oool00`000000oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo0P00000i0?ooo`030?l0003oool0
oooo02L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo00<000000?ooo`3oool0>03oool00`3o
0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool05P3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`030000003oool0oooo03P0
oooo00<0o`000?ooo`3oool0:03oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo01H0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00d0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000oooo
0?ooo`0g0?ooo`030?l0003oool0oooo02T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0F0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo00<0
00000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J
0?ooo`030000003oool0oooo03L0oooo00<0o`000?ooo`3oool0:@3oool00`3o0000oooo0?ooo`09
0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`06
0?ooo`006P3oool00`000000oooo0?ooo`0f0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool01P3oool001X0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool05`3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00H0oooo000J0?ooo`800000=`3oool00`3o0000oooo0?ooo`0[0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00H0oooo000J0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0:`3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0
oooo02`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0
oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo00l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo00<000000?ooo`3oool0=@3oool00`3o
0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0603oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`030000003oool0oooo03D0
oooo00<0o`000?ooo`3oool0;03oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo01P0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00d0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000oooo
0?ooo`080?ooo`D0o`009`3oool00`3o0000oooo0?ooo`0]0?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01<0oooo
00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`030000
003oool0oooo00D0oooo0`3o00050?ooo`<0o`00903oool00`3o0000oooo0?ooo`0]0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0o`0000h0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0
oooo000J0?ooo`030000003oool0oooo0080oooo0`3o000;0?ooo`<0o`008@3oool00`3o0000oooo
0?ooo`0^0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo01<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool01@3o0000oooo
0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00H0oooo000J0?ooo`8000000P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0
003oool0oooo01d0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo01X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0o`000100
oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool03@3oool00`3o0000oooo0?ooo`050?ooo`006P3oool010000000oooo0?l0003o000C0?oo
o`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0
o`000100oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`050?l0003oool0oooo0?ooo`3o0000
403oool00`3o0000oooo0?ooo`050?ooo`006P3oool00`000000o`000?ooo`0E0?ooo`030?l0003o
ool0oooo01/0oooo00<0o`000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo01X0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool0403oool01@3o0000oooo0?ooo`3oool0o`000100oooo
00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`040?l0003oool0oooo0?l00100oooo00<0o`000?oo
o`3oool01@3oool001X0oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo0300oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo0100oooo00D0o`000?ooo`3oool0oooo0?l0000A0?ooo`040?l0003oool0oooo
0?l000l0oooo00@0o`000?ooo`3oool0o`00403oool00`3o0000oooo0?ooo`050?ooo`006P3oool0
0`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo01P0oooo00<0o`000?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool0
1@3o0000oooo0?ooo`3oool0o`000140oooo00@0o`000?ooo`3oool0o`003`3oool0103o0000oooo
0?ooo`3o000@0?ooo`030?l0003oool0oooo00D0oooo000J0?ooo`030000003oool0oooo01P0oooo
0P3o000G0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0J0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0oooo0140oooo00@0o`000?ooo`3oool0o`004@3oool0103o0000
oooo0?ooo`3o000?0?ooo`040?l0003oool0oooo0?l00100oooo00<0o`000?ooo`3oool01@3oool0
01X0oooo00<000000?ooo`3oool06P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo
0340oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool05@3oool01@3o0000oooo0?ooo`3oool0o`0001<0oooo00@0o`00
0?ooo`3oool0o`004@3oool0103o0000oooo0?ooo`3o000?0?ooo`040?l0003oool0oooo0?l00100
oooo00<0o`000?ooo`3oool01@3oool001X0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0C0?ooo`030?l0003oool0oooo0340oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo
0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool05@3oool0103o0000oooo
0?ooo`3o000D0?ooo`040?l0003oool0oooo0?l00140oooo00@0o`000?ooo`3oool0o`003`3oool0
103o0000oooo0?ooo`3o000@0?ooo`030?l0003oool0oooo00D0oooo000J0?ooo`8000007@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo03<0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool05@3oool0
103o0000oooo0?ooo`3o000D0?ooo`040?l0003oool0oooo0?l00140oooo00@0o`000?ooo`3oool0
o`003`3oool0103o0000oooo0?ooo`3o000@0?ooo`030?l0003oool0oooo00D0oooo000J0?ooo`03
0000003oool0oooo01d0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`0c0?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo01D0oooo00@0o`000?ooo`3oool0o`00503oool0103o0000oooo0?ooo`3o000A
0?ooo`040?l0003oool0oooo0?l000l0oooo00@0o`000?ooo`3oool0o`00603oool001X0oooo00<0
00000?ooo`3oool07P3oool00`3o0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo03<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0L0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool05@3oool0103o0000oooo0?ooo`3o000D0?ooo`040?l0003oool0oooo0?l00140
oooo00@0o`000?ooo`3oool0o`00403oool00`3o0000oooo0?l0000H0?ooo`006P3oool00`000000
oooo0?ooo`0O0?ooo`030?l0003oool0oooo00`0oooo0P3o000g0?ooo`050?l0003oool0oooo0?oo
o`3o00007`3oool01@3o0000oooo0?ooo`3oool0o`0001L0oooo00@0o`000?ooo`3oool0o`00503o
ool0103o0000oooo0?ooo`3o000A0?ooo`040?l0003oool0oooo0?l00100oooo00<0o`000?ooo`3o
0000603oool001X0oooo00<000000?ooo`3oool0803oool20?l000/0oooo00<0o`000?ooo`3oool0
=`3oool01@3o0000oooo0?ooo`3oool0o`0001l0oooo00@0o`000?ooo`3oool0o`00603oool0103o
0000oooo0?ooo`3o000D0?ooo`030?l0003oool0o`000180oooo00<0o`000?ooo`3o00004@3oool2
0?l001T0oooo000A0?ooo`<000001P3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0oooo
00P0oooo00<0o`000?ooo`3oool0=`3oool0103o0000oooo0?ooo`3o000Q0?ooo`030?l0003oool0
o`0001P0oooo00@0o`000?ooo`3oool0o`00503oool00`3o0000oooo0?l0000B0?ooo`030?l0003o
ool0o`000140oooo0P3o000I0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02<0oooo00<0o`000?ooo`3oool01@3oool20?l003X0oooo00@0o`000?ooo`3oool0o`008@3o
ool00`3o0000oooo0?l0000I0?ooo`80o`005P3oool20?l001<0oooo0P3o000A0?ooo`80o`006@3o
ool00180oooo00<000000?ooo`3oool01@3oool3000002@0oooo203o000l0?ooo`<0o`008@3oool2
0?l001X0oooo0P3o000F0?ooo`80o`004`3oool20?l00140oooo0P3o000I0?ooo`004P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo103oool00180oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000A0?ooo`8000001`3oool00`000000oooo
0?ooo`3o0?ooo`@0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.527234, -1.12766, \
0.0196943, 0.0127464}}]
}, Open  ]],

Cell[TextData[{
  "What is the instantaneous frequency of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(f(t))\)]],
  "? One way of answering this is to consider the periodic function, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"sin", "(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["f", "\[Prime]",
                    MultilineFunction->None], "(", \(t\_0\), ")"}], " ", 
                "t"}], "-", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["f", "\[Prime]",
                        MultilineFunction->None], "(", \(t\_0\), ")"}], 
                    " ", \(t\_0\)}], "-", \(f(t\_0)\)}], ")"}]}], ")"}], 
          "\[Congruent]", \(sin(\[Omega]\_\(t\_0\)\ t - \[Phi]\_\(t\_0\))\)}],
         TraditionalForm]]],
  ", that has the same frequency as ",
  Cell[BoxData[
      \(TraditionalForm\`sin(f(t))\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_0\)]],
  ". For example, with ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0 = 3\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{"Evaluate", "[", 
              RowBox[{"sin", "(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["f", "\[Prime]",
                        MultilineFunction->None], "(", "3", ")"}], " ", "t"}],
                   "-", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["f", "\[Prime]",
                            MultilineFunction->None], "(", "3", ")"}], " ", 
                        "3"}], "-", \(f(3)\)}], ")"}]}], ")"}], "]"}], 
            ",", \({t, 0, 5}\), 
            ",", \(PlotStyle \[Rule] RGBColor[0, 0, 1]\)}], "]"}], ";"}], 
      TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.309017 0.294302 [
[.21429 .29652 -4.5 -12 ]
[.21429 .29652 4.5 0 ]
[.40476 .29652 -4.5 -12 ]
[.40476 .29652 4.5 0 ]
[.59524 .29652 -4.5 -12 ]
[.59524 .29652 4.5 0 ]
[.78571 .29652 -4.5 -12 ]
[.78571 .29652 4.5 0 ]
[.97619 .29652 -4.5 -12 ]
[.97619 .29652 4.5 0 ]
[.01131 .01472 -15.9375 -6 ]
[.01131 .01472 0 6 ]
[.01131 .16187 -23.4375 -6 ]
[.01131 .16187 0 6 ]
[.01131 .45617 -16.5 -6 ]
[.01131 .45617 0 6 ]
[.01131 .60332 -9 -6 ]
[.01131 .60332 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
gsave
.21429 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .30902 m
.40476 .31527 L
s
gsave
.40476 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 .30902 m
.59524 .31527 L
s
gsave
.59524 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 .30902 m
.78571 .31527 L
s
gsave
.78571 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
gsave
.01131 .01472 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .16187 m
.03006 .16187 L
s
gsave
.01131 .16187 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -70 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .59196 m
.04262 .36918 L
.0522 .20884 L
.05746 .13054 L
.06244 .0715 L
.06506 .04807 L
.06644 .03808 L
.0679 .02936 L
.06912 .02357 L
.06977 .02108 L
.07047 .01885 L
.0717 .0161 L
.07286 .01485 L
.0741 .01497 L
.0748 .0157 L
.07545 .01681 L
.07665 .01993 L
.07792 .02476 L
.07917 .03101 L
.08035 .03822 L
.08255 .05504 L
.08806 .11432 L
.09313 .1863 L
.10458 .37636 L
.10928 .45068 L
.11432 .51871 L
.11676 .54565 L
.11907 .56684 L
.12115 .58197 L
.12223 .58833 L
.1234 .59396 L
.12468 .59861 L
.12588 .60154 L
.12657 .6026 L
.1273 .60321 L
.12861 .60298 L
.12927 .60223 L
.12998 .60096 L
.13125 .59744 L
.13203 .59452 L
.13276 .59123 L
.13414 .58372 L
.13662 .56584 L
.1389 .54469 L
.14407 .48248 L
.15388 .32771 L
.15929 .23656 L
.16442 .15637 L
.16919 .09378 L
.1717 .06701 L
Mistroke
.17438 .04411 L
.17565 .03539 L
.17685 .02854 L
.17802 .02317 L
.1791 .01938 L
.18012 .0168 L
.1812 .01519 L
.18228 .01472 L
.18347 .01553 L
.18469 .0178 L
.18538 .01972 L
.18602 .0219 L
.18716 .02681 L
.18843 .03364 L
.19062 .04894 L
.19294 .0697 L
.19817 .13152 L
.20308 .20421 L
.21181 .35021 L
.22136 .49671 L
.22383 .52706 L
.22647 .55452 L
.22896 .57524 L
.23122 .5893 L
.23255 .59537 L
.23378 .59947 L
.23442 .60103 L
.23512 .60228 L
.23586 .60306 L
.23655 .60332 L
.23782 .60257 L
.23898 .60051 L
.23962 .59881 L
.24031 .59651 L
.24158 .59114 L
.24379 .57816 L
.24624 .55872 L
.25119 .5046 L
.2601 .37117 L
.26951 .21349 L
.27464 .13633 L
.27942 .07791 L
.28193 .05403 L
.28461 .03441 L
.28614 .02614 L
.28689 .02288 L
.28759 .02036 L
.28888 .01687 L
.28957 .0157 L
.29029 .01495 L
Mistroke
.29147 .01483 L
.29274 .01624 L
.29394 .01901 L
.29504 .02276 L
.29632 .0286 L
.29772 .03672 L
.30027 .05603 L
.30559 .11334 L
.3106 .18418 L
.31996 .33912 L
.33016 .49674 L
.3353 .5548 L
.3367 .56713 L
.33821 .57845 L
.33963 .58721 L
.34093 .59366 L
.34219 .59833 L
.34282 .60011 L
.34352 .60162 L
.34422 .60266 L
.34497 .60324 L
.34568 .60328 L
.34633 .60288 L
.34752 .60107 L
.34882 .59752 L
.34948 .59511 L
.35018 .59208 L
.35145 .58545 L
.35403 .56738 L
.35647 .54505 L
.36103 .49115 L
.3795 .19447 L
.38453 .12164 L
.38924 .06763 L
.3916 .04695 L
.39414 .0302 L
.39559 .02331 L
.3963 .02065 L
.39696 .01862 L
.39819 .01596 L
.39884 .01515 L
.39953 .01475 L
.40078 .01521 L
.40193 .01699 L
.4032 .02042 L
.40383 .02272 L
.40453 .02569 L
.40696 .03962 L
.40922 .05738 L
.41346 .10183 L
Mistroke
.41799 .16298 L
.42763 .32005 L
.43785 .48191 L
.44319 .54599 L
.44622 .57279 L
.44768 .58283 L
.44907 .59058 L
.45031 .59601 L
.45097 .59827 L
.45167 .60024 L
.45291 .60252 L
.45406 .60331 L
.45475 .60316 L
.45551 .60246 L
.45622 .60129 L
.45687 .59978 L
.45811 .59577 L
.45942 .58994 L
.46191 .57452 L
.46417 .55569 L
.46926 .49859 L
.47845 .3586 L
.4893 .17908 L
.49407 .11213 L
.49661 .08232 L
.49934 .05563 L
.50183 .03681 L
.50292 .03032 L
.50411 .02447 L
.50524 .02018 L
.50629 .01728 L
.5074 .0154 L
.50859 .01472 L
.50986 .01552 L
.51058 .01667 L
.51124 .01817 L
.51245 .02203 L
.51374 .02767 L
.51597 .04107 L
.51842 .06093 L
.52359 .11845 L
.52914 .19888 L
.53917 .36631 L
.54408 .44468 L
.5493 .51612 L
.5523 .54912 L
.55503 .57281 L
.55634 .58195 L
.55776 .59006 L
.55911 .59598 L
Mistroke
.56034 .5999 L
.5615 .60225 L
.56275 .60329 L
.56393 .60288 L
.565 .60132 L
.56626 .59805 L
.56697 .59553 L
.56763 .59277 L
.57012 .57868 L
.5725 .55997 L
.57512 .53387 L
.58044 .46601 L
.59068 .30062 L
.59626 .20788 L
.60144 .13083 L
.60589 .07718 L
.60817 .0554 L
.61064 .03677 L
.61205 .02857 L
.61335 .02267 L
.61459 .01854 L
.6159 .01579 L
.61708 .01476 L
.61818 .01503 L
.61939 .01669 L
.62068 .02004 L
.62193 .02482 L
.62326 .03153 L
.62566 .04768 L
.62823 .0706 L
.63107 .10202 L
.64093 .24738 L
.64993 .39841 L
.65484 .47329 L
.65941 .53134 L
.66193 .55693 L
.66422 .57567 L
.66543 .58378 L
.66676 .59103 L
.66749 .59431 L
.66816 .5969 L
.66948 .60072 L
.67058 .60261 L
.67161 .60331 L
.67275 .60286 L
.67397 .60098 L
.67524 .59747 L
.67645 .59268 L
.67872 .57999 L
.68122 .56062 L
Mistroke
.68389 .53423 L
.68869 .47381 L
.69957 .29906 L
.70986 .13609 L
.71268 .09978 L
.71565 .06746 L
.71819 .04546 L
.71963 .03554 L
.72098 .02787 L
.72225 .02228 L
.72291 .01994 L
.72362 .01793 L
.72487 .01556 L
.72602 .01473 L
.72666 .01483 L
.72734 .01538 L
.72859 .01755 L
.72931 .0195 L
.73006 .02208 L
.73142 .02807 L
.73383 .04295 L
.73607 .06141 L
.74116 .11809 L
.7599 .41718 L
.76503 .49243 L
.76784 .52719 L
.77047 .55453 L
.77289 .57478 L
.77511 .58874 L
.77637 .59466 L
.77757 .59887 L
.77883 .60182 L
.77955 .60279 L
.78021 .60325 L
.78091 .60327 L
.78155 .60285 L
.78226 .60193 L
.78301 .60044 L
.78426 .59669 L
.78497 .5939 L
.78564 .59086 L
.78801 .57663 L
.79055 .55586 L
.79632 .48996 L
.80156 .41246 L
.81204 .2374 L
.81664 .16491 L
.82172 .09693 L
.82402 .0717 L
.82651 .04926 L
Mistroke
.82771 .04029 L
.82885 .03296 L
.82998 .02692 L
.831 .02247 L
.83218 .01856 L
.83344 .01588 L
.8346 .01478 L
.8357 .01497 L
.83699 .01669 L
.83817 .0197 L
.83947 .02455 L
.84084 .03142 L
.84331 .04814 L
.84596 .07195 L
.85075 .12848 L
.86162 .2995 L
.87178 .46396 L
.87457 .50201 L
.87752 .53699 L
.88008 .5619 L
.88143 .57281 L
.88284 .58258 L
.88407 .58958 L
.88541 .59562 L
.88663 .59962 L
.88777 .60205 L
.88894 .60322 L
.89001 .60313 L
.89124 .60163 L
.8924 .59886 L
.89368 .5943 L
.89503 .58778 L
.89746 .57183 L
.90008 .54892 L
.90296 .51741 L
.91376 .35679 L
.92402 .18648 L
.92848 .12237 L
.93323 .06771 L
.93596 .04422 L
.93844 .02861 L
.93963 .02311 L
.94093 .0187 L
.94215 .01602 L
.94327 .01484 L
.94427 .01483 L
.94518 .01567 L
.94623 .01765 L
.94722 .02051 L
.94814 .02399 L
Mistroke
.94899 .02793 L
.95091 .0393 L
.95284 .05409 L
.95497 .07407 L
.95928 .12501 L
.97619 .39624 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0
oooo103oool00140oooo0`0000060?ooo`030000003oool0oooo0?l0oooo103oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`@00000103oool0
0`000000oooo0?ooo`050?ooo`<000002P3oool20000oa/0oooo0P000?lK0?ooo`80003o6`3oool2
0000oa/0oooo0P000?lK0?ooo`80003o6`3oool20000oa/0oooo0P000?lK0?ooo`80003o3`3oool0
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`80003o6`3oool30000
oaX0oooo0P000?lK0?ooo`80003o6`3oool20000oa/0oooo0P000?lK0?ooo`80003o6`3oool20000
oa/0oooo0P000?l?0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`000?lI0?ooo`040000o`3oool0
oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`000?lI0?ooo`04
0000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`00
0?lI0?ooo`040000o`3oool0oooo0000o`h0oooo000A0?ooo`8000001`3oool00`000000oooo0?oo
o`090?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0
oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3o
ool010000?l0oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3o
ool0003o6@3oool010000?l0oooo0?ooo`000?l>0?ooo`004P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`00
0?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0
oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3o
ool010000?l0oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000o`h0oooo000J0?ooo`030000
003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`000?lI0?oo
o`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?oo
o`000?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool01000
0?l0oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000o`h0oooo000J0?ooo`030000003oool0
oooo00T0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`000?lI0?ooo`040000
o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o6@3oool010000?l0oooo0?ooo`000?lI
0?ooo`040000o`3oool0oooo0000oaT0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`040000
o`3oool0oooo0000oaP0oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`006P3oool2000000X0
oooo00@0003o0?ooo`3oool0003o603oool01@000?l0oooo0?ooo`3oool0003o01T0oooo00@0003o
0?ooo`3oool0003o603oool01@000?l0oooo0?ooo`3oool0003o01T0oooo00@0003o0?ooo`3oool0
003o6@3oool01@000?l0oooo0?ooo`3oool0003o01L0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0F0?ooo`050000o`3oool0oooo0?ooo`000?l05`3oool01@000?l0oooo0?ooo`3o
ool0003o00h0oooo000J0?ooo`030000003oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000
o`0H0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool01@000?l0oooo0?oo
o`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0oooo0?oo
o`000?l0603oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool05@3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo000J0?ooo`030000003oool0oooo
00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`050000o`3oool0oooo
0?ooo`000?l0603oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo000J0?oo
o`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00/0oooo000J0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo000J0?ooo`030000
003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00/0oooo000J0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo000J0?ooo`030000003oool0
oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00/0oooo000J0?ooo`8000002@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool0203oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool001X0oooo
00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02`3oool001X0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool001X0oooo00<00000
0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool02P3oool001X0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool001X0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool02P3oool001X0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool001X0oooo0P0000080?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`006P3oool0
0`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0:0?ooo`006P3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`006P3oool00`000000
oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`006P3oool2000000L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo000J0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo00090?ooo`8000000`3oool00`000000oooo
0?ooo`02000000L0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool000P0oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00030?ooo`@00000
00D0oooo0000003oool0oooo000000070?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`00
203oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool000P0oooo00@000000?ooo`3oool00000103oool3000000L0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00090?ooo`8000001@3oool4000000H0oooo00<000000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool001X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool001X0oooo00<000000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
01X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
0100oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool001X0oooo0P0000060?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`006P3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`006P3oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`00
6P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`006P3oool2000000H0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo000J0?ooo`030000003oool0
oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo000J0?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0
oooo000J0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00L0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo000J0?ooo`80
00001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool01`3oool001X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool001X0oooo00<000000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3o
ool001X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool01`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool02P3oool010000?l0000000000000000<0?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`@00000103oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool00`00
0000003o0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0000000000001`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000000=0?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00@000000?ooo`000?l000002`3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0
oooo000000H0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`0000003@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`000000oooo00X0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo100000050?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3oool0
oooo000000H0oooo000J0?ooo`8000001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000000=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<000000000o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0103oool010000000oooo0?ooo`0000050?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3o
ool0oooo000000H0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`0000003@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0000000/0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`0000001@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l00000000000070?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`000000
000000d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00<0oooo00@000000?ooo`3oool00000103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool010000000003o0?ooo`00000;0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`800000
103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`070?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0000000d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00@0oooo0P0000050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`000000oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02P3o
ool010000?l000000000000000060?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`006P3oool0
0`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`060?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`006P3oool00`000000
oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`060?ooo`00503oool<000000030000o`000000000000`0000000<0003o000000000000
2`0000000`000?l000000000000;000000030000o`000000000000`0000000<0003o000000000000
300000000`000?l000000000000;000000030000o`000000000000`0000000<0003o000000000000
2`0000000`000?l000000000000<000000030000o`000000000000/0000000<0003o000000000000
300000000`000?l000000000000;000000030000o`000000000000`0000000<0003o000000000000
2`0000000`000?l000000000000<000000030000o`000000000000`0000000<0003o000000000000
2`0000000`000?l0000000000006000000006P3oool00`000000oooo0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`0000002P3oool00`000?l0oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`00
0?l01@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0000000T0oooo00@000000?ooo`3o
ool0003o1P3oool00`000000oooo0?ooo`050?ooo`040000o`3oool0oooo000000T0oooo00<00000
0000o`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`0000002@3o
ool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000o`3oool0000000T0oooo00@000000?ooo`3oool0003o
1P3oool00`000000oooo0?ooo`040?ooo`040000o`3oool0oooo000000T0oooo00<000000?ooo`00
0?l01`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000o`000000oooo00H0oooo000J0?ooo`030000
003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0000003oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0000000`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l000000?ooo`060?ooo`006P3o
ool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`060?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`006P3oool00`00
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`060?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`006P3oool00`000000oooo
0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`060?ooo`006P3oool2000000@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00H0oooo000J0?ooo`030000003oool0oooo00<0oooo00<0003o
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo000J0?oo
o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00H0oooo000J0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo000J0?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00H0oooo000J0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo000J0?ooo`030000003oool0
oooo0080oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00H0oooo000J0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo000J0?ooo`8000000`3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool001X0oooo
00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo
00<0003o0?ooo`3oool01@3oool001X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool001X0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o
0?ooo`3oool01@3oool001X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool001X0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool01@3oool001X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000
o`3oool0oooo00h0oooo00<0003o0?ooo`3oool01@3oool001X0oooo00D000000?ooo`3oool0oooo
0000o`0A0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool01@3oool001X0oooo0P00
00020?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool05P3oool001X0oooo00D00000
0?ooo`3oool0oooo0000o`0A0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo01H0oooo000J0?ooo`050000003oool0
oooo0?ooo`000?l04@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0F0?ooo`006P3oool01@000000oooo0?ooo`3o
ool0003o0140oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool05P3oool001X0oooo00D000000?ooo`3oool0oooo0000
o`0A0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo01H0oooo000J0?ooo`050000003oool0oooo0?ooo`000?l04P3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0403o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0F0?ooo`006P3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool05P3oool001X0oooo0P0000020?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool05P3oool001X0oooo00D000000?ooo`3oool0oooo0000o`0B0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo01H0oooo000J0?ooo`050000003oool0oooo0?ooo`000?l04P3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0F
0?ooo`006P3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool0
01X0oooo00@000000?ooo`3oool0003o4`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`006P3oool01000
0000oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01L0oooo00090?ooo`8000000`3oool00`00
0000oooo0?ooo`02000000L0oooo00@000000?ooo`3oool0003o4`3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G
0?ooo`00203oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000H0oooo00@0
00000?ooo`3oool0003o4`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`00203oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00@0oooo0`0000000`000?l0oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo01L0oooo00080?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01L0oooo00080?ooo`040000
003oool0oooo000000@0oooo0`0000070?ooo`040000003oool0oooo0000oa<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool05`3oool000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool05`3oool000T0oooo0P0000050?oo
o`@000001P3oool010000000oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01L0oooo000J0?oo
o`040000003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool05`3oool001X0oooo00@000000?oo
o`3oool0003o4`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0G0?ooo`006P3oool00`000000oooo0000o`0D0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo01L0oooo000J0?ooo`80000000<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0G0?ooo`006P3oool00`000000oooo0000o`0E0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01L0oooo
000J0?ooo`030000003oool0003o01D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05`3oool001X0oooo00<00000
0?ooo`000?l05@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0H0?ooo`006P3oool00`000000oooo0000o`0E0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo01P0oooo000J0?ooo`030000003oool0003o01D0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0603oool001X0oooo00<000000?ooo`000?l05@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0H0?ooo`006P3o
ool00`000000oooo0000o`0E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01P0oooo000J0?ooo`80000000<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0H0?ooo`006P3oool00`000000oooo0000o`0E0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo01P0oooo000J0?ooo`030000003oool0003o01D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0603oool001X0oooo00<000000000o`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0180oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0D0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0H0?ooo`006P3o
ool00`000000003o0?ooo`0E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01P0oooo000J0?ooo`03000000000?l0
oooo01H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0603oool001X0oooo00<000000000o`3oool05P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0I0?ooo`006P3oool00`000000003o0?ooo`0F0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01T0
oooo000J0?ooo`03000000000?l0oooo01H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06@3oool001X0oooo00<0
00000000o`3oool05P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0I0?ooo`006P3oool00`000000003o0?ooo`0F
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo01T0oooo000J0?ooo`03000000000?l0oooo01H0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool06@3oool001X0oooo00<000000000o`3oool05`3oool01@000?l0oooo0?ooo`3oool0003o
01L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0I0?ooo`006P3oool00`000000
003o0?ooo`0G0?ooo`050000o`3oool0oooo0?ooo`000?l05`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo01D0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool05@3oool01@000?l0oooo0?ooo`3oool0003o01`0oooo000J
0?ooo`03000000000?l0oooo01L0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool05@3oool01@000?l0oooo0?ooo`3oool0003o01P0oooo
00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00D0003o0?ooo`3o
ool0oooo0000o`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0703oool001X0oooo00<0003o0?oo
o`3oool05`3oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000
o`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0oooo0?ooo`3oool0003o01P0
oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool0
1@000?l0oooo0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0L0?ooo`006P3o
ool00`000?l000000?ooo`0G0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0oooo
0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0oooo
0?ooo`000?l0603oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo
0000o`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0oooo0?ooo`3oool0003o
01`0oooo000J0?ooo`030000o`3oool0oooo01L0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?oo
o`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00D0
003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0
oooo0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0
oooo0?ooo`000?l0703oool001X0oooo00<0003o0?ooo`3oool05`3oool01@000?l0oooo0?ooo`3o
ool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0H0?ooo`050000o`3oool0oooo0?ooo`00
0?l0603oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00D0003o0?ooo`3oool0oooo0000o`0H
0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool01@000?l0oooo0?ooo`3oool0003o01P0oooo
00D0003o0?ooo`3oool0oooo0000o`0L0?ooo`006P3oool00`000?l0oooo0?ooo`0H0?ooo`040000
o`3oool0oooo0000oaT0oooo00<0003o0?ooo`000?l06@3oool01@000?l0oooo0?ooo`3oool0003o
01P0oooo00@0003o0?ooo`3oool0003o6@3oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00D0
003o0?ooo`3oool0oooo0000o`0I0?ooo`030000o`3oool0003o01T0oooo00D0003o0?ooo`3oool0
oooo0000o`0L0?ooo`006P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0003o01X0oooo
00<0003o0?ooo`000?l06@3oool010000?l0oooo0?ooo`000?lJ0?ooo`030000o`3oool0003o01X0
oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0000o`0J0?ooo`030000o`3oool0003o01X0
oooo00@0003o0?ooo`3oool0003o703oool00140oooo0`0000060?ooo`030000003oool0oooo01P0
oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0000o`0J0?ooo`030000o`3oool0003o01X0
oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0000o`0J0?ooo`030000o`3oool0003o01X0
oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo0000o`0M0?ooo`004P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo
0000o`0J0?ooo`030000o`3oool0003o01X0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo
0000o`0J0?ooo`030000o`3oool0003o01X0oooo00<0003o0?ooo`000?l06P3oool00`000?l0oooo
0000o`0M0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<00000603oool30000oaX0oooo0`00
0?lJ0?ooo`<0003o6P3oool30000oaX0oooo0`000?lJ0?ooo`<0003o6`3oool20000oa/0oooo0P00
0?lM0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo103oool0
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000A0?ooo`80
00001`3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3oool40?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.527234, -1.12765, \
0.0196943, 0.0127464}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Show[%, %%]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.309017 0.294302 [
[.21429 .29652 -4.5 -12 ]
[.21429 .29652 4.5 0 ]
[.40476 .29652 -4.5 -12 ]
[.40476 .29652 4.5 0 ]
[.59524 .29652 -4.5 -12 ]
[.59524 .29652 4.5 0 ]
[.78571 .29652 -4.5 -12 ]
[.78571 .29652 4.5 0 ]
[.97619 .29652 -4.5 -12 ]
[.97619 .29652 4.5 0 ]
[.01131 .01472 -15.9375 -6 ]
[.01131 .01472 0 6 ]
[.01131 .16187 -23.4375 -6 ]
[.01131 .16187 0 6 ]
[.01131 .45617 -16.5 -6 ]
[.01131 .45617 0 6 ]
[.01131 .60332 -9 -6 ]
[.01131 .60332 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
gsave
.21429 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .30902 m
.40476 .31527 L
s
gsave
.40476 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 .30902 m
.59524 .31527 L
s
gsave
.59524 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.78571 .30902 m
.78571 .31527 L
s
gsave
.78571 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01472 m
.03006 .01472 L
s
gsave
.01131 .01472 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .16187 m
.03006 .16187 L
s
gsave
.01131 .16187 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -70 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .59196 m
.04262 .36918 L
.0522 .20884 L
.05746 .13054 L
.06244 .0715 L
.06506 .04807 L
.06644 .03808 L
.0679 .02936 L
.06912 .02357 L
.06977 .02108 L
.07047 .01885 L
.0717 .0161 L
.07286 .01485 L
.0741 .01497 L
.0748 .0157 L
.07545 .01681 L
.07665 .01993 L
.07792 .02476 L
.07917 .03101 L
.08035 .03822 L
.08255 .05504 L
.08806 .11432 L
.09313 .1863 L
.10458 .37636 L
.10928 .45068 L
.11432 .51871 L
.11676 .54565 L
.11907 .56684 L
.12115 .58197 L
.12223 .58833 L
.1234 .59396 L
.12468 .59861 L
.12588 .60154 L
.12657 .6026 L
.1273 .60321 L
.12861 .60298 L
.12927 .60223 L
.12998 .60096 L
.13125 .59744 L
.13203 .59452 L
.13276 .59123 L
.13414 .58372 L
.13662 .56584 L
.1389 .54469 L
.14407 .48248 L
.15388 .32771 L
.15929 .23656 L
.16442 .15637 L
.16919 .09378 L
.1717 .06701 L
Mistroke
.17438 .04411 L
.17565 .03539 L
.17685 .02854 L
.17802 .02317 L
.1791 .01938 L
.18012 .0168 L
.1812 .01519 L
.18228 .01472 L
.18347 .01553 L
.18469 .0178 L
.18538 .01972 L
.18602 .0219 L
.18716 .02681 L
.18843 .03364 L
.19062 .04894 L
.19294 .0697 L
.19817 .13152 L
.20308 .20421 L
.21181 .35021 L
.22136 .49671 L
.22383 .52706 L
.22647 .55452 L
.22896 .57524 L
.23122 .5893 L
.23255 .59537 L
.23378 .59947 L
.23442 .60103 L
.23512 .60228 L
.23586 .60306 L
.23655 .60332 L
.23782 .60257 L
.23898 .60051 L
.23962 .59881 L
.24031 .59651 L
.24158 .59114 L
.24379 .57816 L
.24624 .55872 L
.25119 .5046 L
.2601 .37117 L
.26951 .21349 L
.27464 .13633 L
.27942 .07791 L
.28193 .05403 L
.28461 .03441 L
.28614 .02614 L
.28689 .02288 L
.28759 .02036 L
.28888 .01687 L
.28957 .0157 L
.29029 .01495 L
Mistroke
.29147 .01483 L
.29274 .01624 L
.29394 .01901 L
.29504 .02276 L
.29632 .0286 L
.29772 .03672 L
.30027 .05603 L
.30559 .11334 L
.3106 .18418 L
.31996 .33912 L
.33016 .49674 L
.3353 .5548 L
.3367 .56713 L
.33821 .57845 L
.33963 .58721 L
.34093 .59366 L
.34219 .59833 L
.34282 .60011 L
.34352 .60162 L
.34422 .60266 L
.34497 .60324 L
.34568 .60328 L
.34633 .60288 L
.34752 .60107 L
.34882 .59752 L
.34948 .59511 L
.35018 .59208 L
.35145 .58545 L
.35403 .56738 L
.35647 .54505 L
.36103 .49115 L
.3795 .19447 L
.38453 .12164 L
.38924 .06763 L
.3916 .04695 L
.39414 .0302 L
.39559 .02331 L
.3963 .02065 L
.39696 .01862 L
.39819 .01596 L
.39884 .01515 L
.39953 .01475 L
.40078 .01521 L
.40193 .01699 L
.4032 .02042 L
.40383 .02272 L
.40453 .02569 L
.40696 .03962 L
.40922 .05738 L
.41346 .10183 L
Mistroke
.41799 .16298 L
.42763 .32005 L
.43785 .48191 L
.44319 .54599 L
.44622 .57279 L
.44768 .58283 L
.44907 .59058 L
.45031 .59601 L
.45097 .59827 L
.45167 .60024 L
.45291 .60252 L
.45406 .60331 L
.45475 .60316 L
.45551 .60246 L
.45622 .60129 L
.45687 .59978 L
.45811 .59577 L
.45942 .58994 L
.46191 .57452 L
.46417 .55569 L
.46926 .49859 L
.47845 .3586 L
.4893 .17908 L
.49407 .11213 L
.49661 .08232 L
.49934 .05563 L
.50183 .03681 L
.50292 .03032 L
.50411 .02447 L
.50524 .02018 L
.50629 .01728 L
.5074 .0154 L
.50859 .01472 L
.50986 .01552 L
.51058 .01667 L
.51124 .01817 L
.51245 .02203 L
.51374 .02767 L
.51597 .04107 L
.51842 .06093 L
.52359 .11845 L
.52914 .19888 L
.53917 .36631 L
.54408 .44468 L
.5493 .51612 L
.5523 .54912 L
.55503 .57281 L
.55634 .58195 L
.55776 .59006 L
.55911 .59598 L
Mistroke
.56034 .5999 L
.5615 .60225 L
.56275 .60329 L
.56393 .60288 L
.565 .60132 L
.56626 .59805 L
.56697 .59553 L
.56763 .59277 L
.57012 .57868 L
.5725 .55997 L
.57512 .53387 L
.58044 .46601 L
.59068 .30062 L
.59626 .20788 L
.60144 .13083 L
.60589 .07718 L
.60817 .0554 L
.61064 .03677 L
.61205 .02857 L
.61335 .02267 L
.61459 .01854 L
.6159 .01579 L
.61708 .01476 L
.61818 .01503 L
.61939 .01669 L
.62068 .02004 L
.62193 .02482 L
.62326 .03153 L
.62566 .04768 L
.62823 .0706 L
.63107 .10202 L
.64093 .24738 L
.64993 .39841 L
.65484 .47329 L
.65941 .53134 L
.66193 .55693 L
.66422 .57567 L
.66543 .58378 L
.66676 .59103 L
.66749 .59431 L
.66816 .5969 L
.66948 .60072 L
.67058 .60261 L
.67161 .60331 L
.67275 .60286 L
.67397 .60098 L
.67524 .59747 L
.67645 .59268 L
.67872 .57999 L
.68122 .56062 L
Mistroke
.68389 .53423 L
.68869 .47381 L
.69957 .29906 L
.70986 .13609 L
.71268 .09978 L
.71565 .06746 L
.71819 .04546 L
.71963 .03554 L
.72098 .02787 L
.72225 .02228 L
.72291 .01994 L
.72362 .01793 L
.72487 .01556 L
.72602 .01473 L
.72666 .01483 L
.72734 .01538 L
.72859 .01755 L
.72931 .0195 L
.73006 .02208 L
.73142 .02807 L
.73383 .04295 L
.73607 .06141 L
.74116 .11809 L
.7599 .41718 L
.76503 .49243 L
.76784 .52719 L
.77047 .55453 L
.77289 .57478 L
.77511 .58874 L
.77637 .59466 L
.77757 .59887 L
.77883 .60182 L
.77955 .60279 L
.78021 .60325 L
.78091 .60327 L
.78155 .60285 L
.78226 .60193 L
.78301 .60044 L
.78426 .59669 L
.78497 .5939 L
.78564 .59086 L
.78801 .57663 L
.79055 .55586 L
.79632 .48996 L
.80156 .41246 L
.81204 .2374 L
.81664 .16491 L
.82172 .09693 L
.82402 .0717 L
.82651 .04926 L
Mistroke
.82771 .04029 L
.82885 .03296 L
.82998 .02692 L
.831 .02247 L
.83218 .01856 L
.83344 .01588 L
.8346 .01478 L
.8357 .01497 L
.83699 .01669 L
.83817 .0197 L
.83947 .02455 L
.84084 .03142 L
.84331 .04814 L
.84596 .07195 L
.85075 .12848 L
.86162 .2995 L
.87178 .46396 L
.87457 .50201 L
.87752 .53699 L
.88008 .5619 L
.88143 .57281 L
.88284 .58258 L
.88407 .58958 L
.88541 .59562 L
.88663 .59962 L
.88777 .60205 L
.88894 .60322 L
.89001 .60313 L
.89124 .60163 L
.8924 .59886 L
.89368 .5943 L
.89503 .58778 L
.89746 .57183 L
.90008 .54892 L
.90296 .51741 L
.91376 .35679 L
.92402 .18648 L
.92848 .12237 L
.93323 .06771 L
.93596 .04422 L
.93844 .02861 L
.93963 .02311 L
.94093 .0187 L
.94215 .01602 L
.94327 .01484 L
.94427 .01483 L
.94518 .01567 L
.94623 .01765 L
.94722 .02051 L
.94814 .02399 L
Mistroke
.94899 .02793 L
.95091 .0393 L
.95284 .05409 L
.95497 .07407 L
.95928 .12501 L
.97619 .39624 L
Mfstroke
1 0 0 r
.02381 .55666 m
.03279 .54965 L
.04262 .5433 L
.04758 .54071 L
.05288 .53844 L
.05789 .5368 L
.06006 .53625 L
.06244 .53574 L
.06507 .53533 L
.0665 .53516 L
.06719 .53509 L
.06785 .53504 L
.0691 .53496 L
.07025 .53492 L
.07148 .53491 L
.07218 .53491 L
.07283 .53493 L
.07354 .53495 L
.0743 .53499 L
.07503 .53504 L
.07569 .5351 L
.07829 .5354 L
.07964 .53561 L
.08112 .53588 L
.0841 .53657 L
.08922 .53816 L
.09469 .54043 L
.10458 .54591 L
.12582 .56254 L
.14594 .58125 L
.15559 .58971 L
.16088 .59383 L
.16585 .5972 L
.17042 .59976 L
.17461 .60157 L
.17687 .60231 L
.17802 .60261 L
.17926 .60288 L
.1805 .60308 L
.18165 .60322 L
.18236 .60327 L
.18302 .60331 L
.18427 .60331 L
.18542 .60326 L
.18666 .60313 L
.18783 .60293 L
.1889 .6027 L
.19015 .60235 L
.19151 .60188 L
.19399 .60075 L
Mistroke
.19658 .5992 L
.19933 .5971 L
.20428 .59209 L
.20927 .58531 L
.21397 .57723 L
.22274 .55739 L
.23253 .52737 L
.24285 .48634 L
.26134 .38991 L
.29936 .14348 L
.30941 .08687 L
.31891 .04545 L
.32416 .02932 L
.32713 .02268 L
.32854 .02019 L
.32987 .01827 L
.33107 .01688 L
.33217 .0159 L
.33339 .01515 L
.33471 .01475 L
.3359 .01476 L
.33721 .01519 L
.33787 .01556 L
.33857 .01609 L
.33984 .01736 L
.34108 .019 L
.34244 .02126 L
.34519 .02733 L
.34773 .03474 L
.35011 .04322 L
.35547 .06782 L
.36123 .10233 L
.37177 .18482 L
.38139 .27613 L
.39141 .37781 L
.40206 .47954 L
.41116 .5491 L
.41365 .56397 L
.41634 .57759 L
.41886 .58791 L
.42009 .59203 L
.4212 .59524 L
.42228 .59784 L
.42345 .6001 L
.42468 .60185 L
.42585 .60288 L
.42713 .60332 L
.42778 .60325 L
.42849 .60297 L
.42975 .60189 L
Mistroke
.43093 .60022 L
.43225 .59758 L
.43351 .59432 L
.43587 .58624 L
.4384 .57469 L
.44117 .55879 L
.44578 .52515 L
.45068 .48027 L
.4595 .38125 L
.46922 .25829 L
.47949 .13579 L
.48486 .08361 L
.4877 .06098 L
.49075 .04126 L
.49219 .03372 L
.49355 .02769 L
.49488 .02288 L
.4961 .01941 L
.49727 .01699 L
.4985 .01536 L
.49974 .01472 L
.50044 .01481 L
.5011 .01519 L
.50232 .01663 L
.50345 .01885 L
.50469 .02227 L
.50601 .02703 L
.50871 .04034 L
.51117 .05646 L
.51592 .09785 L
.5204 .14783 L
.5305 .28726 L
.54119 .44317 L
.54579 .50147 L
.55073 .55219 L
.55356 .57425 L
.55615 .58926 L
.55739 .59462 L
.55805 .59695 L
.55875 .59903 L
.56003 .60179 L
.56122 .60311 L
.56247 .60319 L
.56362 .60208 L
.56488 .59954 L
.56552 .59774 L
.56621 .59537 L
.56864 .58384 L
.57091 .56865 L
.57514 .52939 L
Mistroke
.57968 .47358 L
.58932 .32315 L
.59954 .15734 L
.60487 .0872 L
.60791 .05631 L
.60937 .04425 L
.61075 .03458 L
.612 .02746 L
.61266 .02432 L
.61336 .02145 L
.61459 .01761 L
.61574 .01547 L
.61644 .01485 L
.61719 .01475 L
.6179 .01522 L
.61856 .01612 L
.6198 .0191 L
.62111 .02402 L
.62238 .03055 L
.62359 .03829 L
.62586 .05676 L
.63095 .1156 L
.64013 .2663 L
.65026 .44882 L
.65538 .52477 L
.65829 .55838 L
.6596 .57069 L
.66103 .58205 L
.6622 .58965 L
.66346 .59596 L
.66415 .59863 L
.66479 .60055 L
.66602 .60285 L
.66715 .60327 L
.66838 .6019 L
.66953 .59885 L
.6706 .59454 L
.67183 .58777 L
.67299 .57975 L
.67562 .55558 L
.67818 .52467 L
.68093 .48429 L
.69048 .30632 L
.69934 .13841 L
.70425 .06808 L
.70566 .05261 L
.70699 .04031 L
.70817 .03128 L
.70947 .02357 L
.71016 .0204 L
Mistroke
.71081 .01807 L
.7115 .01627 L
.71223 .0151 L
.71292 .01472 L
.71356 .01499 L
.71477 .01716 L
.71547 .01937 L
.7162 .02249 L
.71752 .03005 L
.71894 .04096 L
.72051 .05621 L
.7255 .1252 L
.73088 .22622 L
.74061 .43096 L
.74525 .51404 L
.74784 .55076 L
.7502 .57641 L
.75154 .5874 L
.75225 .59207 L
.75299 .59614 L
.75365 .59897 L
.75437 .60127 L
.75563 .60324 L
.75689 .60255 L
.75759 .601 L
.75824 .59886 L
.75949 .59272 L
.76068 .58452 L
.76189 .57386 L
.76322 .55947 L
.76592 .52243 L
.77078 .43382 L
.77614 .31586 L
.78179 .18975 L
.78659 .09893 L
.78932 .05975 L
.79062 .04494 L
.79186 .03351 L
.79298 .02539 L
.7942 .01912 L
.7953 .01578 L
.79632 .01472 L
.79743 .01577 L
.79864 .01959 L
.79991 .02651 L
.8011 .03567 L
.80239 .04841 L
.80379 .06552 L
.80635 .10463 L
.81114 .20049 L
Mistroke
.81671 .33185 L
.82195 .4526 L
.82436 .50075 L
.8269 .5434 L
.82824 .56168 L
.8297 .57817 L
.83103 .58972 L
.83227 .59738 L
.83348 .60187 L
.83463 .60332 L
.83566 .60228 L
.83678 .59863 L
.838 .59172 L
.8393 .58107 L
.8404 .56938 L
.84162 .55381 L
.84683 .45999 L
.85244 .32582 L
.8577 .19511 L
.86027 .138 L
.8626 .09324 L
.86498 .05656 L
.86607 .04327 L
.86723 .03184 L
.86846 .02276 L
.8696 .01736 L
.87083 .01482 L
.87152 .01489 L
.87217 .01597 L
.87282 .018 L
.87353 .0213 L
.87481 .03019 L
.87606 .04232 L
.87722 .05652 L
.87985 .0984 L
.88264 .15572 L
.888 .28913 L
.89364 .43501 L
.89597 .488 L
.89846 .53596 L
.89989 .55844 L
.9012 .57523 L
.90251 .58833 L
.90375 .59704 L
.90499 .60206 L
.90562 .60314 L
.90632 .60319 L
.90754 .60035 L
.90869 .5943 L
.90938 .5891 L
Mistroke
.91004 .58309 L
.91128 .56906 L
.91406 .52524 L
.91682 .46742 L
.91939 .40409 L
.9252 .24574 L
.92762 .18252 L
.93023 .12138 L
.93254 .07671 L
.93379 .05681 L
.93497 .04145 L
.93633 .02789 L
.93704 .02259 L
.93781 .0184 L
.93852 .01594 L
.93918 .01483 L
.94043 .01596 L
.94166 .0212 L
.94281 .02963 L
.94406 .04276 L
.94539 .06097 L
.97619 .57442 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000J0?ooo`030000003oool0oooo0?l0
oooo103oool00140oooo0`0000060?ooo`030000003oool0oooo0?l0oooo103oool00180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000:0?ooo`@00000103oool0
0`000000oooo0?ooo`050?ooo`<000002P3oool20000oa/0oooo0P000?lK0?ooo`80003o2@3oool4
0?l000h0oooo0P000?lH0?ooo`<0o`000P000?lK0?ooo`80o`005`3oool20?l00080oooo0P000?lA
0?ooo`80o`00203oool20000o`P0oooo0P3o000@0?ooo`80o`0000<0003o0?ooo`3oool03@3oool0
0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`80003o6`3oool30000
oaX0oooo0P000?l90?ooo`040?l0003oool0oooo0?l000h0oooo0P000?lH0?ooo`030?l0003oool0
o`000080003o6P3oool00`3o0000003o0?l0000G0?ooo`040?l0003oool0o`000?ooo`80003o4@3o
ool20?l000P0oooo0P000?l80?ooo`80o`00403oool20?l000030000o`3oool0oooo00d0oooo000B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool010000?l0oooo0?ooo`00
0?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o1`3oool01@3o0000
oooo0?ooo`3oool0o`0000d0oooo00@0003o0?ooo`3oool0003o5`3oool00`3o0000oooo0?l00002
0?ooo`030000o`3oool0oooo01L0oooo00@0o`000?ooo`3o0000003o5P3oool0103o0000oooo0?l0
00000?l20?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o00001`3oool010000?l0oooo
0?ooo`000?l60?ooo`030?l0003oool0o`000100oooo0P3o00000`3oool0003o0?ooo`0=0?ooo`00
4@3oool2000000L0oooo00<000000?ooo`3oool02@3oool010000?l0oooo0?ooo`000?lI0?ooo`04
0000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`3oool0003o5P3oool01`3o0000oooo0?oo
o`000?l0o`000?ooo`000?l06@3oool0103o0000oooo0?l000000?lF0?ooo`040?l0003oool0o`00
0000o`80oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?l000070?ooo`040000o`3oool0
oooo0000o`H0oooo00<0o`000?ooo`3o0000403oool20?l000030?ooo`000?l0oooo00d0oooo000B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool010000?l0oooo0?ooo`00
0?lI0?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`3oool0003o5P3oool01`3o
0000oooo0?ooo`000?l0o`000?ooo`000?l06@3oool0103o0000oooo0?ooo`3o000F0?ooo`040?l0
003oool0o`000000o`80oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?l000070?ooo`04
0000o`3oool0oooo0000o`H0oooo00<0o`000?ooo`3o0000403oool20?l000030?ooo`000?l0oooo
00d0oooo000J0?ooo`030000003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o6@3oool01000
0?l0oooo0?ooo`000?lI0?ooo`040000o`3oool0oooo0000o`H0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`090?ooo`040000o`3oool0oooo0000oaH0oooo00L0o`000?ooo`3oool0
003o0?ooo`3o0000003o01T0oooo00@0o`000?ooo`3oool0o`005P3oool0103o0000oooo0?l00000
0?l20?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o00001`3oool010000?l0oooo0?oo
o`000?l60?ooo`030?l0003oool0o`000100oooo0P3o00000`3oool0003o0?ooo`0=0?ooo`006P3o
ool00`000000oooo0?ooo`090?ooo`040000o`3oool0oooo0000oaT0oooo00@0003o0?ooo`3oool0
003o6@3oool010000?l0oooo0?ooo`000?l50?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`3oool02@3oool010000?l0oooo0?ooo`000?lF0?ooo`070?l0003oool0oooo0000o`3oool0o`00
0000o`0I0?ooo`040?l0003oool0oooo0?l001D0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o00001`3oool010000?l0oooo0?ooo`000?l6
0?ooo`030?l0003oool0o`0000l0oooo00D0o`000?ooo`3oool0o`000000o`0>0?ooo`006P3oool2
000000X0oooo00@0003o0?ooo`3oool0003o603oool01@000?l0oooo0?ooo`3oool0003o01T0oooo
00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0
oooo00D0003o0?ooo`3oool0oooo0000o`0F0?ooo`070?l0003oool0oooo0000o`3oool0o`000000
o`0H0?ooo`060?l000000?l0oooo0?ooo`3o0000003o503oool01@3o0000oooo0?ooo`000?l0o`00
00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?l000070?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool00`3o0000oooo0?l0000?0?ooo`050?l0003oool0oooo0?l000000?l03P3o
ool001X0oooo00<000000?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o01P0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`050000o`3oool0oooo0?ooo`000?l0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00D0003o0?ooo`3oool0
oooo0000o`0F0?ooo`030?l0003oool0003o0080oooo00<0o`000000o`3oool05`3oool01P3o0000
oooo0?ooo`3oool0o`000000oa@0oooo00D0o`000?ooo`3oool0003o0?l000030?ooo`030000o`3o
ool0oooo00`0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3o00003`3oool01@3o0000oooo0?ooo`3o0000003o00h0
oooo000J0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0000o`020?ooo`030?l000000?l0oooo01L0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0B0?ooo`050?l0003oool0oooo0000o`3o00000`3oool00`000?l0oooo0?ooo`0<0?ooo`04
0?l0003oool0oooo0?l000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0o`0000l0oooo00H0o`000?ooo`3oool0o`000?ooo`000?l=0?ooo`006P3oool0
0`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo00@0o`000?ooo`3oool0003o0P3o
ool00`3o0000oooo0000o`0G0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool04P3o
ool01@3o0000oooo0?ooo`000?l0o`0000<0oooo00<0003o0?ooo`3oool0303oool0103o0000oooo
0?ooo`3o00050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0103o0000
oooo0?ooo`3o000>0?ooo`060?l0003oool0oooo0?l0003oool0003o3@3oool001X0oooo00<00000
0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0B0?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`000?l0
5`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00D0o`000?ooo`3oool0
003o0?l000030?ooo`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o000>
0?ooo`060?l0003oool0oooo0?l0003oool0003o3@3oool001X0oooo00<000000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0B0?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`000?l05`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00D0o`000?ooo`3oool0003o0?l000030?oo
o`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o000>0?ooo`060?l0003o
ool0oooo0?l0003oool0003o3@3oool001X0oooo00<000000?ooo`3oool0203oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`04
0?l0003oool0oooo0000o`80oooo00<0o`000?ooo`000?l05`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo0180oooo00D0o`000?ooo`3oool0003o0?l000030?ooo`030000o`3oool0
oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o000>0?ooo`060?l0003oool0oooo0?l0003o
ool0003o3@3oool001X0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`002`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool04P3oool0103o0000oooo0?ooo`000?l2
0?ooo`030?l0003oool0003o01H0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?ooo`0B
0?ooo`050?l0003oool0oooo0000o`3o00000`3oool00`000?l0oooo0?ooo`0;0?ooo`050?l0003o
ool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00@0o`000?ooo`3oool0o`003P3oool01P3o0000oooo0?ooo`3o0000oooo0000o`d0oooo000J0?oo
o`8000002@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`3oool0o`002`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0000o`030?ooo`030?l0003oool0003o01H0oooo00<0003o
0?l0003oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`050?l0003oool0oooo0000o`3o00000`3o
ool00`000?l0oooo0?ooo`0;0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0o`003P3oool01P3o0000
oooo0?ooo`3o0000oooo0000o`d0oooo000J0?ooo`030000003oool0oooo00P0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0503oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?l000/0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0140oooo00@0o`00
0?ooo`3oool0003o0`3oool00`3o0000oooo0000o`0F0?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool04P3oool01@3o0000oooo0?ooo`000?l0o`0000<0oooo00<0003o0?ooo`3oool0
2`3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0oooo0?l000h0oooo00H0o`000?ooo`3oool0o`000?ooo`00
0?l=0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o000;0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`040?l0003oool0oooo0000o`@0oooo
00<0o`000?ooo`000?l05@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo
00D0o`000?ooo`3oool0003o0?l000040?ooo`030000o`3oool0oooo00X0oooo00D0o`000?ooo`3o
ool0oooo0?l000050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0o`0000h0oooo00H0o`000?ooo`3oool0o`000?ooo`000?l=0?ooo`006P3o
ool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?l0000<0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`000?l0
5@3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo00D0o`000?ooo`3oool0
003o0?l000040?ooo`030000o`3oool0oooo00X0oooo00D0o`000?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000d0oooo00L0003o0?l0003oool0oooo0?l0003oool0003o00d0oooo000J0?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
0000oooo00`0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0100oooo00@0o`000?ooo`3oool0003o103oool00`3o0000oooo0000o`0E0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool01@3o0000oooo0000o`3oool0o`0000@0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool0
1@000?l0o`000?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool02P3oool001X0oooo00<00000
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?l0003oool0303oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0403oool0103o0000oooo0?ooo`000?l40?ooo`030?l0003oool0003o01D0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`060?l0003oool0oooo0000o`3oool0
o`00103oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0;
0?ooo`050000o`3o0000oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`0:0?ooo`006P3oool0
0`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0o`000?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`000?l05@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0100oooo00@0o`000?ooo`3oool0003o
0P3oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00<0o`000?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00H0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030?l0003oool0
oooo00/0oooo00D0003o0?l0003oool0oooo0?l000020?ooo`030000o`3oool0oooo00X0oooo000J
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3o0000oooo00`0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo0100oooo00@0o`000?ooo`3oool0003o103oool00`3o0000oooo0000
o`0E0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0403oool0103o0000oooo0?oo
o`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l0303oool00`3o0000oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l01P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0o`000?ooo`020?ooo`030?l0003oool0003o00`0oooo000J0?oo
o`800000203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0
003oool0303oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0403oool0103o0000oooo0?ooo`000?l40?ooo`030?l0003oool0003o01D0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`80oooo00D0
o`000?ooo`3oool0oooo0000o`0<0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l0303oool001X0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0403oool0103o0000oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0000oa<0oooo00<0003o
0?l0003oool01@3oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l0303oool001X0oooo
00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool0403oool0103o0000oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0000
oa<0oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`0@0?ooo`040?l0003oool0oooo
0000o`80oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o0000oooo00<0oooo00<0o`000?ooo`000?l0
303oool001X0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo
00<0o`000?ooo`000?l04`3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0oooo0100oooo
00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00X0oooo00<0003o0?l0003oool00`3oool0
103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo0180oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0?0?ooo`050?l0003oool0
oooo0?ooo`000?l01@3oool00`3o0000oooo0000o`0C0?ooo`030000o`3o0000oooo00D0oooo00<0
o`000?ooo`3oool0403oool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l01`3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo00X0oooo00<0003o0?l0003o
ool00`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0?0?ooo`05
0?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0000o`0C0?ooo`030000o`3o0000oooo
00D0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l01`3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?l0003oool00`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0?
0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0000o`0C0?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool03`3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`050?l0
003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0?0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0000o`0C0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000000o`3oool03`3oool0103o0000oooo0?ooo`000?l3
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`03
0?ooo`050?l0003oool0oooo0?ooo`000?l01`3oool00`000?l0oooo0?l000050?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3o
ool2000000L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`040?ooo`030?l00000
0?l0oooo00h0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00l0oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo0000o`0C0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000000o`3oool03`3oool0103o0000oooo0?ooo`000?l30?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`04
0?l0003oool0oooo0000o`P0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o2`3oool001X0oooo00<000000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`000?l03P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool03P3oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003oool0003o01<0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000003o0?ooo`0?0?ooo`040?l0003oool0oooo0000o`<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00@0
o`000?ooo`3oool0003o203oool00`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?l0003oool00`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0000o`0>0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0>0?ooo`040?l0003oool0oooo0000o`L0oooo00<0o`000000o`3oool04P3oool00`3o0000
oooo0?ooo`050?ooo`030?l000000?l0oooo00l0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool0103o
0000oooo0?ooo`000?l80?ooo`030000o`3oool0o`0000D0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0o`000?ooo`030?ooo`040?l0003oool0oooo0000o`/0oooo000J0?ooo`030000003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
003o00h0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00h0oooo00@0o`000?ooo`3oool0003o1`3oool00`3o0000003o0?ooo`0B0?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool03P3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`040?l0
003oool0oooo0000o`P0oooo00<0003o0?ooo`3o00001@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3o0000oooo00<0oooo00@0o`000?ooo`3oool0003o2`3oool001X0oooo00<000000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`00
0?l03`3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool03P3oool0103o
0000oooo0?ooo`000?l70?ooo`030?l000000?l0oooo0180oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3oool0003o
203oool00`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00T0oooo00<0003o0?l0003oool0
0`3oool0103o0000oooo0?ooo`000?l;0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0000o`0?0?ooo`050?l0
003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`0>0?ooo`040?l0003oool0oooo0000
o`L0oooo00<0o`000000o`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00h0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l80?ooo`030000o`3o
ool0o`0000D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0o`000?ooo`030?ooo`040?l0003o
ool0oooo0000o`/0oooo00090?ooo`8000000`3oool00`000000oooo0?ooo`02000000L0oooo00<0
00000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`000?l03`3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0
3P3oool0103o0000oooo0?ooo`000?l70?ooo`030?l000000?l0oooo0180oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0oooo0000o`@0oooo00D0o`000?oo
o`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l0203oool0
0`000?l0oooo0?l000050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool0103oool0
103o0000oooo0?ooo`000?l;0?ooo`00203oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0003o3`3oool0103o0000oooo0?ooo`000?l90?oo
o`030000o`3oool0oooo00d0oooo00D0o`000?ooo`3oool0oooo0000o`070?ooo`030?l000000?l0
oooo0180oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0
oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`000?l02@3oool00`000?l0o`000?ooo`040?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?l0003oool0103oool0103o0000oooo0?ooo`000?l;0?ooo`000`3o
ool4000000050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`<00000
1P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0
003o3`3oool0103o0000oooo0?ooo`000?l90?ooo`030000o`3oool0oooo00d0oooo00D0o`000?oo
o`3oool0oooo0000o`070?ooo`030?l0003oool0003o0180oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0>0?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l02@3o
ool00`000?l0o`000?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool01@3o
ool0103o0000oooo0?ooo`000?l:0?ooo`00203oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0003o3`3oool0103o0000oooo0?ooo`000?l90?oo
o`030000o`3oool0oooo00d0oooo00@0o`000?ooo`3oool0003o203oool00`3o0000oooo0000o`0B
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0000o`05
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0003o00T0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3o0000oooo00D0oooo00@0o`000?ooo`3oool0003o2P3oool000P0oooo00@00000
0?ooo`3oool00000103oool3000000L0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0>0?ooo`040?l0
003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l80?oo
o`030?l0003oool0003o0180oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0>0?oo
o`030?l0003oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l02@3oool00`000?l0o`000?ooo`040?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool01@3oool0103o0000oooo0?ooo`000?l:
0?ooo`00203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`0?0?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`3oool03@3o
ool0103o0000oooo0?ooo`000?l80?ooo`030?l0003oool0003o0140oooo00<0003o0?l0003oool0
1`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0003o00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l0
2@3oool00`000?l0o`000?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool0
1@3oool0103o0000oooo0?ooo`000?l:0?ooo`002@3oool2000000D0oooo100000060?ooo`030000
003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`040?ooo`050?l0
003oool0oooo0?ooo`000?l03`3oool00`3o0000oooo0000o`090?ooo`030000o`3oool0oooo00d0
oooo00@0o`000?ooo`3oool0003o203oool00`3o0000oooo0000o`0A0?ooo`030000o`3o0000oooo
00L0oooo00<0o`000000o`3oool03P3oool00`3o0000oooo0000o`050?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o
00T0oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000oooo
00D0oooo00@0o`000?ooo`3oool0003o2P3oool001X0oooo00<000000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`0?
0?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`3oool03@3oool0103o0000oooo0?ooo`00
0?l80?ooo`030?l0003oool0003o0140oooo00<0003o0?l0003oool01`3oool00`3o0000003o0?oo
o`0>0?ooo`030?l0003oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`000?l02@3oool00`000?l0o`000?oo
o`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool01@3oool0103o0000oooo0?oo
o`000?l:0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`000?l02@3oool00`000?l0oooo0?ooo`0=0?ooo`040?l0003oool0oooo0000o`T0oooo
00<0o`000000o`3oool0403oool00`000?l0o`000?ooo`070?ooo`030?l000000?l0oooo00d0oooo
00@0o`000?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`090?ooo`030000o`3o0000oooo00@0
oooo00<0o`000?ooo`3oool0203oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000
o`X0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0000o`090?ooo`030000o`3oool0oooo00d0oooo00@0o`000?ooo`3oool0003o2@3oool00`3o
0000003o0?ooo`0@0?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3oool03@3oool0103o
0000oooo0?ooo`000?l50?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00T0oooo00<0003o0?l0003oool0103oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3o0000oooo00D0oooo00@0o`000?ooo`3oool0003o2P3o
ool001X0oooo0P0000060?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`000?l02P3oool0
0`000?l0oooo0?ooo`0<0?ooo`040?l0003oool0oooo0000o`T0oooo00<0o`000000o`3oool0403o
ool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0003o
1@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000003o0?ooo`090?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`X0oooo000J0?ooo`030000
003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0000o`0:0?ooo`030000
o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0003o2@3oool00`3o0000003o0?ooo`0@0?ooo`03
0?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool0103o0000oooo0?ooo`000?l50?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030?l000000?l0oooo00T0oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3o0000oooo00D0oooo00@0o`000?ooo`3oool0003o2P3oool001X0oooo00<000000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0003o00X0oooo00<0003o0?oo
o`3oool02`3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0o`000000o`3oool0403oool0
0`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00@0o`000?ooo`3oool0003o1@3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000003o0?ooo`090?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`X0oooo000J0?ooo`030000003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`3o0000003o0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030?l000000?l0oooo0100oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`040?l0003oool0oooo0000o`H0
oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000000
o`3oool02@3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?l0
003oool01@3oool0103o0000oooo0?ooo`000?l:0?ooo`006P3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00h0oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?ooo`0;0?oo
o`050?l0003oool0oooo0?ooo`000?l02@3oool00`3o0000003o0?ooo`0@0?ooo`030?l0003oool0
oooo00P0oooo00<0o`000?ooo`3oool0303oool0103o0000oooo0?ooo`000?l60?ooo`050?l0003o
ool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00T0oooo
00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000oooo00D0oooo
00@0o`000?ooo`3oool0003o2P3oool001X0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l000000?l0oooo00T0oooo00<0003o0?ooo`3oool02`3oool0103o0000oooo
0?ooo`000?l:0?ooo`030?l000000?l0oooo0100oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`0<0?ooo`040?l0003oool0oooo0000o`H0oooo00D0o`000?ooo`3oool0oooo0000o`08
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000000o`3oool02@3oool00`000?l0o`000?ooo`05
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?l0003oool01@3oool0103o0000oooo0?ooo`00
0?l:0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0000o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0oooo0000o`X0oooo00<0
o`000000o`3oool0403oool00`3o0000oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00@0
o`000?ooo`3oool0003o1P3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000003o0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`X0oooo000J0?ooo`80
00001P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l000000?l0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool0103o0000oooo0?ooo`000?l:0?ooo`030?l000000?l0oooo0100oooo00<0o`000?oo
o`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0003o00L0oooo00D0o`000?oo
o`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000000o`3oool02P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?l0003oool01@3oool0
103o0000oooo0?ooo`000?l:0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00h0oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0
oooo0000o`X0oooo00<0o`000000o`3oool0403oool00`3o0000oooo0?ooo`080?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`000?l01`3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0o`000?ooo`050?ooo`040?l0003oool0oooo0000o`X0
oooo000J0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0003o2P3oool00`3o0000
003o0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0o`000000o`3oool0303oool00`3o0000
oooo0000o`070?ooo`050?l0003oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`070?oo
o`030000o`3o0000oooo00H0oooo00<0o`000?ooo`000?l02P3oool001X0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool0103o0000oooo0?ooo`000?l:0?ooo`030?l0003oool0003o0100oooo00<0o`000?oo
o`3oool0203oool00`3o0000003o0?ooo`0<0?ooo`030?l0003oool0003o00L0oooo00D0o`000?oo
o`3oool0oooo0000o`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o00001`3oool0
103o0000oooo0?ooo`000?l90?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo00l0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?l0003oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0oooo0000o`X0oooo
00<0o`000?ooo`000?l03`3oool00`000?l0o`000?ooo`090?ooo`030?l000000?l0oooo00`0oooo
00<0o`000?ooo`000?l01`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`030?l000000?l0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l000070?ooo`040?l0003oool0oooo0000o`T0
oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo
0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool03@3oool00`000?l0o`000?ooo`090?ooo`03
0000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0003o2P3oool00`3o0000oooo0000o`0?0?oo
o`030000o`3o0000oooo00T0oooo00<0o`000000o`3oool0303oool00`3o0000oooo0000o`070?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3o0000oooo00T0oooo00<0o`000000o`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0o`0000L0oooo00@0o`000?ooo`3oool0003o2@3oool001X0oooo00<000000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0?0?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3o0000oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
1@3o0000oooo0?ooo`3oool0003o00X0oooo00<0o`000?ooo`000?l03`3oool00`000?l0o`000?oo
o`090?ooo`030?l000000?l0oooo00`0oooo00<0o`000?ooo`000?l01`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?oo
o`090?ooo`030?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l0
00070?ooo`040?l0003oool0oooo0000o`T0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0o`000?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00D0
o`000?ooo`3oool0oooo0000o`0:0?ooo`030?l0003oool0003o00l0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0003o00L0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool0
2@3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o0000
1`3oool0103o0000oooo0?ooo`000?l90?ooo`006P3oool2000000D0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0o`000?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00D0o`000?ooo`3oool0
oooo0000o`0:0?ooo`030?l0003oool0003o00l0oooo00<0o`000?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0003o00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool02@3oool00`3o0000
003o0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o00001`3oool0103o0000
oooo0?ooo`000?l90?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00X0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?l0003oool02P3oool00`000?l0oooo0?ooo`090?ooo`050?l0003oool0oooo0?oo
o`000?l02P3oool00`3o0000oooo0000o`0?0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0000o`070?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000oooo00T0oooo00<0o`000000
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0o`0000L0oooo00@0o`000?oo
o`3oool0003o2@3oool001X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3o0000oooo00X0oooo00<0003o0?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0
003o00/0oooo00<0o`000000o`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`000?l01`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0o`000?ooo`090?ooo`030?l000000?l0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l000070?ooo`040?l0003oool0
oooo0000o`T0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool0
1@000?l0oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool03@3oool00`000?l0o`000?oo
o`0:0?ooo`030000o`3oool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0000o`0;0?ooo`030?l0
00000?l0oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0
003oool0003o00L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?l0003oool02@3oool00`3o0000003o0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3o00001`3oool0103o0000oooo0?ooo`000?l90?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00D0003o0?ooo`3oool0
oooo0?l000080?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o00002P3oool00`000?l0
oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`000?l02`3oool00`3o0000003o0?ooo`0>0?oo
o`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0000o`070?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?oo
o`030000o`3o0000oooo00T0oooo00<0o`000000o`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0o`0000L0oooo00@0o`000?ooo`3oool0003o2@3oool001X0oooo00<000000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool02P3oool010000?l0000000000000000<0?ooo`050000o`3oool0oooo0?ooo`3o0000203o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0o`000080oooo100000040?ooo`030000o`3o
ool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0000o`0;0?ooo`030?l000000?l0oooo00d0oooo
00<000000?l0003oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000o`L0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0000
00D0oooo00<0003o0?l0003oool02@3oool00`3o0000003o0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3o00001`3oool0103o0000oooo0?ooo`000?l2000000L0oooo000J0?oo
o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`0000003@3oool01@000?l0oooo0?ooo`3oool0
o`0000P0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?l000020?ooo`040000003oool0
oooo000000@0oooo00<0003o0?ooo`3oool02@3oool0103o0000oooo0?ooo`000?l<0?ooo`030?l0
00000?l0oooo00`0oooo00@000000?ooo`3o000000002`3oool00`3o0000oooo0?ooo`0:0?ooo`04
0?l0003oool0oooo0000o`L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`040?l0003oool0oooo000000D0oooo00<0003o0?l0003oool02@3oool00`3o0000oooo0000o`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o00001`3oool0103o0000oooo0?ooo`00
0?l20?ooo`030000003oool0oooo00@0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`0000003@3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?l000030?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool02@3o
ool0103o0000oooo0?ooo`000?l<0?ooo`030?l000000?l0oooo00h0oooo00<0o`000000003oool0
2P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0003o00P0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`040?l0000000000000000000D0oooo00<0003o0?l0003o
ool02@3oool00`3o0000oooo0000o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
00001`3oool0103o0000oooo0?ooo`000?l20?ooo`030000003oool0oooo00@0oooo000J0?ooo`80
00001@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0000000=0?ooo`050000o`3oool0oooo0?ooo`3o0000203oool00`00
0?l0oooo0?ooo`0=0?ooo`030000o`3oool0o`0000@0oooo00<000000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0000o``0oooo00<0o`000000o`3oool03@3oool0
0`000000o`000?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`000?l0203oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool000001@3o
ool00`000?l0o`000?ooo`090?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?l000070?ooo`040?l0003oool0oooo0000o`80oooo00<000000?ooo`3oool0
103oool001X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0000000=0?ooo`040000o`3o
ool0oooo0?l000T0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?l000050?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00`0
oooo00<0o`000000o`3oool03@3oool00`000?l0o`000000000;0?ooo`030?l0003oool0oooo00X0
oooo00<0o`000?ooo`000?l02@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00@0o`000000
003oool000001@3oool00`000?l0o`000?ooo`090?ooo`030?l0003oool0003o00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?l000070?ooo`040?l0003oool0oooo0000o`8000001`3o
ool001X0oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l000000000000=0?ooo`040000o`3oool0
oooo0?l000T0oooo00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o00020?ooo`040000
003oool0oooo000000@0oooo00<0003o0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o
00`0oooo00<0o`000?ooo`000?l0303oool010000000003o0?l00000000;0?ooo`030?l0003oool0
oooo00X0oooo00<0o`000?ooo`000?l02@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00@0
o`000?ooo`0000000000103oool00`000?l0oooo0?l0000:0?ooo`030?l0003oool0003o00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`070?ooo`040?l0003oool0oooo0000o`T0
oooo000J0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`0000003@3oool010000?l0oooo
0?ooo`3o00090?ooo`030000o`3oool0oooo00`0oooo00@0003o0?ooo`3oool0o`000`3oool20000
00D0oooo00<0003o0?ooo`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00<0o`00
0?ooo`000?l03@3oool00`000?l0o`000?ooo`0;0?ooo`030?l000000?l0oooo00X0oooo00<0o`00
0?ooo`000?l02@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00@0o`000?ooo`3oool00000
103oool00`000?l0oooo0?l0000:0?ooo`030?l0003oool0003o00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0o`000?ooo`080?ooo`030?l0003oool0003o00<000001P3oool001X0oooo00<0
00000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`040000o`3oool0oooo0?l000T0oooo
00<0003o0?ooo`3oool0303oool010000?l0oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo00P0
oooo00D0o`000?ooo`3oool0oooo0000o`0<0?ooo`030?l0003oool0003o00d0oooo00<0003o0?l0
003oool02`3oool00`3o0000003o0?ooo`0:0?ooo`030?l0003oool0003o00T0oooo00D0o`000?oo
o`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o00002P3oool0
0`3o0000oooo0000o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool0203oool0
0`3o0000oooo0000o`090?ooo`006P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030000o`3oool0oooo00`0oooo00@0003o
0?ooo`3oool0o`002`3oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l0
303oool00`3o0000oooo0000o`0=0?ooo`030000o`3o0000oooo00/0oooo00<0o`000000o`3oool0
2P3oool00`3o0000oooo0000o`090?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0o`0000T0oooo00@0o`000?ooo`3oool0003o1P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3o0000oooo00P0oooo00@0o`000?ooo`3oool0003o203oool0
01X0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`050000o`3oool0oooo
0?ooo`3o00002@3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0oooo0?l000/0oooo00<0
003o0?ooo`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00<0o`000?ooo`000?l0
3@3oool00`3o0000oooo0?ooo`0;0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`000?l0
2@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0
oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0o`000?ooo`080?ooo`040?l0003oool0oooo0000o`P0oooo000J0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0
003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3oool0
1`3oool01@3o0000oooo0?ooo`3oool0003o00`0oooo00<0o`000?ooo`000?l03@3oool00`3o0000
oooo0?ooo`0;0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`000?l02@3oool01@3o0000
oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o0008
0?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?oo
o`080?ooo`040?l0003oool0oooo0000o`P0oooo000D0?ooo``0000000<0003o0000000000003000
00000`000?l000000000000;000000030000o`000000000000/0000000<0003o0000000000003000
000010000?l000000000003o000;000000030000o`000000000000/0000000D0003o000000000000
00000?l0000:000000030000o`000000000000L0000000D0o`0000000000000000000000o`0<0000
00030?l000000000003o00d0000000<0o`000000000000002`0000000`3o0000003o0000000:0000
00030?l000000000003o00T0000000<0o`000000000000000P0000000`000?l00000000000030000
00030?l000000000000000D0000000@0003o000000000000o`0020000000103o0000000000000000
0?l6000000030?l000000000000000D0000000<0003o0?l00000000020000000103o000000000000
00000?l8000000006P3oool00`000000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000000
2P3oool00`000?l0oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000?l01@3oool00`000000
oooo0?ooo`050?ooo`030000o`3oool0000000T0oooo00@000000?ooo`3oool0003o0P3oool01@3o
0000oooo0?ooo`3oool0000000L0oooo00@0003o0?ooo`3oool000002@3oool00`000000003o0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool0000000D0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`060000003oool0oooo0?l0
003oool0003o103oool00`000000oooo0?ooo`060?ooo`030?l0003oool0000000T0oooo00@00000
0?ooo`3o0000003o1P3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0003o0080oooo00<0
00000?ooo`3oool0103oool01P3o0000oooo0?ooo`000000oooo0000o`D0oooo00<0o`000?ooo`00
00001@3oool01P000?l0oooo0?ooo`3o0000oooo000000H0oooo00@0o`000?ooo`3oool0003o1P3o
ool0103o0000oooo0?ooo`0000040?ooo`030000o`3o0000oooo0080oooo00<000000?ooo`3oool0
0`3oool01@3o0000oooo0?ooo`000?l0000000L0oooo000J0?ooo`030000003oool0oooo00<0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0000003oool02`3oool010000?l0oooo0?ooo`3o000;0?ooo`030000o`3oool0oooo00/0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00d0oooo00<0o`000000o`3oool0303oool0
0`3o0000oooo0000000<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`0000001@3oool0
10000?l0oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?l000090?ooo`050?l0003oool0oooo0000o`0000001`3oool001X0oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?l000/0
oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0003o0?oo
o`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00d0oooo00<0o`000000o`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool0
10000?l0oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?l000090?ooo`040?l0003oool0oooo0000o`P0oooo000J0?ooo`030000
003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`3o000;0?ooo`03
0000o`3oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l000000?l0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o
00T0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00D0oooo00@0003o0?ooo`3oool0o`00203oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3o00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3o
ool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool0o`00
2`3oool00`000?l0oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`3o00002P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`3o0000
003o0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0000o`090?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000P0oooo00@0o`000?ooo`3oool0003o1P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0o`0000T0oooo00@0o`000?ooo`3oool0003o203o
ool001X0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
o`0000`0oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0
003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0003o00h0oooo00<0o`000000o`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`000?l0
2@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1@3oool010000?l0oooo0?ooo`3o00080?ooo`040?l0003oool0oooo0000o`H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?l000090?ooo`040?l0003oool0oooo0000o`P0oooo000J0?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?l0000<0?oo
o`030000o`3oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030000o`3oool0
oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`0>0?ooo`030?l000000?l0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o00T0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00@0
003o0?ooo`3oool0o`00203oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3o00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3oool2000000@0
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?l0000<0?ooo`030000o`3oool0oooo00/0
oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030000o`3oool0oooo00H0oooo00D0o`000?oo
o`3oool0oooo0000o`0>0?ooo`030?l000000?l0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`T0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0o`00
203oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3oool00`000000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3o0000303oool00`000?l0oooo0?ooo`0;0?ooo`05
0000o`3oool0oooo0?ooo`3o00002P3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo
0?ooo`000?l03P3oool00`3o0000oooo0000o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0o`00
0?ooo`3oool0203oool0103o0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000P0oooo
00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3oool00`000000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0003o0?ooo`3o0000303oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`05
0?l0003oool0oooo0?ooo`000?l03P3oool00`3o0000oooo0000o`0;0?ooo`030000o`3o0000oooo
00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0000o`0:0?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo
0?l000P0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3o00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`00303oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l03P3oool00`3o0000oooo0000o`0;0?ooo`03
0000o`3o0000oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0000o`0:0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`04
0000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3o00002@3oool0103o0000oooo0?ooo`000?l80?ooo`006P3oool0
0`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00@0003o0?ooo`3oool0o`00303o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l03P3oool00`3o0000oooo
0000o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0000o`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`060?ooo`040000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3oool0oooo0000o`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o00002P3oool00`3o0000oooo0000o`080?oo
o`006P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
00003@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l03P3oool00`3o
0000oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool00`3o
0000oooo0000o`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3oool0oooo0000
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o00002P3oool00`3o0000oooo0000
o`080?ooo`006P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3o00003@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0?ooo`000?l03P3o
ool00`3o0000oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0203o
ool00`3o0000oooo0000o`0:0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000P0oooo00D0o`000?ooo`3oool0
oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o00002P3oool00`3o0000
oooo0000o`080?ooo`006P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3o00003@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0000o`0;0?ooo`030?l0003oool0oooo00d0oooo
00<0o`000000o`3oool0203oool00`3o0000oooo0000o`0:0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000P0
oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0
003oool02P3oool0103o0000oooo0?ooo`000?l70?ooo`006P3oool2000000<0oooo00<0003o0?oo
o`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?l0000>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?oo
o`3oool03@3oool00`3o0000003o0?ooo`080?ooo`030?l0003oool0003o00X0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00@0003o0?oo
o`3oool0o`00203oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0o`000?ooo`0:0?ooo`040?l0003oool0oooo0000o`L0oooo000J0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?l0000>0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l00000
0?l0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`3o0000003o0?ooo`080?ooo`030?l0003o
ool0003o00X0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`050?l0003oool0oooo0?ooo`00
0?l01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000oooo00X0oooo00@0o`000?ooo`3o
ool0003o1`3oool001X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0o`0000h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000000o`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0?l000000?l0oooo00P0oooo00<0o`000?ooo`000?l02P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`00
00P0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?l0003oool02P3oool0103o0000oooo0?ooo`000?l70?ooo`006P3oool00`000000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o00003P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000003o0?ooo`0:
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0000o`0:
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`05
0?ooo`050000o`3oool0oooo0?ooo`3o0000203oool01@3o0000oooo0?ooo`3oool0003o00H0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0o`000?ooo`0:0?ooo`040?l0003oool0oooo0000o`L0
oooo000J0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0o`00
0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`3o0000003o
0?ooo`080?ooo`030?l0003oool0003o00/0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000L0oooo00D0003o0?ooo`3oool0oooo0?l000080?ooo`050?l0003oool0oooo
0?ooo`000?l01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000oooo00X0oooo00@0o`00
0?ooo`3oool0003o1`3oool001X0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3o0000oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000000o`3oool02P3oool00`3o0000oooo0?ooo`0=
0?ooo`030?l000000?l0oooo00P0oooo00<0o`000?ooo`000?l02`3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo
00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
00002`3oool0103o0000oooo0?ooo`000?l70?ooo`006P3oool00`000000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?l0003oool03P3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000003o0?ooo`0:0?ooo`03
0?l0003oool0oooo00d0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0000o`0;0?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`050000o`3oool0oooo
0?ooo`3o0000203oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?l0000;0?ooo`040?l0003oool0oooo0000o`L0oooo000J0?ooo`050000003o
ool0oooo0?ooo`000?l04@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0o`000?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo
00D0o`000?ooo`3oool0oooo0000o`0@0?ooo`030?l000000?l0oooo00X0oooo00<0o`000?ooo`3o
ool03@3oool00`3o0000003o0?ooo`080?ooo`030?l0003oool0003o00/0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0o`0000/0oooo00@0o`000?ooo`3oool0003o1`3oool0
01X0oooo0P0000020?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?l0003oool03P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l0403oool00`3o0000003o0?ooo`0:
0?ooo`030?l0003oool0oooo00d0oooo00<0o`000000o`3oool01`3oool0103o0000oooo0?ooo`00
0?l;0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?l0000;0?ooo`030?l0
003oool0oooo00P0oooo000J0?ooo`050000003oool0oooo0?ooo`000?l04@3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`0@0?ooo`03
0?l000000?l0oooo00T0oooo00<0o`000000o`3oool03P3oool00`3o0000003o0?ooo`070?ooo`04
0?l0003oool0oooo0000o`/0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
o`0000L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
o`0000/0oooo00<0o`000?ooo`3oool0203oool001X0oooo00D000000?ooo`3oool0oooo0000o`0A
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3o
ool0003o0100oooo00<0o`000?ooo`000?l02@3oool00`3o0000003o0?ooo`0?0?ooo`030?l0003o
ool0oooo00H0oooo00@0o`000?ooo`3oool0003o2`3oool00`3o0000oooo0?ooo`020?ooo`040000
o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0o`0000/0oooo00<0o`000?ooo`3oool0203oool001X0oooo00D000000?ooo`3oool0
oooo0000o`0A0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3o0000oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`000?l02@3oool00`3o0000
003o0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o2`3oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000/0oooo00<0o`000?ooo`3oool0203oool0
01X0oooo00D000000?ooo`3oool0oooo0000o`0A0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o0000oooo00l0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`000?l02@3oool00`3o0000003o0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00@0o`00
0?ooo`3oool0003o2`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000P0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000/0oooo
00<0o`000?ooo`3oool0203oool001X0oooo00D000000?ooo`3oool0oooo0000o`0B0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3o0000oooo00l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`000?l02@3oool00`3o0000003o0?ooo`0?0?ooo`030?l0
003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o2`3oool00`3o0000oooo0?ooo`020?ooo`04
0000o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0o`0000`0oooo00<0o`000?ooo`3oool01`3oool001X0oooo00D000000?ooo`3o
ool0oooo0000o`0B0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<0o`000000o`3oool0203oool00`3o
0000003o0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0003o2`3oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000`0oooo00<0o`000?ooo`3oool01`3o
ool001X0oooo0P0000020?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000003o0?ooo`080?ooo`030?l000000?l0oooo00l0oooo00<0o`000?ooo`3oool01P3oool0
103o0000oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0o`00
203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o0000
303oool00`3o0000oooo0?ooo`070?ooo`006P3oool01@000000oooo0?ooo`3oool0003o0180oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool03`3oool00`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo00l0oooo
00<0o`000?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3o0000303oool00`3o0000oooo0?ooo`070?ooo`006P3oool01@000000
oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool00`3o0000003o0?ooo`080?oo
o`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000o`0<0?oo
o`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o0000303oool00`3o0000oooo0?ooo`07
0?ooo`006P3oool01@000000oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0000o`0<0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0o`001`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?l0003oool0303o
ool00`3o0000oooo0?ooo`070?ooo`006P3oool010000000oooo0?ooo`000?lC0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`060?ooo`030?l00000
0?l0oooo0140oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`030?l00000
0?l0oooo00H0oooo00<0o`000?ooo`000?l0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0o`0000L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o
00003@3oool00`3o0000oooo0?ooo`070?ooo`006P3oool010000000oooo0?ooo`000?lC0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`060?ooo`03
0?l000000?l0oooo0140oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`03
0?l000000?l0oooo00H0oooo00<0o`000?ooo`000?l0303oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0o`0000L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o
0?ooo`3o00003@3oool00`3o0000oooo0?ooo`070?ooo`002@3oool2000000<0oooo00<000000?oo
o`3oool00P0000070?ooo`040000003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool04@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0o`000000o`3oool01P3oool0
0`3o0000oooo0000o`0<0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o00001`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0?l0000=0?ooo`030?l0
003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
00001P3oool010000000oooo0?ooo`000?lC0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0403oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo0140oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<0o`000000
o`3oool01`3oool00`3o0000003o0?ooo`0@0?ooo`030?l000000?l0oooo00H0oooo00<0o`000?oo
o`000?l0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0o`0000L0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00003@3oool00`3o0000oooo0?oo
o`070?ooo`00203oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo0`00
00000`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0403o
ool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0oooo0140oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00l0oooo00<0o`000000o`3oool01`3o
ool00`3o0000003o0?ooo`0@0?ooo`030?l000000?l0oooo00H0oooo00<0o`000?ooo`000?l03@3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000L0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00003@3oool00`3o0000oooo0?ooo`070?ooo`00
203oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool0003o4`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0000o`0B0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo0?l000D0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000003o0?ooo`070?ooo`030?l000000?l0oooo0100oooo00<0o`00
0000o`3oool01@3oool0103o0000oooo0?ooo`000?l=0?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3o00001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo0?l0000=0?ooo`030?l0003oool0oooo00L0oooo00080?ooo`040000003oool0oooo000000@0
oooo0`0000070?ooo`040000003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`000?l04P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3o00050?ooo`030000o`3oool0oooo00l0oooo00<0o`000000o`3oool01`3oool0
0`3o0000003o0?ooo`0@0?ooo`030?l000000?l0oooo00D0oooo00@0o`000?ooo`3oool0003o3@3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`0000L0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00003@3oool00`3o0000oooo0?ooo`070?ooo`00
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool0003o4`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0000o`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o
0?ooo`3oool0403oool00`3o0000003o0?ooo`070?ooo`030?l000000?l0oooo0100oooo00<0o`00
0000o`3oool01@3oool0103o0000oooo0?ooo`000?l=0?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3o00001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`060?l0003oool0oooo0000o`3oool0
o`003@3oool00`3o0000oooo0?ooo`070?ooo`002@3oool2000000D0oooo100000060?ooo`040000
003oool0oooo0000oa<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`000?l04P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00040?oo
o`030000o`3oool0oooo0100oooo00<0o`000000o`3oool01`3oool00`3o0000003o0?ooo`0A0?oo
o`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o3@3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0o`0000L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool01P3o0000oooo0?ooo`00
0?l0oooo0?l000d0oooo00<0o`000?ooo`3oool01`3oool001X0oooo00@000000?ooo`3oool0003o
4`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0
103oool00`3o0000003o0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo0140oooo00<0o`000?ooo`3o
ool0103oool0103o0000oooo0?ooo`000?l=0?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3o00001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`060?l0003oool0oooo0000o`3oool0o`003@3o
ool00`3o0000oooo0?ooo`070?ooo`006P3oool010000000oooo0?ooo`000?lC0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0003o01@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00@0003o0?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo00H0oooo00<0o`000000o`3oool04@3oool00`3o0000oooo0?ooo`040?ooo`040?l0
003oool0oooo0000o`d0oooo00<0o`000?ooo`3oool00`3oool00`000?l0o`000?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00H0o`000?ooo`3oool0003o0?ooo`3o000=0?ooo`030?l0003oool0
oooo00L0oooo000J0?ooo`030000003oool0003o01@0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l0503oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0140oooo00<0o`000000o`3oool01P3oool0
0`3o0000003o0?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o3@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool01P3o0000oooo0?ooo`000?l0oooo0?l000h0oooo00<0o`000?ooo`3oool01P3oool001X0oooo
0P0000000`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o01@0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0
o`00103oool00`000?l0oooo0?ooo`0A0?ooo`030?l000000?l0oooo00H0oooo00<0o`000?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`d0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00H0o`000?oo
o`3oool0003o0?ooo`3o000>0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`030000003oool0
003o01D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`000?l0503oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00040?ooo`030000o`3o
ool0oooo0140oooo00<0o`000000o`3oool01P3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00@0oooo00@0o`000?ooo`3oool0003o3@3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool01P3o0000oooo0?ooo`000?l0oooo0?l0
00h0oooo00<0o`000?ooo`3oool01P3oool001X0oooo00<000000?ooo`000?l05@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0000o`0D0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000003o0?ooo`060?ooo`030?l0003oool0oooo0140oooo00<0o`000000o`3oool0103oool00`3o
0000oooo0000o`0>0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`060?l0003oool0oooo0000o`3oool0o`003P3oool00`3o0000oooo0?oo
o`060?ooo`006P3oool00`000000oooo0000o`0E0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0000oa@0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00@0
003o0?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`0A0?ooo`030?l000000?l0oooo00H0oooo
00<0o`000?ooo`3oool04@3oool00`3o0000003o0?ooo`040?ooo`030?l0003oool0003o00l0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo
000J0?ooo`030000003oool0003o01D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o503oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo
0?ooo`3o00040?ooo`030000o`3oool0oooo0140oooo00<0o`000000o`3oool01P3oool00`3o0000
oooo0?ooo`0A0?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`000?l03`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0000o`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo
00<000000?ooo`000?l05@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo
00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?lD0?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?l0
00@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000003o0?ooo`050?ooo`030?l000000?l0oooo
0180oooo00<0o`000000o`3oool0103oool00`3o0000oooo0000o`0?0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o
0080oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000
oooo0000o`0E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l000050?oo
o`030000o`3oool0oooo0140oooo00<0o`000000o`3oool01@3oool00`3o0000003o0?ooo`0B0?oo
o`030?l000000?l0oooo00@0oooo00<0o`000?ooo`000?l03`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0000o`020?oo
o`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool001X0oooo00<000000?ooo`00
0?l05@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0180oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o00001@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l000000?l0oooo00D0oooo00<0o`000000o`3oool04`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0003o00l0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000003o0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l00P3oool00`3o
0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`80000000<0003o0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01@0oooo00@0003o0?ooo`3o
ool0o`000`3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000oooo00@0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo01<0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0000o`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000000
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o0080oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000oooo0000o`0E0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool010000?l0oooo0?ooo`3o00030?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3oool00`3o0000003o0?ooo`030?oo
o`030?l0003oool0003o00l0oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00H0oooo000J0?ooo`030000003oool0003o01D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0o`000?ooo`040?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`0C0?ooo`030?l000000?l0oooo00<0oooo00<0o`000000o`3o
ool03`3oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0000o`020?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3o
ool01P3oool001X0oooo00<000000000o`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo01@0oooo00<0003o0?ooo`3o0000103oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3o0000oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo01<0oooo00<0o`000000o`3oool00`3oool00`3o0000003o0?ooo`0?0?ooo`030?l0
003oool0oooo0080oooo00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0003o0080oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`006P3o
ool00`000000003o0?ooo`0E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503o
ool00`000?l0oooo0?l000040?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003oool00`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool04`3o
ool00`3o0000003o0?ooo`030?ooo`030?l000000?l0oooo00l0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`000?l00P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`03000000000?l0
oooo00P0oooo1@3o00090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool0
0`000?l0o`000?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003oool00`3oool0
0`000?l0oooo0?ooo`0C0?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`3oool04`3oool0
0`3o0000003o0?ooo`030?ooo`030?l000000?l0oooo00l0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0?l0
00090?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00H0oooo000J0?ooo`03000000000?l0oooo00D0oooo0`3o0005
0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0003o
0?l0003oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000oooo00<0oooo00<0003o
0?ooo`3oool04`3oool00`3o0000003o0?ooo`040?ooo`030?l0003oool0oooo01<0oooo00<0o`00
0000o`3oool00`3oool00`3o0000003o0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0000o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`3o00002@3o
ool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`060?ooo`006P3oool00`000000003o0?ooo`020?ooo`<0o`002`3oool3
0?l000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3o0000
oooo00<0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`030?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0C0?ooo`030?l000000?l0
oooo00<0oooo00<0o`000000o`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0
o`000?ooo`3oool01P3oool001X0oooo00D000000000o`3oool0oooo0?l0000A0?ooo`040?l0003o
ool0oooo0000o`D0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo01@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool04`3oool00`3o0000003o0?ooo`020?ooo`030?l0
003oool0003o0100oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00D0oooo00<0003o0?oo
o`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000003o0?ooo`020?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool01@3oool0
01X0oooo00@000000000o`3o0000o`004`3oool00`3o0000oooo0000o`050?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo01<0oooo00<0o`000000o`3oool00P3oool00`3o0000oooo0000o`0@0?ooo`070?l0003oool0
oooo0?ooo`3o0000oooo0000o`050?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0
oooo0?l000090?ooo`030000o`3oool0oooo0080oooo00D0o`000000o`3oool0oooo0?l0000@0?oo
o`030?l0003oool0oooo00D0oooo000J0?ooo`030000003o0000oooo01D0oooo00<0o`000000o`3o
ool0103oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000003o0?ooo`0D0?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`00
0?l0403oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l01@3oool00`000?l0oooo0?ooo`06
0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0?l00100oooo00<0o`000?ooo`3oool01@3oool001X0oooo00<0o`000000o`3oool05P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01@0oooo00<0o`000000o`3oool0103o
ool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0oooo01@0oooo00<0o`000000o`3oool00P3o
ool00`3o0000oooo0000o`0@0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`050?ooo`03
0000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`020?oo
o`040?l0003oool0oooo0?l00100oooo00<0o`000?ooo`3oool01@3oool001X0oooo00<000000000
o`3oool05`3oool01@3o0000oooo0?ooo`3oool0003o01H0oooo00<0o`000000o`3oool0103oool0
0`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`020?ooo`030?l000000?l0oooo01@0oooo00<0o`000000o`3oool00P3oool0
0`3o0000oooo0000o`0@0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`050?ooo`030000
o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`020?ooo`04
0?l0003oool0oooo0?l00100oooo00<0o`000?ooo`3oool01@3oool001X0oooo00<000000000o`3o
ool05`3oool01@000?l0o`000?l0003oool0003o01D0oooo00<0o`000?ooo`000?l01@3oool00`00
0?l0oooo0?ooo`0E0?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool00`3o0000oooo0?ooo`05
0?ooo`030?l000000?l0oooo00<0oooo00<0003o0?ooo`3oool0503oool00`3o0000003o0?ooo`02
0?ooo`030?l000000?l0oooo01@0oooo00<0o`000000o`3oool00P3oool00`3o0000oooo0000o`0A
0?ooo`060?l0003oool0oooo0?l0003oool0003o1@3oool00`000?l0oooo0?ooo`070?ooo`040?l0
003oool0oooo0?l000X0oooo00H0003o0?ooo`3oool0oooo0000o`3o00020?ooo`030?l0003oool0
oooo00h0oooo00<0o`000?ooo`3oool01@3oool001X0oooo00<000000000o`3oool05`3oool01@00
0?l0oooo0?ooo`3o0000003o01D0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo0?oo
o`0E0?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool00`3o0000oooo0?ooo`050?ooo`030?l0
00000?l0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`3o0000003o0?ooo`020?ooo`030?l0
00000?l0oooo01D0oooo00L0o`000000o`3oool0oooo0?l0003oool0003o0140oooo00@0o`000?oo
o`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00@0o`000?ooo`3oool0o`00
2P3oool01P000?l0oooo0?ooo`3oool0003o0?l00080oooo00<0o`000?ooo`3oool03P3oool00`3o
0000oooo0?ooo`050?ooo`006P3oool00`000?l0oooo0?ooo`0G0?ooo`050000o`3oool0oooo0?oo
o`3o00005@3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0oooo01H0oooo00D0003o
0?ooo`3oool0oooo0000o`0?0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`0E0?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool05@3o
ool01P3o0000003o0?ooo`3o0000oooo0000oa80oooo00@0o`000?ooo`3oool0o`000P3oool01@00
0?l0oooo0?ooo`3oool0003o00X0oooo00@0o`000?ooo`3oool0o`002P3oool01P000?l0oooo0?oo
o`3oool0003o0?l00080oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`00
6P3oool00`000?l000000?ooo`0G0?ooo`060000o`3oool0oooo0?ooo`000?l0o`004`3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool05P3oool01@000?l0oooo0?ooo`3o
ool0003o0100oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0000o`030?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000000o`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`060?l00000
0?l0oooo0?l0003oool0003o4P3oool0103o0000oooo0?ooo`3o00020?ooo`050000o`3oool0oooo
0?ooo`000?l02P3oool0103o0000oooo0?ooo`3o000:0?ooo`060000o`3oool0oooo0?ooo`000?l0
o`000P3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0oooo000J0?ooo`030000
o`3oool0oooo01L0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0o`000180oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030000o`3oool0oooo01H0oooo00D0003o0?ooo`3oool0oooo0000
o`0@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0E0?ooo`030?l000000?l0oooo0080oooo00<0o`000?ooo`3oool05@3oool01P3o0000003o0?oo
o`3o0000oooo0000oa80oooo00@0o`000?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0
003o00X0oooo00@0o`000?ooo`3oool0o`002P3oool01P000?l0oooo0?ooo`3oool0003o0?l00080
oooo00<0o`000?ooo`3oool05P3oool001X0oooo00<0003o0?ooo`3oool05`3oool01@000?l0oooo
0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00<0003o0?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o0100oooo00<0o`00
0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l30?ooo`030000o`3oool0oooo01D0oooo00<0
o`000000o`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`060?l000000?l0oooo0?l0003oool0
003o4P3oool0103o0000oooo0?ooo`3o00020?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool0
103o0000oooo0?ooo`3o000:0?ooo`090000o`3oool0oooo0?ooo`000?l0oooo0?l0003oool0o`00
01P0oooo000J0?ooo`030000o`3oool0oooo01P0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o
0000oooo0?ooo`0<0?ooo`80o`001@3oool00`000?l0oooo0000o`0I0?ooo`050000o`3oool0oooo
0?ooo`000?l04@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0003o
6@3oool01@3o0000oooo0?ooo`3oool0o`0001L0oooo00H0o`000000o`3oool0o`000?ooo`000?lB
0?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?ooo`000?l02`3oool0103o0000oooo0?oo
o`3o000:0?ooo`090000o`3oool0oooo0?ooo`000?l0oooo0?l0003oool0o`0001P0oooo000J0?oo
o`030000o`3oool0oooo01P0oooo00<0003o0?ooo`000?l01@3oool20?l000/0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0000o`0I0?ooo`040000o`3oool0oooo0000oa80oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0003o01T0oooo00@0o`000000o`3oool0o`00
603oool01@3o0000oooo0000o`3o0000003o01<0oooo00<0o`000?ooo`3o0000103oool00`000?l0
oooo0000o`0;0?ooo`030?l0003oool0o`0000`0oooo00D0003o0?ooo`3oool0003o0?ooo`020?l0
01T0oooo000A0?ooo`<000001P3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0003o00L0
oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0003o01X0
oooo00<0003o0?ooo`000?l04P3oool0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0003o
01X0oooo00<0o`000?ooo`3o0000603oool01@3o0000oooo0000o`3o0000003o01<0oooo00<0o`00
0?ooo`3o0000103oool00`000?l0oooo0000o`0;0?ooo`030?l0003oool0o`0000`0oooo00<0003o
0?ooo`000?l00P3oool20?l001T0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0603oool00`000?l0oooo0000o`080?ooo`030?l0003oool0oooo00D0oooo0P3o00080?oo
o`030000o`3oool0003o01X0oooo00<0003o0?ooo`000?l04P3oool0103o0000oooo0?ooo`3o0004
0?ooo`030000o`3oool0003o01X0oooo00<0o`000?ooo`3o00006@3oool20?l000030?ooo`000?l0
oooo01<0oooo0P3o00040?ooo`030000o`3oool0003o00`0oooo0P3o000<0?ooo`030000o`3oool0
003o0080oooo0P3o000I0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`<00000603oool30000
o`T0oooo203o00090?ooo`<0003o6P3oool30000oa<0oooo0`3o00040?ooo`<0003o6P3oool20?l0
00030000o`3oool0oooo01L0oooo0P3o00020000oa@0oooo0P3o00050?ooo`80003o303oool20?l0
00d0oooo0P000?l20?ooo`80o`006@3oool00180oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`3o0?ooo`@0oooo000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3oool40?ooo`004@3oool2000000L0oooo00<000000?ooo`3oool0o`3oool40?ooo`004P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo103oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.527234, -1.12765, \
0.0196943, 0.0127464}}]
}, Open  ]],

Cell[TextData[{
  "From this it can be seen that the (angular) frequency of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(f(t))\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_0\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{\(2\ \[Pi]\[Nu]\), "=", 
            RowBox[{
              SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "(", \(t\_0\), ")"}]}]}], 
        TraditionalForm]]],
  " and the phase is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "=", 
          RowBox[{\(f(t\_0)\), "-", 
            RowBox[{
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "(", \(t\_0\), ")"}], 
              " ", \(t\_0\)}]}]}], TraditionalForm]]],
  ". Hence the ",
  StyleBox["instantaneous frequency",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`sin(2\ \[Pi]\ f\ t\^2)\)]],
  " is"
}], "Text",
  CellTags->{"instantaneous frequency", "phase"}],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      FractionBox[
        FractionBox[\(\[PartialD]\((2\ \[Pi]\ f\ t\^2)\)\), \(\[PartialD]t\),
          MultilineFunction->None], \(2\ \[Pi]\)], TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ f\ t\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "and the rate of increase of frequency is ",
  Cell[BoxData[
      \(TraditionalForm\`2  f\ t\[NonBreakingSpace]Hz\)]],
  " per second."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Touch-tone Phone"
}], "Subsection"],

Cell[TextData[{
  "It turns out that all the 12 tones on a touch-tone phone (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`1 - 9\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`#\)]],
  ") are generated by forming the superposition of two tones of differing \
frequencies, played for 0.1 seconds."
}], "Text"],

Cell["Forming pairs", "Subsubsection"],

Cell[TextData[{
  "Use ",
  StyleBox["Outer", "InlineInputTraditionalForm"],
  " to generate a list of all the possible pairs of frequencies from the \
lists ",
  Cell[BoxData[
      \(TraditionalForm\`{697, 770, 852, 941}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{1209, 1336, 1477}\)]],
  ".  You should get a total of ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Times]3 = 12\)]],
  " pairs. You will need to appropriately ",
  StyleBox["Flatten", "InlineInputTraditionalForm"],
  " this result to get rid of one level of brackets. Call the result ",
  StyleBox["tones", "InlineInputTraditionalForm"],
  "."
}], "BeginEndQuestion",
  CellTags->"Outer"],

Cell[CellGroupData[{

Cell[TextData[{
  "Write a simple procedure called ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(PlayTouchTone[{f1_, \ f2_}]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " which takes two frequencies and play a superposition of them for 0.1 \
seconds. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ":You have already done this above for middle C and A440 in question ",
  
  CounterBox["Exercise", "C and A"],
  "."
}], "BeginEndQuestion"],

Cell["The numbers 0-9", "Subsubsection"]
}, Open  ]],

Cell[TextData[{
  "Play each pair of frequencies generated in question ",
  
  CounterBox["Exercise", "Outer"],
  ". Go to a touch-tone phone and check which sound corresponds to each \
member of your array. Order your array so that the \
\[OpenCurlyDoubleQuote]numerical\[CloseCurlyDoubleQuote] sounds are in \
ascending order, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", from 0 to 9."
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  "Define ",
  StyleBox["TouchTone", "InlineInputTraditionalForm"],
  " by entering "
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`TouchTone(
        n_Integer /; 0 \[LessEqual] n \[LessEqual] 9) := 
      PlayTouchTone(
        tones\[LeftDoubleBracket]n + 1\[RightDoubleBracket])\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Note that this code can only handle single-digits. ", "EndQuestion"],

Cell["Multiple digits", "Subsubsection"]
}, Open  ]],

Cell[TextData[{
  "Generalize to multiple digits by making ",
  StyleBox["TouchTone", "InlineInputTraditionalForm"],
  " have the ",
  StyleBox["Attribute", "InlineInputTraditionalForm"],
  " ",
  StyleBox["Listable", "InlineInputTraditionalForm"],
  " and use ",
  StyleBox["IntegerDigits", "InlineInputTraditionalForm"],
  " to turn a single integer into a list of digits.  Check your definition of \
",
  StyleBox["TouchTone", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["??", "InlineInputTraditionalForm"],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Dial the University switchboard using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(TouchTone[93803838];\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " You can animate this sequence of graphics/sounds using ",
  StyleBox["Animate Selected Graphics", "Menu"],
  " under the ",
  StyleBox["Cell", "Menu"],
  " menu."
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Marks"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    FontFamily->"Times",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Marks", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Marks", "Printout"]]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Fourier series"->{
    Cell[3732, 133, 560, 15, 42, "Text",
      CellTags->{"Fourier series", "orthogonality integrals"}]},
  "orthogonality integrals"->{
    Cell[3732, 133, 560, 15, 42, "Text",
      CellTags->{"Fourier series", "orthogonality integrals"}]},
  "periodic"->{
    Cell[8231, 316, 185, 5, 24, "Text",
      CellTags->"periodic"]},
  "square wave"->{
    Cell[8419, 323, 424, 11, 37, "NumberedEquation",
      CellTags->"square wave"]},
  "periodicity condition"->{
    Cell[8971, 343, 315, 9, 22, "NumberedEquation",
      CellTags->"periodicity condition"]},
  "Fourier coefficients"->{
    Cell[10447, 411, 194, 11, 32, "Subsection",
      CellTags->"Fourier coefficients"]},
  "partial sum"->{
    Cell[13214, 510, 262, 14, 32, "Subsection",
      CellTags->"partial sum"]},
  "Lanczos \[Sigma] factors"->{
    Cell[15697, 618, 1129, 41, 56, "Text",
      CellTags->{"Lanczos \[Sigma] factors", "Gibbs phenomenon"}]},
  "Gibbs phenomenon"->{
    Cell[15697, 618, 1129, 41, 56, "Text",
      CellTags->{"Lanczos \[Sigma] factors", "Gibbs phenomenon"}]},
  "Hamming (1973)"->{
    Cell[18900, 737, 206, 6, 38, "Text",
      CellTags->"Hamming (1973)"]},
  "Lanczsos (1956)"->{
    Cell[19109, 745, 171, 6, 38, "Text",
      CellTags->"Lanczsos (1956)"]},
  "FFT"->{
    Cell[20183, 807, 198, 5, 24, "Text",
      CellTags->{"FFT", "DFT", "DCT", "JPEG"}]},
  "DFT"->{
    Cell[20183, 807, 198, 5, 24, "Text",
      CellTags->{"FFT", "DFT", "DCT", "JPEG"}]},
  "DCT"->{
    Cell[20183, 807, 198, 5, 24, "Text",
      CellTags->{"FFT", "DFT", "DCT", "JPEG"}]},
  "JPEG"->{
    Cell[20183, 807, 198, 5, 24, "Text",
      CellTags->{"FFT", "DFT", "DCT", "JPEG"}]},
  "discrete dataset"->{
    Cell[20384, 814, 498, 10, 58, "Warning",
      CellTags->"discrete dataset"]},
  "Hartley transform"->{
    Cell[20885, 826, 742, 15, 56, "Text",
      CellTags->{
      "Hartley transform", "DWT", "discrete wavelet transform", 
        "fingerprints"}]},
  "DWT"->{
    Cell[20885, 826, 742, 15, 56, "Text",
      CellTags->{
      "Hartley transform", "DWT", "discrete wavelet transform", 
        "fingerprints"}]},
  "discrete wavelet transform"->{
    Cell[20885, 826, 742, 15, 56, "Text",
      CellTags->{
      "Hartley transform", "DWT", "discrete wavelet transform", 
        "fingerprints"}]},
  "fingerprints"->{
    Cell[20885, 826, 742, 15, 56, "Text",
      CellTags->{
      "Hartley transform", "DWT", "discrete wavelet transform", 
        "fingerprints"}]},
  "1D FFT"->{
    Cell[22044, 868, 183, 11, 32, "Subsection",
      CellTags->"1D FFT"]},
  "holography"->{
    Cell[115932, 2477, 584, 13, 58, "Text",
      CellTags->{"holography", "spatial filtering", "hologram"}]},
  "spatial filtering"->{
    Cell[115932, 2477, 584, 13, 58, "Text",
      CellTags->{"holography", "spatial filtering", "hologram"}]},
  "hologram"->{
    Cell[115932, 2477, 584, 13, 58, "Text",
      CellTags->{"holography", "spatial filtering", "hologram"}]},
  "edge detection"->{
    Cell[599658, 12589, 565, 12, 54, "Text",
      CellTags->{
      "edge detection", "step-function", "Heaviside function", 
        "Dirac delta"}]},
  "step-function"->{
    Cell[599658, 12589, 565, 12, 54, "Text",
      CellTags->{
      "edge detection", "step-function", "Heaviside function", 
        "Dirac delta"}]},
  "Heaviside function"->{
    Cell[599658, 12589, 565, 12, 54, "Text",
      CellTags->{
      "edge detection", "step-function", "Heaviside function", 
        "Dirac delta"}]},
  "Dirac delta"->{
    Cell[599658, 12589, 565, 12, 54, "Text",
      CellTags->{
      "edge detection", "step-function", "Heaviside function", 
        "Dirac delta"}]},
  "Laplacian operator"->{
    Cell[602010, 12673, 788, 25, 56, "Text",
      CellTags->"Laplacian operator"]},
  "discrete Laplacian filter"->{
    Cell[605418, 12781, 87, 1, 36, "Text",
      CellTags->"discrete Laplacian filter"]},
  "edge enhancement"->{
    Cell[627452, 13336, 121, 4, 36, "Text",
      CellTags->"edge enhancement"]},
  "C and A"->{
    Cell[628850, 13399, 470, 13, 66, "BeginEndQuestion",
      CellTags->"C and A"]},
  "instantaneous frequency"->{
    Cell[921510, 19371, 1050, 34, 42, "Text",
      CellTags->{"instantaneous frequency", "phase"}]},
  "phase"->{
    Cell[921510, 19371, 1050, 34, 42, "Text",
      CellTags->{"instantaneous frequency", "phase"}]},
  "Outer"->{
    Cell[923760, 19464, 672, 19, 70, "BeginEndQuestion",
      CellTags->"Outer"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Fourier series", 991762, 21899},
  {"orthogonality integrals", 991899, 21902},
  {"periodic", 992021, 21905},
  {"square wave", 992110, 21908},
  {"periodicity condition", 992225, 21911},
  {"Fourier coefficients", 992348, 21914},
  {"partial sum", 992457, 21917},
  {"Lanczos \[Sigma] factors", 992570, 21920},
  {"Gibbs phenomenon", 992705, 21923},
  {"Hamming (1973)", 992838, 21926},
  {"Lanczsos (1956)", 992938, 21929},
  {"FFT", 993027, 21932},
  {"DFT", 993128, 21935},
  {"DCT", 993229, 21938},
  {"JPEG", 993331, 21941},
  {"discrete dataset", 993445, 21944},
  {"Hartley transform", 993553, 21947},
  {"DWT", 993716, 21952},
  {"discrete wavelet transform", 993902, 21957},
  {"fingerprints", 994074, 21962},
  {"1D FFT", 994240, 21967},
  {"holography", 994334, 21970},
  {"spatial filtering", 994470, 21973},
  {"hologram", 994597, 21976},
  {"edge detection", 994730, 21979},
  {"step-function", 994904, 21984},
  {"Heaviside function", 995083, 21989},
  {"Dirac delta", 995255, 21994},
  {"Laplacian operator", 995434, 21999},
  {"discrete Laplacian filter", 995552, 22002},
  {"edge enhancement", 995666, 22005},
  {"C and A", 995763, 22008},
  {"instantaneous frequency", 995880, 22011},
  {"phase", 995995, 22014},
  {"Outer", 996110, 22017}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 114, 5, 74, "Title",
  CounterAssignments->{{"Title", 3}}],
Cell[1904, 60, 29, 0, 26, "Author"],
Cell[1936, 62, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2375, 78, 39, 0, 42, "Subsubsection"],
Cell[2417, 80, 215, 5, 26, "Text"],
Cell[2635, 87, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2750, 91, 87, 3, 24, "Text"],
Cell[2840, 96, 117, 2, 24, "Input",
  InitializationCell->True],
Cell[2960, 100, 212, 6, 26, "Text"],
Cell[3175, 108, 209, 4, 24, "Input",
  InitializationCell->True],
Cell[3387, 114, 183, 4, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3607, 123, 122, 8, 41, "SectionFirst"],
Cell[3732, 133, 560, 15, 42, "Text",
  CellTags->{"Fourier series", "orthogonality integrals"}],
Cell[4295, 150, 208, 4, 45, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4528, 158, 151, 10, 54, "Subsection"],
Cell[4682, 170, 97, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[4804, 177, 207, 4, 45, "Subsubsection",
  Evaluatable->False],
Cell[5014, 183, 51, 0, 24, "Text"],
Cell[5068, 185, 178, 3, 41, "NumberedEquation"]
}, Closed]],
Cell[5261, 191, 459, 18, 53, "BeginEndQuestion"],
Cell[5723, 211, 237, 6, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[5985, 221, 354, 11, 52, "BeginEndQuestion"],
Cell[6342, 234, 55, 0, 24, "Text"],
Cell[6400, 236, 210, 5, 29, "Subsubsection",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6647, 246, 202, 6, 53, "BeginEndQuestion"],
Cell[6852, 254, 210, 5, 29, "Subsubsection",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[7099, 264, 319, 12, 53, "BeginEndQuestion"],
Cell[7421, 278, 247, 5, 30, "Subsubsection",
  Evaluatable->False]
}, Open  ]],
Cell[7683, 286, 359, 13, 54, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[8079, 304, 149, 10, 32, "Subsection"],
Cell[8231, 316, 185, 5, 24, "Text",
  CellTags->"periodic"],
Cell[8419, 323, 424, 11, 37, "NumberedEquation",
  CellTags->"square wave"],
Cell[8846, 336, 122, 5, 26, "Text"],
Cell[8971, 343, 315, 9, 22, "NumberedEquation",
  CellTags->"periodicity condition"],
Cell[9289, 354, 165, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[9479, 363, 47, 0, 35, "BeginQuestion"],
Cell[9529, 365, 114, 2, 24, "Input"],
Cell[9646, 369, 75, 1, 24, "Input"],
Cell[9724, 372, 238, 6, 24, "Input"]
}, Open  ]],
Cell[9977, 381, 341, 20, 39, "EndQuestion"],
Cell[10321, 403, 89, 3, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[10447, 411, 194, 11, 32, "Subsection",
  CellTags->"Fourier coefficients"],
Cell[10644, 424, 124, 3, 24, "Text"],
Cell[10771, 429, 462, 7, 113, "NumberedEquation"],

Cell[CellGroupData[{
Cell[11258, 440, 1134, 32, 79, "BeginEndQuestion"],
Cell[12395, 474, 19, 0, 24, "Answer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12451, 479, 399, 11, 49, "BeginEndQuestion"],
Cell[12853, 492, 19, 0, 24, "Answer"]
}, Open  ]],
Cell[12887, 495, 290, 10, 49, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[13214, 510, 262, 14, 32, "Subsection",
  CellTags->"partial sum"],
Cell[13479, 526, 598, 27, 24, "Text"],
Cell[14080, 555, 179, 3, 46, "Input"],

Cell[CellGroupData[{
Cell[14284, 562, 823, 24, 71, "BeginEndQuestion"],
Cell[15110, 588, 373, 12, 26, "Warning"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15532, 606, 162, 10, 32, "Subsection"],
Cell[15697, 618, 1129, 41, 56, "Text",
  CellTags->{"Lanczos \[Sigma] factors", "Gibbs phenomenon"}],
Cell[16829, 661, 125, 2, 53, "Input"],
Cell[16957, 665, 330, 12, 24, "Text"],
Cell[17290, 679, 203, 3, 46, "Input"],

Cell[CellGroupData[{
Cell[17518, 686, 664, 18, 70, "BeginEndQuestion"],
Cell[18185, 706, 19, 0, 24, "Answer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18241, 711, 574, 18, 66, "BeginEndQuestion"],
Cell[18818, 731, 19, 0, 24, "Answer"],

Cell[CellGroupData[{
Cell[18862, 735, 35, 0, 42, "Subsubsection"],
Cell[18900, 737, 206, 6, 38, "Text",
  CellTags->"Hamming (1973)"],
Cell[19109, 745, 171, 6, 38, "Text",
  CellTags->"Lanczsos (1956)"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19341, 758, 153, 10, 32, "Subsection"],
Cell[19497, 770, 526, 22, 48, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20072, 798, 108, 7, 39, "Section"],
Cell[20183, 807, 198, 5, 24, "Text",
  CellTags->{"FFT", "DFT", "DCT", "JPEG"}],
Cell[20384, 814, 498, 10, 58, "Warning",
  CellTags->"discrete dataset"],
Cell[20885, 826, 742, 15, 56, "Text",
  CellTags->{
  "Hartley transform", "DWT", "discrete wavelet transform", "fingerprints"}],

Cell[CellGroupData[{
Cell[21652, 845, 149, 10, 54, "Subsection"],
Cell[21804, 857, 203, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[22044, 868, 183, 11, 32, "Subsection",
  CellTags->"1D FFT"],
Cell[22230, 881, 54, 0, 42, "Subsubsection"],
Cell[22287, 883, 559, 18, 50, "BeginEndQuestion"],
Cell[22849, 903, 532, 14, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[23406, 921, 1132, 28, 84, "BeginEndQuestion"],
Cell[24541, 951, 66, 2, 24, "Answer",
  Evaluatable->False],
Cell[24610, 955, 765, 21, 44, "Warning"],
Cell[25378, 978, 78745, 1105, 298, 1507, 147, "GraphicsData", "PostScript", \
"Graphics"],

Cell[CellGroupData[{
Cell[104148, 2087, 95, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[104246, 2091, 197, 5, 26, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[104492, 2102, 900, 23, 70, "BeginEndQuestion"],
Cell[105395, 2127, 18, 0, 24, "Answer"],
Cell[105416, 2129, 79, 2, 26, "Subsubsection",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[105532, 2136, 139, 2, 35, "BeginQuestion"],
Cell[105674, 2140, 165, 3, 39, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105876, 2148, 641, 16, 70, "BeginEndQuestion"],
Cell[106520, 2166, 172, 2, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106729, 2173, 1002, 22, 88, "BeginEndQuestion"],
Cell[107734, 2197, 18, 0, 24, "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[107801, 2203, 161, 10, 32, "Subsection"],

Cell[CellGroupData[{
Cell[107987, 2217, 98, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[108088, 2221, 835, 23, 60, "Text"],
Cell[108926, 2246, 180, 5, 39, "Input",
  InitializationCell->True],
Cell[109109, 2253, 56, 0, 24, "Text"],
Cell[109168, 2255, 200, 5, 39, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[109405, 2265, 87, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[109495, 2269, 47, 0, 24, "Text"],
Cell[109545, 2271, 257, 6, 24, "Input"]
}, Closed]],
Cell[109817, 2280, 141, 4, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[109983, 2288, 567, 18, 66, "BeginEndQuestion"],
Cell[110553, 2308, 18, 0, 24, "Answer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110608, 2313, 262, 5, 52, "BeginEndQuestion"],
Cell[110873, 2320, 18, 0, 24, "Answer"],
Cell[110894, 2322, 77, 2, 26, "Subsubsection",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[111008, 2329, 263, 8, 52, "BeginEndQuestion"],
Cell[111274, 2339, 18, 0, 24, "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[111341, 2345, 161, 10, 32, "Subsection"],

Cell[CellGroupData[{
Cell[111527, 2359, 33, 0, 42, "Subsubsection"],
Cell[111563, 2361, 68, 0, 24, "Text"],
Cell[111634, 2363, 484, 12, 39, "Input"],
Cell[112121, 2377, 386, 10, 39, "Input"],
Cell[112510, 2389, 221, 6, 26, "Text"],
Cell[112734, 2397, 2425, 51, 39, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115196, 2453, 626, 16, 52, "BeginEndQuestion"],
Cell[115825, 2471, 19, 0, 32, "Answer"],

Cell[CellGroupData[{
Cell[115869, 2475, 60, 0, 42, "Subsubsection"],
Cell[115932, 2477, 584, 13, 58, "Text",
  CellTags->{"holography", "spatial filtering", "hologram"}],
Cell[116519, 2492, 63, 0, 24, "Text"],
Cell[116585, 2494, 187, 4, 24, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[116821, 2504, 510, 11, 66, "BeginEndQuestion"],
Cell[117334, 2517, 18, 0, 24, "Answer"],

Cell[CellGroupData[{
Cell[117377, 2521, 39, 0, 26, "Subsubsection"],
Cell[117419, 2523, 142, 3, 24, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[117610, 2532, 390, 8, 66, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[118025, 2544, 68, 0, 26, "Subsubsection"],
Cell[118096, 2546, 57, 0, 24, "Text"],
Cell[118156, 2548, 134, 3, 26, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[118339, 2557, 510, 11, 66, "BeginEndQuestion"],
Cell[118852, 2570, 18, 0, 24, "Answer"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[118919, 2576, 149, 10, 32, "Subsection"],
Cell[119071, 2588, 187, 4, 24, "Text"],
Cell[119261, 2594, 85, 2, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[119371, 2600, 1041, 27, 70, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[120437, 2631, 88, 1, 24, "Input"],
Cell[120528, 2634, 59, 1, 22, "Output"]
}, Open  ]],
Cell[120602, 2638, 123, 2, 24, "Input"],
Cell[120728, 2642, 177, 4, 24, "Input"],

Cell[CellGroupData[{
Cell[120930, 2650, 339, 9, 24, "Input"],
Cell[121272, 2661, 52758, 706, 298, 2043, 75, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174067, 3372, 334, 9, 24, "Input"],
Cell[174404, 3383, 118417, 2796, 244, 61251, 2086, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[292858, 6184, 180, 3, 24, "Input"],
Cell[293041, 6189, 83205, 2014, 244, 54473, 1655, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[376261, 8206, 244, 5, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[376542, 8216, 207, 5, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[376774, 8225, 79, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[376856, 8229, 117, 3, 24, "Text"],
Cell[376976, 8234, 198, 4, 39, "Input"],
Cell[377177, 8240, 146, 5, 24, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[377372, 8251, 684, 22, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[378081, 8277, 78, 1, 24, "Input"],
Cell[378162, 8280, 50380, 676, 298, 2043, 75, "GraphicsData", "PostScript", \
"Graphics"],
Cell[428545, 8958, 174, 4, 22, "Output"]
}, Open  ]],
Cell[428734, 8965, 18, 0, 24, "Answer"],

Cell[CellGroupData[{
Cell[428777, 8969, 84, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[428864, 8973, 552, 15, 42, "Text"],
Cell[429419, 8990, 283, 7, 26, "Text"],
Cell[429705, 8999, 223, 5, 24, "Input"],
Cell[429931, 9006, 207, 6, 24, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[430187, 9018, 465, 13, 52, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[430677, 9035, 147, 2, 24, "Input"],
Cell[430827, 9039, 51717, 693, 298, 2043, 75, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[482581, 9737, 399, 11, 24, "Input"],
Cell[482983, 9750, 115977, 2802, 244, 62280, 2135, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[598975, 12555, 397, 11, 24, "Input"],
Cell[599375, 12568, 18, 0, 24, "Answer"],
Cell[599396, 12570, 58, 1, 24, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[599503, 12577, 152, 10, 32, "Subsection"],
Cell[599658, 12589, 565, 12, 54, "Text",
  CellTags->{
  "edge detection", "step-function", "Heaviside function", "Dirac delta"}],

Cell[CellGroupData[{
Cell[600248, 12605, 102, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[600353, 12609, 88, 3, 24, "Text"],
Cell[600444, 12614, 158, 3, 42, "Input"],
Cell[600605, 12619, 432, 14, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[601074, 12638, 804, 25, 66, "BeginEndQuestion"],
Cell[601881, 12665, 19, 0, 24, "Answer"],

Cell[CellGroupData[{
Cell[601925, 12669, 82, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[602010, 12673, 788, 25, 56, "Text",
  CellTags->"Laplacian operator"],
Cell[602801, 12700, 509, 14, 33, "Text"],
Cell[603313, 12716, 361, 8, 45, "Input"],
Cell[603677, 12726, 243, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[603945, 12736, 362, 10, 39, "Input"],
Cell[604310, 12748, 1093, 30, 38, "Output"]
}, Open  ]],
Cell[605418, 12781, 87, 1, 36, "Text",
  CellTags->"discrete Laplacian filter"],
Cell[605508, 12784, 351, 10, 55, "Input"],
Cell[605862, 12796, 707, 23, 42, "Text"],

Cell[CellGroupData[{
Cell[606594, 12823, 392, 7, 55, "Input"],
Cell[606989, 12832, 381, 8, 83, "Output"]
}, Open  ]],
Cell[607385, 12843, 105, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[607515, 12850, 81, 1, 24, "Input"],
Cell[607599, 12853, 138, 2, 38, "Output"]
}, Open  ]],
Cell[607752, 12858, 571, 19, 44, "Text"],

Cell[CellGroupData[{
Cell[608348, 12881, 111, 2, 25, "Input"],
Cell[608462, 12885, 842, 15, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[609341, 12905, 114, 2, 24, "Input"],
Cell[609458, 12909, 7735, 178, 221, "Output"]
}, Open  ]],
Cell[617208, 13090, 103, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[617336, 13097, 87, 1, 24, "Input"],
Cell[617426, 13100, 6511, 154, 221, "Output"]
}, Open  ]],
Cell[623952, 13257, 63, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[624040, 13261, 72, 1, 24, "Input"],
Cell[624115, 13264, 1306, 19, 77, "Output"]
}, Open  ]],
Cell[625436, 13286, 202, 7, 26, "Text"],

Cell[CellGroupData[{
Cell[625663, 13297, 93, 1, 24, "Input"],
Cell[625759, 13300, 1306, 19, 77, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[627126, 13326, 323, 8, 52, "BeginEndQuestion"],
Cell[627452, 13336, 121, 4, 36, "Text",
  CellTags->"edge enhancement"],
Cell[627576, 13342, 180, 4, 24, "Text"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[627817, 13353, 102, 7, 39, "Section"],
Cell[627922, 13362, 297, 9, 26, "Text"],

Cell[CellGroupData[{
Cell[628244, 13375, 151, 10, 54, "Subsection"],
Cell[628398, 13387, 449, 10, 40, "Text"],
Cell[628850, 13399, 470, 13, 66, "BeginEndQuestion",
  CellTags->"C and A"],

Cell[CellGroupData[{
Cell[629345, 13416, 33, 0, 35, "BeginQuestion"],
Cell[629381, 13418, 1229, 34, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[630647, 13457, 207, 7, 41, "EndQuestion"],
Cell[630857, 13466, 18, 0, 24, "Answer"],
Cell[630878, 13468, 122, 5, 24, "Text"],
Cell[631003, 13475, 75, 1, 25, "Input"],

Cell[CellGroupData[{
Cell[631103, 13480, 122, 2, 24, "Input"],
Cell[631228, 13484, 77272, 1598, 188, 13659, 808, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[708515, 15085, 1166, 34, 40, "Text"],

Cell[CellGroupData[{
Cell[709706, 15123, 876, 22, 24, "Input"],
Cell[710585, 15147, 92126, 1809, 188, 14233, 843, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[802748, 16961, 63, 1, 24, "Input"],
Cell[802814, 16964, 118681, 2404, 188, 19375, 1173, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[921510, 19371, 1050, 34, 42, "Text",
  CellTags->{"instantaneous frequency", "phase"}],

Cell[CellGroupData[{
Cell[922585, 19409, 202, 4, 51, "Input"],
Cell[922790, 19415, 58, 1, 22, "Output"]
}, Open  ]],
Cell[922863, 19419, 166, 5, 24, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[923078, 19430, 154, 10, 32, "Subsection"],
Cell[923235, 19442, 481, 18, 42, "Text"],
Cell[923719, 19462, 38, 0, 42, "Subsubsection"],
Cell[923760, 19464, 672, 19, 70, "BeginEndQuestion",
  CellTags->"Outer"],

Cell[CellGroupData[{
Cell[924457, 19487, 472, 14, 64, "BeginEndQuestion"],
Cell[924932, 19503, 40, 0, 26, "Subsubsection"]
}, Open  ]],
Cell[924987, 19506, 419, 11, 64, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[925431, 19521, 122, 4, 39, "BeginQuestion"],
Cell[925556, 19527, 226, 5, 24, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[925819, 19537, 74, 0, 39, "EndQuestion"],
Cell[925896, 19539, 40, 0, 26, "Subsubsection"]
}, Open  ]],
Cell[925951, 19542, 551, 15, 70, "BeginEndQuestion"],
Cell[926505, 19559, 385, 11, 72, "BeginEndQuestion"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

