(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    110418,       3164]*)
(*NotebookOutlinePosition[    177616,       5555]*)
(*  CellTagsIndexPosition[    176966,       5533]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Differential Equations"
}], "Title",
  CounterAssignments->{{"Title", 4}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "We modify ",
  Cell[BoxData[
      FormBox[
        StyleBox["Equal",
          "Input"], TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      FormBox[
        StyleBox["Listable",
          "Input"], TraditionalForm]]],
  " operations are automatically applied to both sides of any equality:"
}], "BrightIdea",
  CellTags->{"Equal", "Listable"}],

Cell[BoxData[
    \(TraditionalForm\`\(Unprotect[Equal];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`listableQ(f_) := 
      MemberQ(Attributes(f), Listable)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`Equal /: \ 
      lhs : f_Symbol?
            listableQ[___, \ _Equal, \ ___]\  := \n\ \ \ \ \ \ \ \ Thread[\ 
        Unevaluated[lhs], \ Equal\ ]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(TraditionalForm\`\(Protect[Equal];\)\)], "Input",
  InitializationCell->True],

Cell["Now, we can directly manipulate equations.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Planet Moving in the Field of Two Suns"
}], "SectionFirst"],

Cell[TextData[{
  "In this section you will explore the trajectories of a planet moving in \
the gravitational field of two fixed, equal mass suns. The suns are of mass \
",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and are located at the points ",
  Cell[BoxData[
      \(TraditionalForm\`\(+D\)\)]],
  " and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(-D\)\)\)]],
  " along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-axis. Rescaling the variables by ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] D\ x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Rule] D\ y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] t \@\( D\^3/\((G\ M)\)\)\)]],
  ", the equations become ",
  StyleBox["dimensionless",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"dimensionless"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["x", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "\[Equal]", \(\(1 - x(t)\)\/\((\((x(t) - 1)\)\^2 + \(y(t)\)\^2)\)\^\
\(3/2\) - \(x(t) + 1\)\/\((\((x(t) + 1)\)\^2 + \(y(t)\)\^2)\)\^\(3/2\)\)}], 
        ",", "\n", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "\[Equal]", \(\(-\(\(y(
                    t)\)\/\((\((x(t) - 1)\)\^2 + \(y(t)\)\^2)\)\^\(3/2\)\)\) \
- \(\(\(y(t)\)\/\((\((x(t) + 1)\)\^2 + \(y(t)\)\^2)\)\^\(3/2\)\)\(.\)\)\)}]}],
       TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "These coupled differential equations are very difficult to solve ",
  StyleBox["analytically",
    FontSlant->"Italic"],
  ".  In fact, the general 3-body problem in classical mechanics (where all \
the masses can be different and none are fixed) is a famous problem. Series \
solution reveals that the solution is unstable to small perturbations and the \
system dynamics are chaotic."
}], "Text",
  CellTags->{"unstable", "chaotic"}],

Cell["\<\
Conservation of angular momentum requires that if all three objects \
and their velocity vectors are initially confined to a plane then this \
condition will continue to hold for all future times (in the absence of \
external torques).\
\>", "Warning",
  CellTags->"angular momentum"],

Cell[TextData[{
  "These second-order equations can be reduced to a system of coupled \
first-order equations. This is often required as many numerical integrators \
are only designed to solve first-order equations. However, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can handle this system of equations (numerically) in a direct way. With \
the equations:"
}], "Warning"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"eqns", "=", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "==", \(\(1 - x(t)\)\/\((\((x(t) - 1)\)\^2 + \(y(t)\)\^2)\)\^\
\(3/2\) - \(x(t) + 1\)\/\((\((x(t) + 1)\)\^2 + \(y(t)\)\^2)\)\^\(3/2\)\)}], 
              ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], 
                "==", \(\(-\(\(y(
                          t)\)\/\((\((x(t) - 1)\)\^2 + \
\(y(t)\)\^2)\)\^\(3/2\)\)\) - \(y(t)\)\/\((\((x(t) + 1)\)\^2 + \(y(t)\)\^2)\)\
\^\(3/2\)\)}]}], "}"}]}], ";"}], TraditionalForm]], "Input",
  InitializationCell->True],

Cell["and initial conditions:", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"ics", "=", 
          RowBox[{"{", 
            RowBox[{\(x(0) == 0\), ",", \(y(0) == 0\), ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}], "==", "1"}], 
              ",", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}], "==", "1"}]}], 
            "}"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "(",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", starting from the origin with a specified velocity), here is a \
parametric plot of the solution for 8 time units:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`nsol = 
      NDSolve[Join[eqns, ics], {x, y}, {t, 0, 8}]; \)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ParametricPlot, 
        Epilog \[Rule] {PointSize[0.02], Hue[1], Point[{\(-1\), 0}], 
            Point[{1, 0}]}];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(ParametricPlot[
        Evaluate[{x(t), y(t)} /. \[InvisibleSpace]nsol], {t, 0, 
          8}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.436174 0.329374 0.43852 0.318501 [
[.1068 .42602 -7.96875 -12 ]
[.1068 .42602 7.96875 0 ]
[.27149 .42602 -11.7188 -12 ]
[.27149 .42602 11.7188 0 ]
[.60086 .42602 -8.25 -12 ]
[.60086 .42602 8.25 0 ]
[.76555 .42602 -4.5 -12 ]
[.76555 .42602 4.5 0 ]
[.93023 .42602 -8.25 -12 ]
[.93023 .42602 8.25 0 ]
[.42367 .04039 -28.4375 -6 ]
[.42367 .04039 0 6 ]
[.42367 .12002 -15.9375 -6 ]
[.42367 .12002 0 6 ]
[.42367 .19964 -28.4375 -6 ]
[.42367 .19964 0 6 ]
[.42367 .27927 -23.4375 -6 ]
[.42367 .27927 0 6 ]
[.42367 .35889 -28.4375 -6 ]
[.42367 .35889 0 6 ]
[.42367 .51814 -21.5 -6 ]
[.42367 .51814 0 6 ]
[.42367 .59777 -16.5 -6 ]
[.42367 .59777 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1068 .43852 m
.1068 .44477 L
s
gsave
.1068 .42602 -68.9688 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27149 .43852 m
.27149 .44477 L
s
gsave
.27149 .42602 -72.7188 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.60086 .43852 m
.60086 .44477 L
s
gsave
.60086 .42602 -69.25 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.76555 .43852 m
.76555 .44477 L
s
gsave
.76555 .42602 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.93023 .43852 m
.93023 .44477 L
s
gsave
.93023 .42602 -69.25 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.13974 .43852 m
.13974 .44227 L
s
.17268 .43852 m
.17268 .44227 L
s
.20561 .43852 m
.20561 .44227 L
s
.23855 .43852 m
.23855 .44227 L
s
.30443 .43852 m
.30443 .44227 L
s
.33736 .43852 m
.33736 .44227 L
s
.3703 .43852 m
.3703 .44227 L
s
.40324 .43852 m
.40324 .44227 L
s
.46911 .43852 m
.46911 .44227 L
s
.50205 .43852 m
.50205 .44227 L
s
.53499 .43852 m
.53499 .44227 L
s
.56792 .43852 m
.56792 .44227 L
s
.6338 .43852 m
.6338 .44227 L
s
.66674 .43852 m
.66674 .44227 L
s
.69967 .43852 m
.69967 .44227 L
s
.73261 .43852 m
.73261 .44227 L
s
.79849 .43852 m
.79849 .44227 L
s
.83142 .43852 m
.83142 .44227 L
s
.86436 .43852 m
.86436 .44227 L
s
.8973 .43852 m
.8973 .44227 L
s
.07386 .43852 m
.07386 .44227 L
s
.04093 .43852 m
.04093 .44227 L
s
.00799 .43852 m
.00799 .44227 L
s
.96317 .43852 m
.96317 .44227 L
s
.99611 .43852 m
.99611 .44227 L
s
.25 Mabswid
0 .43852 m
1 .43852 L
s
.43617 .04039 m
.44242 .04039 L
s
gsave
.42367 .04039 -89.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.43617 .12002 m
.44242 .12002 L
s
gsave
.42367 .12002 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.43617 .19964 m
.44242 .19964 L
s
gsave
.42367 .19964 -89.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.43617 .27927 m
.44242 .27927 L
s
gsave
.42367 .27927 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.43617 .35889 m
.44242 .35889 L
s
gsave
.42367 .35889 -89.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.43617 .51814 m
.44242 .51814 L
s
gsave
.42367 .51814 -82.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.43617 .59777 m
.44242 .59777 L
s
gsave
.42367 .59777 -77.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.43617 .05632 m
.43992 .05632 L
s
.43617 .07224 m
.43992 .07224 L
s
.43617 .08817 m
.43992 .08817 L
s
.43617 .10409 m
.43992 .10409 L
s
.43617 .13594 m
.43992 .13594 L
s
.43617 .15187 m
.43992 .15187 L
s
.43617 .16779 m
.43992 .16779 L
s
.43617 .18372 m
.43992 .18372 L
s
.43617 .21557 m
.43992 .21557 L
s
.43617 .23149 m
.43992 .23149 L
s
.43617 .24742 m
.43992 .24742 L
s
.43617 .26334 m
.43992 .26334 L
s
.43617 .29519 m
.43992 .29519 L
s
.43617 .31112 m
.43992 .31112 L
s
.43617 .32704 m
.43992 .32704 L
s
.43617 .34297 m
.43992 .34297 L
s
.43617 .37482 m
.43992 .37482 L
s
.43617 .39074 m
.43992 .39074 L
s
.43617 .40667 m
.43992 .40667 L
s
.43617 .42259 m
.43992 .42259 L
s
.43617 .45444 m
.43992 .45444 L
s
.43617 .47037 m
.43992 .47037 L
s
.43617 .48629 m
.43992 .48629 L
s
.43617 .50222 m
.43992 .50222 L
s
.43617 .53407 m
.43992 .53407 L
s
.43617 .55 m
.43992 .55 L
s
.43617 .56592 m
.43992 .56592 L
s
.43617 .58185 m
.43992 .58185 L
s
.43617 .02447 m
.43992 .02447 L
s
.43617 .00854 m
.43992 .00854 L
s
.43617 .6137 m
.43992 .6137 L
s
.25 Mabswid
.43617 0 m
.43617 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.43617 .43852 m
.48907 .48841 L
.55046 .53777 L
.5868 .56071 L
.62384 .57897 L
.64657 .58764 L
.66814 .59411 L
.68041 .59703 L
.69398 .59961 L
.70027 .60058 L
.70699 .60146 L
.71279 .60208 L
.71915 .60262 L
.72517 .60299 L
.73078 .60322 L
.73616 .60332 L
.74191 .60331 L
.74757 .60317 L
.7529 .60293 L
.75769 .60263 L
.76287 .60219 L
.7748 .60077 L
.78078 .59984 L
.78732 .59865 L
.80942 .59325 L
.82961 .5863 L
.85032 .57694 L
.88448 .55555 L
.90254 .5404 L
.9175 .52512 L
.93163 .50762 L
.94484 .48735 L
.95371 .47047 L
.9615 .45199 L
.96783 .43234 L
.97009 .42343 L
.97208 .41394 L
.97367 .40448 L
.97477 .39593 L
.97519 .39183 L
.97555 .38741 L
.97582 .38324 L
.97601 .37942 L
.97614 .37499 L
.97619 .37087 L
.97616 .36638 L
.97611 .36386 L
.97604 .36158 L
.97584 .35701 L
.97568 .35444 L
Mistroke
.97552 .35207 L
.97468 .34317 L
.97346 .33394 L
.972 .3254 L
.96852 .30985 L
.96374 .29372 L
.95748 .27704 L
.9446 .25075 L
.92759 .22469 L
.90712 .20062 L
.88599 .1811 L
.86252 .16393 L
.83902 .1504 L
.81707 .14049 L
.80447 .13584 L
.79249 .13207 L
.77976 .12872 L
.76799 .12619 L
.75481 .12398 L
.74786 .12308 L
.74053 .12231 L
.73382 .12178 L
.73006 .12155 L
.72665 .12138 L
.72345 .12126 L
.71999 .12117 L
.71672 .12112 L
.7137 .12111 L
.71018 .12113 L
.70689 .1212 L
.705 .12125 L
.70328 .1213 L
.69941 .12147 L
.69569 .12167 L
.69164 .12195 L
.68428 .12259 L
.67131 .12415 L
.65914 .12611 L
.63153 .13236 L
.60489 .14076 L
.57654 .15229 L
.52576 .17987 L
.47411 .21731 L
.3826 .30472 L
.32674 .36394 L
.2629 .42427 L
.21968 .45575 L
.20531 .46411 L
.18836 .47249 L
.17214 .47888 L
Mistroke
.16207 .48199 L
.152 .4844 L
.14216 .48603 L
.13081 .48696 L
.11958 .48678 L
.10886 .48545 L
.09821 .48288 L
.08878 .47938 L
.0785 .47404 L
.06968 .46791 L
.06119 .46028 L
.05357 .45158 L
.04305 .43535 L
.03864 .42631 L
.03528 .41801 L
.03227 .40906 L
.02974 .39981 L
.02795 .39172 L
.02643 .38305 L
.0254 .37541 L
.0247 .36844 L
.0244 .36453 L
.02415 .36048 L
.02388 .3534 L
.02382 .34954 L
.02381 .346 L
.02385 .34217 L
.02395 .33814 L
.02424 .33151 L
.02447 .32785 L
.02471 .32452 L
.02592 .31231 L
.02735 .3017 L
.02916 .29094 L
.03768 .25519 L
.04349 .23696 L
.04937 .22107 L
.07815 .16276 L
.10723 .12104 L
.13861 .08708 L
.17385 .05857 L
.20797 .03861 L
.22719 .03023 L
.24466 .02426 L
.25326 .02187 L
.26233 .01973 L
.27018 .01819 L
.27859 .01686 L
.28333 .01625 L
.28765 .01578 L
Mistroke
.29205 .0154 L
.2961 .01512 L
.29835 .01499 L
.30083 .01488 L
.30333 .0148 L
.30469 .01477 L
.30597 .01474 L
.30717 .01473 L
.30832 .01472 L
.31047 .01472 L
.31278 .01474 L
.31409 .01476 L
.3153 .01478 L
.31756 .01485 L
.31996 .01495 L
.32424 .01518 L
.32885 .01553 L
.33391 .01601 L
.34297 .01716 L
.35143 .01855 L
.36723 .02198 L
.38415 .02686 L
.42142 .04205 L
.4567 .06218 L
.52435 .117 L
.60003 .20371 L
.64242 .26238 L
.69123 .33517 L
.71862 .37652 L
.73741 .40415 L
.74416 .41372 L
.75356 .42645 L
.76282 .42728 L
.7565 .41328 L
.72168 .34708 L
.69861 .30681 L
Mfstroke
1 0 0 r
.02 w
.1068 .43852 Mdot
.76555 .43852 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{287.5, 177.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000/B000`400?l00000o`00003oO@3oool0
0`000000oooo0?ooo`2O0?ooo`00O@3oool00`000000oooo0?ooo`2O0?ooo`00O@3oool200000:00
oooo001m0?ooo`030000003oool0oooo09l0oooo001A0?oooa4000006`3oool00`000000oooo0?oo
o`2O0?ooo`00BP3oool700000140oooo1P00000E0?ooo`030000003oool0oooo09l0oooo00170?oo
o`<000007P3oool500000100oooo00<000000?ooo`3oool0W`3oool004@0oooo0`00000V0?ooo`<0
00003@3oool200000:00oooo00100?ooo`@00000;03oool2000000/0oooo00<000000?ooo`3oool0
W`3oool003h0oooo0P00000V0?ooo`<000000P3oool00`000000oooo00000003000000040?ooo`00
00000000000000P0oooo00<000000?ooo`3oool0W`3oool003`0oooo0P00000Y0?ooo`030000003o
ool0oooo00<0oooo00L000000?ooo`3oool000000?ooo`000000oooo008000001`3oool00`000000
oooo0?ooo`2O0?ooo`00>P3oool2000002@0oooo100000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool3000000D0oooo0P00002P0?ooo`00>@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`02000000<0oooo00<000000?ooo`3oool0W`3oool003L0oooo0P00000^0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000000P0000050?ooo`80000000<0oooo0000003oool0X03oool0
03H0oooo00<000000?ooo`3oool0;@3oool2000000D0oooo00H000000?ooo`3oool000000?ooo`00
00090?ooo`800000X@3oool003@0oooo0P00000a0?ooo`030000003oool0oooo00@0oooo0P000002
0?ooo`@000001`3oool200000:00oooo000c0?ooo`030000003oool0oooo04L0oooo1000002N0?oo
o`00<@3oool2000004X0oooo00D000000?ooo`3oool0oooo0000002M0?ooo`00<03oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0080oooo0P00002K0?ooo`00;`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool002h0oooo00<0
00000?ooo`3oool0C03oool2000000H0oooo00<000000?ooo`3oool0U`3oool002`0oooo0P00001?
0?ooo`030000003oool0oooo00H0oooo0P00002G0?ooo`00:`3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0U03oool002X0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09<0oooo000Y0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool02P3oool2000009<0oooo000X0?ooo`030000003o
ool0oooo0580oooo0P00000=0?ooo`030000003oool0oooo0900oooo000W0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2?0?ooo`009P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo00h0oooo0P00002?0?ooo`009@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0S03oool002@0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08/0oooo
000S0?ooo`030000003oool0oooo05L0oooo0P00000C0?ooo`800000R`3oool00280oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo08P0oooo000Q0?oo
o`030000003oool0oooo04l0oooo0`0000070?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0Q`3oool00200oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0QP3oool001l0oooo00<000000?ooo`3oool0
BP3oool4000000@0oooo00<000000?ooo`3oool01P3oool2000001L0oooo00<000000?ooo`3oool0
;`3oool8000004l0oooo000O0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo2P0000080?ooo`/00000A03o
ool001h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool07`3oool4000001d0oooo0`0000110?ooo`007@3oool00`00
0000oooo0?ooo`1C0?ooo`800000203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01X0oooo1000000T0?ooo`@00000?@3oool001`0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05@3oool4000002`0
oooo0`00000j0?ooo`00703oool00`000000oooo0?ooo`1N0?ooo`800000703oool00`000000oooo
0?ooo`0A0?ooo`<00000<`3oool4000003H0oooo000K0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?ooo`<00000>P3oool2000003@0oooo000J
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:
0?ooo`<00000?`3oool300000340oooo000I0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`<00000A@3oool2000002l0oooo000I0?ooo`03
0000003oool0oooo0640oooo0P00000O0?ooo`030000003oool0oooo00<0oooo0P00001:0?ooo`80
0000;@3oool001P0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00800000CP3oool00`000000oooo0?ooo`0Z0?ooo`005`3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo0200oooo0P00001A0?ooo`800000:P3oool001H0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0N0?ooo`80000000<0oooo0000003oool0DP3oool0
0`000000oooo0?ooo`0W0?ooo`005P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
01d0oooo00D000000?ooo`3oool0oooo0000001D0?ooo`8000009`3oool001D0oooo00<000000?oo
o`3oool0I@3oool2000001`0oooo0P0000050?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool0903oool001D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0I0?ooo`80
0000203oool00`000000oooo0?ooo`1C0?ooo`800000903oool001@0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`0G0?ooo`8000002`3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0240oooo000D0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool05@3o
ool2000000h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0P0?ooo`004`3oool0
0`000000oooo0?ooo`1W0?ooo`8000005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo05@0oooo0P00000P0?ooo`004`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01d0oooo000B0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool04@3oool2000001@0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0L0?ooo`004P3oool00`000000oooo
0?ooo`1A0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`800000203oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0K0?ooo`004P3oool00`000000oooo0?ooo`1@0?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool2000001T0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0J0?oo
o`004@3oool00`000000oooo0?ooo`1<0?ooo`@0000000D0oooo0000003oool0oooo000000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000h0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01T0oooo000A0?ooo`03
0000003oool0oooo0540oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool06@3oool00100oooo00<000000?ooo`3o
ool0DP3oool010000000oooo0?ooo`0000070?ooo`030000003oool0000000800000203oool00`00
0000oooo0?ooo`0:0?ooo`8000007`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01P0oooo000@0?ooo`030000003oool0oooo0580oooo00@000000?ooo`3oool00000103oool01P00
0000oooo0?ooo`000000oooo000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool000l0oooo00<00000
0?ooo`3oool0E03oool2000000D0oooo100000000`3oool0000000000002000000L0oooo0P000009
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`003`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo0P00000U0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000h0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`003P3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01<0oooo000=0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04`3o
ool000d0oooo00<000000?ooo`3oool0K@3oool2000000<0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000<0?ooo`030000003oool0oooo
06h0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04@3oool000`0oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`00000a
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0403oool000`0oooo00<000000?oo
o`3oool0KP3oool00`000000oooo0000000b0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0403oool000`0oooo00<000000?ooo`3oool0KP3oool2000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0?0?ooo`002`3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0>0?ooo`002`3o
ool00`000000oooo0?ooo`1^0?ooo`800000=`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo00h0oooo000;0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`000000=`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00d0oooo000;0?ooo`030000003oool0oooo
06`0oooo00@000000?ooo`3oool00000>03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00d0oooo000;0?ooo`030000003oool0oooo06/0oooo00@000000?ooo`3oool0oooo0P00000h
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool03@3oool000X0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0<0?ooo`002P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo05h0oooo0P0000030?ooo`030000
003oool0oooo0080000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0303oool000T0oooo00<000000?ooo`3oool0GP3o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000
003oool0oooo05T0oooo100000001@3oool000000?ooo`3oool0000000H0oooo0P0000070?ooo`80
0000>`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000
003oool0oooo05h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo000000070?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0:0?ooo`00
203oool00`000000oooo0?ooo`1O0?ooo`040000003oool0oooo000000@0oooo0`0000080?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0:0?ooo`00
203oool00`000000oooo0?ooo`1O0?ooo`040000003oool0oooo000000<0oooo0P00000:0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0:0?ooo`00
203oool00`000000oooo0?ooo`1P0?ooo`8000000`3oool00`000000oooo00000003000000L0oooo
0P00000n0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool02@3oool000P0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`090?ooo`00203oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo00P0oooo00080?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`080?ooo`001`3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0>0?ooo`800000@@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool01`3oool000L0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0oooo00070?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`060?ooo`001`3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01P3oool000L0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0B0?ooo`800000A03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01P3oool000L0oooo
00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00H0oooo
00070?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`060?ooo`001`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool05`3oool2000004L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`030000003oool0000000<000000P3oool2000000P0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
E@3oool5000000050?ooo`000000oooo0?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00D0oooo0P00001:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
DP3oool2000000L0oooo00@000000?ooo`3oool000001`3oool00`000000oooo00000002000000P0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool000000?ooo`00000:
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool02@3oool2000000H0oooo0P0000020?ooo`@000001`3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0240oooo0P00001>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
1@3oool000P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo00080?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`050?ooo`00203oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
02D0oooo0P00001A0?ooo`050000003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`05
0?ooo`00203oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool01P3oool000P0oooo00<000000?ooo`3oool05P3oool3000002P0oooo0P0000030?ooo`03
0000003oool00000008000009`3oool00`000000oooo0?ooo`0V0?ooo`8000000`3oool00`000000
oooo0?ooo`0200000240oooo00D000000?ooo`3oool0oooo000000030?ooo`<00000:03oool30000
0080oooo00<000000?ooo`3oool00P0000080?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool09P3oool010000000oooo0?ooo`0000030?oo
o`8000000P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`00000Q0?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0?0?ooo`@00000
103oool00`000000oooo0?ooo`0P0?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0U0?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00090?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool09P3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?ooo`3oool0903o
ool2000002H0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0P0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`002@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P0000030?ooo`<00000
9`3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo000000@0oooo0`00000T0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?oo
o`<00000203oool00`000000oooo0?ooo`060?ooo`002@3oool00`000000oooo0?ooo`0E0?ooo`80
0000:03oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool09@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool0oooo0`00000Y0?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09`3oool2
000000D0oooo1000000V0?ooo`030000003oool0oooo02H0oooo0P0000050?ooo`@000008`3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000:P3oool00`000000oooo0?ooo`030?ooo`@00000
1`3oool00`000000oooo0?ooo`060?ooo`002P3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo02h0oooo0P00001F0?ooo`050000003oool0oooo0?ooo`000000>`3oool00`000000oooo
0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0l0?ooo`800000<@3oool00`000000oooo0?oo
o`1F0?ooo`040000003oool0oooo000003/0oooo00<000000?ooo`3oool01`3oool000/0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05L0oooo1000
000j0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000003oool0oooo00l0oooo0`3o000X
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0F@3oool30?l003P0oooo00<00000
0?ooo`3oool0203oool000`0oooo00<000000?ooo`3oool03@3oool50?l002D0oooo0P00000e0?oo
o`030000003oool0oooo05P0oooo1@3o000g0?ooo`030000003oool0oooo00P0oooo000L000000D0
o`00]`0000050?l00480000000020?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`030000
003oool0oooo00@0oooo1@3o00070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo1@3o00070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool2000000L0oooo0@0000010?ooo`40oooo
000>0?ooo`030000003oool0oooo00`0oooo0`3o000R0?ooo`8000002P3oool00`000000oooo0?oo
o`0/0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0:P3oool30?l002h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo0000002A0?ooo`030000
003oool0oooo00T0oooo000?0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02@3o
ool00100oooo00<000000?ooo`3oool0:`3oool2000003d0oooo0P0000040?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool02@3oool00140oooo0P00000Y0?ooo`800000?`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02P3oool001<0
oooo00<000000?ooo`3oool0903oool200000440oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo00/0oooo000D0?ooo`030000003oool0oooo0240oooo
0P0000130?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04<0oooo0P00
00080?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0303oool001H0oooo0P00000M
0?ooo`800000AP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0303oool001P0oooo00<000000?ooo`3oool05`3oool3000004P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo00d0oooo000I0?ooo`<0
00004@3oool5000004/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo00d0oooo000L0?ooo`H00000203oool300000500oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00d0oooo000R0?ooo`P00000D`3o
ool2000000d0oooo0P0000200?ooo`030000003oool0oooo00h0oooo001m0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0>0?ooo`00O@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool03`3oool007d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0100
oooo001m0?ooo`8000004P3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0100oooo
001m0?ooo`030000003oool0oooo0180oooo0P00001g0?ooo`030000003oool0oooo0140oooo001m
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0B
0?ooo`00IP3oool2000000<0oooo00<000000?ooo`0000000`0000020?ooo`800000203oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool04P3oool006D0
oooo00@000000?ooo`3oool00000103oool01P000000oooo0?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool04`3oool006D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo0P00000H0?ooo`800000K`3oool00`000000oooo0?oo
o`0D0?ooo`00I@3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool05@3oool006D0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0000
0002000000P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo01H0oooo001U0?ooo`040000003oool0oooo000000@0oooo00H000000?ooo`3oool00000
0?ooo`00000:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`0G0?ooo`00IP3oool2000000H0oooo0P0000020?ooo`@000001`3oool2000001d0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0H0?ooo`00O@3oool00`000000oooo0?oo
o`0M0?ooo`800000I03oool00`000000oooo0?ooo`0I0?ooo`00O@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05l0oooo0P00000L0?ooo`00O@3oool00`000000oooo0?ooo`0P0?oo
o`800000GP3oool00`000000oooo0?ooo`0L0?ooo`00O@3oool00`000000oooo0?ooo`0R0?ooo`80
0000F`3oool00`000000oooo0?ooo`0M0?ooo`00O@3oool2000002D0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0N0?ooo`00O@3oool00`000000oooo0?ooo`0U0?ooo`800000E@3o
ool200000240oooo001m0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0Q0?ooo`00O@3oool00`000000oooo0?ooo`0X0?ooo`800000C`3oool20000
02@0oooo001m0?ooo`800000:`3oool2000004`0oooo00<000000?ooo`3oool0903oool007d0oooo
00<000000?ooo`3oool0;03oool2000004T0oooo00<000000?ooo`3oool09@3oool007d0oooo00<0
00000?ooo`3oool0;P3oool2000004D0oooo0P00000X0?ooo`00O@3oool00`000000oooo0?ooo`0`
0?ooo`800000@P3oool00`000000oooo0?ooo`0X0?ooo`00O@3oool00`000000oooo0?ooo`0b0?oo
o`800000?P3oool2000002/0oooo001m0?ooo`800000=@3oool3000003P0oooo0`00000]0?ooo`00
O@3oool00`000000oooo0?ooo`0g0?ooo`800000<`3oool300000300oooo001[0?ooo`8000000`3o
ool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool0>@3oool4000002`0oooo0`00
000c0?ooo`00JP3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0?@3oool5000002@0oooo0`00000f0?ooo`00JP3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo00D0oooo0P0000130?ooo`<000007P3oool3000003T0oooo
001Z0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`150?ooo`D000004P3oool7000003`0oooo001Z0?ooo`040000003oool0oooo000000@0oooo
0`0000080?ooo`030000003oool0oooo04X0oooo4P0000130?ooo`00JP3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0W`3oool006/0oooo0P00
00050?ooo`@000001`3oool00`000000oooo0?ooo`2O0?ooo`00O@3oool200000:00oooo001m0?oo
o`030000003oool0oooo09l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 286.5}, {176.688, 0}} -> {-1.32937, -1.37683, \
0.0106328, 0.0109958}}]
}, Open  ]],

Cell[TextData[{
  "The fixed suns are indicated by ",
  StyleBox["\[FilledCircle]",
    FontSize->9,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " and the trajectory shows the motion of the planet."
}], "Warning"],

Cell[TextData[{
  "It is easy to turn these steps into a procedure which can be used to \
investigate the trajectory as a function of the initial velocity, ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_x, v\_y}\)]],
  ", and total time, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(TrajectoryPlot(vx_, vy_, \[Tau]_:  25)\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({ics, nsol}\), ",", 
            RowBox[{
              RowBox[{"ics", "=", 
                RowBox[{"{", 
                  RowBox[{\(x(0) == 0\), ",", \(y(0) == 0\), ",", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["x", "\[Prime]",
                          MultilineFunction->None], "(", "0", ")"}], "==", 
                      "vx"}], ",", 
                    RowBox[{
                      RowBox[{
                        SuperscriptBox["y", "\[Prime]",
                          MultilineFunction->None], "(", "0", ")"}], "==", 
                      "vy"}]}], "}"}]}], 
              ";", \(nsol = 
                NDSolve[Join[eqns, ics], {x, y}, {t, 0, \[Tau]}]\), 
              ";", \(ParametricPlot[
                Evaluate[{x(t), y(t)} /. \[InvisibleSpace]nsol], {t, 
                  0, \[Tau]}]\), ";"}]}], "]"}]}], TraditionalForm]], "Input"],

Cell[TextData[{
  " The syntax ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Tau]_:  25\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " means that if no total time is supplied it defaults to 25 time units."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". For ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(vy = 1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and vary ",
  StyleBox["vx", "InlineInputTraditionalForm"],
  " (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["vx",
            "Input"], "<", "1"}], TraditionalForm]]],
  ") and see if you can find an initial velocity that results in a \"figure-8\
\" orbit around the two suns. (",
  StyleBox["NB",
    FontSlant->"Italic"],
  ": maintain your intermediate attempts so that the steps towards a solution \
are apparent)."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Heat Equation"
}], "Section"],

Cell["\<\
It is well known that  diffusion  processes cause \
\[OpenCurlyQuote]smoothing\[CloseCurlyQuote]. For example in the thermal \
context one would expect any steepness in the temperature profile to be \
smoothed out as time goes on. In this section we will consider the scaled \
heat equation,\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[\(\[PartialD]Q\), \(\[PartialD]t\),
          MultilineFunction->None], "=", 
        RowBox[{
          FractionBox[\(\[PartialD]\^2 Q\), \(\[PartialD]x\^2\),
            MultilineFunction->None], "\[CenterDot]", Cell[""]}]}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  " to solve the scaled heat equation for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.4\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`Q(0, t) \[Equal] \ Q(1, t) \[Equal] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Q(x, 0) \[Equal] x\ \((1 - x)\)\)]],
  ". Visualize the solution as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " using ",
  StyleBox["Plot3D", "InlineInputTraditionalForm"],
  ". What can you say about the solution as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  "?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ".Visualize ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ \((\(tanh(k\ x - 5)\)\/\(tanh(5)\) + 1)\)\)]],
  " for various values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". For large values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " what type of function does this approximate well?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  " to solve the scaled heat equation for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`Q(0, t) \[Equal] 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Q(1, t) \[Equal] 1\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`Q(x, 0) \[Equal] 
        1\/2\ \((\(tanh(10\ x - 5)\)\/\(tanh(5)\) + 1)\)\)]],
  ". Visualize the solution as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " using ",
  StyleBox["Plot3D", "InlineInputTraditionalForm"],
  ". What can you say about the solution as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  "?"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Normal Modes of Coupled Oscillators"
}], "Section"],

Cell[TextData[{
  "In this section you will explore the natural frequencies and normal modes \
of a system of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " coupled oscillators.  The case with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 3\)]],
  " looks like:"
}], "Text",
  CellTags->{"natural frequencies", "normal modes", "coupled oscillators"}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006;0000O0P10`4000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^OShn03ooeGooj[oooclo5H/1EGooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_Oclo5D00:X00?l00000EED0EJX00=d81Slo?ginO[fm_Oclo0<30d92@X61PL30`000
EED0EJX0EOl0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0ZP00
e5D0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9RLS8b000oeD0ojX0ool0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=SLc<c01E05EE0:YE0?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVMSHf01EoeEEojYEoomEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][Nc/k03o05Go0:[o0?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0S0000?l0S0000?l0S0000?l0;P03oe/0
003o02d000Go0000o`1J0000H@000ol0001O00GoJ0000ol0001H0000H@000ol0001P0003o`0006H0
0omK0000H@000ol0001Q0003o`0006H000?o0000FP00064000?o0000HP000ol0001V0005o`000?l0
20000ol0001<0000H@000ol0001S0003o`0005`000Ko0000o`05o`030?l000@00_l30003o`0004/0
001P00;o10000ol000060003o`00054000Go0000o`020003o`0000H000?o0000D0001Ol0003o00L0
00?o00000P000ol000030003o`0004/0001I0005o`000?l00`001Ol0003o00D00_l30003o`0004X0
00Go0000o`0200?o0P000ol0000300;o0`000ol0001@0003o`3o00L000?o00000`000ol000040003
o`0004X0001I0005o`000?l01`000ol000020003o`0000<000?o0000BP001Ol0003o00L000?o0000
0P000ol000030003o`00054000?o00001P000ol000030003o`0000@000?o0000BP0005X000?o0?l0
1`000ol000030003o`0000@000?o0000BP000ol0o`070003o`0000<000?o000010000ol0001?0003
o`3o00L000?o00000`000ol000040003o`0004X0001K0003o`0000H000?o00000`000ol000040003
o`0004/000?o00001P000ol000030003o`0000@000?o0000CP001Ol0003o00H000?o00000`000ol0
00040003o`0004X0001J0003o`3o00L000?o00000`000ol000040003o`0004X000?o0?l01`000ol0
00030003o`0000@000?o0000CP001Ol0003o00H000?o00000P03o`D000?o0000BP0005T000Go0000
o`060003o`0000<000?o000010000ol000190005o`000?l01P000ol000030003o`0000@000?o0000
FP000ol000020003o`0000<000?o0000B`0005T000Go0000o`060003o`0000800ol50003o`0004T0
00Go0000o`060003o`0000800ol50003o`0005X000?o00000P000ol000030003o`0004/0001U0003
o`00008000?o00000`000ol0001F0003o`00008000?o00000`000ol0001L0003o`0000H000?o0000
C00006D000?o00000P000ol000030003o`0005H000?o00000P000ol000030003o`000;@0001V0003
o`0000H000?o0000F0000ol000060003o`000;D0003o08`0003o08`0003o08`0003o02d000?o0000
G0000?l0;@000ol0001L0000G`000ol0001Q0003o`0006H000?o0000G00005l000?o0000H@000ol0
001V0003o`0005`0001O0003o`00064000?o0000IP000ol0001L0000G`000ol0001Q0003o`0004L0
0olL0003o`0001l00_lk0000G`000ol0001Q0003o`0004<01olL0003o`0001l01_lg0000@003oa`0
00?o00007`02ob400olL0003o`0001l00_lO05;o<`0003`01olL0003o`0001l01_lI00Oo70000ol0
000O00Ko7P07oa`000?o00007`06ocL0000i05;o4P1Boah00olL0003o`0001l00_lk0000?007oa`0
00?o00007`06oaT01olL0003o`0001l01_m10003o`0005`0001000?o70000ol0000O00;o8@03oa`0
00?o00007`02odD000?o0000G00005l000?o0000H@000ol0001V0003o`0005`0001O0003o`000640
00?o0000a@0005l000?o0000H@000ol000350000o`2<0000o`2<0000o`2<0000o`2<0000o`2<0000
o`2<00001000o_l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l00_l0Q03o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`<00000oP3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0P00ROl0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o00800002003no`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`02o`260?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l300000?h0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`8008Wo0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`0200000P00o_l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l00_l0QP3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0`00003n0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l20029o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l00P0000800?ko0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o00;o08H0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`<00000oP3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0P00ROl0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o00800002003no`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`02o`260?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l300000?h0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`8008Wo0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`0200000P00o_l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l00_l0QP3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0`00003n0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l20029o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l00P0000800?ko0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o00;o08H0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`<00000oP3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o
0?l0o`3o0?l0o`3o0P00N_l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0o`3o0?l0
o`3o0?l0o`3o0?l0o`3o0?l01?l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l0oombo`0:
0?l0o`3o0?l0o`8000003@3o0?l0o`3o0?l0o`00oombo`0<0?l0o`3o0?l0o`3o0@00008000co0?l0
o`3o0?l0o`02ocT000?o0000:P000ol0000e0003o`0002X000?o0000>0000ol0000Z0003o`0003H0
0ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o>@000ol0000Z0003o`0003D000?o0000
:P000ol0000h0003o`0002X000?o0000=P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0
o`02ocT000?o0000:P000ol0000e0003o`0002X000?o0000>0000ol0000Z0003o`0003H00ol02P3o
0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o>@000ol0000Z0003o`0003D000?o0000:P000ol0
000h0003o`0002X000?o0000=P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT0
00?o0000:P000ol0000e0003o`0002X000?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o
0?l2000000d0o`3o0?l0o`3o0?l000?o>@000ol0000Z0003o`0003D000?o0000:P000ol0000h0003
o`0002X000?o0000=P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000
:P000ol0000e0003o`0002X000?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o0?l20000
00d0o`3o0?l0o`3o0?l000?o>@000ol0000Z0003o`0003D000?o0000:P000ol0000h0003o`0002X0
00?o0000=P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000:P000ol0
000e0003o`0002X000?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o0?l2000000d0o`3o
0?l0o`3o0?l000?o>@000ol0000Z0003o`0003D000?o0000:P000ol0000h0003o`0002X000?o0000
=P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000:P000ol0000e0003
o`0002X000?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o
0?l000?o>@000ol0000Z0003o`0003D000?o0000:P000ol0000h0003o`0002X000?o0000=P02o`0<
0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000:P000ol0000e0003o`0002X0
00?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o
>@000ol0000Z0003o`0003D000?o00005`05o`h000?o0000>0000ol0000J00?o3@000ol0000f00;o
00`0o`3o0?l0o`3o0?l100000P003?l0o`3o0?l0o`3o00;o1`000ol000090003o`0000T00_l;0003
o`0000T00_l/0003o`0000@000?o00002@000ol0000900;o2`000ol000090003o`0001P000?o0000
3`000ol000060003o`0000T000?o00002@02o`/000?o00002@02oa/000Go0000o`0<0003o`0000D0
00?o00002@000ol0000900;o2`000ol0000900?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o
0003o`H00_l;0003o`0000T00_l;0003o`0000T00_lM0003o`0000`000?o00000`02o`/000?o0000
2@02o`/000?o00002@000ol0000I0003o`0000h000?o00001@02o`/000?o00002@02o`/000?o0000
2@02oal000?o00002P000ol0000400;o2`000ol0000900;o2`000ol0000900;o00`0o`3o0?l0o`3o
0?l100000P003?l0o`3o0?l0o`3o00;o1P000ol0o`0900;o2P001?l00?l90003o`3o00T000?o0?l0
7@000ol0000<0003o`0000<000?o0?l02@02o`X000Co003o2@000ol0o`0900;o70000ol0000=0003
o`0000D000?o0?l02@02o`X000Co003o2@000ol0o`090003o`3o01`00ol=0003o`0000@000?o0?l0
2@02o`X000Co003o2@000ol0o`0900Co00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o0003o`D0
00Co003o2@000ol0o`090004o`00o`T000?o0?l02@000ol0o`0M0003o`0000`000?o00000P001?l0
0?l90003o`3o00T000Co003o2@000ol0o`0900;o7@000ol0000<0003o`0000@000Co003o2@000ol0
o`090004o`00o`T000?o0?l02@000ol0o`0M0003o`0000`000?o00000`001?l00?l90003o`3o00T0
00Co003o2@000ol0o`0900?o00`0o`3o0?l0o`3o0?l100000P003?l0o`3o0?l0o`3o00;o1@001Ol0
003o00L000Co003o20000ol000020003o`0000D000Go0000o`070004o`00oad000?o000030000ol0
00020005o`000?l01`001?l00?l80003o`00008000?o00001@001Ol0003o00L000?o0?l06@001Ol0
003o00h000?o000010001Ol0003o00L000Co003o20000ol000020003o`0000D000Go0000o`070004
o`00oah000?o00002`000ol000030005o`000?l01`001?l00?l80003o`00008000?o00001@001Ol0
003o00L000?o0?l00_l02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o10000ol000020003
o`0000D000Go0000o`070003o`00008000?o00001@001Ol0003o00L000Co003o7@000ol0000<0005
o`000?l010000ol000050005o`000?l01`000ol000020003o`0000D000Go0000o`070003o`3o01X0
0ol?0003o`0000<000?o00000P000ol000050005o`000?l01`000ol000020003o`0000D000Go0000
o`070004o`00oa/01Ol<0003o`00008000?o00000P000ol000050005o`000?l01`000ol000020003
o`0000D000Go0000o`07000@o`3oo`3o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_l40003
o`00008000?o00001@001Ol0003o00L000?o00000P000ol000040003o`00008000?o000010001Ol0
003o01`00_l>0005o`000?l010000ol000050005o`000?l01`000ol000020003o`0000@000?o0000
0P000ol000040004o`00ob`000?o00000`000ol000020003o`0000D000Go0000o`070003o`000080
00?o000010000ol000020003o`0000@000Go0000o`0/0003o`00008000?o00000P000ol000050005
o`000?l01`000ol000020003o`0000@000?o00000P000ol000040003o`0000?o00X0o`3o0?l0o`3o
0P00000=0?l0o`3o0?l0o`3o0003o`@000?o00000`000ol000030003o`00008000?o000010000ol0
00040003o`0000<000?o00000`000ol000030005o`000?l07@000ol0000<0005o`000?l01@000ol0
00030003o`00008000?o000010000ol000040003o`0000<000?o00000`000ol000030004o`00o`X0
00Go0000o`030003o`0001L000?o00000`000ol000030003o`0000<000?o00000P000ol000040003
o`0000@000?o00000`000ol000030003o`0000<000Go0000o`0<0005o`000?l00`000ol0000E0003
o`00008000?o00000`000ol000030003o`00008000?o000010000ol000040003o`0000<000?o0000
0`000ol000030003o`0000;o00`0o`3o0?l0o`3o0?l100000P003?l0o`3o0?l0o`3o00;o0`000ol0
00040003o`0000<000?o00000`000ol000030003o`0000@000?o00000P000ol000040003o`000080
00?o00000P000ol0000:0005o`000?l00`000ol0000E0004o`00o`H000?o00000`000ol000030003
o`0000<000?o000010000ol000020003o`0000@000?o00000P001Ol0003o00X000Go0000o`030003
o`0001L000?o00000P000ol000040003o`0000<000?o00000`000ol000030003o`0000@000?o0000
0P000ol000040003o`00008000?o00000P000ol0000:0005o`000?l00`000ol0000E0005o`000?l0
1P000ol000030003o`0000<000?o00000`000ol000040003o`00008000?o000010000ol000020004
o`0000?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o0003o`<000?o00001@001Ol0003o00H0
00?o00000P000ol000060005o`000?l01`001Ol0003o00@000?o00002P001Ol0003o00<000?o0000
5@001?l00?l70005o`000?l01P000ol000020003o`0000H000Go0000o`070005o`000?l00`000ol0
00080005o`000?l00`000ol0000G0003o`00008000?o00001@001Ol0003o00H000?o00000P000ol0
00060005o`000?l01`001Ol0003o00@000?o00002P001Ol0003o00<000?o00005@001Ol0003o00L0
00Go0000o`060003o`00008000?o00001P001Ol0003o00L000Go0000o`0300;o00`0o`3o0?l0o`3o
0?l100000P003?l0o`3o0?l0o`3o00;o0P000ol000060005o`000?l01`001Ol0003o00P000Co003o
20001?l00?l50003o`0000X000Go0000o`030003o`0001D000?o0?l020001Ol0003o00L000Go0000
o`080004o`00o`P000Co003o10000ol000080005o`000?l00`000ol0000G0005o`000?l020001Ol0
003o00L000Go0000o`080004o`00o`P000Co003o1@000ol0000:0005o`000?l00`000ol0000E0004
o`00o`P000Go0000o`070005o`000?l020001?l00?l80004o`00o`@00ol02P3o0?l0o`3o0?l20000
00d0o`3o0?l0o`3o0?l000?o0P000ol000070003o`3o00P000Co003o2P000ol0o`090003o`3o00D0
00?o00002P001Ol0003o00<000?o00005@000ol0o`090003o`3o00P000Co003o2P000ol0o`090003
o`3o00@000?o000020001Ol0003o00<000?o00005`001Ol0003o00T000?o0?l020001?l00?l:0003
o`3o00T000?o0?l01@000ol0000:0005o`000?l00`000ol0000E0004o`00o`T000?o0?l020001?l0
0?l:0003o`3o00T000?o0?l01002o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02o`03
0?l000T000?o0?l02@000ol0o`0:00;o2P02o`H000?o00002P001Ol0003o00<000?o00005@02o`X0
00?o0?l02@000ol0o`0:00;o2P02o`D000?o00002002o`800_l20003o`0001L000Co003o2P000ol0
o`090003o`3o00X00_l:00;o1P000ol0000:00;o0P02o`8000?o00005@000ol0o`0:0003o`3o00T0
00?o0?l02P02o`X00_l500?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o0003o`030?l000T0
00?o0?l02@000ol0o`0:00;o2P02o`H000?o00002P02o`800_l20003o`0001D00_l:0003o`3o00T0
00?o0?l02P02o`X00_l50003o`0000P000Co0?oo0P02oaX000Co003o2P000ol0o`090003o`3o00X0
0_l:00;o1P000ol0000:0004o`3oo`800_lH0003o`3o00X000?o0?l02@000ol0o`0:00;o2P02o`D0
0_l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_l00`3o000:0003o`0000P00_l;00;o
2P02o`H000?o00002P001?l0ool200;o6002o`/000?o00002002o`/00_l:00;o1@000ol0000Z0004
o`00o`/000?o00002002o`/00_l:00;o1P000ol0000Z0003o`3o00/000?o00002002o`/00_l:00;o
1@03o`0:0?l0o`3o0?l0o`8000003@3o0?l0o`3o0?l0o`001?lH0003o`0001d000?o0000:P000ol0
000F0003o`0001`000?o0000:P000ol0o`0H0003o`0001d000?o0000:P02oaP000?o00007002o`0<
0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000:P000ol0000e0003o`0002X0
00?o0000>0000ol0000Z0003o`0003H00ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o
>@000ol0000Z0003o`0003D000?o0000:P000ol0000h0003o`0002X000?o0000=P02o`0<0?l0o`3o
0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ocT000?o0000:P000ol0000e0003o`0002X000?o0000
>0000ol0000Z0003o`0002D000?o00003P03o`0:0?l0o`3o0?l0o`8000003@3o0?l0o`3o0?l0o`00
0oli0003o`0002X000?o0000=@000ol0000Z0003o`0003P000?o0000:P000ol0000U0003o`0000h0
0_l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_li0003o`0002X000?o0000=@000ol0
000Z0003o`0003P000?o0000:P000ol0000R00Go3`03o`0:0?l0o`3o0?l0o`8000003@3o0?l0o`3o
0?l0o`000oli0003o`0002X000?o0000=@000ol0000Z0003o`0002<00olB0003o`0002X000?o0000
8P001?l00?l@00;o00`0o`3o0?l0o`3o0?l100000P003?l0o`3o0?l0o`3o00;o8@000ol0000E0003
o`0002X000?o0000=@000ol0000Z0003o`00028000Go0000o`0A0003o`0002X000?o00005P001Ol0
003o00P000?o0?l04003o`0:0?l0o`3o0?l0o`8000003@3o0?l0o`3o0?l0o`000olQ0003o`0001D0
00?o0000:P000ol0000N00Go4P000ol0000Z0003o`0002H000?o00003`000ol0000Z0003o`0001H0
00Co003o2P02oa000_l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_lQ0003o`0001D0
00?o0000:P000ol0000O0003o`0001<000?o0000:P000ol0000S00?o4P000ol0000Z0003o`0001H0
00?o0?l030000ol0000>00?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o0003ob4000?o0000
5@000ol0000Z0003o`00020000?o00004P000ol0000Z0003o`0001H000Go0000o`090003o`000140
00?o0000:P000ol0000F00;o7P02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ob40
00?o00005@000ol0000Z0003o`00024000?o00004@000ol0000Z0003o`0001H000Co003o2`000ol0
000@0003o`0002X000?o00005P000ol0o`0M00?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o
0003oa@000?o00002@02oaL000?o0000:P000ol0000B0005o`000?l02`000ol0000@0003o`0002X0
00?o00005P000ol0o`0900Go4@000ol0000Z0003o`0001H000Co003o7002o`0<0?l0o`3o0?l0o`3o
0@00008000co0?l0o`3o0?l0o`02oa@000Co003o2@000ol0000E0003o`0002X000?o00004P001?l0
0?l80005o`000?l04P0^oaP00_lP02ko60001Ol0003o01/00ol02P3o0?l0o`3o0?l2000000d0o`3o
0?l0o`3o0?l000?o50000ol0o`0R02ko50000ol0o`0:00?oF@000ol0o`1U0003o`0001d00_l0303o
0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_lD00;oI@02ofL000Co003oI0000ol0000M00?o
00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o0003oa@000?o0?l0I0000ol0o`1V0005o`000?l0
P`02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02oa@000Co003oH`001?l00?mU0003
o`0008D00ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?o50001Ol0003o068000Go0000
o`1T0003o`0008D00_l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l00_lD0003o`0006@0
00?o0000kP03o`0:0?l0o`3o0?l0o`8000003@3o0?l0o`3o0?l0o`000olD0003o`0006@000?o0000
kP02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ool0K@03o`0:0?l0o`3o0?l0o`80
00003@3o0?l0o`3o0?l0o`000ooo06d00_l0303o0?l0o`3o0?l0o`400002000<o`3o0?l0o`3o0?l0
0_oo06d00ol02P3o0?l0o`3o0?l2000000d0o`3o0?l0o`3o0?l000?oo`1]00;o00`0o`3o0?l0o`3o
0?l100000P003?l0o`3o0?l0o`3o00;oo`1]00?o00X0o`3o0?l0o`3o0P00000=0?l0o`3o0?l0o`3o
0003ool0K@02o`0<0?l0o`3o0?l0o`3o0@00008000co0?l0o`3o0?l0o`02ool0K@03o`0:0?l0o`3o
0?l0o`8000003@3o0?l0o`3o0?l0o`000ooo07`00002000<o`3o0?l0o`3o0?l00_oo07`000003@3o
0?l0o`3o0?l0o`000ooo07`0003o08`0003o08`0003o08`00000\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{395, 124},
  ImageMargins->{{32, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The parameters ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  " are the spring constants; ",
  Cell[BoxData[
      \(TraditionalForm\`m\_i\)]],
  " are the masses of the blocks; and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_i\)(t)\)]],
  " are the displacements from the equilibrium positions."
}], "Text",
  CellTags->"equilibrium"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Equations of Motion"
}], "Subsection"],

Cell[CellGroupData[{

Cell["Fixed end-points", "Subsubsection"],

Cell[TextData[{
  "In this section we focus on the case where the end-points are ",
  StyleBox["fixed",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the boundary conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_0\)(t) \[Equal] \(x\_\(N + 1\)\)(t) \[Equal] 
        0\)]],
  ". For a system of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " coupled oscillators, the equation of motion for ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\)]],
  "reads:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(m\_1\), " ", 
            RowBox[{
              SubsuperscriptBox["x", "1", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], 
          "==", \(k\_2\ \((\(x\_2\)(t) - \(x\_1\)(t))\) - 
            k\_1\ \(\(x\_1\)(t)\)\)}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "Symbolic analysis of the case with general values for ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\_i\)]],
  " is quite complicated.  We will firstly examine the case where all the ",
  Cell[BoxData[
      \(TraditionalForm\`k\_i\)]],
  " are equal to ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and all the ",
  Cell[BoxData[
      \(TraditionalForm\`m\_i\)]],
  " equal ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". This case can be obtained using a ",
  StyleBox["substitution rule",
    FontSlant->"Italic"],
  ", ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", "
}], "Text",
  CellTags->{"substitution rule", "replacement rule"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`% /. \[InvisibleSpace]{m\_n_ \[Rule] m, 
          k\_n_ \[Rule] k} // Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"m", " ", 
          RowBox[{
            SubsuperscriptBox["x", "1", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}]}], 
        "==", \(k\ \((\(x\_2\)(t) - 2\ \(\(x\_1\)(t)\))\)\)}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the case of equal masses and spring constants, introducing the \
frequency (time-scale), ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(k/m\)\)]],
  ", (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", rescaling time by this factor) ",
  "the equations can be cast into the ",
  StyleBox["dimensionless",
    FontSlant->"Italic"],
  " form:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubsuperscriptBox["x", "i", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], " ", 
          "\[Equal]", \(\(x\_\(i + 1\)\)(t) - 
            2 \(\( x\_i\)(t)\) + \(x\_\(i - 1\)\)(t)\)}], 
        ",", \(1 \[LessEqual] i \[LessEqual] \(\(N\)\(.\)\)\)}], 
      TraditionalForm]], "NumberedEquation"],

Cell["For the following we set", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalN] = 4; \)], "Input"],

Cell[TextData[{
  StyleBox["i.e.",
    FontSlant->"Italic"],
  StyleBox[", 4 masses. The fixed end-point boundary conditions are",
    FontSlant->"Plain"]
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(x\_0\)(t_) = 0; \)], "Input"],

Cell["and", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(x\_\(\[ScriptCapitalN] + 1\)\)(t_) = 0; \)], "Input"],

Cell[TextData[{
  "and the equations of motion for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " masses are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalE]\_n_\), ":=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SubsuperscriptBox["x", "n", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "t", ")"}], 
            "==", \(\(x\_\(n - 1\)\)(t) + \(x\_\(n + 1\)\)(t) - 
              2\ \(\(x\_n\)(t)\)\)}], 
          "/;", \(1 \[LessEqual] n \[LessEqual] \[ScriptCapitalN]\)}]}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter these expressions and display the set of equations for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], \[ScriptCapitalN]\)]],
  " in a table (",
  StyleBox["TableForm", "InlineInputTraditionalForm"],
  " will be helpful)."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrix form of the equations", "Subsubsection"],

Cell[TextData[{
  "Since the motion of each mass is expected to be ",
  StyleBox["simple-harmonic",
    FontSlant->"Italic"],
  ", one can propose that the solution is of the form (this is called an ",
  StyleBox["ans\[ADoubleDot]tz",
    FontSlant->"Italic"],
  "):"
}], "Text",
  CellTags->"simple-harmonic"],

Cell[BoxData[
    \(TraditionalForm\`\(x\_i_\)(t_) = 
      c\_i\ \(cos(\[CapitalOmega]\ t)\); \)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter this expression. Simplify and display the equations, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalE]\_n\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], \[ScriptCapitalN]\)]],
  " in a table. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": You should find that ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[CapitalOmega]\ t)\)]],
  " appears on both sides of each equation. Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[CapitalOmega]\ t)\)]],
  " should help.)"
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Turn the resulting set of equations into a matrix equation by filling in \
the blanks:"
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", \(-1\), "0", "0"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"}
                }], "\[NoBreak]", ")"}], " ", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(c\_1\)},
                {\(c\_2\)},
                {"\[Placeholder]"},
                {"\[Placeholder]"}
                }], "\[NoBreak]", ")"}]}], "\[Equal]", 
        RowBox[{"\[Placeholder]", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {\(c\_1\)},
                {"\[Placeholder]"},
                {"\[Placeholder]"},
                {"\[Placeholder]"}
                }], "\[NoBreak]", ")"}]}]}], TraditionalForm]], "Input"],

Cell[TextData[{
  "The matrix on the left-hand side is called the ",
  StyleBox["normal-mode matrix",
    FontSlant->"Italic"],
  ". Recall that the eigenvalues, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", and eigenvectors, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", of a matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  " satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] . x = \[Lambda]\ x\)]],
  "."
}], "Text",
  CellTags->{"normal-mode matrix", "eigenvalues", "eigenvectors"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Assign ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_4\)]],
  " to be the ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Times]4\)]],
  " normal-mode matrix. Deduce the relationship between the eigenvalues of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_4\)]],
  " and the natural frequencies, \[CapitalOmega], of the oscillating system."
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the eigenvalues of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_4\)]],
  ". Note that the ",
  StyleBox["exact values",
    FontSlant->"Italic"],
  " are generated. "
}], "BeginEndQuestion"],

Cell[TextData[{
  "Remember that the eigenvalues, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", of the matrix \[ScriptCapitalA] satisfy the ",
  StyleBox["characteristic equation",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Det[\[ScriptCapitalA] - \[Lambda]\ I] \[Equal] 
        0\)]],
  "."
}], "Text",
  CellTags->"characteristic equation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["Det", "InlineInputTraditionalForm"],
  " to produce the characteristic equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_4\)]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ":  use ",
  StyleBox["IdentityMatrix", "InlineInputTraditionalForm"],
  " and, to find the size of a square matrix, use ",
  StyleBox["Length", "InlineInputTraditionalForm"],
  "). Compare this to the result generated by ",
  StyleBox["CharacteristicPolynomial", "InlineInputTraditionalForm"],
  ". Use ",
  StyleBox["Solve", "InlineInputTraditionalForm"],
  " to find the eigenvalues. Compare your results to those obtained using ",
  StyleBox["Eigenvalues", "InlineInputTraditionalForm"],
  " above."
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "It is impossible, in general, to compute exactly the eigenvalues of an ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " matrix of size greater than 4\[Times]4. Why? "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "You might want to visit ",
  ButtonBox["http://library.wolfram.com/examples/quintic/",
    ButtonData:>{
      URL[ "http://library.wolfram.com/examples/quintic/"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["http://mathworld.wolfram.com/QuinticEquation.html",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/QuinticEquation.html"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["General normal-mode matrix", "Subsubsection"],

Cell[TextData[{
  "By looking at ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_4\)]],
  " you should be able to deduce the ",
  StyleBox["general",
    FontSlant->"Italic"],
  " normal-mode matrix for a system of \[ScriptCapitalN] masses. "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "The diagonal elements of the normal-mode matrix are all ",
  StyleBox["2", "InlineInputTraditionalForm"],
  ".  Define this by entering the expression"
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`a\_\(i_, j_\) := 2 /; i == j\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "This can be read as ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i, j\)\)]],
  " is 2 if ",
  Cell[BoxData[
      \(TraditionalForm\`i \[Equal] j\)]],
  ".  The \"if\" condition is produced by the ",
  StyleBox["Condition", "InlineInputTraditionalForm"],
  " or ",
  StyleBox["/;", "InlineInputTraditionalForm"],
  " syntax."
}], "EndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Similarly define the values of all other entries of the general \
normal-mode matrix. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": there are only a four cases to consider; diagonal, super-diagonal, \
sub-diagonal, and everything else. The last case can be handled by a ",
  StyleBox["catch-all",
    FontSlant->"Italic"],
  " rule, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", one with no conditional testing)"
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Complete the following procedure for constructing, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_n\)]],
  ", the normal-mode matrix of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  ". "
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalM]\_n_ := 
      Table[a\_\(i, j\),  ... ]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Check that your procedure correctly generates the ",
  Cell[BoxData[
      \(TraditionalForm\`7\[Times]7\)]],
  " normal-mode matrix."
}], "EndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Lookup ",
  StyleBox["Eigensystem", "InlineInputTraditionalForm"],
  " to find out what it returns. Obtain the ",
  StyleBox["numerical values",
    FontSlant->"Italic"],
  " of the eigensystem of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_5\)]],
  " by applying ",
  StyleBox["Eigensystem", "InlineInputTraditionalForm"],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"N", "[", 
            FormBox[\(\[ScriptCapitalM]\_5\),
              "TraditionalForm"], "]"}],
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Save the result as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({\[Lambda], \ \[ScriptU]}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  (",
  StyleBox["Note",
    FontSlant->"Italic"],
  ": You can get rid of the small complex values that may arise in the \
numerical solution by using ",
  StyleBox["Chop", "InlineInputTraditionalForm"],
  ").  Compute ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalM]\_5 . \[ScriptU]\[LeftDoubleBracket]
                i\[RightDoubleBracket] - \[Lambda]\[LeftDoubleBracket]
                i\[RightDoubleBracket] \[ScriptU]\[LeftDoubleBracket]
                i\[RightDoubleBracket]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " for a number of values of ",
  StyleBox["i", "InlineInputTraditionalForm"],
  " to verify that your eigenvectors and eigenvalues are correct."
}], "BeginEndQuestion"],

Cell[TextData[{
  "Note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " returns the set of eigenvectors as the ",
  StyleBox["rows",
    FontSlant->"Italic"],
  " of a matrix. Hence y",
  "ou can check ",
  StyleBox["all",
    FontSlant->"Italic"],
  " eigenvalues and eigenvectors in one go uisng ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalM]\_5 . \[ScriptU]\^T - \[ScriptU]\^T . 
                DiagonalMatrix[\[Lambda]] // Chop\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "."
}], "BrightIdea"],

Cell[TextData[{
  "In general, the output from ",
  StyleBox["Eigensystem", "InlineInputTraditionalForm"],
  " is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " ordered. However, in most physical systems the ordering is relevant."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "What is the relationship between the energy of the normal-mode and its \
frequency ?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell["Let us find a method for sorting a pair of related lists:", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FormBox[\(l\_1\),
              "TraditionalForm"],
            "InlineInputTraditionalForm"], 
          StyleBox["=",
            "InlineInputTraditionalForm"], 
          StyleBox[" ",
            "InlineInputTraditionalForm"], 
          StyleBox[\({5, 3, 1}\),
            "InlineInputTraditionalForm"], " "}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(l\_2 = \ {a, b, c}\),
            "InlineInputTraditionalForm"]}], TraditionalForm]]],
  ".  See what ",
  StyleBox["Transpose[{", "InlineInputTraditionalForm"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`l\_1\)], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  StyleBox[",", "InlineInputTraditionalForm"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`l\_2\)], "InlineInputTraditionalForm"], 
    "InlineInputTraditionalForm"],
  StyleBox["}]", "InlineInputTraditionalForm"],
  " does. Apply ",
  StyleBox["Sort", "InlineInputTraditionalForm"],
  " and then ",
  StyleBox["Transpose", "InlineInputTraditionalForm"],
  " the result. Use this sorting method to sort the eigenvalues (and their \
corresponding eigenvectors) into ascending order. Re-define ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({\[Lambda], \ \[ScriptU]}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " as the sorted values. "
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Graphical Display of the Eigenvectors and Eigenvalues"
}], "Subsection"],

Cell[CellGroupData[{

Cell["ModePlot", "Subsubsection"],

Cell[TextData[{
  "The following code uses ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " to display the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-th eigenvector, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptU]\[LeftDoubleBracket]n\[RightDoubleBracket]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`ModePlot(n_, opts___) := 
      ListPlot[Join[{0}, \[ScriptU]\[LeftDoubleBracket]
            n\[RightDoubleBracket], {0}], PlotJoined \[Rule] True, 
        PlotLabel \[Rule] "\<\[CapitalOmega]=\>" <> 
            ToString[\@\[Lambda]\[LeftDoubleBracket]n\[RightDoubleBracket]], 
        opts]; \)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the endpoints, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(N + 1\) = 0\)]],
  " have been joined to the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-th eigenvector using the ",
  StyleBox["Join", "InlineInputTraditionalForm"],
  " command and also that the (normal-mode) oscillation frequencies are \
computed from the (square root) of the eigenvalues."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Plot the 5 normal modes (since ",
  Cell[BoxData[
      \(TraditionalForm\`N = 5\)]],
  ") using ",
  StyleBox["ModePlot", "InlineInputTraditionalForm"],
  ".  (You might try supplying an option to ",
  StyleBox["ModePlot", "InlineInputTraditionalForm"],
  " so that all plots have the same ",
  StyleBox["PlotRange", "InlineInputTraditionalForm"],
  "). What is the relationship between the number of (interior) nodes, the \
eigenvalue number, and the frequency (and hence energy) or each mode?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "In light of the above graphics, what do the eigenvectors represent \
physically?"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute and sort the ",
  StyleBox["numerical",
    FontSlant->"Italic"],
  " eigensystem for ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_50\)]],
  " and use ",
  StyleBox["ModePlot", "InlineInputTraditionalForm"],
  " to visualize modes,  1, 5, 10, and 50. What do these plots remind you of? \
(Analogies are very important in physics!)"
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency-level diagram", "Subsubsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Using the ",
  StyleBox["numerical",
    FontSlant->"Italic"],
  " eigenvalues, \[Lambda], of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_50\)]],
  ", compute the frequencies and call them \[Nu].  (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": Note that functions like ",
  Cell[BoxData[
      \(TraditionalForm\`\(\@\ \)\)]],
  " are ",
  StyleBox["Listable", "InlineInputTraditionalForm"],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", you can apply them to a whole list of numbers at one go). Plot \[Nu] \
versus mode number using ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  ". Show a frequency-level diagram using by drawing a line from ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " at each frequency ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " using"
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{\(energylevel[y_]\), ":=", 
        RowBox[{"Line", "[", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "y"},
                {"1", "y"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], "]"}]}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(Show[Graphics[energylevel /@ \[Nu]], 
        Axes \[Rule] True, AspectRatio \[Rule] 3, 
        Ticks \[Rule] {None, Automatic}];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["General formula", "Subsubsection"],

Cell[TextData[{
  "It can be shown that, for the special case of equal masses and spring \
constants with both ends fixed, the general formula for the frequencies (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the square root of the eigenvalues) satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega]\_i = 
        2\ \(sin(\(i\ \[Pi]\)\/\(2\ \((\[ScriptCapitalN] + 1)\)\))\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega]\_i\)]],
  " is the frequency of the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th mode for a system of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " masses."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Verify that this general formula for \[ScriptCapitalN] masses gives the \
same frequencies as those obtained using ",
  StyleBox["Eigenvalues", "InlineInputTraditionalForm"],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": taking the difference may be useful and ",
  StyleBox["Chop", "InlineInputTraditionalForm"],
  " can be used to simplify the result.)"
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " One End Free"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Obtain the equations of motion for the case where one end is free. \
Suitably modify ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\_n\)]],
  " and ",
  StyleBox["ModePlot", "InlineInputTraditionalForm"],
  " in this case (Note carefully how the boundary conditions are included in \
the code for ",
  StyleBox["ModePlot", "InlineInputTraditionalForm"],
  "). Examine the case of 10 masses by plotting a few of the normal modes. \
Compare the behaviour to that with both ends fixed."
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " General Tri-diagonal Matrix"
}], "Subsection"],

Cell[TextData[{
  "In the analysis of this problem, tri-diagonal matrices have appeared, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " matrices with only the diagonal, sub-diagonal and super-diagonal, \
non-vanishing. These matrices often arise in physical problems. It can be \
shown that ",
  StyleBox["any",
    FontSlant->"Italic"],
  " matrix can be reduced to tri-diagonal form (using a finite sequence of \
unitarily similar transformations).  Hence it is worthwhile to study these \
objects in their own right."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define suitable right-hand sides for the following three expressions to \
produce the ",
  StyleBox["general",
    FontSlant->"Italic"],
  " elements of a tri-diagonal matrix of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalT]\_n\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", with non-zero entries ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_\(i, j\)\)]],
  ":"
}], "BeginQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_\(i_, j_\) := \(\(...\)\(/;\)\(\
\[LeftBracketingBar]i - j\[RightBracketingBar] \[LessEqual] 1\)\)\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_\(i_, j_\) :=  ... \)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalT]\_n_ := Table[ ... ]\)], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_n_ := \(\[Delta]\_n = 
            Det[\[ScriptCapitalT]\_n]\)\),
        "InlineInputTraditionalForm"]]],
  " and compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_1\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_3\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_4\)]],
  ". Express each higher term as (simple) linear combinations of the \
preceding two terms.  (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": regard ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_0\)]],
  " as having the value 1.  Express ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_2\)]],
  " as simply as possible in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_0\)]],
  ". Proceed to express ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_3\)]],
  " as simply as possible in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_2\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_1\)]],
  ", ",
  StyleBox["etc",
    FontSlant->"Italic"],
  ". You should obtain a simple ",
  StyleBox["recurrence formula",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " for computing the general determinant of an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  " tri-diagonal matrix.   "
}], "BeginEndQuestion"],

Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_\(i_, j_\) := \[Beta]\_\(i, j\) /; \
\[LeftBracketingBar]i - j\[RightBracketingBar] \[LessEqual] 1\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\[Alpha]\_\(i_, j_\) := 0\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalT]\_n_ := 
      Table[\[Alpha]\_\(i, j\), {i, n}, {j, n}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalT]\_5\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[Beta]\_\(1, 1\)\), \(\[Beta]\_\(1, 2\)\), "0", "0", "0"},
            {\(\[Beta]\_\(2, 1\)\), \(\[Beta]\_\(2, 2\)\), \(\[Beta]\_\(2, 
                  3\)\), "0", "0"},
            {
              "0", \(\[Beta]\_\(3, 2\)\), \(\[Beta]\_\(3, 
                  3\)\), \(\[Beta]\_\(3, 4\)\), "0"},
            {"0", 
              "0", \(\[Beta]\_\(4, 3\)\), \(\[Beta]\_\(4, 
                  4\)\), \(\[Beta]\_\(4, 5\)\)},
            {"0", "0", "0", \(\[Beta]\_\(5, 4\)\), \(\[Beta]\_\(5, 5\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[\(\[Delta]\_n_ := \(\[Delta]\_n = 
            Det[\[ScriptCapitalT]\_n]\)\),
        "InlineInputTraditionalForm"], TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Delta]\_1\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Beta]\_\(1, 1\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Delta]\_2\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Beta]\_\(1, 1\)\ \[Beta]\_\(2, 2\) - \[Beta]\_\(1, 2\
\)\ \[Beta]\_\(2, 1\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Delta]\_3\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\[Beta]\_\(1, 1\)\)\ \[Beta]\_\(2, 3\)\ \
\[Beta]\_\(3, 2\) - \[Beta]\_\(1, 2\)\ \[Beta]\_\(2, 1\)\ \[Beta]\_\(3, 3\) + \
\[Beta]\_\(1, 1\)\ \[Beta]\_\(2, 2\)\ \[Beta]\_\(3, 3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`PolynomialReduce[\[Delta]\_3, {\[Delta]\_2, \
\[Delta]\_1}, 
      Flatten[Table[\[Beta]\_\(i, j\), {i, 2, 3}, {j, i + 1, 3}]]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{\[Beta]\_\(3, 3\), \(-\[Beta]\_\(2, 3\)\)\ \[Beta]\_\
\(3, 2\)}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`PolynomialReduce[\[Delta]\_5, {\[Delta]\_4, \
\[Delta]\_3}, 
      Flatten[Table[\[Beta]\_\(i, j\), {i, 2, 5}, {j, i + 1, 5}]]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{\[Beta]\_\(5, 5\), \(-\[Beta]\_\(4, 5\)\)\ \[Beta]\_\
\(5, 4\)}, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Delta]\_4\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Beta]\_\(1, 2\)\ \[Beta]\_\(2, 1\)\ \[Beta]\_\(3, \
4\)\ \[Beta]\_\(4, 3\) - \[Beta]\_\(1, 1\)\ \[Beta]\_\(2, 2\)\ \[Beta]\_\(3, \
4\)\ \[Beta]\_\(4, 3\) - \[Beta]\_\(1, 1\)\ \[Beta]\_\(2, 3\)\ \[Beta]\_\(3, \
2\)\ \[Beta]\_\(4, 4\) - \[Beta]\_\(1, 2\)\ \[Beta]\_\(2, 1\)\ \[Beta]\_\(3, \
3\)\ \[Beta]\_\(4, 4\) + \[Beta]\_\(1, 1\)\ \[Beta]\_\(2, 2\)\ \[Beta]\_\(3, \
3\)\ \[Beta]\_\(4, 4\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalE]\_n_\), ":=", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["x", "n", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "==", \(\(x\_\(n - 1\)\)(t) + \(x\_\(n + 1\)\)(t) - 
            2\ \(\(x\_n\)(t)\)\)}]}], TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalE]\_n /. 
      x\_n_ \[Rule] 
        Function[
          t, \(a\_n\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)]\)], \
"Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\)\ \
\[Omega]\^2\ a\_n == \[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\ a\_\(n \
- 1\) - 2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\ a\_n + \
\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\ a\_\(n + 1\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`%\/\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\)], \
"Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\[Omega]\^2\)\ a\_n == \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ t\ \[Omega]\)\ \((\[ExponentialE]\^\(\[ImaginaryI]\ t\ \
\[Omega]\)\ a\_\(n - 1\) - 
            2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\ a\_n + \
\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\ a\_\(n + 1\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Simplify[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ a\_n == 
      a\_n\ \[Omega]\^2 + a\_\(n - 1\) + a\_\(n + 1\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`% /. 
      a\_j_ \[Rule] 
        a\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2  j\ \[Gamma] + \
\[Delta])\)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ a\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2\ n\ \
\[Gamma] + \[Delta])\)\) == 
      a\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2\ n\ \[Gamma] + \[Delta])\)\)\ \
\[Omega]\^2 + 
        a\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2\ \((n - 1)\)\ \[Gamma] + \
\[Delta])\)\) + 
        a\ \[ExponentialE]\^\(\[ImaginaryI]\ \((2\ \((n + 1)\)\ \[Gamma] + \
\[Delta])\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Simplify[%\/\[ExponentialE]\^\(\[ImaginaryI]\ \((2  j\ \
\[Gamma] + \[Delta])\)\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0 == 
      a\ \[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \((j - n + 1)\)\ \
\[Gamma]\)\ \((\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Gamma]\)\ \
\((\[Omega]\^2 - 2)\) + \[ExponentialE]\^\(4\ \[ImaginaryI]\ \[Gamma]\) + 
            1)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`% /. \[Omega]\^2 \[Rule] \[Omega]2\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0 == 
      a\ \[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \((j - n + 1)\)\ \
\[Gamma]\)\ \((\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Gamma]\)\ \((\[Omega]2 \
- 2)\) + \[ExponentialE]\^\(4\ \[ImaginaryI]\ \[Gamma]\) + 1)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Omega]2 /. First[Solve[%, \[Omega]2]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \
\[Gamma]\)\)\ \((\(-1\) + \[ExponentialE]\^\(2\ \[ImaginaryI]\ \
\[Gamma]\))\)\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FullSimplify[%] /. \[Gamma] \[Rule] \[Gamma]\/2\)], \
"Input"],

Cell[BoxData[
    \(TraditionalForm\`4\ \(\(sin\^2\)(\[Gamma]\/2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Simplify[\@%%%, \[Gamma] > 0]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2\ \[LeftBracketingBar]sin(\[Gamma]\/2)\
\[RightBracketingBar]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`TrigExpand[%]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`2 - 2\ \(cos(\[Gamma])\)\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Equal"->{
    Cell[2967, 100, 369, 13, 23, "BrightIdea",
      CellTags->{"Equal", "Listable"}]},
  "Listable"->{
    Cell[2967, 100, 369, 13, 23, "BrightIdea",
      CellTags->{"Equal", "Listable"}]},
  "dimensionless"->{
    Cell[4144, 149, 838, 29, 43, "Text",
      CellTags->"dimensionless"]},
  "unstable"->{
    Cell[5735, 199, 454, 9, 42, "Text",
      CellTags->{"unstable", "chaotic"}]},
  "chaotic"->{
    Cell[5735, 199, 454, 9, 42, "Text",
      CellTags->{"unstable", "chaotic"}]},
  "angular momentum"->{
    Cell[6192, 210, 294, 6, 40, "Warning",
      CellTags->"angular momentum"]},
  "natural frequencies"->{
    Cell[54517, 1681, 360, 10, 24, "Text",
      CellTags->{
      "natural frequencies", "normal modes", "coupled oscillators"}]},
  "normal modes"->{
    Cell[54517, 1681, 360, 10, 24, "Text",
      CellTags->{
      "natural frequencies", "normal modes", "coupled oscillators"}]},
  "coupled oscillators"->{
    Cell[54517, 1681, 360, 10, 24, "Text",
      CellTags->{
      "natural frequencies", "normal modes", "coupled oscillators"}]},
  "equilibrium"->{
    Cell[76512, 1966, 368, 12, 24, "Text",
      CellTags->"equilibrium"]},
  "substitution rule"->{
    Cell[78033, 2029, 742, 27, 42, "Text",
      CellTags->{"substitution rule", "replacement rule"}]},
  "replacement rule"->{
    Cell[78033, 2029, 742, 27, 42, "Text",
      CellTags->{"substitution rule", "replacement rule"}]},
  "simple-harmonic"->{
    Cell[81561, 2158, 310, 9, 26, "Text",
      CellTags->"simple-harmonic"]},
  "normal-mode matrix"->{
    Cell[83912, 2232, 561, 18, 26, "Text",
      CellTags->{"normal-mode matrix", "eigenvalues", "eigenvectors"}]},
  "eigenvalues"->{
    Cell[83912, 2232, 561, 18, 26, "Text",
      CellTags->{"normal-mode matrix", "eigenvalues", "eigenvectors"}]},
  "eigenvectors"->{
    Cell[83912, 2232, 561, 18, 26, "Text",
      CellTags->{"normal-mode matrix", "eigenvalues", "eigenvectors"}]},
  "characteristic equation"->{
    Cell[85216, 2281, 393, 13, 26, "Text",
      CellTags->"characteristic equation"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Equal", 174894, 5475},
  {"Listable", 174998, 5478},
  {"dimensionless", 175107, 5481},
  {"unstable", 175199, 5484},
  {"chaotic", 175297, 5487},
  {"angular momentum", 175404, 5490},
  {"natural frequencies", 175512, 5493},
  {"normal modes", 175664, 5497},
  {"coupled oscillators", 175823, 5501},
  {"equilibrium", 175974, 5505},
  {"substitution rule", 176075, 5508},
  {"replacement rule", 176203, 5511},
  {"simple-harmonic", 176330, 5514},
  {"normal-mode matrix", 176435, 5517},
  {"eigenvalues", 176570, 5520},
  {"eigenvectors", 176706, 5523},
  {"characteristic equation", 176853, 5526}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 121, 5, 74, "Title",
  CounterAssignments->{{"Title", 4}}],
Cell[1911, 60, 29, 0, 26, "Author"],
Cell[1943, 62, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2382, 78, 39, 0, 42, "Subsubsection"],
Cell[2424, 80, 215, 5, 26, "Text"],
Cell[2642, 87, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2757, 91, 87, 3, 24, "Text"],
Cell[2847, 96, 117, 2, 24, "Input",
  InitializationCell->True],
Cell[2967, 100, 369, 13, 23, "BrightIdea",
  CellTags->{"Equal", "Listable"}],
Cell[3339, 115, 99, 2, 24, "Input",
  InitializationCell->True],
Cell[3441, 119, 134, 3, 24, "Input",
  InitializationCell->True],
Cell[3578, 124, 225, 5, 42, "Input",
  InitializationCell->True],
Cell[3806, 131, 97, 2, 24, "Input",
  InitializationCell->True],
Cell[3906, 135, 58, 0, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4001, 140, 140, 7, 41, "SectionFirst"],
Cell[4144, 149, 838, 29, 43, "Text",
  CellTags->"dimensionless"],
Cell[4985, 180, 747, 17, 81, "NumberedEquation"],
Cell[5735, 199, 454, 9, 42, "Text",
  CellTags->{"unstable", "chaotic"}],
Cell[6192, 210, 294, 6, 40, "Warning",
  CellTags->"angular momentum"],
Cell[6489, 218, 388, 8, 42, "Warning"],
Cell[6880, 228, 891, 21, 43, "Input",
  InitializationCell->True],
Cell[7774, 251, 39, 0, 24, "Text"],
Cell[7816, 253, 583, 15, 24, "Input"],
Cell[8402, 270, 200, 6, 26, "Text"],
Cell[8605, 278, 109, 2, 24, "Input"],
Cell[8717, 282, 208, 4, 24, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8950, 290, 149, 3, 24, "Input"],
Cell[9102, 295, 39673, 1175, 188, 15257, 869, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[48790, 1473, 257, 8, 24, "Warning"],
Cell[49050, 1483, 312, 9, 24, "Text"],
Cell[49365, 1494, 1063, 23, 42, "Input"],
Cell[50431, 1519, 250, 7, 24, "Warning"],
Cell[50684, 1528, 652, 22, 66, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[51373, 1555, 110, 7, 39, "Section"],
Cell[51486, 1564, 315, 6, 40, "Text"],
Cell[51804, 1572, 333, 8, 45, "DisplayFormula"],
Cell[52140, 1582, 827, 29, 70, "BeginEndQuestion"],
Cell[52970, 1613, 18, 0, 32, "Answer"],
Cell[52991, 1615, 387, 13, 55, "BeginEndQuestion"],
Cell[53381, 1630, 18, 0, 32, "Answer"],
Cell[53402, 1632, 922, 33, 73, "BeginEndQuestion"],
Cell[54327, 1667, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[54382, 1672, 132, 7, 39, "Section"],
Cell[54517, 1681, 360, 10, 24, "Text",
  CellTags->{"natural frequencies", "normal modes", "coupled oscillators"}],
Cell[54880, 1693, 21629, 271, 134, 21488, 266, "GraphicsData", "Bitmap", \
"Graphics",
  Evaluatable->False],
Cell[76512, 1966, 368, 12, 24, "Text",
  CellTags->"equilibrium"],

Cell[CellGroupData[{
Cell[76905, 1982, 157, 10, 54, "Subsection"],

Cell[CellGroupData[{
Cell[77087, 1996, 41, 0, 42, "Subsubsection"],
Cell[77131, 1998, 526, 18, 42, "Text"],
Cell[77660, 2018, 370, 9, 24, "Input"],
Cell[78033, 2029, 742, 27, 42, "Text",
  CellTags->{"substitution rule", "replacement rule"}],

Cell[CellGroupData[{
Cell[78800, 2060, 129, 2, 25, "Input"],
Cell[78932, 2064, 306, 8, 23, "Output"]
}, Open  ]],
Cell[79253, 2075, 391, 13, 45, "Text"],
Cell[79647, 2090, 417, 10, 23, "NumberedEquation"],
Cell[80067, 2102, 40, 0, 24, "Text"],
Cell[80110, 2104, 73, 1, 24, "Input"],
Cell[80186, 2107, 166, 5, 26, "Text"],
Cell[80355, 2114, 68, 1, 24, "Input"],
Cell[80426, 2117, 19, 0, 24, "Text"],
Cell[80448, 2119, 92, 1, 24, "Input"],
Cell[80543, 2122, 133, 5, 24, "Text"],
Cell[80679, 2129, 465, 11, 25, "Input"],
Cell[81147, 2142, 321, 9, 52, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[81505, 2156, 53, 0, 26, "Subsubsection"],
Cell[81561, 2158, 310, 9, 26, "Text",
  CellTags->"simple-harmonic"],
Cell[81874, 2169, 134, 3, 25, "Input"],
Cell[82011, 2174, 689, 21, 64, "BeginEndQuestion"],
Cell[82703, 2197, 164, 6, 35, "BeginQuestion"],
Cell[82870, 2205, 1039, 25, 73, "Input"],
Cell[83912, 2232, 561, 18, 26, "Text",
  CellTags->{"normal-mode matrix", "eigenvalues", "eigenvectors"}],
Cell[84476, 2252, 447, 13, 48, "BeginEndQuestion"],
Cell[84926, 2267, 18, 0, 32, "Answer"],
Cell[84947, 2269, 266, 10, 50, "BeginEndQuestion"],
Cell[85216, 2281, 393, 13, 26, "Text",
  CellTags->"characteristic equation"],
Cell[85612, 2296, 806, 22, 70, "BeginEndQuestion"],
Cell[86421, 2320, 254, 8, 50, "BeginEndQuestion"],
Cell[86678, 2330, 18, 0, 32, "Answer"],
Cell[86699, 2332, 436, 12, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[87172, 2349, 51, 0, 26, "Subsubsection"],
Cell[87226, 2351, 269, 8, 26, "Text"],
Cell[87498, 2361, 228, 7, 39, "BeginQuestion"],
Cell[87729, 2370, 104, 2, 25, "Input"],
Cell[87836, 2374, 367, 12, 43, "EndQuestion"],
Cell[88206, 2388, 507, 16, 66, "BeginEndQuestion"],
Cell[88716, 2406, 294, 10, 35, "BeginQuestion"],
Cell[89013, 2418, 133, 3, 25, "Input"],
Cell[89149, 2423, 172, 5, 39, "EndQuestion"],
Cell[89324, 2430, 1541, 43, 88, "BeginEndQuestion"],
Cell[90868, 2475, 560, 18, 39, "BrightIdea"],
Cell[91431, 2495, 246, 7, 26, "Text"],
Cell[91680, 2504, 165, 6, 48, "BeginEndQuestion"],
Cell[91848, 2512, 18, 0, 32, "Answer"],
Cell[91869, 2514, 73, 0, 24, "Text"],
Cell[91945, 2516, 1540, 44, 67, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[93534, 2566, 191, 10, 32, "Subsection"],

Cell[CellGroupData[{
Cell[93750, 2580, 33, 0, 42, "Subsubsection"],
Cell[93786, 2582, 377, 12, 26, "Text"],
Cell[94166, 2596, 372, 7, 27, "Input"],
Cell[94541, 2605, 475, 14, 42, "Text"],
Cell[95019, 2621, 570, 14, 66, "BeginEndQuestion"],
Cell[95592, 2637, 18, 0, 32, "Answer"],
Cell[95613, 2639, 161, 6, 48, "BeginEndQuestion"],
Cell[95777, 2647, 18, 0, 32, "Answer"],
Cell[95798, 2649, 431, 13, 66, "BeginEndQuestion"],
Cell[96232, 2664, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[96287, 2669, 48, 0, 26, "Subsubsection"],
Cell[96338, 2671, 965, 33, 72, "BeginQuestion"],
Cell[97306, 2706, 328, 9, 39, "Input"],
Cell[97637, 2717, 210, 4, 24, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[97884, 2726, 40, 0, 26, "Subsubsection"],
Cell[97927, 2728, 661, 19, 47, "Text"],
Cell[98591, 2749, 442, 12, 66, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[99082, 2767, 150, 10, 32, "Subsection"],
Cell[99235, 2779, 572, 14, 70, "BeginEndQuestion"],
Cell[99810, 2795, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[99865, 2800, 165, 10, 32, "Subsection"],
Cell[100033, 2812, 537, 12, 60, "Text"],
Cell[100573, 2826, 556, 19, 37, "BeginQuestion"],
Cell[101132, 2847, 186, 4, 25, "Input"],
Cell[101321, 2853, 105, 2, 25, "Input"],
Cell[101429, 2857, 87, 1, 25, "Input"],
Cell[101519, 2860, 1550, 56, 82, "BeginEndQuestion"],
Cell[103072, 2918, 184, 3, 25, "Input"],
Cell[103259, 2923, 101, 2, 25, "Input"],
Cell[103363, 2927, 123, 2, 25, "Input"],

Cell[CellGroupData[{
Cell[103511, 2933, 70, 1, 24, "Input"],
Cell[103584, 2936, 650, 13, 95, "Output"]
}, Open  ]],
Cell[104249, 2952, 186, 4, 25, "Input"],

Cell[CellGroupData[{
Cell[104460, 2960, 61, 1, 24, "Input"],
Cell[104524, 2963, 68, 1, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104629, 2969, 61, 1, 24, "Input"],
Cell[104693, 2972, 128, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104858, 2979, 61, 1, 24, "Input"],
Cell[104922, 2982, 231, 3, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105190, 2990, 177, 3, 25, "Input"],
Cell[105370, 2995, 120, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105527, 3002, 177, 3, 25, "Input"],
Cell[105707, 3007, 120, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105864, 3014, 61, 1, 24, "Input"],
Cell[105928, 3017, 443, 6, 23, "Output"]
}, Open  ]],
Cell[106386, 3026, 357, 8, 25, "Input"],

Cell[CellGroupData[{
Cell[106768, 3038, 186, 5, 26, "Input"],
Cell[106957, 3045, 316, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107310, 3054, 102, 2, 39, "Input"],
Cell[107415, 3058, 340, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107792, 3068, 61, 1, 24, "Input"],
Cell[107856, 3071, 116, 2, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108009, 3078, 157, 4, 26, "Input"],
Cell[108169, 3084, 410, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108616, 3097, 132, 2, 39, "Input"],
Cell[108751, 3101, 284, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109072, 3111, 84, 1, 25, "Input"],
Cell[109159, 3114, 269, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109465, 3123, 89, 1, 24, "Input"],
Cell[109557, 3126, 179, 3, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109773, 3134, 99, 2, 36, "Input"],
Cell[109875, 3138, 81, 1, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109993, 3144, 79, 1, 27, "Input"],
Cell[110075, 3147, 113, 2, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110225, 3154, 63, 1, 24, "Input"],
Cell[110291, 3157, 75, 1, 22, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

