(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     69153,       2359]*)
(*NotebookOutlinePosition[    143878,       4940]*)
(*  CellTagsIndexPosition[    141991,       4886]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Dynamical Systems and Chaos"
}], "Title",
  CounterAssignments->{{"Title", 5}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "The following options for ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ", ",
  StyleBox["DensityPlot", "InlineInputTraditionalForm"],
  ", and ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " are desirable."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ParametricPlot, 
        AspectRatio \[Rule] Automatic];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[DensityPlot, PlotPoints \[Rule] 100, 
        Mesh \[Rule] False, Compiled \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ListPlot, 
        PlotStyle \[Rule] AbsolutePointSize(0.002)];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " Planar Pendulum"
}], "SectionFirst",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that is constrained by a rigid and massless rod to move in a vertical \
circle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ".  The equation of motion is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Omega]\^2\ \(sin(\[Theta](t))\) = 0, \ \[Omega] = 
      g\/l, \)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  StyleBox[" ",
    FontFamily->"Symbol",
    FontSlant->"Italic"],
  "is the angle measured from the vertical direction with clockwise \
positive."
}], "Text"],

Cell[TextData[{
  "Usually, only the ",
  StyleBox["harmonic approximation",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\[Theta])\)]],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ") of this equation is considered:"
}], "Text",
  CellTags->"harmonic approximation"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Omega]\^2\ \(\[Theta](t)\) = 0. \)], "NumberedEquation"],

Cell[TextData[{
  "Here, the more general equation (which includes ",
  StyleBox["damping",
    FontSlant->"Italic"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  \[NotEqual] \ 0\)]],
  " and a ",
  StyleBox["sinusoidal driving term",
    FontSlant->"Italic"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  \[NotEqual] \ 0\)]],
  ")"
}], "Text",
  CellTags->{"damping", "sinusoidal driving term"}],

Cell[BoxData[
    \(TraditionalForm\`\(\[Theta]\&\[DoubleDot]\)(
          t) + \[Beta]\ \(\(\[Theta]\& . \)(
            t)\) + \[Omega]\^2\ \(sin(\[Theta](
              t))\) = \[Alpha]\ \(sin(\[Omega]\_d\ t)\)\)], "NumberedEquation"],

Cell[TextData[{
  "will be examined. The units of mass, length, and time are chosen so that \
they are all equal to unity, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", we are working with ",
  StyleBox["dimensionless variables",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Undamped pendulum"
}], "Subsection"],

Cell[TextData[{
  "The dimensionless equation for the undamped pendulum in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation reads"
}], "Text",
  CellTags->"undamped pendulum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], 
              "+", \(sin(\[Theta](t))\)}], "==", "0"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  " to numerically solve ",
  StyleBox["\[ScriptCapitalP]", "InlineInputTraditionalForm"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " for 10 units of time (\"seconds\") with the initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) == 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^\[Prime]\)(0) \[Equal] 1\)]],
  " and call the result ",
  StyleBox["\[ScriptU]", "InlineInputTraditionalForm"],
  ". (NB. It is more convenient to solve for \[Theta] rather than ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)]],
  "). Display a ",
  StyleBox["phase-space plot",
    FontSlant->"Italic"],
  " by pairing up the angle and angular velocity values using ",
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"{", 
            RowBox[{\(\[Theta](t)\), ",", 
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}]}], "}"}], "/.", 
          "\[InvisibleSpace]", \(First[\[ScriptU]]\)}], TraditionalForm]], 
    "InlineInputTraditionalForm"], "InlineInputTraditionalForm"],
  " and visualize the motion using ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  ". Describe the trajectory that results. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"phase-space plot"],

Cell[" ", "Answer"],

Cell[TextData[{
  "Note that we are using the first (in this case there is only one) \
numerical solution to the differential equation and computing its derivative \
(",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "t", ")"}], TraditionalForm]]],
  ") ",
  StyleBox["numerically",
    FontSlant->"Italic"],
  "."
}], "Warning"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Increase the initial velocity, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", to something slightly less than 2 and redo ",
  
  CounterBox["Exercise", "phase-space plot"],
  ". Explain what is happening here. ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Set ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " to 2 and redo ",
  
  CounterBox["Exercise", "phase-space plot"],
  ",  but over a longer time interval. Explain what is happening here. ",
  StyleBox["[2 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Explain the critical value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " from an energy viewpoint (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": the kinetic energy is proportional to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\/2\), " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}], "2"]}], 
        TraditionalForm]]],
  " and the initial potential energy is 0. What is the total energy at the \
top of the loop?). ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Damped pendulum"
}], "Subsection"],

Cell[TextData[{
  "The equation for the ",
  StyleBox["damped pendulum",
    FontSlant->"Italic"],
  " (where the damping is proportional to the velocity) can be written:"
}], "Text",
  CellTags->"damped pendulum"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "+", 
              RowBox[{"\[Beta]", " ", 
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}]}], 
              "+", \(sin(\[Theta](t))\)}], "==", "0"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Numerically solve the equation for the damped pendulum with damping ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[Beta] \[Rule] 0.2\),
            "TraditionalForm"]}], TraditionalForm]]],
  " and initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) == 0\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "(", "0", ")"}], "==", "1"}], 
        TraditionalForm]]],
  " for 20 seconds. Display a phase-space plot and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Damped driven pendulum"
}], "Subsection"],

Cell[TextData[{
  "The equation for the ",
  StyleBox["damped driven pendulum",
    FontSlant->"Italic"],
  " can be written"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalP]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "t", ")"}], "+", 
              RowBox[{"\[Beta]", " ", 
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}]}], 
              "+", \(sin(\[Theta](t))\)}], 
            "==", \(\[Alpha]\ \(cos(\[Omega]\ t)\)\)}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Numerically solve the equation for the damped driven pendulum with ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Beta] \[Rule] 0.2, \[Alpha] \[Rule] 
          0.52, \[Omega] \[Rule] 0.694}\)]],
  " and initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) == 0.8\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "(", "0", ")"}], "\[Equal]", "0.8"}], 
        TraditionalForm]]],
  " for 400 seconds and call the result ",
  StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
  ". You will need to increase the number of time-steps by playing with the \
",
  StyleBox["MaxSteps", "InlineInputTraditionalForm"],
  " option of ",
  StyleBox["NDSolve", "InlineInputTraditionalForm"],
  ". Display a phase-space plot of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{\(\[Theta](t)\), ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " using ",
  StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
  " with ",
  StyleBox["AspectRatio \[Rule] 1/4", "InlineInputTraditionalForm"],
  " and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Physically, since the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \[Element] \([\(-\[Pi]\), \[Pi]]\)\)]],
  ", it makes more sense to examine ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[\(\((\[Theta] - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
          Mod[ 
            Plus[ 
              \[Theta][ t], 
              Times[ -1, Pi]], 
            Times[ 2, Pi]]], TraditionalForm]]],
  ". Display a phase-space plot of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            
            InterpretationBox[\(\((\[Theta](
                      t) - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
              Mod[ 
                Plus[ 
                  \[Theta][ t], 
                  Times[ -1, Pi]], 
                Times[ 2, Pi]]], ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " and interpret the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "You should see that the resulting phase-space diagram is ",
  StyleBox["periodic",
    FontSlant->"Italic"],
  " (in the language of chaos it shows a ",
  StyleBox["period-3 limit cycle",
    FontSlant->"Italic"],
  ")."
}], "Text",
  CellTags->{"period-3 limit cycle", "periodic"}],

Cell[TextData[{
  "The ",
  StyleBox["Poincar\[EAcute] section",
    FontSlant->"Italic"],
  " provides a simplification of the phase diagram by sampling at time \
intervals equal to the period of the driving frequency.  "
}], "Text",
  CellTags->{"Poincar\[EAcute] section", "driving frequency"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the period using ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = \(2\ \[Pi]\)\/\[Omega]\)]],
  ". How many cycles were present in the first 100 seconds? ",
  StyleBox["[2 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["\<\
To avoid transient effects, the data for the first few cycles \
should be discarded.\
\>", "Text",
  CellTags->"transient effects"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Visualize the Poincar\[EAcute] section by applying ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " to a table of values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            
            InterpretationBox[\(\((\[Theta](
                      t) - \[Pi])\)\ mod\ \((2\ \[Pi])\)\),
              Mod[ 
                Plus[ 
                  \[Theta][ t], 
                  Times[ -1, Pi]], 
                Times[ 2, Pi]]], ",", 
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
        TraditionalForm]]],
  " between ",
  Cell[BoxData[
      \(TraditionalForm\`t = 10  \[Tau]\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", discarding the first 10 cycles) and 400 in steps of \[Tau]. Interpret \
the result. ",
  StyleBox["[3 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Series solution"
}], "Subsection"],

Cell[TextData[{
  "The easiest way to get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve differential equations such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "x", ")"}], 
            "+", \(k\^2\ \(y(x)\)\)}], "=", "0"}], TraditionalForm]]],
  " using series methods is direct expansion of the equation, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"series solution"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"eqn", "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "x", ")"}], 
            "+", \(k\^2\ \(y(x)\)\), "+", \(\(O(x)\)\^7\)}], "==", "0"}]}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        InterpretationBox[
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(\(y(0)\)\ k\^2\), "+", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]",
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{
                    SuperscriptBox["y", 
                      TagBox[\((3)\),
                        Derivative],
                      MultilineFunction->None], "(", "0", ")"}]}], ")"}], " ",
               "x"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]\[Prime]",
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((4)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^2\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((3)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/6\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((5)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^3\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((4)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/24\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((6)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^4\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/120\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((5)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/120\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((7)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^5\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/720\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((6)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}], 
                    " ", \(k\^2\)}], "+", 
                  RowBox[{\(1\/720\), " ", 
                    RowBox[{
                      SuperscriptBox["y", 
                        TagBox[\((8)\),
                          Derivative],
                        MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], 
              " ", \(x\^6\)}], "+", 
            InterpretationBox[\(O(x\^7)\),
              SeriesData[ x, 0, {}, 0, 7, 1]]}],
          SeriesData[ x, 0, {
            Plus[ 
              Times[ 
                Power[ k, 2], 
                y[ 0]], 
              Derivative[ 2][ y][ 0]], 
            Plus[ 
              Times[ 
                Power[ k, 2], 
                Derivative[ 1][ y][ 0]], 
              Derivative[ 3][ y][ 0]], 
            Plus[ 
              Times[ 
                Rational[ 1, 2], 
                Power[ k, 2], 
                Derivative[ 2][ y][ 0]], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 4][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 6], 
                Power[ k, 2], 
                Derivative[ 3][ y][ 0]], 
              Times[ 
                Rational[ 1, 6], 
                Derivative[ 5][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 24], 
                Power[ k, 2], 
                Derivative[ 4][ y][ 0]], 
              Times[ 
                Rational[ 1, 24], 
                Derivative[ 6][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 120], 
                Power[ k, 2], 
                Derivative[ 5][ y][ 0]], 
              Times[ 
                Rational[ 1, 120], 
                Derivative[ 7][ y][ 0]]], 
            Plus[ 
              Times[ 
                Rational[ 1, 720], 
                Power[ k, 2], 
                Derivative[ 6][ y][ 0]], 
              Times[ 
                Rational[ 1, 720], 
                Derivative[ 8][ y][ 0]]]}, 0, 7, 1]], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is equivalent to expanding ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " (and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "x", ")"}], TraditionalForm]]],
  ") into a power series."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`yseries = y(x) + \(O(x)\)\^7\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{\(y(0)\), "+", 
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", "x"}], "+", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^2\)}], 
          "+", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^3\)}], 
          "+", 
          RowBox[{\(1\/24\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((4)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^4\)}], 
          "+", 
          RowBox[{\(1\/120\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((5)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^5\)}], 
          "+", 
          RowBox[{\(1\/720\), " ", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((6)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^6\)}], 
          "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {
          y[ 0], 
          Derivative[ 1][ y][ 0], 
          Times[ 
            Rational[ 1, 2], 
            Derivative[ 2][ y][ 0]], 
          Times[ 
            Rational[ 1, 6], 
            Derivative[ 3][ y][ 0]], 
          Times[ 
            Rational[ 1, 24], 
            Derivative[ 4][ y][ 0]], 
          Times[ 
            Rational[ 1, 120], 
            Derivative[ 5][ y][ 0]], 
          Times[ 
            Rational[ 1, 720], 
            Derivative[ 6][ y][ 0]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can see that the expression multiplying each power of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the expansion of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "x", ")"}], 
          "+", \(k\^2\ \(y(x)\)\)}], TraditionalForm]]],
  " must vanish identically, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(y(0)\)\ k\^2\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
        TraditionalForm]]],
  ", \[Ellipsis]   To see the equations generated you can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["LogicalExpand",
          "Input"], TraditionalForm]]],
  " (this step is not required). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`LogicalExpand[eqn]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\(y(0)\)\ k\^2\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/6\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/6\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/24\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/24\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/120\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/120\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((7)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], 
        "\[And]", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/720\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], " ", \(k\^2\)}], 
            "+", 
            RowBox[{\(1\/720\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((8)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}]}]}], "==", 
          "0"}]}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  " are ",
  StyleBox["not",
    FontSlant->"Italic"],
  " determined but that you can solve for the undetermined coefficients (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["y", 
            TagBox[\((3)\),
              Derivative],
            MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
  ", \[Ellipsis]) in terms of the initial conditions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"Solve", "[", 
        RowBox[{"eqn", ",", 
          RowBox[{"Table", "[", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((n)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              ",", \({n, 2, 8}\)}], "]"}]}], "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((7)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(-k\^6\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((8)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(k\^8\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((5)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(k\^4\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((6)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\(-k\^6\)\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((4)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(k\^4\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\(-k\^2\)\ \(y(0)\)\)}], ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              RowBox[{\(-k\^2\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}]}]}], "}"}], 
        "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To obtain the series solution to the original equation you substitute \
these coefficients into the series expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`yseries /. First[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{\(y(0)\), "+", 
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", "x"}], 
          "-", \(1\/2\ \((k\^2\ \(y(0)\))\)\ x\^2\), "-", 
          RowBox[{\(1\/6\), " ", 
            RowBox[{"(", 
              RowBox[{\(k\^2\), " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "(", "0", ")"}]}], ")"}], 
            " ", \(x\^3\)}], "+", \(1\/24\ k\^4\ \(y(0)\)\ x\^4\), "+", 
          RowBox[{\(1\/120\), " ", \(k\^4\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "0", ")"}], " ", \(x\^5\)}], 
          "-", \(1\/720\ \((k\^6\ \(y(0)\))\)\ x\^6\), "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {
          y[ 0], 
          Derivative[ 1][ y][ 0], 
          Times[ 
            Rational[ -1, 2], 
            Power[ k, 2], 
            y[ 0]], 
          Times[ 
            Rational[ -1, 6], 
            Power[ k, 2], 
            Derivative[ 1][ y][ 0]], 
          Times[ 
            Rational[ 1, 24], 
            Power[ k, 4], 
            y[ 0]], 
          Times[ 
            Rational[ 1, 120], 
            Power[ k, 4], 
            Derivative[ 1][ y][ 0]], 
          Times[ 
            Rational[ -1, 720], 
            Power[ k, 6], 
            y[ 0]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "If you now supply the initial conditions \[LongDash] say ",
  Cell[BoxData[
      \(TraditionalForm\`y(0) = 1\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "(", "0", ")"}], "=", "0"}], 
        TraditionalForm]]],
  " \[LongDash] you get "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"%", "/.", 
        RowBox[{"{", 
          RowBox[{\(y(0) \[Rule] 1\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
              "0"}]}], "}"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{
        "1", "-", \(\(k\^2\ x\^2\)\/2\), "+", \(\(k\^4\ x\^4\)\/24\), 
          "-", \(\(k\^6\ x\^6\)\/720\), "+", 
          InterpretationBox[\(O(x\^7)\),
            SeriesData[ x, 0, {}, 0, 7, 1]]}],
        SeriesData[ x, 0, {1, 0, 
          Times[ 
            Rational[ -1, 2], 
            Power[ k, 2]], 0, 
          Times[ 
            Rational[ 1, 24], 
            Power[ k, 4]], 0, 
          Times[ 
            Rational[ -1, 720], 
            Power[ k, 6]]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Series solution for the undamped pendulum"
}], "Subsection"],

Cell["We would like to analytically solve the equation", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "+", \(\[Omega]\^2\ \(sin(\[Theta](t))\)\)}], "=", "0."}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Obtain the series solution to equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation"],
  ") up to tenth order using the method of \[Section]",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection", "series solution"],
  " for the initial conditions, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{\(\[Theta](0) \[Rule] 0\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "(", "0", ")"}], 
              "\[Rule]", \(\[Omega]\_0\)}]}], "}"}], TraditionalForm]]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": it is a good idea to find the series solution to lower order first to \
check that you are doing the right thing.) ",
  StyleBox["[5 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{\(\[Omega]\_0\ t\), 
          "-", \(1\/6\ \((\[Omega]\^2\ \[Omega]\_0)\)\ t\^3\), 
          "+", \(1\/120\ \[Omega]\^2\ \[Omega]\_0\ \((\[Omega]\^2 + \
\[Omega]\_0\%2)\)\ t\^5\), 
          "-", \(\((\((\[Omega]\^2\ \[Omega]\_0\ \((2\ \[Omega]\^4 + 
                        22\ \[Omega]\_0\%2\ \[Omega]\^2 + 
                        2\ \[Omega]\_0\%4)\))\)\ t\^7)\)/10080\), 
          "+", \(\((\[Omega]\^2\ \[Omega]\_0\ \((\[Omega]\^6 + 
                    102\ \[Omega]\_0\%2\ \[Omega]\^4 + 
                    57\ \[Omega]\_0\%4\ \[Omega]\^2 + \[Omega]\_0\%6)\)\ \
t\^9)\)/362880\), "+", 
          InterpretationBox[\(O(t\^10)\),
            SeriesData[ t, 0, {}, 1, 10, 1]]}],
        SeriesData[ t, 0, {
          Subscript[ \[Omega], 0], 0, 
          Times[ 
            Rational[ -1, 6], 
            Power[ \[Omega], 2], 
            Subscript[ \[Omega], 0]], 0, 
          Times[ 
            Rational[ 1, 120], 
            Power[ \[Omega], 2], 
            Subscript[ \[Omega], 0], 
            Plus[ 
              Power[ \[Omega], 2], 
              Power[ 
                Subscript[ \[Omega], 0], 2]]], 0, 
          Times[ 
            Rational[ -1, 10080], 
            Power[ \[Omega], 2], 
            Subscript[ \[Omega], 0], 
            Plus[ 
              Times[ 2, 
                Power[ \[Omega], 4]], 
              Times[ 22, 
                Power[ \[Omega], 2], 
                Power[ 
                  Subscript[ \[Omega], 0], 2]], 
              Times[ 2, 
                Power[ 
                  Subscript[ \[Omega], 0], 4]]]], 0, 
          Times[ 
            Rational[ 1, 362880], 
            Power[ \[Omega], 2], 
            Subscript[ \[Omega], 0], 
            Plus[ 
              Power[ \[Omega], 6], 
              Times[ 102, 
                Power[ \[Omega], 4], 
                Power[ 
                  Subscript[ \[Omega], 0], 2]], 
              Times[ 57, 
                Power[ \[Omega], 2], 
                Power[ 
                  Subscript[ \[Omega], 0], 4]], 
              Power[ 
                Subscript[ \[Omega], 0], 6]]]}, 1, 10, 1]], 
      TraditionalForm]], "Output"],

Cell[TextData[{
  "The ",
  StyleBox["linearized equation",
    FontSlant->"Italic"],
  " results by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\[Theta])\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ". "
}], "Text",
  CellTags->"linearized equation"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "t", ")"}], 
          "+", \(\[Omega]\^2\ \(\[Theta](t)\)\)}], "=", "0."}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve the linearized ",
  "equation",
  " (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation"],
  ") taking into account the initial conditions. To what order do these \
solutions agree? (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you can take the difference between the series solution and the exact \
solution to the linearized equation and simplify.)",
  " What does the difference say about the behaviour over a long period of \
time?",
  " ",
  StyleBox["[6 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Iterative Operations"
}], "Section"],

Cell["\<\
This section presents four examples of visualizing iterative \
operations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Julia set"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Julia set",
    FontSlant->"Italic"],
  " associated to a fixed complex number ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is found by iterating the map ",
  Cell[BoxData[
      \(TraditionalForm\`z \[RightTeeArrow] z\^2 + c\)]],
  ". The set of points, ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", that do not escape to infinity (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", their absolute value remains bounded, say ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 2\)]],
  ", after ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " iterations have been carried out) is the Julia set. "
}], "Text",
  CellTags->{"Iterated mapping", "Bounded absolute value"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter the function ",
  Cell[BoxData[
      \(TraditionalForm\`f[z_] := z\^2 + 0.5  \[ImaginaryI]\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", starting at ",
  Cell[BoxData[
      \(TraditionalForm\`c\  = \ 0.5\ \[ImaginaryI]\)]],
  ". ",
  StyleBox["Using ",
    FontSlant->"Plain"],
  StyleBox["NestList", "InlineInputTraditionalForm",
    FontSlant->"Plain"],
  StyleBox[", iterate ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  StyleBox[" ten times, starting at ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 0.1\)]],
  ".  Compute the absolute value of these complex numbers. Are they remaining \
bounded? ",
  StyleBox["Try ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 0.5\)]],
  StyleBox[" and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ 1\)]],
  StyleBox[" and comment.",
    FontSlant->"Plain"],
  " ",
  StyleBox["[5 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "The following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " procedural code (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", similar in style to Fortran, C, Pascal, Basic,\[Ellipsis]) iterates ",
  Cell[BoxData[
      \(TraditionalForm\`z = z\^2 + c\)]],
  " for a particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ".  Either the value of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " escapes to \[Infinity] which can be tested using ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]z\[RightBracketingBar] < 
        2.0\)]],
  " or it hops around a finite number of times, bounded above by ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "."
}], "Text",
  CellTags->"Module"],

Cell[BoxData[
    \(TraditionalForm\`\(JuliaModule(w_, c_, m_) := 
        Module({z = w, n = 0}, 
          While(\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] n < m, 
            z = z\^2 + c; \(++n\)); n);\)\)], "Input"],

Cell[TextData[{
  "Alternatively, we can implement this as a pure function (using ",
  StyleBox["Function", "InlineInputTraditionalForm"],
  ") with ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({w, c, m}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " as ",
  StyleBox["dummy arguments",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->{"pure function", "Function"}],

Cell[BoxData[
    \(TraditionalForm\`\(JuliaFunction = 
        Function({w, c, m}, 
          Module({z = w, n = 0}, 
            While(\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] 
                n < m, z = z\^2 + c; \(++n\)); n));\)\)], "Input"],

Cell["\<\
A table of values using either implementation is somewhat \
slow:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(Table[
            JuliaModule(x + \[ImaginaryI]\ y, 1 + 0.3\ \[ImaginaryI], 
              35), {x, \(-1.5\), 1.5, 0.1}, {y, \(-1.5\), 1.5, 0.1}];\) // 
        Timing\) // First\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.41666666666606034`\ Second\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\(Table[
            JuliaFunction(x + \[ImaginaryI]\ y, 1 + 0.3\ \[ImaginaryI], 
              35), {x, \(-1.5\), 1.5, 0.1}, {y, \(-1.5\), 1.5, 0.1}];\) // 
        Timing\) // First\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`0.43333333333339397`\ Second\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Numerical function compilation, using ",
  StyleBox["Compile", "InlineInputTraditionalForm"],
  ", is a useful way of speeding up a computation. The following code expects \
three arguments: the point ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", the point ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", and the maximum number of iterations."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"JuliaCompile", "=", 
          RowBox[{"Compile", "[", 
            RowBox[{
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"w", "_Complex"},
                    {"c", "_Complex"},
                    {"m", "_Integer"}
                    }], "\[NoBreak]", ")"}], 
              ",", \(Module[{z = w, n = 0}, 
                While[\[LeftBracketingBar]z\[RightBracketingBar] < 2 \[And] 
                    n < m, z = z\^2 + c; \(n++\)]; n]\)}], "]"}]}], ";"}], 
      TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compare the speed of ",
  StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["JuliaFunction", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "I don't expect you to get into the details of ",
  StyleBox["Compile", "InlineInputTraditionalForm"],
  " \[LongDash] just know that it can make code faster. For numerical \
functions, it is often advantageous writing them using ",
  Cell[BoxData[
      FormBox[
        StyleBox["Function",
          "Input"], TraditionalForm]]],
  " because it is straightforward to \"compile\" a function: usually it is \
only a matter of replacing ",
  Cell[BoxData[
      FormBox[
        StyleBox["Function",
          "Input"], TraditionalForm]]],
  " with ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " and \"typing\" the arguments. "
}], "Warning",
  CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
    "Compile", "argument typing"}],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " assumes its arguments should be compiled as ",
  ButtonBox["machine-precision",
    ButtonData:>{"3.1.6"},
    ButtonStyle->"MainBookLink"],
  " real numbers unless it is directed to do otherwise by variable \
declarations such as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({w, _Complex}\),
          "Input"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({m, _Integer}\),
          "Input"], TraditionalForm]]],
  "."
}], "Warning",
  CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
     "_Integer"}],

Cell[TextData[{
  "The first argument of ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " is a list of lists (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", a rank-2 tensor) and is typeset in ",
  Cell[BoxData[
      FormBox[
        StyleBox["TraditionalForm",
          "Input"], TraditionalForm]]],
  " as a matrix. You can either enter it as an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]2\)]],
  " matrix:"
}], "Warning"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"w", "_Complex"},
            {"c", "_Complex"},
            {"m", "_Integer"}
            }], ")"}], TraditionalForm]], "Input"],

Cell["or as a list of lists:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`{{w, _Complex}, {c, _Complex}, {m, _Integer}}\)], \
"Input"],

Cell[TextData[{
  "The variable types appearing in the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Module",
          "Input"], TraditionalForm]]],
  " part of ",
  Cell[BoxData[
      FormBox[
        StyleBox["JuliaCompile",
          "Input"], TraditionalForm]]],
  " are guessed based on the first time they are set. Since the local \
variable ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          "Input"], TraditionalForm]]],
  " is first initialized to ",
  Cell[BoxData[
      FormBox[
        StyleBox["w",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " knows it is a complex variable. Similarly, the statement ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(n = 0\),
          "Input"], TraditionalForm]]],
  " indicates to ",
  Cell[BoxData[
      FormBox[
        StyleBox["Compile",
          "Input"], TraditionalForm]]],
  " that ",
  StyleBox["n", "InlineInputTraditionalForm",
    FontSlant->"Italic"],
  " is an integer. "
}], "Warning",
  CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Use ",
    FontSlant->"Plain"],
  StyleBox["DensityPlot", "InlineInputTraditionalForm"],
  StyleBox[" to visualize the Julia set over ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1.5\), \ 1.5]\)\ \[Times]\ \([\(-1.3\), \ 
          1.3]\)\)]],
  StyleBox[" in the complex plane for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`c\  = \ \[ImaginaryI]\)]],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Algorithms for computing fractal sets often involve iterating a formula \
until a specified condition is met. By default, ",
  StyleBox["FixedPoint", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " stop iterating when two successive calculations give the same result. To \
specify our own stopping condition, we can use the ",
  StyleBox["SameTest", "InlineInputTraditionalForm"],
  " option. This option takes a pure function of two arguments that returns \
",
  StyleBox["True", "InlineInputTraditionalForm"],
  " if the two arguments can be considered \[OpenCurlyDoubleQuote]the same\
\[CloseCurlyDoubleQuote]. For example, here we iterate the square root \
function, applied to 10, and stop when two successive values are within 0.1 \
of each other."
}], "Text",
  CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
    "SameTest", "pure function", "True"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FixedPoint(Sqrt, 10.0, 
      SameTest \[Rule] \((\[LeftBracketingBar]#1 - #2\[RightBracketingBar] < 
              0.1 &)\))\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1.0746078283213176`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Find a ",
    FontSlant->"Plain"],
  StyleBox["FixedPoint", "InlineInputTraditionalForm"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`cos(x)\)]],
  ", stopping when two successive values are within ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-5\)\)]],
  " of each other. ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Here is an elegant alternative implementation of ",
  StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
  " using a ",
  StyleBox["fixed",
    FontSlant->"Italic"],
  " number of iterations (here 35)."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"JuliaCompile", "=", 
          RowBox[{"Compile", "(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"z", "_Complex"},
                    {"c", "_Complex"}
                    }], ")"}], 
              ",", \(Length(
                FixedPointList(#\^2 + c &, z, 35, 
                  SameTest \[Rule] \((\[LeftBracketingBar]#2\
\[RightBracketingBar] > 2.0 &)\)))\)}], ")"}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "Using ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(SameTest \[Rule] \((\[LeftBracketingBar]#2\
\[RightBracketingBar] < 2.0 &)\)\),
          "Input"], TraditionalForm]]],
  " ",
  "tests whether the last value (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["#2", "InlineInputTraditionalForm"],
  ") generated by ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " remains bounded (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[LeftBracketingBar]z\[RightBracketingBar]<2). The length of the result \
of ",
  StyleBox["FixedPointList", "InlineInputTraditionalForm"],
  " is the number of iterations."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Plot the Julia set associated with ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0.27334 + 0.00742\ \[ImaginaryI]\)]],
  " ",
  StyleBox["over ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1.2\), \ 1.2]\)\ \[Times]\ \([\(-1.2\), \ 
          1.2]\)\)]],
  StyleBox[" in the complex plane.",
    FontSlant->"Plain"],
  " ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"Julia set"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Interact with the plot of exercise ",
  
  CounterBox["Exercise", "Julia set"],
  " to find a point that is in the Julia set, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", click on the graphic, hold down the Apple key (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[CloverLeaf]) on a Macintosh or the Control key (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[ControlKey]) under Windows, and move the mouse around.  The \
mouse-coordinates will appear in the status box (bottom left corner of the \
Notebook).  Click at an appropriate point and copy the coordinate value(s) \
using Copy (\[CloverLeaf]-C or \[ControlKey]-V). Paste this value into the \
Notebook (in a new cell) and check that it is in the Julia set by applying ",
  StyleBox["JuliaComplie", "InlineInputTraditionalForm"],
  " to it. (Note that ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Complex\  @@ \ {a, \ b}\),
          "Input"], TraditionalForm]]],
  " yields the complex number ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Complex[a, \ b]\),
          "Input"], TraditionalForm]]],
  "). ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "For fun, run the following code to produce an array of plots with ",
  Cell[BoxData[
      \(TraditionalForm\`z\  \[Element] \ \([\(-1.1\) - 1.1  \[ImaginaryI], 
          1.1 + 1.1  \[ImaginaryI]]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c = 
        a + b\ \[ImaginaryI]\ \( \[Element] \_\ \)\([\(-2\) - \[ImaginaryI], 
            1 + \[ImaginaryI]]\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(Show(
        GraphicsArray(
          Table(DensityPlot(\(-\(JuliaCompile(x + \[ImaginaryI]\ y, 
                  a + b\ \[ImaginaryI])\)\), {x, \(-1.1\), 
                1.1}, {y, \(-1.1\), 1.1}, Frame \[Rule] False, 
              Axes \[Rule] False, PlotPoints \[Rule] 20, 
              DisplayFunction \[Rule] Identity), {b, \(-1\), 1, 
              1\/3}, {a, \(-2\), 1, 1\/3})));\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " The Mandelbrot set"
}], "Subsection"],

Cell[TextData[{
  "For each ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in the complex plane, those points that remain bounded upon iterating the \
map ",
  Cell[BoxData[
      \(TraditionalForm\`c \[RightTeeArrow] c\^2 + c\)]],
  " generate the ",
  StyleBox["Mandelbrot set",
    FontSlant->"Italic"],
  ". It turns out that points in the Mandelbrot set have connected Julia \
sets. "
}], "Text",
  CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Modify the Julia code to compute and visualize the Mandlebrot set. ",
  StyleBox["[6 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Newton's Method"
}], "Subsection"],

Cell[TextData[{
  "Consider using Newton's method to compute the (complex) argument of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-th roots of unity, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the roots of ",
  Cell[BoxData[
      \(TraditionalForm\`f(z) = z\^n - 1\)]],
  ". The Newton iteration, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "\[Rule]", 
          RowBox[{"z", "-", 
            FractionBox[\(f(z)\), 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]]}]}], 
        TraditionalForm]]],
  ", becomes"
}], "Text",
  CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
    "Newton's method"}],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"z", "-", 
            FractionBox[\(f(z)\), 
              RowBox[{
                SuperscriptBox["f", "\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]]}], 
          "/.", \(f \[Rule] Function(z, z\^n - 1)\)}], "//", "Simplify"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(z\ \((z\^\(-n\) + n - 1)\)\)\/n\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To evaluate both ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f(z)\),
          "Input"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], \((z)\)}],
          "Input"], TraditionalForm]]],
  " we use a pure function replacement rule for ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          "Input"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f \[Rule] Function(z, z\^n - 1)\),
          "Input"], TraditionalForm]]],
  "."
}], "BrightIdea",
  CellTags->"pure function replacement rule"],

Cell["The compiled function", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"NewtonIteration", "=", 
          RowBox[{"Compile", "(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"n", "_Integer"},
                    {"c", "_Complex"}
                    }], ")"}], 
              ",", \(Arg(
                FixedPoint(Function(z, \(z\ \((z\^\(-n\) + n - 1)\)\)\/n), c, 
                  35))\)}], ")"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "can be used to show the convergence of points in the complex plane for \
specific ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". "
}], "Text",
  CellTags->"attracting root"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 4\)]],
  ", visualize to which \[OpenCurlyDoubleQuote]attracting\
\[CloseCurlyDoubleQuote] root (out of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[PlusMinus]\[ImaginaryI]\),
          "Input"], TraditionalForm]]],
  ") the Newton iteration converges. Note that the color of each point is \
determined by the ",
  Cell[BoxData[
      FormBox[
        StyleBox["Arg",
          "Input"], TraditionalForm]]],
  " of the attracting root ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Arg({\(+1\), \(-1\), \(+\[ImaginaryI]\), \
\(-\[ImaginaryI]\)})\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Interpret the result. ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "For fun, run the following code to produce an array of graphics (generated \
using ",
  Cell[BoxData[
      FormBox[
        StyleBox["GraphicsArray",
          "Input"], TraditionalForm]]],
  ") that show the convergence of points in the complex plane, for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ranging from 5 to 13."
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(Show(
        GraphicsArray(
          Partition(
            Table(DensityPlot(
                NewtonIteration(n, x + \[ImaginaryI]\ y), {x, 
                  1.1, \(-1.1\)}, {y, \(-1.1\), 1.1}, PlotPoints \[Rule] 30, 
                Compiled \[Rule] False, Frame \[Rule] False, 
                DisplayFunction \[Rule] Identity), {n, 5, 13}), 3), 
          GraphicsSpacing \[Rule] 0.05));\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " Feigenbaum Bifurcation Diagram"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Feigenbaum bifurcation diagram",
    FontSlant->"Italic"],
  " shows the behavior of iterates of ",
  Cell[BoxData[
      \(TraditionalForm\`x \[RightTeeArrow] \[Mu]\ x\ \((1 - x)\)\)]],
  " and displays the ",
  StyleBox["period-doubling route to chaos",
    FontSlant->"Italic"],
  ". The following code iterates this mapping 300 times using ",
  Cell[BoxData[
      FormBox[
        StyleBox["NestList",
          "Input"], TraditionalForm]]],
  " and then deletes the first 100 iterations (during which time the \
iteration \"settles down\")."
}], "Text",
  CellTags->{
  "NestList", "period-doubling route to chaos", 
    "Feigenbaum bifurcation diagram"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"Feigenbaum", "=", 
          RowBox[{"Compile", "(", 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"\[Mu]", "_Real"}
                    }], ")"}], 
              ",", \(\(({\[Mu], #} &)\) /@ \(Drop(
                  NestList(\[Mu]\ #\ \((1 - #)\) &, 0.2, 300), 100)\)\)}], 
            ")"}]}], ";"}], TraditionalForm]], "Input",
  CellTags->"Feigenbaum"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Mu]values = 
              Flatten(Table(Feigenbaum(\[Mu]), {\[Mu], 1.0, 4.0, 0.005}), 
                1);\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " generates a table of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({\[Mu], Feigenbaum(\[Mu])}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " values for ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Mu]",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " ranging from 1 to 4 in steps of 0.005.  Visualize ",
  StyleBox["Union[\[Mu]values]", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  ". (",
  StyleBox["Union", "InlineInputTraditionalForm"],
  " eliminates duplicates.) Where does period-doubling commence? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Fvalues = Last /@ \[Mu]values;\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " to obtain a list of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Feigenbaum(\[Mu])\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " values. Listen to ",
  StyleBox["Fvalues", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["ListPlay", "InlineInputTraditionalForm"],
  ". Describe what you hear. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P00000=j8W4?m0oeThGBNb0dL5N`?P0080001804P000003;T8^`01
0000I00000400@410?l00BL?00400@0000000000000006P801T1T0000000h000
00000000004000000000000000000082\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "harmonic approximation"->{
    Cell[4765, 170, 388, 15, 26, "Text",
      CellTags->"harmonic approximation"]},
  "damping"->{
    Cell[5297, 191, 433, 15, 26, "Text",
      CellTags->{"damping", "sinusoidal driving term"}]},
  "sinusoidal driving term"->{
    Cell[5297, 191, 433, 15, 26, "Text",
      CellTags->{"damping", "sinusoidal driving term"}]},
  "undamped pendulum"->{
    Cell[6436, 239, 194, 6, 26, "Text",
      CellTags->"undamped pendulum"]},
  "phase-space plot"->{
    Cell[7008, 259, 1508, 40, 86, "BeginEndQuestion",
      CellTags->"phase-space plot"]},
  "damped pendulum"->{
    Cell[10924, 397, 214, 6, 38, "Text",
      CellTags->"damped pendulum"]},
  "period-3 limit cycle"->{
    Cell[16028, 571, 301, 9, 38, "Text",
      CellTags->{"period-3 limit cycle", "periodic"}]},
  "periodic"->{
    Cell[16028, 571, 301, 9, 38, "Text",
      CellTags->{"period-3 limit cycle", "periodic"}]},
  "Poincar\[EAcute] section"->{
    Cell[16332, 582, 297, 7, 38, "Text",
      CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
  "driving frequency"->{
    Cell[16332, 582, 297, 7, 38, "Text",
      CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
  "transient effects"->{
    Cell[16926, 602, 141, 4, 36, "Text",
      CellTags->"transient effects"]},
  "series solution"->{
    Cell[18278, 659, 575, 18, 38, "Text",
      CellTags->"series solution"]},
  "linearized equation"->{
    Cell[43552, 1438, 292, 12, 38, "Text",
      CellTags->"linearized equation"]},
  "Iterated mapping"->{
    Cell[45250, 1524, 773, 24, 54, "Text",
      CellTags->{"Iterated mapping", "Bounded absolute value"}],
    Cell[60882, 2058, 485, 14, 54, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "Bounded absolute value"->{
    Cell[45250, 1524, 773, 24, 54, "Text",
      CellTags->{"Iterated mapping", "Bounded absolute value"}]},
  "Module"->{
    Cell[47121, 1593, 765, 25, 54, "Text",
      CellTags->"Module"]},
  "pure function"->{
    Cell[48123, 1626, 402, 13, 38, "Text",
      CellTags->{"pure function", "Function"}],
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "Function"->{
    Cell[48123, 1626, 402, 13, 38, "Text",
      CellTags->{"pure function", "Function"}],
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "rank-2 tensor"->{
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "TraditionalForm"->{
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "numerical functions"->{
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "Compile"->{
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}],
    Cell[51713, 1744, 709, 24, 40, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "argument typing"->{
    Cell[50868, 1718, 842, 24, 42, "Warning",
      CellTags->{
      "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
        "Compile", "argument typing"}]},
  "machine-precision numbers"->{
    Cell[51713, 1744, 709, 24, 40, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "variable declarations"->{
    Cell[51713, 1744, 709, 24, 40, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "_Complex"->{
    Cell[51713, 1744, 709, 24, 40, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "_Integer"->{
    Cell[51713, 1744, 709, 24, 40, "Warning",
      CellTags->{
      "Compile", "machine-precision numbers", "variable declarations", 
        "_Complex", "_Integer"}]},
  "Guessing variable types"->{
    Cell[53269, 1804, 1159, 42, 42, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "local variable"->{
    Cell[53269, 1804, 1159, 42, 42, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "JuliaCompile"->{
    Cell[53269, 1804, 1159, 42, 42, "Warning",
      CellTags->{
      "Guessing variable types", "local variable", "JuliaCompile"}]},
  "FixedPoint"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "FixedPointList"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "fractal sets"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "stopping condition"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "SameTest"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "True"->{
    Cell[54980, 1868, 972, 19, 78, "Text",
      CellTags->{
      "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
        "SameTest", "pure function", "True"}]},
  "Julia set"->{
    Cell[58104, 1966, 494, 17, 50, "BeginEndQuestion",
      CellTags->"Julia set"]},
  "connected Julia sets"->{
    Cell[60882, 2058, 485, 14, 54, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "Mandelbrot set"->{
    Cell[60882, 2058, 485, 14, 54, "Text",
      CellTags->{
      "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
  "complex argument"->{
    Cell[61748, 2096, 749, 24, 42, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "n-th roots of unity"->{
    Cell[61748, 2096, 749, 24, 42, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "Newton iteration"->{
    Cell[61748, 2096, 749, 24, 42, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "Newton's method"->{
    Cell[61748, 2096, 749, 24, 42, "Text",
      CellTags->{
      "complex argument", "n-th roots of unity", "Newton iteration", 
        "Newton's method"}]},
  "pure function replacement rule"->{
    Cell[62992, 2140, 697, 26, 35, "BrightIdea",
      CellTags->"pure function replacement rule"]},
  "attracting root"->{
    Cell[64196, 2184, 201, 7, 36, "Text",
      CellTags->"attracting root"]},
  "NestList"->{
    Cell[66347, 2265, 699, 20, 42, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "period-doubling route to chaos"->{
    Cell[66347, 2265, 699, 20, 42, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "Feigenbaum bifurcation diagram"->{
    Cell[66347, 2265, 699, 20, 42, "Text",
      CellTags->{
      "NestList", "period-doubling route to chaos", 
        "Feigenbaum bifurcation diagram"}]},
  "Feigenbaum"->{
    Cell[67049, 2287, 450, 12, 24, "Input",
      CellTags->"Feigenbaum"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"harmonic approximation", 133664, 4671},
  {"damping", 133764, 4674},
  {"sinusoidal driving term", 133894, 4677},
  {"undamped pendulum", 134018, 4680},
  {"phase-space plot", 134121, 4683},
  {"damped pendulum", 134236, 4686},
  {"period-3 limit cycle", 134342, 4689},
  {"periodic", 134455, 4692},
  {"Poincar\[EAcute] section", 134584, 4695},
  {"driving frequency", 134719, 4698},
  {"transient effects", 134854, 4701},
  {"series solution", 134957, 4704},
  {"linearized equation", 135063, 4707},
  {"Iterated mapping", 135171, 4710},
  {"Bounded absolute value", 135441, 4716},
  {"Module", 135564, 4719},
  {"pure function", 135656, 4722},
  {"Function", 135949, 4729},
  {"rank-2 tensor", 136244, 4736},
  {"TraditionalForm", 136450, 4741},
  {"numerical functions", 136660, 4746},
  {"Compile", 136858, 4751},
  {"argument typing", 137234, 4760},
  {"machine-precision numbers", 137450, 4765},
  {"variable declarations", 137650, 4770},
  {"_Complex", 137837, 4775},
  {"_Integer", 138024, 4780},
  {"Guessing variable types", 138226, 4785},
  {"local variable", 138383, 4789},
  {"JuliaCompile", 138538, 4793},
  {"FixedPoint", 138691, 4797},
  {"FixedPointList", 138899, 4802},
  {"fractal sets", 139105, 4807},
  {"stopping condition", 139317, 4812},
  {"SameTest", 139519, 4817},
  {"True", 139717, 4822},
  {"Julia set", 139920, 4827},
  {"connected Julia sets", 140034, 4830},
  {"Mandelbrot set", 140188, 4834},
  {"complex argument", 140344, 4838},
  {"n-th roots of unity", 140532, 4843},
  {"Newton iteration", 140717, 4848},
  {"Newton's method", 140901, 4853},
  {"pure function replacement rule", 141100, 4858},
  {"attracting root", 141224, 4861},
  {"NestList", 141319, 4864},
  {"period-doubling route to chaos", 141516, 4869},
  {"Feigenbaum bifurcation diagram", 141713, 4874},
  {"Feigenbaum", 141890, 4879}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 126, 5, 74, "Title",
  CounterAssignments->{{"Title", 5}}],
Cell[1916, 60, 29, 0, 26, "Author"],
Cell[1948, 62, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2387, 78, 39, 0, 42, "Subsubsection"],
Cell[2429, 80, 215, 5, 26, "Text"],
Cell[2647, 87, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2762, 91, 87, 3, 24, "Text"],
Cell[2852, 96, 117, 2, 24, "Input",
  InitializationCell->True],
Cell[2972, 100, 270, 8, 26, "Text"],
Cell[3245, 110, 175, 4, 24, "Input",
  InitializationCell->True],
Cell[3423, 116, 245, 5, 24, "Input",
  InitializationCell->True],
Cell[3671, 123, 182, 4, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3890, 132, 165, 9, 41, "SectionFirst",
  Evaluatable->False],
Cell[4058, 143, 286, 9, 24, "Text"],
Cell[4347, 154, 169, 3, 36, "NumberedEquation"],
Cell[4519, 159, 243, 9, 29, "Text"],
Cell[4765, 170, 388, 15, 26, "Text",
  CellTags->"harmonic approximation"],
Cell[5156, 187, 138, 2, 25, "NumberedEquation"],
Cell[5297, 191, 433, 15, 26, "Text",
  CellTags->{"damping", "sinusoidal driving term"}],
Cell[5733, 208, 237, 4, 25, "NumberedEquation"],
Cell[5973, 214, 280, 9, 26, "Text"],

Cell[CellGroupData[{
Cell[6278, 227, 155, 10, 54, "Subsection"],
Cell[6436, 239, 194, 6, 26, "Text",
  CellTags->"undamped pendulum"],
Cell[6633, 247, 372, 10, 24, "Input"],
Cell[7008, 259, 1508, 40, 86, "BeginEndQuestion",
  CellTags->"phase-space plot"],
Cell[8519, 301, 19, 0, 32, "Answer"],
Cell[8541, 303, 422, 13, 26, "Warning"],
Cell[8966, 318, 461, 14, 50, "BeginEndQuestion"],
Cell[9430, 334, 445, 15, 50, "BeginEndQuestion"],
Cell[9878, 351, 19, 0, 32, "Answer"],
Cell[9900, 353, 809, 25, 70, "BeginEndQuestion"],
Cell[10712, 380, 19, 0, 32, "Answer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10768, 385, 153, 10, 54, "Subsection"],
Cell[10924, 397, 214, 6, 38, "Text",
  CellTags->"damped pendulum"],
Cell[11141, 405, 564, 14, 24, "Input"],
Cell[11708, 421, 740, 23, 64, "BeginEndQuestion"],
Cell[12451, 446, 19, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[12507, 451, 160, 10, 32, "Subsection"],
Cell[12670, 463, 137, 5, 26, "Text"],
Cell[12810, 470, 608, 15, 24, "Input"],
Cell[13421, 487, 1443, 41, 84, "BeginEndQuestion"],
Cell[14867, 530, 18, 0, 32, "Answer"],
Cell[14888, 532, 1116, 35, 64, "BeginEndQuestion"],
Cell[16007, 569, 18, 0, 32, "Answer"],
Cell[16028, 571, 301, 9, 38, "Text",
  CellTags->{"period-3 limit cycle", "periodic"}],
Cell[16332, 582, 297, 7, 38, "Text",
  CellTags->{"Poincar\[EAcute] section", "driving frequency"}],
Cell[16632, 591, 291, 9, 54, "BeginEndQuestion"],
Cell[16926, 602, 141, 4, 36, "Text",
  CellTags->"transient effects"],
Cell[17070, 608, 994, 32, 68, "BeginEndQuestion"],
Cell[18067, 642, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[18122, 647, 153, 10, 32, "Subsection"],
Cell[18278, 659, 575, 18, 38, "Text",
  CellTags->"series solution"],

Cell[CellGroupData[{
Cell[18878, 681, 335, 9, 25, "Input"],
Cell[19216, 692, 5970, 160, 72, "Output"]
}, Open  ]],
Cell[25201, 855, 328, 11, 24, "Text"],

Cell[CellGroupData[{
Cell[25554, 870, 78, 1, 25, "Input"],
Cell[25635, 873, 2081, 60, 38, "Output"]
}, Open  ]],
Cell[27731, 936, 1444, 46, 42, "Text"],

Cell[CellGroupData[{
Cell[29200, 986, 68, 1, 24, "Input"],
Cell[29271, 989, 3478, 99, 72, "Output"]
}, Open  ]],
Cell[32764, 1091, 870, 28, 26, "Text"],

Cell[CellGroupData[{
Cell[33659, 1123, 407, 11, 25, "Input"],
Cell[34069, 1136, 2372, 61, 25, "Output"]
}, Open  ]],
Cell[36456, 1200, 210, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[36691, 1210, 69, 1, 24, "Input"],
Cell[36763, 1213, 1606, 45, 38, "Output"]
}, Open  ]],
Cell[38384, 1261, 391, 13, 24, "Text"],

Cell[CellGroupData[{
Cell[38800, 1278, 343, 9, 24, "Input"],
Cell[39146, 1289, 586, 17, 41, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[39781, 1312, 179, 10, 32, "Subsection"],
Cell[39963, 1324, 64, 0, 24, "Text"],
Cell[40030, 1326, 309, 8, 25, "NumberedEquation"],
Cell[40342, 1336, 986, 38, 66, "BeginEndQuestion"],
Cell[41331, 1376, 2218, 60, 38, "Output"],
Cell[43552, 1438, 292, 12, 38, "Text",
  CellTags->"linearized equation"],
Cell[43847, 1452, 304, 8, 25, "NumberedEquation"],
Cell[44154, 1462, 627, 25, 66, "BeginEndQuestion"],
Cell[44784, 1489, 18, 0, 32, "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44851, 1495, 123, 8, 39, "Section"],
Cell[44977, 1505, 98, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[45100, 1512, 147, 10, 54, "Subsection"],
Cell[45250, 1524, 773, 24, 54, "Text",
  CellTags->{"Iterated mapping", "Bounded absolute value"}],
Cell[46026, 1550, 1071, 39, 68, "BeginEndQuestion"],
Cell[47100, 1591, 18, 0, 32, "Answer"],
Cell[47121, 1593, 765, 25, 54, "Text",
  CellTags->"Module"],
Cell[47889, 1620, 231, 4, 25, "Input"],
Cell[48123, 1626, 402, 13, 38, "Text",
  CellTags->{"pure function", "Function"}],
Cell[48528, 1641, 258, 5, 25, "Input"],
Cell[48789, 1648, 89, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[48903, 1655, 233, 4, 24, "Input"],
Cell[49139, 1661, 79, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49255, 1667, 235, 4, 24, "Input"],
Cell[49493, 1673, 79, 1, 22, "Output"]
}, Open  ]],
Cell[49587, 1677, 392, 11, 42, "Text"],
Cell[49982, 1690, 606, 15, 55, "Input"],
Cell[50591, 1707, 274, 9, 52, "BeginEndQuestion"],
Cell[50868, 1718, 842, 24, 42, "Warning",
  CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
    "Compile", "argument typing"}],
Cell[51713, 1744, 709, 24, 40, "Warning",
  CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
     "_Integer"}],
Cell[52425, 1770, 499, 18, 26, "Warning"],
Cell[52927, 1790, 198, 6, 55, "Input"],
Cell[53128, 1798, 38, 0, 24, "Text"],
Cell[53169, 1800, 97, 2, 24, "Input"],
Cell[53269, 1804, 1159, 42, 42, "Warning",
  CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],
Cell[54431, 1848, 546, 18, 52, "BeginEndQuestion"],
Cell[54980, 1868, 972, 19, 78, "Text",
  CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
    "SameTest", "pure function", "True"}],

Cell[CellGroupData[{
Cell[55977, 1891, 175, 3, 24, "Input"],
Cell[56155, 1896, 70, 1, 22, "Output"]
}, Open  ]],
Cell[56240, 1900, 418, 15, 52, "BeginEndQuestion"],
Cell[56661, 1917, 238, 7, 26, "Text"],
Cell[56902, 1926, 514, 14, 39, "Input"],
Cell[57419, 1942, 682, 22, 44, "Text"],
Cell[58104, 1966, 494, 17, 50, "BeginEndQuestion",
  CellTags->"Julia set"],
Cell[58601, 1985, 1221, 33, 102, "BeginEndQuestion"],
Cell[59825, 2020, 414, 11, 24, "Text"],
Cell[60242, 2033, 444, 8, 72, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60723, 2046, 156, 10, 32, "Subsection"],
Cell[60882, 2058, 485, 14, 54, "Text",
  CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],
Cell[61370, 2074, 185, 5, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[61592, 2084, 153, 10, 32, "Subsection"],
Cell[61748, 2096, 749, 24, 42, "Text",
  CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
    "Newton's method"}],

Cell[CellGroupData[{
Cell[62522, 2124, 368, 10, 42, "Input"],
Cell[62893, 2136, 84, 1, 39, "Output"]
}, Open  ]],
Cell[62992, 2140, 697, 26, 35, "BrightIdea",
  CellTags->"pure function replacement rule"],
Cell[63692, 2168, 37, 0, 24, "Text"],
Cell[63732, 2170, 461, 12, 41, "Input"],
Cell[64196, 2184, 201, 7, 36, "Text",
  CellTags->"attracting root"],
Cell[64400, 2193, 898, 29, 65, "BeginEndQuestion"],
Cell[65301, 2224, 18, 0, 32, "Answer"],
Cell[65322, 2226, 366, 11, 40, "Text"],
Cell[65691, 2239, 448, 9, 42, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[66176, 2253, 168, 10, 32, "Subsection"],
Cell[66347, 2265, 699, 20, 42, "Text",
  CellTags->{
  "NestList", "period-doubling route to chaos", 
    "Feigenbaum bifurcation diagram"}],
Cell[67049, 2287, 450, 12, 24, "Input",
  CellTags->"Feigenbaum"],
Cell[67502, 2301, 963, 28, 67, "BeginEndQuestion"],
Cell[68468, 2331, 18, 0, 32, "Answer"],
Cell[68489, 2333, 603, 19, 52, "BeginEndQuestion"],
Cell[69095, 2354, 18, 0, 32, "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

