(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    134878,       4431]*)
(*NotebookOutlinePosition[    210954,       7047]*)
(*  CellTagsIndexPosition[    209269,       7002]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ". Schr\[ODoubleDot]dinger Equation"
}], "Title",
  CounterAssignments->{{"Title", 6}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "Several ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics packages are used in this work. Entering"
}], "Text"],

Cell[BoxData[
    FormBox[
      FormBox[\(<< Graphics`\),
        "TraditionalForm"], TraditionalForm]], "Input",
  InitializationCell->True],

Cell["and for \[OpenCurlyDoubleQuote]pretty\[CloseCurlyDoubleQuote] plots:", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\(SetOptions[ParametricPlot3D, 
        PlotPoints \[Rule] {50, 20}, PlotRange \[Rule] All, 
        Axes \[Rule] True, AxesLabel \[Rule] {x, y, z}, Ticks \[Rule] None, 
        Boxed \[Rule] True, BoxRatios \[Rule] {1, 1, 1}];\)\)], "Input",
  InitializationCell->True],

Cell["We define a routine for plotting angular momentum diagrams:", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(vecs(l_)\), ":=", 
        RowBox[{"Show", "[", 
          RowBox[{"Graphics", "[", 
            RowBox[{
              RowBox[{"Table", "[", 
                RowBox[{
                  RowBox[{"{", 
                    
                    RowBox[{\(Text[\@\(j\ \((j + 1)\)\), \ 
                        0.85 {\@\(l\ \((l + 1)\)\), \@\(l\ \((l + 1)\)\)}]\), 
                      ",", \(GrayLevel[0.5]\), ",", 
                      RowBox[{"Line", "[", 
                        RowBox[{"(", "\[NoBreak]", GridBox[{
                              {"0", "m"},
                              {\(\@\(l\ \((l + 1)\) - m\^2\)\), "m"}
                              }], "\[NoBreak]", ")"}], "]"}], 
                      ",", \(GrayLevel[0]\), 
                      ",", \(Arrow({0, 0}, {\@\(l\ \((l + 1)\) - m\^2\), 
                          m})\), ",", \(Hue[1]\), 
                      ",", \(Circle[{0, 
                          0}, \ \@\(l\ \((l + 1)\)\), {\(-\[Pi]\)\/2, \
\[Pi]\/2}]\)}], "}"}], ",", \({m, \(-l\), l}\)}], "]"}], 
              ",", \(AspectRatio \[Rule] Automatic\), 
              ",", \(Axes \[Rule] True\), 
              ",", \(AxesLabel \[Rule] {"\<\>", m}\), 
              ",", \(Ticks \[Rule] {Table[i, {i, 0, l}], 
                  Table[i, {i, \(-l\), l}]}\)}], "]"}], "]"}]}], 
      TraditionalForm]], "Input",
  InitializationCell->True],

Cell["\<\
Complex conjugation is easily achieved using a replacement \
rule:\
\>", "Text",
  CellTags->"complex conjugation"],

Cell[BoxData[
    \(TraditionalForm\`\(exp_\^*\) := 
      exp /. Complex(a_, b_) \[Rule] Complex(a, \(-b\))\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "We use the ",
  StyleBox["Notation", "InlineInputTraditionalForm"],
  " package,"
}], "Text"],

Cell[BoxData[
    FormBox[
      FormBox[\(Utilities`Notation`AutoLoadNotationPalette\  = \ False;\),
        "TraditionalForm"], TraditionalForm]], "Input",
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      FormBox[\(<< Utilities`Notation`\),
        "TraditionalForm"], TraditionalForm]], "Input",
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      FormBox[\(SetOptions[Notation, 
            WorkingForm\  \[Rule] \ TraditionalForm];\),
        "TraditionalForm"], TraditionalForm]], "Input",
  InitializationCell->True],

Cell[TextData[{
  "to define custom input and output notation for the 3-",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " and Clebsch-Gordan coefficients."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[
            SubscriptBox[
              RowBox[{"(", GridBox[{
                    {"j1_", "j2_", "j3_"},
                    {"m1_", "m2_", "m3_"}
                    }], " ", ")"}], \(3  j\)],
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          
          TagBox[\(ThreeJSymbol[{j1_, \ m1_}, \ {j2_, \ m2_}, \ {j3_, \ 
                m3_}]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      TraditionalForm]], "Input",
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      FormBox[
        RowBox[{"Notation", "[", 
          RowBox[{
            
            TagBox[\(\[LeftAngleBracket]\(\(j1_\)\(,\)\)\[InvisibleComma]\(\(\
j2_\)\(,\)\)\[InvisibleComma]\(\(m1_\)\(,\)\)\[InvisibleComma]\(\(m2_ \
\[VerticalSeparator] j_\)\(,\)\)\[InvisibleComma]m_\[RightAngleBracket]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"], " ", 
            "\[DoubleLongLeftRightArrow]", " ", 
            
            TagBox[\(ClebschGordan[{j1_, \ m1_}, \ {j2_, \ m2_}, \ {j_, \ 
                  m_}]\),
              NotationBoxTag,
              TagStyle->"NotationTemplateStyle"]}], "]"}],
        "TraditionalForm"], TraditionalForm]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ". Hydrogen"
}], "SectionFirst"],

Cell["\<\
Atomic orbitals are obtained by solving the Schr\[ODoubleDot]dinger \
equation,\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"H", " ", 
            RowBox[{"\[CapitalPsi]", "(", 
              StyleBox["r",
                FontWeight->"Bold"], ")"}]}], "=", 
          RowBox[{"E", " ", 
            RowBox[{"\[CapitalPsi]", "(", 
              StyleBox["r",
                FontWeight->"Bold"], ")"}]}]}], ",", " ", 
        RowBox[{"H", "=", 
          RowBox[{"T", "+", 
            RowBox[{"V", "(", 
              StyleBox["r",
                FontWeight->"Bold"], ")"}]}]}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " are the kinetic and potential energy operators, respectively."
}], "Text"],

Cell[TextData[{
  "For a one-electron atom the potential is ",
  StyleBox["spherically symmetric",
    FontSlant->"Italic"],
  " ",
  "and the solutions can be separated into radial and angular components via \
spherical polar coordinates ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold"], "=", \((r, \[Theta], \[Phi])\)}], 
        TraditionalForm]]],
  ". The complete solution, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalPsi]", "(", 
          StyleBox["r",
            FontWeight->"Bold"], ")"}], TraditionalForm]]],
  ", is simply the product of these functions and depends upon three ",
  StyleBox["quantum numbers",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->{
  "spherical polar coordinates", "spherically symmetric", "quantum numbers"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[CapitalPsi]\_\(n, l, m\)\), "(", 
          StyleBox["r",
            FontWeight->"Bold"], ")"}], 
        "=", \(\(\(R\_\(n, l\)\)(
            r)\) \(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\(.\)\)\)}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "To assist you in understanding the concepts presented in this assignment, \
you may find the information at the ",
  ButtonBox["Atomic Orbitals",
    ButtonData:>{
      URL[ "http://www.shodor.org/chemviz/"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Computational Chemistry",
    ButtonData:>{
      URL[ "http://www.calvin.edu/academic/chemistry/homedocs/compchem/"], 
      None},
    ButtonStyle->"Hyperlink"],
  " hyperlinks useful."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". ",
  "Laplacian operator"
}], "Subsection"],

Cell[TextData[{
  "For a one-electron atom the kinetic energy operator (in ",
  ButtonBox["atomic units",
    ButtonData:>{
      URL[ 
      "http://www.calvin.edu/academic/chemistry/homedocs/compchem/primer/\
intro2e.htm"], None},
    ButtonStyle->"Hyperlink"],
  ") is ",
  Cell[BoxData[
      \(TraditionalForm\`T = \(-\(1\/2\)\) \[CapitalDelta]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  " is the three-dimensional Laplacian operator,"
}], "Text",
  CellTags->{"Laplacian operator", "kinetic energy operator", "atomic units"}],

Cell[BoxData[
    \(TraditionalForm\`\[CapitalDelta] = \[PartialD]\^2\/\[PartialD]x\^2 + \
\[PartialD]\^2\/\[PartialD]y\^2 + \(\(\[PartialD]\^2\/\[PartialD]z\^2\)\(\
\[CenterDot]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "In spherical polar coordinate",
  "s, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold"], "=", \((r, \[Theta], \[Phi])\)}], 
        TraditionalForm]]],
  ", this becomes"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[CapitalDelta]", "=", 
          RowBox[{
            RowBox[{\(1\/r\^2\), 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  RowBox[{"(", 
                    RowBox[{\(r\^2\), " ", 
                      FractionBox["\[PartialD]", \(\[PartialD]r\),
                        MultilineFunction->None]}], ")"}]}], \(\[PartialD]r\),
                
                MultilineFunction->None]}], 
            "-", \(\(1\/r\^2\) \(\(l\^2\)(\[Theta], \[Phi])\)\)}]}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where the angular part, ",
  Cell[BoxData[
      \(TraditionalForm\`\(l\^2\)(\[Theta], \[Phi])\)]],
  ", is the square of the (total) angular momentum operator,"
}], "Text",
  CellTags->"angular momentum operator"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(l\^2\)(\[Theta], \[Phi])\), "=", 
        RowBox[{"-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(1\/\(sin(\[Theta])\)\), 
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      RowBox[{"(", 
                        RowBox[{\(sin(\[Theta])\), " ", 
                          FractionBox["\[PartialD]", \(\[PartialD]\[Theta]\),
                            MultilineFunction->None]}], 
                        ")"}]}], \(\[PartialD]\[Theta]\),
                    MultilineFunction->None]}], "+", 
                RowBox[{\(1\/\(\(sin\^2\)(\[Theta])\)\), 
                  FractionBox[\(\[PartialD]\^2\), \(\[PartialD]\[Phi]\^2\),
                    MultilineFunction->None]}]}], ")"}], "."}]}]}], 
      TraditionalForm]], "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Schr\[ODoubleDot]dinger equation for ",
  "one-electron atoms"
}], "Subsection"],

Cell[TextData[{
  "For a spherically symmetric potential, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"V", "(", 
            StyleBox["r",
              FontWeight->"Bold"], ")"}], "=", \(V(r)\)}], 
        TraditionalForm]]],
  ", using ",
  StyleBox["separation of variables ",
    FontSlant->"Italic"],
  "the solution can be written as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalPsi]", "(", 
            StyleBox["r",
              FontWeight->"Bold"], ")"}], 
          "=", \(\(R(r)\) \(Y(\[Theta], \[Phi])\)\)}], TraditionalForm]]],
  ". Substituting this expression into the Schr\[ODoubleDot]dinger equation \
and choosing the ",
  StyleBox["separation constant",
    FontSlant->"Italic"],
  " to be ",
  Cell[BoxData[
      \(TraditionalForm\`l\ \((l + 1)\)\)]],
  " leads to a pair of equations: the angular equation,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\(l\^2\)(\[Theta], \[Phi])\) \(Y(\[Theta], \
\[Phi])\) = 
      l\ \((l + 1)\) \(Y(\[Theta], \[Phi])\)\)\(,\)\)\)], "NumberedEquation"],

Cell["and the radial equation,", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(R\_\(n, l\)\%\[DoublePrime]\)(
          r) + \(2\/r\) \(\(R\_\(n, l\)\%\[Prime]\)(
            r)\) + \((2  E - 
              2 \( V(r)\) - \(l\ \((l + 1)\)\)\/r\^2)\) \(\(R\_\(n, l\)\)(
            r)\) = 0. \)], "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Angular solutions"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData["Table of values"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The angular eigenfunctions are the spherical harmonics, ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  ", which are built-in."
}], "Text",
  CellTags->"spherical harmonics"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Produce a table of ",
    FontSlant->"Plain"],
  "spherical harmonics",
  StyleBox[", ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  ", ",
  StyleBox["for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, 2\)]],
  " ",
  StyleBox["and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m = \(-l\), \(-l\) + 1, \ \[Ellipsis], \ l - 1, \ 
      l\)]],
  StyleBox[". Display using ",
    FontSlant->"Plain"],
  StyleBox["TableForm", "InlineInputTraditionalForm",
    FontSlant->"Plain"],
  StyleBox[". ",
    FontSlant->"Plain"],
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenfunction equation", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation, the (squared) total angular momentum operator, \
\[ScriptCapitalL], is"
}], "Text",
  CellTags->"total angular momentum operator"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalL][f_]\), ":=", 
        RowBox[{"-", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(1\/\(sin(\[Theta])\)\), 
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    RowBox[{"(", 
                      RowBox[{\(sin(\[Theta])\), " ", 
                        
                        FractionBox[\(\[PartialD]f\), \(\[PartialD]\[Theta]\),
                          
                          MultilineFunction->None]}], 
                      ")"}]}], \(\[PartialD]\[Theta]\),
                  MultilineFunction->None]}], "+", 
              RowBox[{\(1\/\(\(sin\^2\)(\[Theta])\)\), 
                FractionBox[\(\[PartialD]\^2 f\), \(\[PartialD]\[Phi]\^2\),
                  MultilineFunction->None]}]}], ")"}]}]}], 
      TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "and the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-component operator is"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalL]\_z[f_]\), ":=", 
        RowBox[{\(-\[ImaginaryI]\), " ", 
          FractionBox[\(\[PartialD]f\), \(\[PartialD]\[Phi]\),
            MultilineFunction->None]}]}], TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell["The spherical harmonics satisfy the eigenfunction relations:", "Text",
  CellTags->"eigenfunction relation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\(l\^2\)(\[Theta], \[Phi])\) \(\(Y\_l\%m\)(\
\[Theta], \[Phi])\) = 
      l\ \((l + 
            1)\) \(\(Y\_l\%m\)(\[Theta], \[Phi])\)\)\(,\)\)\)], \
"NumberedEquation"],

Cell[BoxData[
    \(TraditionalForm\`\(\(l\_z\)(\[Theta], \[Phi])\) \(\(Y\_l\%m\)(\[Theta], \
\[Phi])\) = 
      m\ \(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\(.\)\)\)], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Verify that the ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  StyleBox[" satisfy both eigenfunction equations for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], 3\)]],
  " ",
  StyleBox["and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m = \(-l\), \(-l\) + 1, \ \[Ellipsis], \ l - 1, \ 
      l\)]],
  StyleBox[". ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["Orthonormality", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The usefulness of the spherical harmonics, ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  ", is that they are orthogonal (actually orthonormal) and form a complete \
basis set for the expansion of ",
  StyleBox["any",
    FontSlant->"Italic"],
  " angular function in 3-space (including the atomic orbitals of any atom). \
The orthonormality is defined by"
}], "Text",
  CellTags->"complete basis set"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%\[Pi]\), 
              RowBox[{
                
                FormBox[
                  \(\(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\^*\) 
                    \(\(Y\_L\%M\)(\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\),
                  "TraditionalForm"], \(\[DifferentialD]\[Theta]\), 
                \(\[DifferentialD]\[Phi]\)}]}]}], "=", 
          \(\(\[Delta]\_\(l, L\)\) \[Delta]\_\(m, M\)\)}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\^*\)\)]],
  " is the ",
  StyleBox["complex conjugate",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  " (implemented as a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  ButtonBox["rule",
    ButtonData:>"complex conjugation",
    ButtonStyle->"Hyperlink"],
  " in the pre-requisites section above), and the ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\[Theta])\)]],
  " term comes from the angular part of the integration volume element, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[DifferentialD]", 
            StyleBox["r",
              FontWeight->"Bold"]}], "=", 
          RowBox[{\(r\^2\), \(\[DifferentialD]r\), 
            FormBox[\(sin(\[Theta])\),
              
              "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->{"integration volume element", "complex conjugate"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Verify that ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\^*\) == \
\(Y\_l\%m\)(\[Theta], \(-\[Phi]\))\)]],
  StyleBox[" by checking ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], 3\)]],
  " ",
  StyleBox["and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m = \(-l\), \(-l\) + 1, \ \[Ellipsis], \ l - 1, \ 
      l\)]],
  StyleBox[". ",
    FontSlant->"Plain"],
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["\<\
The general inner product can be defined using bra-ket notation \
as\
\>", "Text",
  CellTags->"bra-ket notation"],

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]{l_, m_}, {L_, 
          M_}\[RightAngleBracket] := \[Integral]\_0\%\(2\ \
\[Pi]\)\(\[Integral]\_0\%\[Pi]\(\( 
                  Y\_l\%m\)(\[Theta], \(-\[Phi]\))\)\ \(\(Y\_L\%M\)(\[Theta], \
\[Phi])\)\ \(sin(\[Theta])\) \[DifferentialD]\[Theta] \
\[DifferentialD]\[Phi]\)\)], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Verify that the ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  StyleBox[" are orthonormal by checking ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`l, L = 0, 1, \[Ellipsis], 3\)]],
  " ",
  StyleBox["and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`m = \(-l\), \(-l\) + 1, \ \[Ellipsis], \ l - 1, \ 
      l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M = \(-L\), \(-L\) + 1, \ \[Ellipsis], \ L - 1, \ 
      L\)]],
  ".",
  StyleBox[" ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "The spherical harmonics are eigenfunctions of the (squared) total angular \
momentum operator and therefore are a ",
  StyleBox["representation",
    FontSlant->"Italic"],
  " of a state of angular momentum, ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ", and projection quantum number, ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "."
}], "Text",
  CellTags->"representation"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Visualization"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  " are, in general, ",
  StyleBox["complex",
    FontSlant->"Italic"],
  ". We therefore can either plot the real or imaginary parts or the absolute \
value. The ",
  StyleBox["angular charge density distribution",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"angular charge density distribution"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\[CapitalOmega]\_\(l, 
            m\)\)(\[Theta]) = \[LeftBracketingBar]\(Y\_l\%m\)(\[Theta], \
\[Phi])\[RightBracketingBar]\^2\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "is axially symmetric with respect to the azimuthal angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ". After defining the angular distribution function:"
}], "Text",
  CellTags->"axial symmetry"],

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalOmega]\_\(l_, 
            m_\)\)(\[Theta]_) := \(\(Y\_l\%m\)(\[Theta], \[Phi])\)\ \
\(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\^*\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "individual charge densities can be immediately examined, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalOmega]\_\(3, 1\)\)(\[Theta])\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(21\ \((5\ \(\(cos\^2\)(\[Theta])\) - 1)\)\^2\ \
\(\(sin\^2\)(\[Theta])\)\)\/\(64\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can see that this result is ",
  "independent of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ". In such cases, ",
  StyleBox["PolarPlot", "InlineInputTraditionalForm"],
  " can provide a complete view of the atomic orbitals.  "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["PolarPlot", "InlineInputTraditionalForm"],
  " to visualize the atomic orbitals for the ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-states (",
  Cell[BoxData[
      \(TraditionalForm\`l = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, 1\)]],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  "-states (",
  Cell[BoxData[
      \(TraditionalForm\`l = 2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, 1, 2\)]],
  "). ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"PolarPlot"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Use ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["SphericalPlot3D",
          "Input"], TraditionalForm]]],
  StyleBox[" to plot ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalOmega]\_\(3, 1\)\)(\[Theta])\)]],
  StyleBox[" (an ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  "-orbital) ",
  StyleBox["over appropriate ranges for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  StyleBox[" and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  StyleBox[".",
    FontSlant->"Plain"],
  " ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"SphericalPlot3D"],

Cell[TextData[{
  "Your graphic should be similar to the usual pictures you see of atomic \
orbitals. The colour shown is simply an artificial shading (generated by ",
  Cell[BoxData[
      FormBox[
        StyleBox["Lighting",
          "Input"], TraditionalForm]]],
  ").  It is possible to shade the ",
  Cell[BoxData[
      FormBox[
        StyleBox["SphericalPlot3D",
          "Input"], TraditionalForm]]],
  " by, say, the ",
  StyleBox["phase",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[Phi])\)]],
  ". You need to turn off ",
  Cell[BoxData[
      FormBox[
        StyleBox["Lighting",
          "Input"], TraditionalForm]]],
  " if you do this. "
}], "Warning"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Radial solutions"
}], "Subsection"],

Cell[TextData[{
  "Assuming nuclear charge ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ", the (Coulomb) potential is ",
  Cell[BoxData[
      \(TraditionalForm\`V = \(-\(Z\/r\)\)\)]],
  " and the radial equation reads"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(R\_\(n, l\)\%\[DoublePrime]\)(
          r) + \(2\/r\) \(\(R\_\(n, l\)\%\[Prime]\)(
            r)\) + \((2  
                E + \(2  Z\)\/r - \(l\ \((l + 1)\)\)\/r\^2)\) \(\(R\_\(n, 
                l\)\)(r)\) = 0. \)], "NumberedEquation",
  CellTags->"radial equation"],

Cell["\<\
It turns out that this equation can be solved directly in terms of \
confluent hypergeometric functions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"Simplify", "[", 
        RowBox[{
          FormBox[
            RowBox[{"DSolve", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["R", "\[Prime]\[Prime]",
                        MultilineFunction->None], "(", "r", ")"}], "+", 
                    FractionBox[
                      RowBox[{"2", " ", 
                        RowBox[{
                          SuperscriptBox["R", "\[Prime]",
                            MultilineFunction->None], "(", "r", ")"}]}], "r"],
                     "+", \(\((2  \[ScriptCapitalE] + \(2\ Z\)\/r - \(l\ \((l \
+ 1)\)\)\/r\^2)\)\ \(R(r)\)\)}], "==", "0"}], ",", \(R(r)\), ",", "r"}], 
              "]"}],
            "TraditionalForm"], ",", \(l \[GreaterEqual] 0\)}], "]"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{\(R(r)\), "\[Rule]", 
            
            RowBox[{\(\[ExponentialE]\^\(\(-\@2\)\ r\ \
\@\(-\[ScriptCapitalE]\)\)\), " ", \(r\^l\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "2"], " ", 
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{
                            SubscriptBox["\[InvisiblePrefixScriptBase]", 
                              FormBox["1",
                                "TraditionalForm"]], 
                            SubscriptBox["F", 
                              FormBox["1",
                                "TraditionalForm"]]}], 
                          "\[InvisibleApplication]", 
                          RowBox[{"(", 
                            RowBox[{
                              TagBox[
                                TagBox[
                                  
                                  TagBox[\(l + \(Z\ \
\[ScriptCapitalE]\)\/\(\@2\ \((\(-\[ScriptCapitalE]\))\)\^\(3/2\)\) + 1\),
                                    Hypergeometric1F1,
                                    Editable->True],
                                  InterpretTemplate[ {
                                    SlotSequence[ 1]}&]],
                                Hypergeometric1F1,
                                Editable->False], ";", 
                              TagBox[
                                TagBox[
                                  TagBox[\(2\ \((l + 1)\)\),
                                    Hypergeometric1F1,
                                    Editable->True],
                                  InterpretTemplate[ {
                                    SlotSequence[ 1]}&]],
                                Hypergeometric1F1,
                                Editable->False], ";", 
                              TagBox[\(2\ \@2\ r\ \@\(-\[ScriptCapitalE]\)\),
                                Hypergeometric1F1,
                                Editable->True]}], ")"}]}],
                        InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                        Editable->False],
                      Hypergeometric1F1]}], "+", 
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "1"], " ", 
                    RowBox[{
                      TagBox["U",
                        HypergeometricU], 
                      "(", \(l + \(Z\ \[ScriptCapitalE]\)\/\(\@2\ \((\(-\
\[ScriptCapitalE]\))\)\^\(3/2\)\) + 1, 2\ \((l + 1)\), 
                      2\ \@2\ r\ \@\(-\[ScriptCapitalE]\)\), ")"}]}]}], 
                ")"}]}]}], "}"}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To examine ",
  StyleBox["bound states",
    FontSlant->"Italic"],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE] < 0\)]],
  ") we put ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE] \[Rule] \(-\(Z\^2\/\(2 
                 n\^2\)\)\)\)]],
  " which simplifies things slightly (note that we are not yet assuming ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " to be an integer)."
}], "Text",
  CellTags->"bound states"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"Simplify", "[", 
        RowBox[{
          
          FormBox[\(% /. \[InvisibleSpace]\[ScriptCapitalE] \[Rule] \(-\(Z\^2\
\/\(2  n\^2\)\)\)\),
            "TraditionalForm"], ",", \(n > 0 \[And] Z > 0\)}], "]"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{\(R(r)\), "\[Rule]", 
            
            RowBox[{\(\[ExponentialE]\^\(-\(\(r\ Z\)\/n\)\)\), " ", \(r\^l\), 
              " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "2"], " ", 
                    TagBox[
                      TagBox[
                        RowBox[{
                          RowBox[{
                            SubscriptBox["\[InvisiblePrefixScriptBase]", 
                              FormBox["1",
                                "TraditionalForm"]], 
                            SubscriptBox["F", 
                              FormBox["1",
                                "TraditionalForm"]]}], 
                          "\[InvisibleApplication]", 
                          RowBox[{"(", 
                            RowBox[{
                              TagBox[
                                TagBox[
                                  TagBox[\(l - n + 1\),
                                    Hypergeometric1F1,
                                    Editable->True],
                                  InterpretTemplate[ {
                                    SlotSequence[ 1]}&]],
                                Hypergeometric1F1,
                                Editable->False], ";", 
                              TagBox[
                                TagBox[
                                  TagBox[\(2\ l + 2\),
                                    Hypergeometric1F1,
                                    Editable->True],
                                  InterpretTemplate[ {
                                    SlotSequence[ 1]}&]],
                                Hypergeometric1F1,
                                Editable->False], ";", 
                              TagBox[\(\(2\ r\ Z\)\/n\),
                                Hypergeometric1F1,
                                Editable->True]}], ")"}]}],
                        InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                        Editable->False],
                      Hypergeometric1F1]}], "+", 
                  RowBox[{
                    SubscriptBox[
                      TagBox["c",
                        C], "1"], " ", 
                    RowBox[{
                      TagBox["U",
                        HypergeometricU], "(", \(l - n + 1, 
                      2\ l + 2, \(2\ r\ Z\)\/n\), ")"}]}]}], ")"}]}]}], "}"}],
         "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
However, you might find it difficult to reconcile this result with \
that presented in your textbook so we now proceed to examine the solution \
using a general method for analysing differential equations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData["General considerations"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{
      "Consider", " ", "the", " ", "differential", " ", "equation", " ", 
        RowBox[{Cell[TextData[Cell[BoxData[
              FormBox[
                RowBox[{
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["y", "\[Prime]\[Prime]",
                        MultilineFunction->None], "(", "x", ")"}], "+", 
                    RowBox[{\(p(x)\), " ", 
                      RowBox[{
                        SuperscriptBox["y", "\[Prime]",
                          MultilineFunction->None], "(", "x", ")"}]}], 
                    "+", \(\(q(x)\)\ \(y(x)\)\)}], "=", "0"}], 
                TraditionalForm]]]]], "."}]}], TraditionalForm]], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". What type of differential equation is this? How many linearly \
independent solutions does this equation have? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[StyleBox["", "NumberedAnswer"]], "Answer",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_1\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_2\)(x)\)]],
  " are linearly independent solutions, what determines the values of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  " in the general solution ",
  Cell[BoxData[
      \(TraditionalForm\`y(
          x) = \(c\_1\) \(\(y\_1\)(x)\) + \(c\_2\) \(\(y\_2\)(x)\)\)]],
  "? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Re-scaled equation"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve the radial differential equation for a spherically symmetric \
potential, let's follow the standard solution method. We would like to find a \
suitable re-scaling of the radial variable to simplify the radial equation ",
  StyleBox["which can be entered as",
    FontSlant->"Plain"]
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalR](R_)\), "=", 
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 R\), \(\[DifferentialD]r\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(2\/r\), " ", 
              FractionBox[\(\[DifferentialD]R\), \(\[DifferentialD]r\),
                MultilineFunction->None]}], 
            "+", \(\((2\ \[ScriptCapitalE] + \(2\ Z\)\/r - \(l\ \((l + 1)\)\)\
\/r\^2)\)\ R\)}]}], ";"}], TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Total derivatives (",
    FontSlant->"Plain"],
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        FractionBox[\(\[DifferentialD]R\), \(\[DifferentialD]r\),
          MultilineFunction->None], TraditionalForm]]],
  ") are used so that ",
  StyleBox["we can easily change variables.",
    FontSlant->"Plain"]
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Declare ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " to be a ",
  StyleBox["Constant", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["SetAttributes", "InlineInputTraditionalForm"],
  ". To re-scale lengths by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " we determine the radial equation for ",
  Cell[BoxData[
      \(TraditionalForm\`R(\[Alpha]\ r)\)]],
  " using ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR](R(\[Alpha]\ r))\)]],
  ". Divide through by the coefficient of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", \(\[Alpha]\ r\), ")"}], 
        TraditionalForm]]],
  Cell[BoxData[Cell[""]]],
  ", ",
  StyleBox["Expand", "InlineInputTraditionalForm"],
  ", and then replace ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\/\[Alpha]\)]],
  ". Group terms in ",
  Cell[BoxData[
      \(TraditionalForm\`R(\[Rho])\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "(", "\[Rho]", ")"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "\[Rho]", ")"}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " using ",
  StyleBox["Collect", "InlineInputTraditionalForm"],
  " (with the optional 3rd argument set to ",
  StyleBox["Factor", "InlineInputTraditionalForm"],
  "). ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "We are free to choose the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". ",
  StyleBox["Put ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Rule] \(2  Z\)\/n\)]],
  StyleBox[" and determine the energy, ",
    FontSlant->"Plain"],
  "\[ScriptCapitalE]",
  StyleBox[", so that ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(2\ \[ScriptCapitalE]\)\/\[Alpha]\^2\)]],
  " simplifies ",
  StyleBox["to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\(1\/4\)\)\)]],
  StyleBox[" (",
    FontSlant->"Plain"],
  "the result should look familiar and the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(1\/4\)\)\)]],
  " ",
  "is",
  StyleBox[" chosen to simplify the algebra somewhat). Substitute this value \
back into the differential equation and g",
    FontSlant->"Plain"],
  "roup terms in ",
  Cell[BoxData[
      \(TraditionalForm\`R(\[Rho])\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["R", "\[Prime]",
            MultilineFunction->None], "(", "\[Rho]", ")"}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "(", "\[Rho]", ")"}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  StyleBox[".",
    FontSlant->"Plain"],
  " ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["\<\
If you have followed all the steps correctly, the re-scaling of the \
radial variable has changed the radial equation to the dimensionless \
form\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SubsuperscriptBox["R", \(n, l\), "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "\[Rho]", ")"}], "+", 
            FractionBox[
              RowBox[{"2", " ", 
                RowBox[{
                  SubsuperscriptBox["R", \(n, l\), "\[Prime]",
                    MultilineFunction->None], "(", "\[Rho]", ")"}]}], 
              "\[Rho]"], 
            "-", \(\((\(l\ \((l + 1)\)\)\/\[Rho]\^2 - n\/\[Rho] + 
                  1\/4)\) \(\(R\_\(n, l\)\)(\[Rho])\)\)}], "=", "0"}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"dimensionless radial equation"],

Cell[TextData[{
  "which only has the two parameters (quantum numbers) ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ". "
}], "Text",
  CellTags->"quantum numbers"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter the dimensionless differential equation as follows. ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginQuestion"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalR](R_)\), "=", 
          RowBox[{
            
            FractionBox[\(\[DifferentialD]\^2 
                R\), \(\[DifferentialD]\[Rho]\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(2\/\[Rho]\), " ", 
              FractionBox[\(\[DifferentialD]R\), \(\[DifferentialD]\[Rho]\),
                MultilineFunction->None]}], 
            "-", \(\((\(l\ \((l + 1)\)\)\/\[Rho]\^2 - n\/\[Rho] + 1\/4)\) 
              R\)}]}], ";"}], TraditionalForm]], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Behaviour as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] \[Infinity]\)]]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In the limit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] \[Infinity]\)]],
  ", equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "dimensionless radial equation"],
  ") becomes"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["R", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "\[Rho]", ")"}], 
            "-", \(\(1\/4\) \(R(\[Rho])\)\)}], "==", "0"}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where the dependence on ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " has been suppressed."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Explain why this is so. Use ",
  StyleBox["DSolve", "InlineInputTraditionalForm"],
  " to find the two solutions to this equation. Call the physical asymptotic \
solution ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[ScriptCapitalA](\[Rho]_)\),
          "Input"], TraditionalForm]]],
  " (set any constants equal to unity). Explain why you rejected the other \
solution. ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Behaviour as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] 0\)]]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Solve equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "dimensionless radial equation"],
  ") in the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] 0\)]],
  " limit and use ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " assuming ",
  Cell[BoxData[
      \(TraditionalForm\`l \[GreaterEqual] 0\)]],
  ". Call the ",
  StyleBox["physical",
    FontSlant->"Italic"],
  " solution ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP](\[Rho]_)\)], "Input"], "Input"],
  " (set any constants equal to unity). Explain why you reject one of the \
solutions as unphysical. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that, just because a solution is infinite at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Congruent] \[Alpha]\ r = 0\)]],
  " is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " ",
  "sufficient grounds for excluding it. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/r\) \[ExponentialE]\^\(-r\)\)]],
  " is singular at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " but it is still square-integrable (normalisable) because the radial \
volume element contains an ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\^2\) \[DifferentialD]r\)]],
  " term,"
}], "Warning"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\(\((\(1\/r\) \
\[ExponentialE]\^\(-r\))\)\^2\) \(r\^2\) \[DifferentialD]r\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For a solution to be acceptable, expectation values of the kinetic energy \
and potential energy operators must exist. Since the Coulomb potential energy \
operator is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  ", it should be clear that a ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  " singularity in the wave function means that the potential expectation \
value would not be finite. A similar argument can be applied to the kinetic \
energy operator. (Consider what happens when ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  " is applied to a ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  " singularity and then attempt to compute the expectation value of the \
kinetic energy operator.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Factoring off the asymptotic behaviour", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The physical solution, ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_\(n, l\)\)(\[Rho])\)]],
  ", to the original differential equation must have the correct behaviour \
for both ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] \[Infinity]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Rule] 0\)]],
  ". One way to ensure this is to construct the solution in the form of a ",
  StyleBox["product",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_\(n, 
              l\)\)(\[Rho]) == \(\[ScriptCapitalA](\[Rho])\)\ \(\
\[ScriptCapitalP](\[Rho])\)\ \(\(L\_\(n . l\)\)(\[Rho])\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_\(n . l\)\)(\[Rho])\)]],
  " is to be determined. Note that there is no power series solution of",
  " equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "dimensionless radial equation"],
  ")",
  " because (truncated) power series cannot display an exponential decrease \
(or increase) for large values of the expansion variable.  In fact, series \
always diverge to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Infinity]\)\)]],
  "!  Hence you must factor off the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " asymptotic behaviour to be able to obtain a power series solution valid \
over a wide domain. After factoring off the large and small ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " behaviour, the resulting differential equation admits a simple series \
solution (which, for hydrogen, turns out to be a polynomial)."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Declare ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " as ",
  StyleBox["Constant", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["SetAttributes", "InlineInputTraditionalForm"],
  ". Obtain the equation for ",
  Cell[BoxData[
      \(TraditionalForm\`L(\[Rho])\)]],
  " by substituting ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalA](\[Rho])\)\ \(\[ScriptCapitalP](\
\[Rho])\)\ \(L(\[Rho])\)\)]],
  " into computing ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR](\(\[ScriptCapitalA](\[Rho])\)\ \(\
\[ScriptCapitalP](\[Rho])\)\ \(L(\[Rho])\))\)]],
  ", dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(\[ScriptCapitalA](\[Rho])\)\ \(\
\[ScriptCapitalP](\[Rho])\)\)\/\[Rho]\)\(\ \)\)\)]],
  " (which is finite over ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, \[Infinity])\)\)]],
  "), and ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " the result. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "You should obtain ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((n - l - 1)\)\ \(L(\[Rho])\)\), "+", 
          RowBox[{\((2\ l - \[Rho] + 2)\), " ", 
            RowBox[{
              SuperscriptBox["L", "\[Prime]",
                MultilineFunction->None], "(", "\[Rho]", ")"}]}], "+", 
          RowBox[{"\[Rho]", " ", 
            RowBox[{
              SuperscriptBox["L", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "\[Rho]", ")"}]}]}], 
        TraditionalForm]]],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can solve this differential equation \[LongDash] again in terms of ",
  StyleBox["hypergeometric ",
    FontSlant->"Italic"],
  "functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"DSolve", "[", 
        RowBox[{
          RowBox[{
            RowBox[{\(\((n - l - 1)\)\ \ \(L(\[Rho])\)\), "+", 
              RowBox[{\((2\ l - \[Rho] + 2)\), " ", 
                RowBox[{
                  SuperscriptBox["L", "\[Prime]",
                    MultilineFunction->None], "(", "\[Rho]", ")"}]}], "+", 
              RowBox[{"\[Rho]", " ", 
                RowBox[{
                  SuperscriptBox["L", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "\[Rho]", ")"}]}]}], "==", 
            "0"}], ",", \(L(\[Rho])\), ",", "\[Rho]"}], "]"}], 
      TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{"{", 
          RowBox[{\(L(\[Rho])\), "\[Rule]", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "2"], " ", 
                TagBox[
                  TagBox[
                    RowBox[{
                      RowBox[{
                        SubscriptBox["\[InvisiblePrefixScriptBase]", 
                          FormBox["1",
                            "TraditionalForm"]], 
                        SubscriptBox["F", 
                          FormBox["1",
                            "TraditionalForm"]]}], "\[InvisibleApplication]", 
                      
                      RowBox[{"(", 
                        RowBox[{
                          TagBox[
                            TagBox[
                              TagBox[\(\(-l\) - n\),
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox[
                            TagBox[
                              TagBox[\(\(-2\)\ l\),
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox["\[Rho]",
                            Hypergeometric1F1,
                            Editable->True]}], ")"}]}],
                    InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                    Editable->False],
                  Hypergeometric1F1], " ", \(\[Rho]\^\(\(-2\)\ l - 1\)\)}], 
              "+", 
              RowBox[{
                SubscriptBox[
                  TagBox["c",
                    C], "1"], " ", 
                TagBox[
                  TagBox[
                    RowBox[{
                      RowBox[{
                        SubscriptBox["\[InvisiblePrefixScriptBase]", 
                          FormBox["1",
                            "TraditionalForm"]], 
                        SubscriptBox["F", 
                          FormBox["1",
                            "TraditionalForm"]]}], "\[InvisibleApplication]", 
                      
                      RowBox[{"(", 
                        RowBox[{
                          TagBox[
                            TagBox[
                              TagBox[\(l - n + 1\),
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox[
                            TagBox[
                              TagBox[\(2\ l + 2\),
                                Hypergeometric1F1,
                                Editable->True],
                              InterpretTemplate[ {
                                SlotSequence[ 1]}&]],
                            Hypergeometric1F1,
                            Editable->False], ";", 
                          TagBox["\[Rho]",
                            Hypergeometric1F1,
                            Editable->True]}], ")"}]}],
                    InterpretTemplate[ HypergeometricPFQ[ #, #2, #3]&],
                    Editable->False],
                  Hypergeometric1F1]}]}]}], "}"}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Instead, we will solve this differential equation using power \
series.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Power Series Solution", "Subsubsection"],

Cell[TextData[{
  "To solve differential equations such as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "x", ")"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "(", "x", ")"}], "+", \(y(x)\)}], 
          " ", "\[Equal]", "0"}], TraditionalForm]]],
  " using series we substitute in the ",
  StyleBox["generic term",
    FontSlant->"Italic"],
  " of the series solution ",
  Cell[BoxData[
      \(TraditionalForm\`y(
          x) = \[Sum]\+\(i = 0\)\%\[Infinity]\( a\_i\) x\^i\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"generic term"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"x", " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]\[Prime]",
                    MultilineFunction->None], "(", "x", ")"}]}], "+", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "(", "x", ")"}], "+", \(y(x)\)}], 
            " ", "\[Equal]", "0"}], 
          "/.", \(y \[Rule] Function[x, \(a\_i\) x\^i]\)}], "//", 
        "ExpandAll"}], TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`i\^2\ a\_i\ x\^\(i - 1\) + a\_i\ x\^i == 0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Next we use ",
  StyleBox["pattern matching",
    FontSlant->"Italic"],
  " to find the recurrence relation that must be satisfied by the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  ". "
}], "Text",
  CellTags->{"pattern matching", "recurrence relation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`% /. \ 
        c_\ x\^\(i + k_. \) \[RuleDelayed] \((c /. i \[Rule] i - k - 1)\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\_i\ i\^2 + a\_\(i - 1\) == 0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This works by looking for the pattern ",
  Cell[BoxData[
      \(TraditionalForm\`c_\ x\^\(i + k_. \)\)]],
  " (which means anything, ",
  Cell[BoxData[
      \(TraditionalForm\`c_\)]],
  ", multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(i + k_. \)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k_. \)]],
  " means anything or 0) and replacing it with ",
  Cell[BoxData[
      \(TraditionalForm\`c /. i \[Rule] i - k - 1\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is reduced by ",
  Cell[BoxData[
      \(TraditionalForm\`k + 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(i + k\)\)]],
  " is omitted). "
}], "BrightIdea"],

Cell[TextData[{
  "Now we can solve the recurrence relation to find ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(i - 1\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Solve[%, a\_i]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{{a\_i \[Rule] \(-\(a\_\(i - 1\)\/i\^2\)\)}}\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Apply the power series method to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[Rho]", " ", 
              RowBox[{
                SuperscriptBox["L", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "\[Rho]", ")"}]}], "+", 
            RowBox[{\((2\ l - \[Rho] + 2)\), " ", 
              RowBox[{
                SuperscriptBox["L", "\[Prime]",
                  MultilineFunction->None], "(", "\[Rho]", ")"}]}], 
            "+", \(\((n - l - 1)\)\ \(L(\[Rho])\)\)}], "\[Equal]", "0"}], 
        TraditionalForm]]],
  ".",
  " ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"power series method"],

Cell[TextData[{
  "For finiteness, this series must terminate and this requires ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " to be an integer (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the states are quantized).",
  " If the series did not terminate, it can be shown that the recurrence \
relation implies that the solution would blow up exponentially for large ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "When does the series solution terminate?",
  " ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "It turns out that the recurrence produces a special function known as the \
associated Laguerre polynomials (which are special cases of ",
  StyleBox["Hypergeometric1F1", "InlineInputTraditionalForm"],
  " functions), ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_\(n - l - 1\)\%\(2\ l + 1\)\)(\[Rho])\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Expand ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_\(n - l - 1\)\%\(2\ l + 1\)\)(\[Rho])\)]],
  " into a series in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " up to ",
  Cell[BoxData[
      \(TraditionalForm\`O[\[Rho]]\^6\)]],
  " and verify that the coefficients in agree with the ",
  "recurrence relation",
  " determined in question ",
  
  CounterBox["Exercise", "power series method"],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": use ",
  StyleBox["CoefficientList", "InlineInputTraditionalForm"],
  " to determine the coefficients in the series expansion and determine \
ratios of successive terms using ",
  StyleBox["RotateLeft", "InlineInputTraditionalForm"],
  " and simplify the ratios using ",
  StyleBox["FunctionExpand", "InlineInputTraditionalForm"],
  ".) ",
  " ",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["General formula", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Combining the above results, since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \(2  Zr\)\/n\)]],
  " you should be able to confirm that the (un-normalised) radial orbitals \
are given by (for ",
  Cell[BoxData[
      \(TraditionalForm\`n - l - 1 \[GreaterEqual] 0\)]],
  ")"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(R\_\(n_, l_\)\)(r_) = 
        r\^l\ \[ExponentialE]\^\(-\(\(Z\ r\)\/n\)\)\ \(\(L\_\(n - l - 
                  1\)\%\(2\ l + 1\)\)(\(2\ Z\ r\)\/n)\);\)\)], "Input"],

Cell[TextData[{
  "From the quantization condition, the energy of each state is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\_n = \(-Z\^2\)\/\(2  n\^2\)\)]],
  ", and the radial equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "radial equation"],
  ") becomes"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SubsuperscriptBox["R", \(n, l\), "\[Prime]\[Prime]",
              MultilineFunction->None], "(", "r", ")"}], "+", 
          RowBox[{\(2\/r\), " ", 
            RowBox[{
              SubsuperscriptBox["R", \(n, l\), "\[Prime]",
                MultilineFunction->None], "(", "r", ")"}]}], 
          "+", \(\((\(-\(\(l(l + 1)\)\/r\^2\)\) - 
                Z\^2\/n\^2 + \(2  Z\)\/r)\)\ \(\(R\_\(n, l\)\)(r)\)\)}], "=", 
        "0."}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notation one can write"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalD]\_\(n_, l_\)[R_]\), "=", 
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 R\), \(\[DifferentialD]r\^2\),
              MultilineFunction->None], "+", 
            RowBox[{\(2\/r\), " ", 
              FractionBox[\(\[DifferentialD]R\), \(\[DifferentialD]r\),
                MultilineFunction->None]}], 
            "+", \(\((\(-\(\(l\ \((l + 1)\)\)\/r\^2\)\) - 
                  Z\^2\/n\^2 + \(2  Z\)\/r)\)\ R\)}]}], ";"}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Declare ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " to be a ",
  StyleBox["Constant", "InlineInputTraditionalForm"],
  " using ",
  StyleBox["SetAttributes", "InlineInputTraditionalForm"],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 6\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], n - 1\)]],
  ", verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_\(n, l\)\)(r)\)]],
  " satisfies the differential equation generated by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalD]\_\(n . l\)\)]],
  ". ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Normalization"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The radial wavefunctions given above are ",
  StyleBox["not",
    FontSlant->"Italic"],
  " normalised. To achieve this, one requires that"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
            RowBox[{
              SuperscriptBox[
                FormBox[\(\(R\_\(n, l\)\)(r)\),
                  "TraditionalForm"], 
                "2"], \(r\^2\), \(\[DifferentialD]r\)}]}], "==", "1"}], ","}],
       TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\^2\) \[DifferentialD]r\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "term comes from the integration volume element. "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define a routine, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\_\(n_, l_\)\)]],
  ", that computes and saves (using ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  ") the normalization constant for ",
  Cell[BoxData[
      \(TraditionalForm\`n > l \[GreaterEqual] 0\)]],
  ". Compute the normalization constant for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], n - 1\)]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": ",
  "it is a good idea to ",
  StyleBox["Expand", "InlineInputTraditionalForm"],
  " the integrand before computing the integral because it makes the \
computation of the integrals much more efficient and then ",
  StyleBox["Simplify", "InlineInputTraditionalForm"],
  " the result assuming ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Z > 0\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Also you might want set ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(SetOptions[Integrate, Assumptions \[Rule] Z > 0]\),
          "Input"], TraditionalForm]]],
  " to help ",
  StyleBox["Integrate", "InlineInputTraditionalForm"],
  ".) ",
  StyleBox["[5 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "A closed form expression can be found for the normalization integral. It \
turns out to be ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\(2\ Z\)\/n)\)\^\(l + 
              3/2\)\) \@\(\(\((n - l - 1)\)!\)\/\(2  n\ \(\((n + \
l)\)!\)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Check that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\_\(n, l\) \[Equal] \(\((\(2\ \
Z\)\/n)\)\^\(l + 
                3/2\)\) \@\(\(\((n - l - 1)\)!\)\/\(2  n\ \(\((n + \
l)\)!\)\)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], n - 1\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  StyleBox["You are now in a position to define the ",
    FontSlant->"Plain"],
  StyleBox["normalized",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Plain"],
  "radial wavefunctions",
  StyleBox[" for ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`n > l \[GreaterEqual] 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Enter the normalized ",
    FontSlant->"Plain"],
  "radial wavefunctions, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\_\(n_, l_, Z_:  1\)\)(
            r_) = \(\((\(2\ Z\)\/n)\)\^\(l + 
                  3/2\)\) \(\@\(\(\((n - l - 1)\)!\)\/\(2  
                      n\ \(\((n + l)\)!\)\)\)\) 
            r\^l\ \[ExponentialE]\^\(-\(\(Z\ r\)\/n\)\)\ \(\(L\_\(n - l - 
                    1\)\%\(2\ l + 1\)\)(\(2\ Z\ r\)\/n)\);\)\)]],
  ". (The syntax, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Z_:  1\),
          FontWeight->"Bold"], TraditionalForm]]],
  ", indicates that if the argument ",
  Cell[BoxData[
      FormBox[
        StyleBox["Z",
          FontWeight->"Bold"], TraditionalForm]]],
  " is not supplied it will default to the value 1.) Verify that that these \
states are correctly normalized by computing ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
          RowBox[{
            SuperscriptBox[
              FormBox[\(\(R\_\(n, l\)\)(r)\),
                "TraditionalForm"], "2"], \(r\^2\), \(\[DifferentialD]r\)}]}],
         TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 4\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, \[Ellipsis], n - 1\)]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": ",
  "it is a good idea to ",
  StyleBox["Expand", "InlineInputTraditionalForm"],
  " the integrand before computing the integral because it makes the \
computation of the integrals much more efficient.) ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Energy orthogonality"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
          RowBox[{
            FormBox[\(\(R\_\(n, l\)\)(r)\),
              "TraditionalForm"], 
            FormBox[\(\(R\_\(p, l\)\)(r)\),
              "TraditionalForm"], \(r\^2\), \(\[DifferentialD]r\)}]}], 
        TraditionalForm]]],
  " which involves two states with different principal quantum numbers (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] p\)]],
  " which implies the states have different energy)."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Examine such integrals for a physical range of ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " parameter values. What do you conclude? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Other integrals"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Consider ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
          RowBox[{
            FormBox[\(\(R\_\(n, l\)\)(r)\),
              "TraditionalForm"], 
            FormBox[\(\(R\_\(n, L\)\)(r)\),
              "TraditionalForm"], \(r\^2\), \(\[DifferentialD]r\)}]}], 
        TraditionalForm]]],
  " which  involves two radial states of different orbital angular momentum \
(",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l \[NotEqual] L\)]],
  ")."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Examine such integrals for a range of physical ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " parameter values. Are these functions orthogonal? What does the \
orthonormality of states of differing angular momentum tell you about \
integrals of these radial states when their angular parts are included? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Visualization"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Plot the radial variation of the 3p state (",
    FontSlant->"Plain"],
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3, \ l = 1\)]],
  StyleBox[") from ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  StyleBox[" to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r = 30\)]],
  " (atomic units). ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "It is physically more relevant to examine the ",
  StyleBox["radial probability density",
    FontSlant->"Italic"],
  " which is given by "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(P(r)\), "=", 
        RowBox[{\(r\^2\), 
          RowBox[{
            SuperscriptBox[
              FormBox[\(\(R\_\(n, l\)\)(r)\),
                "TraditionalForm"], "2"], "."}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell["\<\
After normalisation, this will integrate to unity as required for a \
probability density.\
\>", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Plot the radial probability density of the 3p state (",
    FontSlant->"Plain"],
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3, \ l = 1\)]],
  StyleBox[") from  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  StyleBox[" to ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r = 30\)]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "The ",
  StyleBox["nodes",
    FontSlant->"Italic"],
  " of this function are places with zero probability of finding an electron. \
Since the radial functions depend only on the radius, ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", this leads to a number of concentric electron \"shells\"."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Determine the location of the nodes of the 5d state (",
    FontSlant->"Plain"],
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5, \ l = 2\)]],
  StyleBox[")",
    FontSlant->"Plain"],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["By examining a few states, deduce the relationship between the \
number of nodes of the radial wavefunction and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`n - l - 1\)]],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ". Stark effect for hydrogen"
}], "Section"],

Cell[TextData[{
  "Consider a hydrogen atom in a weak uniform external electric field ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["E",
            FontWeight->"Bold"], "0"], TraditionalForm]]],
  "(",
  StyleBox["not",
    FontSlant->"Italic"],
  " related to the ground-state energy) which is in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " direction, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the Hamiltonian perturbation is given by ",
  Cell[BoxData[
      \(TraditionalForm\`H\^\[Prime] = \(E\_0\) z\)]],
  ". Applying first-order perturbation theory, the associated energy shift \
between two states with the same principal quantum number, ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", is given by"
}], "Text",
  CellTags->{"first-order perturbation theory", "energy shift"}],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[CapitalDelta]\ E = \(\(E\_0\) \
\[LeftAngleBracket]n\ L\ M \[LeftBracketingBar]z\[RightBracketingBar] 
              n\ l\ m\[RightAngleBracket] = \(E\_0\) \[LeftAngleBracket]n\ L\ \
M \[LeftBracketingBar]r\ \(cos(\[Theta])\)\[RightBracketingBar] 
              n\ l\ m\[RightAngleBracket]\)\)\(,\)\)\)], "NumberedEquation"],

Cell["where", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\(\(\ \)\(\[RightBracketingBar]\)\) 
              n\ l\ m\)\(\[RightAngleBracket]\)\), "\[Congruent]", 
          
          FormBox[\(\(\(R\_\(n, l\)\)(
                r)\)\ \(\(Y\_l\%m\)(\[Theta], \[Phi])\)\),
            "TraditionalForm"]}], ","}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "and the ",
  Cell[BoxData[
      \(TraditionalForm\`\(R\_\(n, l\)\)(r)\)]],
  " are ",
  StyleBox["normalised",
    FontSlant->"Italic"],
  ". Explicitly, this requires the computation of"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[LeftAngleBracket]n\ L\ M \[LeftBracketingBar]r\ \(cos(\
\[Theta])\)\[RightBracketingBar] 
                n\ l\ m\[RightAngleBracket] \[Congruent] \[LeftAngleBracket]n\
\ L \[LeftBracketingBar]r\[RightBracketingBar] 
                  n\ l\[RightAngleBracket] \[LeftAngleBracket]L\ M \
\[LeftBracketingBar]cos(\[Theta])\[RightBracketingBar] 
                  l\ m\[RightAngleBracket]\), "=", 
          RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
            RowBox[{
              FormBox[\(\(\(R\_\(n, L\)\)(r)\)\ \(\(R\_\(n, l\)\)(r)\)\),
                "TraditionalForm"], \(r\^3\), \(\[DifferentialD]r\), 
              "\[Times]", 
              RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
                RowBox[{\(\[Integral]\_0\%\[Pi]\), 
                  RowBox[{
                    
                    FormBox[\(\(\(\(Y\_L\%M\)(\[Theta], \[Phi])\)\^*\)\ \(\(Y\
\_l\%m\)(\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\ \(cos(\[Theta])\)\),
                      
                      "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}]}]}]}]}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"ME(r cos)"],

Cell["\<\
where the separability of the radial and angular integrals is made \
evident. In this section you will use the expressions for the hydrogen \
wavefunction developed above to compute these integrals and find the \
associated energy shifts.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Radial Integral"
}], "Subsection",
  CellTags->"ME(r)"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define the matrix element of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]n\ L \[LeftBracketingBar]r\
\[RightBracketingBar] 
            n\ l\[RightAngleBracket] = \[Integral]\_0\%\[Infinity]\(\( 
                  R\_\(n, L\)\)(r)\)\ \(\(R\_\(n, l\)\)(
              r)\) \(r\^3\) \[DifferentialD]r\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]n_, L_, 
        l_\[RightAngleBracket]\)]],
  ". Use dynamic programming and also take into account symmetry under \
interchange of quantum number labels (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", use the syntax ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]n_, L_, 
          l_\[RightAngleBracket] := \(\[LeftAngleBracket]n, L, 
            l\[RightAngleBracket] = \(\[LeftAngleBracket]n, l, 
              L\[RightAngleBracket] = \[Ellipsis]\)\)\)]],
  " to save the computed values for both cases at the same time). Compute the \
radial matrix elements for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l, L = 0, 1, \[Ellipsis], n - 1\)]],
  ". ",
  StyleBox["[4 Marks]", "MarkersComment"],
  " "
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Angular Integrals"
}], "Subsection",
  CellTags->"ME(cos)"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define the matrix element of ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Theta])\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[LeftAngleBracket]L\ M \[LeftBracketingBar]cos(\[Theta])\
\[RightBracketingBar] l\ m\[RightAngleBracket]\), "=", 
          RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%\[Pi]\), 
              RowBox[{
                
                FormBox[\(\(\(\(Y\_L\%M\)(\[Theta], \[Phi])\)\^*\)\ \
\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\ \(cos(\[Theta])\)\),
                  
                  "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}]}]}], TraditionalForm]]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]{L_, M_}, {l_, 
          m_}\[RightAngleBracket]\)]],
  ". ",
  StyleBox["Use ",
    FontSlant->"Plain"],
  "dynamic programming",
  StyleBox[" ",
    FontSlant->"Plain"],
  "and also take into account symmetry under interchange of quantum number \
labels",
  StyleBox[" to save the computed values. ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the angular matrix elements for ",
  Cell[BoxData[
      \(TraditionalForm\`l, L = 0, 1, 2\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(-l\), \(-l\) + 1, \[Ellipsis], l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M = \(-L\), \(-L\) + 1, \[Ellipsis], L\)]],
  ". You should find that most of the integrals are identically zero. Can you \
work out the ",
  StyleBox["selection rules",
    FontSlant->"Italic"],
  " for the non-zero elements (",
  StyleBox["c.f.",
    FontSlant->"Italic"],
  ", the electric dipole selection rules, ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\ l = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\ m = 0, \(\[PlusMinus]1\)\)]],
  ")? ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
  CellTags->"selection rules"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[LeftAngleBracket]{L_, M_}, {l_, m_}\[RightAngleBracket]\), ":=",
         
        RowBox[{\(\[LeftAngleBracket]{L, M}, {l, m}\[RightAngleBracket]\), 
          "=", 
          RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
            RowBox[{\(\[Integral]\_0\%\[Pi]\), 
              RowBox[{
                
                FormBox[\(\((\(-1\))\)\^M\ \(\(Y\_L\%\(-M\)\)(\[Theta], \
\[Phi])\)\ \(\(Y\_l\%m\)(\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\ \(cos(\
\[Theta])\)\),
                  
                  "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}]}]}]}], TraditionalForm]], "Input",
  ShowCellBracket->False,
  CellElementSpacings->{"ClosedCellHeight"->0.5},
  CellOpen->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Table[\[LeftAngleBracket]{L, M}, {l, 
          m}\[RightAngleBracket], {L, 0, 2}, {l, 0, 2}, {M, \(-L\), 
        L}, {m, \(-l\), l}]\)], "Input",
  ShowCellBracket->False,
  CellElementSpacings->{"ClosedCellHeight"->0.5},
  CellOpen->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", \(1\/\@3\), "0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0", "0", "0"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/\@3\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0"},
                    {"0", "0", "0"},
                    {"0", "0", "0"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", \(1\/\@5\), "0", "0", "0"},
                    {"0", "0", \(2\/\@15\), "0", "0"},
                    {"0", "0", "0", \(1\/\@5\), "0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0"},
                    {\(1\/\@5\), "0", "0"},
                    {"0", \(2\/\@15\), "0"},
                    {"0", "0", \(1\/\@5\)},
                    {"0", "0", "0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0", "0", "0", "0", "0"},
                    {"0", "0", "0", "0", "0"},
                    {"0", "0", "0", "0", "0"},
                    {"0", "0", "0", "0", "0"},
                    {"0", "0", "0", "0", "0"}
                    },
                  ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
  ShowCellBracket->False,
  CellElementSpacings->{"ClosedCellHeight"->0.5},
  CellOpen->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". An aside\[ThinSpace]\[LongDash]\[ThinSpace]Clebsch-Gordan coefficients"
}], "Subsection"],

Cell[TextData[{
  "Introducing the ",
  StyleBox["Clebsch-Gordan",
    FontSlant->"Italic"],
  " coefficients, ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\(l\_1\) l\_2\ \(m\_1\) 
            m\_2 \[VerticalSeparator] L\ M\[RightAngleBracket]\)]],
  " (there are many notations for these coefficients \[LongDash] see, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", Appendix 4 of ",
  "Bransden and Joachain, ",
  StyleBox["Physics of Atoms and Molecules",
    FontSlant->"Italic"],
  " (Longman, 1983)), and the closely related (more symmetric) 3-",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "symbols, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {\(j\_1\), \(j\_2\), \(j\_3\)},
              {\(m\_1\), \(m\_2\), \(m\_3\)}
              }], ")"}], TraditionalForm]]],
  ","
}], "Text",
  CellTags->"Clebsch-Gordan coefficients"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[LeftAngleBracket]\(l\_1\) l\_2\ \(m\_1\) 
                m\_2 \[VerticalSeparator] L\ M\[RightAngleBracket]\), "=", 
          FormBox[
            
            RowBox[{\(\((\(-1\))\)\^\(M + l\_1 - l\_2\)\), 
              " ", \(\@\(2\ L + 1\)\), " ", 
              RowBox[{"(", GridBox[{
                    {\(l\_1\), \(l\_2\), "L"},
                    {\(m\_1\), \(m\_2\), \(-M\)}
                    }], ")"}]}],
            "TraditionalForm"]}], ","}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "which vanish unless ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1 + m\_2 \[Equal] \ M\)]],
  " (",
  StyleBox["physical condition",
    FontSlant->"Italic"],
  " for addition of projection quantum number) and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]l\_1 - 
            l\_2\[RightBracketingBar] \[LessEqual] L \[LessEqual] 
        l\_1 + l\_2\)]],
  " (",
  StyleBox["triagularity condition",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", imagine the angular momenta ",
  Cell[BoxData[
      \(TraditionalForm\`l\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l\_2\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " as the (integer) side-lengths of a triangle), ",
  "the angular integrals can be computed directly using the following general \
identity:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
          RowBox[{\(\[Integral]\_0\%\[Pi]\), 
            RowBox[{
              
              FormBox[\(\(\(Y\_\(l\_1\)\%\(m\_1\)\)(\[Theta], \[Phi])\)\ \
\(\(Y\_\(l\_2\)\%\(m\_2\)\)(\[Theta], \[Phi])\)\ \(\(Y\_\(l\_3\)\%\(m\_3\)\)(\
\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\),
                
                "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}]}], "=", "\n", "\t", 
        RowBox[{\(\@\(\(\((2  l\_1 + 1)\) \((2  l\_2 + 1)\) \((2  l\_3 + 
                        1)\)\)\/\(4  \[Pi]\)\)\), 
          RowBox[{"(", GridBox[{
                {\(l\_1\), \(l\_2\), \(l\_3\)},
                {"0", "0", "0"}
                }], ")"}], 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {\(l\_1\), \(l\_2\), \(l\_3\)},
                  {\(m\_1\), \(m\_2\), \(m\_3\)}
                  }], ")"}], "."}]}]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(Y\_1\%0\)(\[Theta], \[Phi])\),
            "TraditionalForm"], "=", 
          RowBox[{\(1\/2\), " ", \(\@\(3\/\[Pi]\)\), " ", 
            FormBox[\(cos(\[Theta])\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(\(Y\_l\%m\)(\[Theta], \[Phi])\)\^*\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(\(Y\_l\%m\)(\[Theta], \(-\[Phi]\))\),
              "TraditionalForm"], "=", 
            
            FormBox[\(\((\(-1\))\)\^m\ \(\(Y\_l\%\(-m\)\)(\[Theta], \[Phi])\)\
\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", we find that"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
          RowBox[{\(\[Integral]\_0\%\[Pi]\), 
            RowBox[{
              
              FormBox[\(\(\(\(Y\_L\%M\)(\[Theta], \[Phi])\)\^*\)\ \(\(Y\_l\%m\
\)(\[Theta], \[Phi])\)\ \(sin(\[Theta])\)\ \(cos(\[Theta])\)\),
                
                "TraditionalForm"], \(\[DifferentialD]\[Theta]\), \(\
\[DifferentialD]\[Phi]\)}]}]}], "=", 
        RowBox[{\(\((\(-1\))\)\^m\), \(\[Delta]\_\(M, 
              m\)\), \(\@\(\((2  L + 1)\) \((2  l + 1)\)\)\), 
          RowBox[{"(", GridBox[{
                {"L", "l", "1"},
                {"0", "0", "0"}
                }], ")"}], 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"L", "l", "1"},
                  {\(-M\), "m", "0"}
                  }], ")"}], "."}]}]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Verify that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(Y\_1\%0\)(\[Theta], \[Phi])\),
            "TraditionalForm"], "\[Equal]", 
          RowBox[{\(1\/2\), " ", \(\@\(3\/\[Pi]\)\), " ", 
            FormBox[\(cos(\[Theta])\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". ",
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  "Since the 3-",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "symbol ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {\(j\_1\), \(j\_2\), \(j\_3\)},
              {\(m\_1\), \(m\_2\), \(m\_3\)}
              }], ")"}], TraditionalForm]]],
  " is built-in to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as ",
  Cell[BoxData[
      FormBox[
        StyleBox["ThreeJSymbol",
          "Input"], TraditionalForm]]],
  ", computing these integrals can be sped up. "
}], "Text"],

Cell["Here is a palette for entering this special notation.", "Text"],

Cell[BoxData[
    FormBox[
      ButtonBox[
        SubscriptBox[
          RowBox[{"(", GridBox[{
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]"},
                {"\[Placeholder]", "\[Placeholder]", "\[Placeholder]"}
                }], " ", ")"}], \(3  j\)]], TraditionalForm]], "Input",
  Active->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Taking into account the ",
  StyleBox["triangularity condition",
    FontSlant->"Italic"],
  ", show that",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((\(-1\))\)\^m\), \(\[Delta]\_\(M, 
              m\)\), \(\@\(\((2  L + 1)\) \((2  l + 1)\)\)\), 
          SubscriptBox[
            RowBox[{"(", GridBox[{
                  {"L", "l", "1"},
                  {"0", "0", "0"}
                  }], " ", ")"}], \(3  j\)], 
          SubscriptBox[
            RowBox[{"(", GridBox[{
                  {"L", "l", "1"},
                  {\(-M\), "m", "0"}
                  }], " ", ")"}], \(3  j\)]}], TraditionalForm]]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]{L, M}, {l, 
          m}\[RightAngleBracket]\)]],
  ". ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Total Matrix Element"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Define ",
  StyleBox["a general expression for computing the ",
    FontSlant->"Plain"],
  StyleBox["total",
    FontSlant->"Italic"],
  StyleBox[" matrix element, ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]n\ L\ M \[LeftBracketingBar]r\ \
\(cos(\[Theta])\)\[RightBracketingBar] n\ l\ m\[RightAngleBracket]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]{n_, L_, M_}, {n_, l_, 
          m_}\[RightAngleBracket]\)]],
  ". by  forming the product of ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]n\ L \[LeftBracketingBar]r\
\[RightBracketingBar] n\ l\[RightAngleBracket]\)]],
  " ",
  StyleBox["and ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]L\ M \[LeftBracketingBar]cos(\
\[Theta])\[RightBracketingBar] l\ m\[RightAngleBracket]\)]],
  " ",
  StyleBox["and c",
    FontSlant->"Plain"],
  "heck that it works properly",
  StyleBox[". ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`n = 2\)]]], "Subsubsection"],

Cell[TextData[{
  "Fix attention to the case ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  ". The possible ",
  Cell[BoxData[
      \(TraditionalForm\`{n, l, m}\)]],
  " triples (",
  StyleBox["kets",
    FontSlant->"Italic"],
  ") are"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"kets", "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "0", "0"},
                {"2", "1", \(-1\)},
                {"2", "1", "0"},
                {"2", "1", "1"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}]}], ";"}], 
      TraditionalForm]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "and the perturbation matrix \[LongDash] computed from the matrix element \
of each pair of kets using ",
  StyleBox["Outer", "InlineInputTraditionalForm"],
  " \[LongDash] is simply"
}], "Text",
  CellTags->"perturbation matrix"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Outer[AngleBracket, kets, kets, 1]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", \(-3\), "0"},
            {"0", "0", "0", "0"},
            {\(-3\), "0", "0", "0"},
            {"0", "0", "0", "0"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The (matrix) eigenvalues of the perturbation matrix give the ",
  StyleBox["energy shifts",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"energy shift"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{\[Lambda], u} = Eigensystem[%]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-3\), "0", "0", "3"},
            {\({1, 0, 1, 0}\), \({0, 0, 0, 1}\), \({0, 1, 0, 0}\), \({\(-1\), 
                0, 1, 0}\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Lambda]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{\(-3\), 0, 0, 3}\)], "Output"]
}, Open  ]],

Cell["\<\
The (matrix) eigenvectors give the appropriate linear combinations \
of the initial states that correspond to these energy shifts. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`u . Apply[Ket, kets, 1] // TableForm\)], "Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {\(Ket(2, 0, 0) + Ket(2, 1, 0)\)},
            {\(Ket(2, 1, 1)\)},
            {\(Ket(2, 1, \(-1\))\)},
            {\(Ket(2, 1, 0) - Ket(2, 0, 0)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {
          Plus[ 
            Ket[ 2, 0, 0], 
            Ket[ 2, 1, 0]], 
          Ket[ 2, 1, 1], 
          Ket[ 2, 1, -1], 
          Plus[ 
            Times[ -1, 
              Ket[ 2, 0, 0]], 
            Ket[ 2, 1, 0]]}]], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Interpret these results. Comment on the energy degeneracy of the \
perturbed states and contrast this to the unperturbed situation.",
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`n = 3\)]]], "Subsubsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Compute the energy shifts and ",
    FontSlant->"Plain"],
  "perturbed states",
  StyleBox[" for  ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  " and interpret.",
  StyleBox[" ",
    FontSlant->"Plain"],
  StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Helium perturbation calculation"
}], "Section"],

Cell[TextData[{
  "The Schr\[ODoubleDot]dinger equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section", "Schr\[ODoubleDot]dinger equation"],
  ".",
  
  CounterBox["Equation", "Schr\[ODoubleDot]dinger equation"],
  ") for a two-electron atom ",
  "(with nuclear charge ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ")",
  " reads"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[ScriptCapitalH]", " ", 
            RowBox[{"\[CapitalPsi]", "(", 
              StyleBox["r",
                FontWeight->"Bold"], ")"}]}], "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                
                UnderscriptBox[\(\(-\(1\/2\)\) \((\[CapitalDelta]\_1 + \
\[CapitalDelta]\_2)\)\), 
                  UnderscriptBox["\[UnderBrace]", 
                    StyleBox["\[ScriptCapitalT]",
                      FontSize->12]]], 
                RowBox[{"\[CapitalPsi]", "(", 
                  StyleBox["r",
                    FontWeight->"Bold"], ")"}]}], "+", 
              RowBox[{
                UnderscriptBox[\((\(-\(Z\/r\_1\)\) - Z\/r\_2 + 1\/r\_12)\), 
                  UnderscriptBox["\[UnderBrace]", 
                    StyleBox["\[ScriptCapitalV]",
                      FontSize->12]]], 
                RowBox[{"\[CapitalPsi]", "(", 
                  StyleBox["r",
                    FontWeight->"Bold"], ")"}]}]}], "=", 
            RowBox[{"\[ScriptCapitalE]", " ", 
              RowBox[{"\[CapitalPsi]", "(", 
                StyleBox["r",
                  FontWeight->"Bold"], ")"}]}]}]}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\)]],
  " is the Hamiltonian, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  " is the kinetic energy operator, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalV]\)]],
  " is the potential energy. The ",
  StyleBox["interparticle coordinates\[ThinSpace]",
    FontSlant->"Italic"],
  "\[LongDash]\[ThinSpace]",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_2\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_12\)]],
  "\[ThinSpace]\[LongDash]\[ThinSpace]are defined below:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(Show[
        Graphics[{\[IndentingNewLine]Arrow({0, 0}, {1, 0}), 
            Arrow({1, 0}, {1.3, 1}), 
            Arrow({0, 0}, {1.3, 1}), \[IndentingNewLine]Text[
              r\_1, \ {1/2, \(-0.1\)}], Text[r\_12, \ {1.2, 0.5}], 
            Text[r\_2, \ {0.7, 0.63}]}]];\)\)], "Input",
  Evaluatable->False,
  CellOpen->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.732601 0.0682245 0.535094 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .06822 m
.75641 .06822 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
.75641 .06822 m
.97619 .60332 L
s
% Start of user PostScript
1. 0 1.3 1. MAarrowhead1
% End of user PostScript
.02381 .06822 m
.97619 .60332 L
s
% Start of user PostScript
0 0 1.3 1. MAarrowhead1
% End of user PostScript
gsave
.39011 .01472 -67.2188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.90293 .33577 -68.9688 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
gsave
.53663 .40533 -67.2188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{137, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oL03oool0
0`000000oooo0?ooo`2]0?ooo`00L03oool00`000000oooo0?ooo`2]0?ooo`00J`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0:d0oooo001[0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0[@3oool006`0oooo00<000000?ooo`3oool0/@3oool006`0oooo0P00002b
0?ooo`00J`3oool2000000030?ooo`000000oooo0;00oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003:0?ooo`<00000D`3oool00<X0oooo2000001>0?ooo`00
bP3oool=000004T0oooo00070?ooom800000A`3oool000T0oooo0P00002o0?ooo``000000P3oool0
0`000000oooo0?ooo`150?ooo`002`3oool00`000000oooo0?ooo`2l0?ooo`T000001P3oool00`00
0000oooo0?ooo`140?ooo`00303oool200000;`0oooo1@00000:0?ooo`030000003oool0oooo04@0
oooo000>0?ooo`800000^P3oool2000000d0oooo00<000000?ooo`3oool0A03oool00100oooo0P00
00380?ooo`030000003oool0oooo04<0oooo000B0?ooo`800000aP3oool00`000000oooo0?ooo`13
0?ooo`00503oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0480oooo000E0?ooo`80
0000a03oool00`000000oooo0?ooo`120?ooo`005`3oool200000<<0oooo00<000000?ooo`3oool0
@@3oool001T0oooo0P0000310?ooo`030000003oool0oooo0440oooo000K0?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0@@3oool001`0oooo0P00002o0?ooo`030000003oool0oooo
0400oooo000N0?ooo`800000_@3oool00`000000oooo0?ooo`100?ooo`00803oool200000;`0oooo
00<000000?ooo`3oool0?`3oool00280oooo0P00002j0?ooo`030000003oool0oooo03l0oooo000T
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0?`3oool002D0oooo0P00002h0?oo
o`030000003oool0oooo03h0oooo000W0?ooo`800000]P3oool00`000000oooo0?ooo`0n0?ooo`00
:@3oool200000;D0oooo00<000000?ooo`3oool0?@3oool002/0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0m0?ooo`00;03oool200000;80oooo00<000000?ooo`3oool0?@3oool0
02h0oooo0P00002a0?ooo`030000003oool0oooo03`0oooo000`0?ooo`800000[`3oool00`000000
oooo0?ooo`0l0?ooo`00<P3oool200000:h0oooo00<000000?ooo`3oool0>`3oool003@0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0k0?ooo`00=@3oool200000:`0oooo00<00000
0?ooo`3oool0>P3oool003L0oooo0P00002Z0?ooo`030000003oool0oooo03X0oooo000i0?ooo`80
0000Z03oool00`000000oooo0?ooo`0j0?ooo`00>`3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo03T0oooo000l0?ooo`800000YP3oool00`000000oooo0?ooo`0i0?ooo`00?P3oool2
00000:D0oooo00<000000?ooo`3oool0>03oool00400oooo0P00002S0?ooo`030000003oool0oooo
03P0oooo00120?ooo`800000X@3oool00`000000oooo0?ooo`0h0?ooo`00A03oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo03L0oooo00150?ooo`800000W`3oool00`000000oooo0?oo
o`0g0?ooo`00A`3oool2000009h0oooo00<000000?ooo`3oool0=P3oool004T0oooo0P00002L0?oo
o`030000003oool0oooo03H0oooo001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0=P3oool004`0oooo0P00002J0?ooo`030000003oool0oooo03D0oooo001>0?ooo`800000V03o
ool00`000000oooo0?ooo`0e0?ooo`00D03oool2000009L0oooo00<000000?ooo`3oool0=03oool0
0580oooo0P00002E0?ooo`030000003oool0oooo03@0oooo001D0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0<`3oool005D0oooo0P00002C0?ooo`030000003oool0oooo03<0oooo
001G0?ooo`800000T@3oool00`000000oooo0?ooo`0c0?ooo`00F@3oool200000900oooo00<00000
0?ooo`3oool0<P3oool005/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?oo
o`00G03oool2000008h0oooo00<000000?ooo`3oool0<@3oool005h0oooo0P00002<0?ooo`030000
003oool0oooo0340oooo001P0?ooo`800000RP3oool00`000000oooo0?ooo`0a0?ooo`00HP3oool2
000008T0oooo00<000000?ooo`3oool0<03oool006@0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0`0?ooo`00I@3oool2000008L0oooo00<000000?ooo`3oool0;`3oool006L0oooo
0P0000250?ooo`030000003oool0oooo02l0oooo001Y0?ooo`800000P`3oool00`000000oooo0?oo
o`0_0?ooo`00J`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo02h0oooo001/0?oo
o`800000P@3oool00`000000oooo0?ooo`0^0?ooo`00KP3oool200000800oooo00<000000?ooo`3o
ool0;@3oool00700oooo0P00001n0?ooo`030000003oool0oooo02d0oooo001b0?ooo`800000O@3o
ool00`000000oooo0?ooo`0/0?ooo`00M03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo02`0oooo001e0?ooo`800000NP3oool00`000000oooo0?ooo`0/0?ooo`00M`3oool2000007T0
oooo00<000000?ooo`3oool0:`3oool007T0oooo0P00001g0?ooo`030000003oool0oooo02/0oooo
001k0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0:P3oool007`0oooo0P00001e
0?ooo`030000003oool0oooo02X0oooo001n0?ooo`800000L`3oool00`000000oooo0?ooo`0Z0?oo
o`00P03oool200000780oooo00<000000?ooo`3oool0:@3oool00880oooo0P00001`0?ooo`030000
003oool0oooo02T0oooo00240?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0:03o
ool008D0oooo0P00001^0?ooo`030000003oool0oooo02P0oooo00270?ooo`800000K03oool00`00
0000oooo0?ooo`0X0?ooo`00R@3oool2000006/0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`3oool2000001T0oooo002;0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool0000001X0oooo002<0?ooo`800000J@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0G0?ooo`00SP3oool2000006L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`060000003oool0oooo0000003oool000006@3oool00900oooo0P00001V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`00
TP3oool2000006@0oooo00<000000?ooo`3oool00P3oool200000240oooo002D0?ooo`030000003o
ool0oooo0640oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0O0?ooo`00U@3o
ool200000680oooo00<000000?ooo`3oool0903oool009L0oooo0P00001P0?ooo`030000003oool0
oooo02@0oooo002I0?ooo`800000G`3oool00`000000oooo0?ooo`0S0?ooo`00V`3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo02<0oooo002L0?ooo`800000G03oool00`000000oooo
0?ooo`0S0?ooo`00WP3oool2000005/0oooo00<000000?ooo`3oool08P3oool00:00oooo0P00001I
0?ooo`030000003oool0oooo0280oooo002R0?ooo`800000F03oool00`000000oooo0?ooo`0Q0?oo
o`00Y03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0240oooo002U0?ooo`800000
E@3oool00`000000oooo0?ooo`0Q0?ooo`00Y`3oool2000005@0oooo00<000000?ooo`3oool0803o
ool00:T0oooo0P00001B0?ooo`030000003oool0oooo0200oooo002[0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool07`3oool009X0oooo0P00000@0?ooo`800000D03oool00`000000
oooo0?ooo`0O0?ooo`00VP3oool00`000000oooo0?ooo`0A0?ooo`800000C`3oool00`000000oooo
0?ooo`0N0?ooo`00U@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo0P00
001=0?ooo`030000003oool0oooo01h0oooo002E0?ooo`070000003oool0oooo0?ooo`000000oooo
0000000F0?ooo`800000B`3oool00`000000oooo0?ooo`0N0?ooo`00UP3oool01@000000oooo0?oo
o`3oool0000001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0M0?ooo`00UP3o
ool2000001d0oooo0P0000190?ooo`030000003oool0oooo01d0oooo002E0?ooo`80000000<0oooo
0000003oool07@3oool2000004P0oooo00<000000?ooo`3oool0703oool00;T0oooo0P0000160?oo
o`030000003oool0oooo01`0oooo002k0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0703oool00;`0oooo0P0000140?ooo`030000003oool0oooo01/0oooo002n0?ooo`800000@P3o
ool00`000000oooo0?ooo`0K0?ooo`00`03oool200000440oooo00<000000?ooo`3oool06P3oool0
0<80oooo0P00000o0?ooo`030000003oool0oooo01X0oooo00340?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool06P3oool00<D0oooo0P00000m0?ooo`030000003oool0oooo01T0oooo
00370?ooo`800000>`3oool00`000000oooo0?ooo`0I0?ooo`00b@3oool2000003X0oooo00<00000
0?ooo`3oool0603oool00</0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0H0?oo
o`00c03oool2000003P0oooo00<000000?ooo`3oool05`3oool00<h0oooo0P00000f0?ooo`030000
003oool0oooo01L0oooo003@0?ooo`800000=03oool00`000000oooo0?ooo`0G0?ooo`00dP3oool2
000003<0oooo00<000000?ooo`3oool05P3oool00=@0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0F0?ooo`00e@3oool200000340oooo00<000000?ooo`3oool05@3oool00=L0oooo
0P00000_0?ooo`030000003oool0oooo01D0oooo003I0?ooo`800000;@3oool00`000000oooo0?oo
o`0E0?ooo`00f`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo003L0?oo
o`800000:`3oool00`000000oooo0?ooo`0D0?ooo`00gP3oool2000002X0oooo00<000000?ooo`3o
ool04`3oool00>00oooo0P00000X0?ooo`030000003oool0oooo01<0oooo003R0?ooo`8000009P3o
ool00`000000oooo0?ooo`0C0?ooo`00i03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo0180oooo003U0?ooo`800000903oool00`000000oooo0?ooo`0B0?ooo`00i`3oool2000002<0
oooo00<000000?ooo`3oool04@3oool00>T0oooo0P00000Q0?ooo`030000003oool0oooo0140oooo
003[0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0403oool00>`0oooo0P00000O
0?ooo`030000003oool0oooo0100oooo003^0?ooo`8000007@3oool00`000000oooo0?ooo`0@0?oo
o`00l03oool2000001`0oooo00<000000?ooo`3oool03`3oool00?80oooo0P00000J0?ooo`030000
003oool0oooo00l0oooo003d0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3o
ool00?D0oooo0P00000H0?ooo`030000003oool0oooo00h0oooo003g0?ooo`8000005P3oool00`00
0000oooo0?ooo`0>0?ooo`00n@3oool2000001D0oooo00<000000?ooo`3oool03@3oool00?/0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`00o03oool2000001<0oooo00<0
00000?ooo`3oool0303oool00?h0oooo0P00000A0?ooo`030000003oool0oooo008000002P3oool0
0?l0oooo0@3oool2000000l0oooo1@00000:0?ooo`00o`3oool30?ooo`8000002`3oool7000000X0
oooo003o0?ooo`D0oooo00<000000?ooo`3oool0203oool7000000X0oooo003o0?ooo`H0oooo0P00
00060?ooo`030000003oool0oooo00L000002@3oool00?l0oooo203oool2000000@0oooo0P000002
0?ooo`H000002@3oool00?l0oooo2P3oool2000000030?ooo`00000000000080000000<0oooo0000
00000000100000090?ooo`00o`3oool<0?ooo`H0000000<0oooo0000000000000`0000090?ooo`00
o`3oool<0?ooo`L0000000<0oooo0000000000000P0000090?ooo`00o`3oool;0?ooo`d000002@3o
ool00?l0oooo2P3oool>000000T0oooo003o0?ooo`d0oooo300000080?ooo`00o`3oool@0?ooo`T0
0000203oool00?l0oooo503oool5000000P0oooo003o0?oooaL0oooo0P0000080?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0341929, -0.127506, \
0.00476789, 0.00652776}}]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_i\)]],
  " is the three-dimensional Laplacian operator for electron ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ","
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalDelta]\_i\), "=", 
        RowBox[{
          RowBox[{\(1\/r\_i\%2\), 
            FractionBox[
              RowBox[{"\[PartialD]", 
                RowBox[{"(", 
                  RowBox[{\(r\_i\%2\), " ", 
                    FractionBox["\[PartialD]", \(\[PartialD]r\_i\),
                      MultilineFunction->None]}], 
                  ")"}]}], \(\[PartialD]r\_i\),
              MultilineFunction->None]}], 
          "-", \(\(1\/r\_i\%2\) \(\(\(l\_i\%2\)(\[Theta]\_i, \
\[Phi]\_i)\)\(.\)\)\)}]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "Considering the inter-electron potential, ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\_12\)]],
  ", as a perturbation, the Hamiltonian  can be written as"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalH]", "=", 
          RowBox[{
            
            UnderscriptBox[\(\(-\(1\/2\)\) \((\[CapitalDelta]\_1 + \
\[CapitalDelta]\_2)\) - Z\/r\_1 - Z\/r\_2\), 
              UnderscriptBox["\[UnderBrace]", 
                SuperscriptBox[
                  StyleBox["\[ScriptCapitalH]",
                    FontSize->12], \((0)\)]]], "+", 
            UnderscriptBox[\(1\/r\_12\), 
              UnderscriptBox["\[UnderBrace]", 
                SuperscriptBox[
                  StyleBox["\[ScriptCapitalH]",
                    FontSize->12], "\[Prime]"]]]}]}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell["where", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptCapitalH]\^\((0)\) = \(-\(1\/2\)\) \((\
\[CapitalDelta]\_1 + \[CapitalDelta]\_2)\) - Z\/r\_1 - 
          Z\/r\_2 \[Congruent] \(\(-\(1\/2\)\) \[CapitalDelta]\_1 - Z\/r\_1\)\
\+\(\[UnderBrace]\+\(\[ScriptCapitalH]\_1\)\) - \(1\/2\) \[CapitalDelta]\_2 - \
\(Z\/r\_2\)\+\(\[UnderBrace]\+\(\[ScriptCapitalH]\_2\)\)\)\(,\)\)\)], \
"NumberedEquation"],

Cell["and", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalH]\^\[Prime] = \(\(1\/r\_12\)\(\
\[CenterDot]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "To zeroth order, the Hamiltonian is simply separated into the sum of two \
single-particle (hydrogenic) operators, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\^\((0)\) = \[ScriptCapitalH]\_1 + \
\[ScriptCapitalH]\_2\)]],
  ". Hence the (unnormalised) ground state of the a two-electron atom can be \
approximated by a ",
  StyleBox["product",
    FontSlant->"Italic"],
  " of hydrogenic functions (with nuclear charge ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  "),"
}], "Text",
  CellTags->"helium"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Psi]\^\((0)\) = \[ExponentialE]\^\(\(-Z\)\ \
\((r\_1 + r\_\(\(2\)\(\ \)\))\)\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "and the energy is the ",
  StyleBox["sum",
    FontSlant->"Italic"],
  " of the two hydrogenic (ground-state) energies, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ","
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(\[ScriptCapitalH]\^\((0)\)\) \[Psi]\^\((0)\)\), "=", 
        RowBox[{
          
          RowBox[{\(\[ScriptCapitalE]\^\((0)\)\), \(\[Psi]\^\((0)\)\), Cell[
            " where "], \(\[ScriptCapitalE]\^\((0)\)\)}], 
          "=", \(\(-\(Z\^2\/2\)\) - Z\^2\/2 = \(-\(\(Z\^2\)\(.\)\)\)\)}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Show that ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\^\((0)\)\)]],
  " is an eigenfunction of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\^\((0)\)\)]],
  " with corresponding zeroth order energy, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\^\((0)\) = \(-Z\^2\)\)]],
  ".",
  StyleBox[" ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["What is the helium ground state energy of the zeroth order \
approximation? Compare this to the exact value of -2.904...  ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The first-order perturbation energy, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\^\((1)\)\)]],
  ", is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\^\((1)\) = \
\[ScriptCapitalE]\^\((0)\) + \[CapitalDelta]\[VeryThinSpace]\[ScriptCapitalE]\
\)]],
  ", where the energy shift is given by"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[CapitalDelta]\[VeryThinSpace]\[ScriptCapitalE] = \
\(\(\[LeftAngleBracket]\(\[Psi]\^\((0)\)\) \[LeftBracketingBar]1\/r\_12\
\[RightBracketingBar] \
\[Psi]\^\((0)\)\[RightAngleBracket]\/\[LeftAngleBracket]\[Psi]\^\((0)\) \
\[VerticalSeparator] \[Psi]\^\((0)\)\[RightAngleBracket]\)\(.\)\)\)], \
"NumberedEquation",
  CellTags->"first-order perturbation energy"],

Cell[TextData[{
  "In ",
  "interparticle coordinates ",
  "\[ThinSpace]the matrix element of a ",
  StyleBox["general",
    FontSlant->"Italic"],
  " operator, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalO]\)]],
  ", can be computed from the integral"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]\[Psi] \[LeftBracketingBar]\
\[GothicCapitalO]\[RightBracketingBar] \[Psi]\[RightAngleBracket] = 
      8 \( \[Pi]\^2\) \(\[Integral]\_0\%\[Infinity]\( 
                r\_1\) \[DifferentialD]r\_1 \(\[Integral]\_0\%\[Infinity]\( 
                    r\_2\) \[DifferentialD]r\_2 \(\[Integral]\_\(\
\[LeftBracketingBar]r\_1 - r\_2\[RightBracketingBar]\)\%\(r\_1 + r\_2\)\(\
\[Psi]\^*\) \[GothicCapitalO]\ \[Psi]\ \(r\_12\) \
\(\(\[DifferentialD]r\_12\)\(.\)\)\)\)\)\)], "NumberedEquation",
  CellTags->{"interparticle coordinates", "general matrix element"}],

Cell[TextData[{
  "In the following sections we will compute the first-order perturbation \
energy from equations (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section", "first-order perturbation energy"],
  ".",
  
  CounterBox["Equation", "first-order perturbation energy"],
  ") and (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section", "general matrix element"],
  ".",
  
  CounterBox["Equation", "general matrix element"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". A generating integral"
}], "Subsection"],

Cell["In this section you will verify that", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[LeftAngleBracket]\[Phi] \
\[LeftBracketingBar]1\/\(\(r\_1\) \(r\_2\) r\_12\)\[RightBracketingBar] \
\[Phi]\[RightAngleBracket] = \(2  \[Pi]\^2\)\/\(\((\[Lambda]\_1 + \
\[Lambda]\_2)\) \((\[Lambda]\_1 + \[Lambda]\_12)\) \((\[Lambda]\_2 + \
\[Lambda]\_12)\)\)\)\(,\)\)\)], "NumberedEquation"],

Cell["where", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Phi](
        r) = \(\(\[ExponentialE]\^\(\(-\[Lambda]\_1\) r\_1 - \(\[Lambda]\_2\) 
                r\_2 - \(\[Lambda]\_12\) 
                r\_12\)\)\(.\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "The importance of this integral is that matrix elements of ",
  StyleBox["any",
    FontSlant->"Italic"],
  " combination of integral powers (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GreaterEqual]\)\(-1\)\)\)]],
  ") of the interparticle coordinates can be obtained by ",
  StyleBox["differentiation",
    FontSlant->"Italic"],
  " with respect to the parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  ".  Moreover, this general integral permits the examination of a whole \
class of zeroth order approximations (including exponential terms of the \
above form multiplied by polynomials in the interparticle coordinates)."
}], "Text"],

Cell["\<\
Before commencing this section it is a good idea to quit the \
kernel.\
\>", "Warning"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`r\_1 > \ r\_2\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The integral for the case ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`r\_1 > r\_2\)]],
  StyleBox[" can be computed through the steps",
    FontSlant->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`SetOptions[Integrate, 
      GenerateConditions \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{Assumptions \[Rule] {}, 
      GenerateConditions \[Rule] False, 
      PrincipalValue \[Rule] False}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`8\ \[Pi]\^2\ \(\[Integral]\_\(r\_1 - r\_2\)\%\(r\_1 + \
r\_2\)\(\[ExponentialE]\^\(\(-2\)\ r\_1\ \[Lambda]\_1 - 
                2\ \[Lambda]\_2\ r\_2 - 
                2\ \[Lambda]\_12\ r\_12\)\) \[DifferentialD]r\_12\)\)], \
"Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`8\ \[Pi]\^2\ \((\[ExponentialE]\^\(\(-2\)\ r\_1\ \
\[Lambda]\_1 - 2\ r\_2\ \[Lambda]\_2 - 2\ \((r\_1 - r\_2)\)\ \
\[Lambda]\_12\)\/\(2\ \[Lambda]\_12\) - \[ExponentialE]\^\(\(-2\)\ r\_1\ \
\[Lambda]\_1 - 2\ r\_2\ \[Lambda]\_2 - 2\ \((r\_1 + r\_2)\)\ \
\[Lambda]\_12\)\/\(2\ \[Lambda]\_12\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%\(r\_1\)% \[DifferentialD]r\_2 // 
      Simplify\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \[ExponentialE]\^\(\(-2\)\ r\_1\ \((\[Lambda]\_1 \
+ \[Lambda]\_2 + 2\ \[Lambda]\_12)\)\)\ \[Pi]\^2\ \((\((\(-1\) + \
\[ExponentialE]\^\(4\ r\_1\ \[Lambda]\_12\))\)\ \[Lambda]\_2 + \((1 + \
\[ExponentialE]\^\(4\ r\_1\ \[Lambda]\_12\) - 2\ \[ExponentialE]\^\(2\ r\_1\ \
\((\[Lambda]\_2 + \[Lambda]\_12)\)\))\)\ \
\[Lambda]\_12)\)\)\/\(\[Lambda]\_12\%3 - \[Lambda]\_2\%2\ \[Lambda]\_12\)\)], \
"Output"]
}, Open  ]],

Cell["and", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%\[Infinity] % \[DifferentialD]r\_1 // 
      Simplify\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \[Pi]\^2\)\/\(\((\[Lambda]\_1 + \[Lambda]\_2)\)\ \
\((\[Lambda]\_1 + \[Lambda]\_12)\)\ \((\[Lambda]\_1 + \[Lambda]\_2 + 2\ \
\[Lambda]\_12)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Under the conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " we have"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalI]\_\(r\_1 > r\_2\) = \(2\ \[Pi]\^2\)\/\
\(\((\[Lambda]\_1 + \[Lambda]\_2)\)\ \((\[Lambda]\_1 + \[Lambda]\_12)\)\ \((\
\[Lambda]\_1 + \[Lambda]\_2 + 2\ \[Lambda]\_12)\)\); \)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`r\_1 < \ r\_2\)]]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Suitably modify the steps above to compute the integral in this \
case and name the result. Think ",
    FontSlant->"Plain"],
  StyleBox["carefully",
    FontSlant->"Plain"],
  StyleBox[" about how the integration limits need to be modified. ",
    FontSlant->"Plain"],
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Total integral"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  StyleBox["Compute the sum of the two case above and simplify using ",
    FontSlant->"Plain"],
  StyleBox["Together", "InlineInputTraditionalForm",
    FontSlant->"Plain"],
  StyleBox[" and call the result ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox["\[ScriptCapitalI]",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".",
  StyleBox[" ",
    FontSlant->"Plain"],
  StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell["General matrix elements", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](
          r) = \[ExponentialE]\^\(\(-\[Lambda]\_1\) r\_1 - \(\[Lambda]\_2\) r\
\_2 - \(\[Lambda]\_12\) r\_12\)\)]],
  ","
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[PartialD]\_\(\[Lambda]\_i\)\[LeftAngleBracket]\[Phi] \
\[LeftBracketingBar]1\/\(\(r\_1\) \(r\_2\) r\_12\)\[RightBracketingBar] \
\[Phi]\[RightAngleBracket] = \(-2\) \[LeftAngleBracket]\[Phi] \
\[LeftBracketingBar]r\_i\/\(\(r\_1\) \(r\_2\) r\_12\)\[RightBracketingBar] \
\[Phi]\[RightAngleBracket], \ i = 1, 2, 12. \)], "NumberedEquation",
  CellTags->"general matrix element"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Explain why this result holds.",
  StyleBox[" ",
    FontSlant->"Plain"],
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["General relation"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["From this it can be shown that", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[PartialD]\^\(i + j + m + 3\)\/\(\[PartialD]\
\[Lambda]\_1\%\(i + 1\) \[PartialD]\[Lambda]\_2\%\(j + 1\) \[PartialD]\
\[Lambda]\_12\%\(m + 1\)\)\) \[LeftAngleBracket]\[Phi] \
\[LeftBracketingBar]1\/\(\(r\_1\) \(r\_2\) r\_12\)\[RightBracketingBar] \
\[Phi]\[RightAngleBracket] = \(\((\(-2\))\)\^\(i + j + m + 
              3\)\) \(\(\[LeftAngleBracket]\[Phi] \
\[LeftBracketingBar]\(r\_1\%i\) \(r\_2\%j\) 
                  r\_12\%m\[RightBracketingBar] \
\[Phi]\[RightAngleBracket]\)\(.\)\(\ \)\)\)], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Referring to equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "general matrix element"],
  ") justify this result. ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  StyleBox["Define this ",
    FontSlant->"Plain"],
  StyleBox["general matrix element",
    FontSlant->"Italic"],
  StyleBox[" (after moving the power of 2 to the left-hand side of the \
equation) as",
    FontSlant->"Plain"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]i_, j_, 
        m_\[RightAngleBracket] := \(\[LeftAngleBracket]i, j, 
          m\[RightAngleBracket] = 
        Simplify[\(1\/\((\(-2\))\)\^\(i + j + m + 3\)\) \[PartialD]\_\({\
\[Lambda]\_1, i + 1}, {\[Lambda]\_2, j + 1}, {\[Lambda]\_12, m + 1}\)\
\[ScriptCapitalI]]\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Normalisation"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use the ",
  "general matrix element ",
  "to compute the normalization of the zeroth order approximation. (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you need to compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]\[Psi]\^\((0)\) \
\[VerticalSeparator] \[Psi]\^\((0)\)\[RightAngleBracket]\)]],
  ". After differentiation, the values of the matrix element with the \
zeroth-order wavefunction defined above can be easily obtained by the \
substitution (replacement rule) ",
  Cell[BoxData[
      FormBox[
        StyleBox[\({\[Lambda]\_1 \[Rule] Z, \[Lambda]\_2 \[Rule] 
              Z, \[Lambda]\_12 \[Rule] 0}\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".)",
  " ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Electron-electron interaction"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use the general matrix element to compute the value of the \
electron-electron perturbation, equation (",
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section", "first-order perturbation energy"],
  ".",
  
  CounterBox["Equation", "first-order perturbation energy"],
  "). ",
  StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Total energy"
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Using the value you obtained for the electron-electron perturbation \
energy, what is the first-order energy, ",
  Cell[BoxData[
      \(TraditionalForm\`E\^\((1)\)\)]],
  "? ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the first-order perturbation energy for ",
  Cell[BoxData[
      \(TraditionalForm\`Z = 2\)]],
  " and compare it to the exact value.",
  " ",
  StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowToolbars->{},
InitializationCellEvaluation->True,
InitializationCellWarning->False,
CellGrouping->Automatic,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"], 
    "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "complex conjugation"->{
    Cell[5168, 157, 125, 4, 24, "Text",
      CellTags->"complex conjugation"]},
  "Schr\[ODoubleDot]dinger equation"->{
    Cell[7978, 258, 633, 18, 34, "NumberedEquation",
      CellTags->"Schr\[ODoubleDot]dinger equation"]},
  "spherical polar coordinates"->{
    Cell[8830, 288, 1057, 37, 56, "Text",
      CellTags->{
      "spherical polar coordinates", "spherically symmetric", 
        "quantum numbers"}]},
  "spherically symmetric"->{
    Cell[8830, 288, 1057, 37, 56, "Text",
      CellTags->{
      "spherical polar coordinates", "spherically symmetric", 
        "quantum numbers"}]},
  "quantum numbers"->{
    Cell[8830, 288, 1057, 37, 56, "Text",
      CellTags->{
      "spherical polar coordinates", "spherically symmetric", 
        "quantum numbers"}],
    Cell[43913, 1446, 230, 9, 36, "Text",
      CellTags->"quantum numbers"]},
  "Laplacian operator"->{
    Cell[10870, 365, 570, 16, 40, "Text",
      CellTags->{
      "Laplacian operator", "kinetic energy operator", "atomic units"}]},
  "kinetic energy operator"->{
    Cell[10870, 365, 570, 16, 40, "Text",
      CellTags->{
      "Laplacian operator", "kinetic energy operator", "atomic units"}]},
  "atomic units"->{
    Cell[10870, 365, 570, 16, 40, "Text",
      CellTags->{
      "Laplacian operator", "kinetic energy operator", "atomic units"}]},
  "angular momentum operator"->{
    Cell[12524, 417, 233, 6, 36, "Text",
      CellTags->"angular momentum operator"]},
  "spherical harmonics"->{
    Cell[15594, 524, 226, 6, 24, "Text",
      CellTags->"spherical harmonics"]},
  "total angular momentum operator"->{
    Cell[16720, 570, 221, 7, 26, "Text",
      CellTags->"total angular momentum operator"]},
  "eigenfunction relation"->{
    Cell[18243, 617, 114, 1, 24, "Text",
      CellTags->"eigenfunction relation"]},
  "complete basis set"->{
    Cell[19489, 662, 455, 11, 42, "Text",
      CellTags->"complete basis set"]},
  "integration volume element"->{
    Cell[20549, 691, 1098, 34, 42, "Text",
      CellTags->{"integration volume element", "complex conjugate"}]},
  "complex conjugate"->{
    Cell[20549, 691, 1098, 34, 42, "Text",
      CellTags->{"integration volume element", "complex conjugate"}]},
  "bra-ket notation"->{
    Cell[22271, 751, 124, 4, 24, "Text",
      CellTags->"bra-ket notation"]},
  "representation"->{
    Cell[23458, 793, 412, 13, 42, "Text",
      CellTags->"representation"]},
  "angular charge density distribution"->{
    Cell[24006, 815, 405, 12, 26, "Text",
      CellTags->"angular charge density distribution"]},
  "axial symmetry"->{
    Cell[24619, 834, 229, 6, 24, "Text",
      CellTags->"axial symmetry"]},
  "PolarPlot"->{
    Cell[25763, 875, 630, 26, 52, "BeginEndQuestion",
      CellTags->"PolarPlot"]},
  "SphericalPlot3D"->{
    Cell[26396, 903, 813, 32, 50, "BeginEndQuestion",
      CellTags->"SphericalPlot3D"]},
  "radial equation"->{
    Cell[28382, 986, 311, 6, 50, "NumberedEquation",
      CellTags->"radial equation"]},
  "bound states"->{
    Cell[32659, 1090, 531, 19, 43, "Text",
      CellTags->"bound states"]},
  "dimensionless radial equation"->{
    Cell[43196, 1427, 714, 17, 55, "NumberedEquation",
      CellTags->"dimensionless radial equation"]},
  "generic term"->{
    Cell[57593, 1883, 837, 26, 26, "Text",
      CellTags->"generic term"]},
  "pattern matching"->{
    Cell[59156, 1934, 286, 9, 26, "Text",
      CellTags->{"pattern matching", "recurrence relation"}]},
  "recurrence relation"->{
    Cell[59156, 1934, 286, 9, 26, "Text",
      CellTags->{"pattern matching", "recurrence relation"}]},
  "power series method"->{
    Cell[60902, 2007, 756, 23, 50, "BeginEndQuestion",
      CellTags->"power series method"]},
  "first-order perturbation theory"->{
    Cell[77242, 2605, 847, 25, 42, "Text",
      CellTags->{"first-order perturbation theory", "energy shift"}]},
  "energy shift"->{
    Cell[77242, 2605, 847, 25, 42, "Text",
      CellTags->{"first-order perturbation theory", "energy shift"}],
    Cell[98451, 3288, 183, 6, 26, "Text",
      CellTags->"energy shift"]},
  "ME(r cos)"->{
    Cell[79066, 2661, 1220, 25, 41, "NumberedEquation",
      CellTags->"ME(r cos)"]},
  "ME(r)"->{
    Cell[80576, 2697, 175, 11, 54, "Subsection",
      CellTags->"ME(r)"]},
  "ME(cos)"->{
    Cell[82162, 2755, 179, 11, 32, "Subsection",
      CellTags->"ME(cos)"]},
  "selection rules"->{
    Cell[83608, 2808, 894, 28, 65, "BeginEndQuestion",
      CellTags->"selection rules"]},
  "Clebsch-Gordan coefficients"->{
    Cell[88264, 2945, 938, 29, 53, "Text",
      CellTags->"Clebsch-Gordan coefficients"]},
  "perturbation matrix"->{
    Cell[97754, 3263, 248, 6, 26, "Text",
      CellTags->"perturbation matrix"]},
  "helium"->{
    Cell[119644, 3889, 546, 15, 42, "Text",
      CellTags->"helium"]},
  "first-order perturbation energy"->{
    Cell[122167, 3976, 399, 7, 53, "NumberedEquation",
      CellTags->"first-order perturbation energy"]},
  "interparticle coordinates"->{
    Cell[122851, 3997, 612, 9, 42, "NumberedEquation",
      CellTags->{"interparticle coordinates", "general matrix element"}]},
  "general matrix element"->{
    Cell[122851, 3997, 612, 9, 42, "NumberedEquation",
      CellTags->{"interparticle coordinates", "general matrix element"}],
    Cell[129999, 4241, 415, 6, 52, "NumberedEquation",
      CellTags->"general matrix element"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"complex conjugation", 203892, 6863},
  {"Schr\[ODoubleDot]dinger equation", 204013, 6866},
  {"spherical polar coordinates", 204155, 6869},
  {"spherically symmetric", 204337, 6874},
  {"quantum numbers", 204513, 6879},
  {"Laplacian operator", 204770, 6886},
  {"kinetic energy operator", 204935, 6890},
  {"atomic units", 205089, 6894},
  {"angular momentum operator", 205256, 6898},
  {"spherical harmonics", 205371, 6901},
  {"total angular momentum operator", 205492, 6904},
  {"eigenfunction relation", 205616, 6907},
  {"complete basis set", 205727, 6910},
  {"integration volume element", 205843, 6913},
  {"complex conjugate", 205982, 6916},
  {"bra-ket notation", 206120, 6919},
  {"representation", 206221, 6922},
  {"angular charge density distribution", 206342, 6925},
  {"axial symmetry", 206463, 6928},
  {"PolarPlot", 206557, 6931},
  {"SphericalPlot3D", 206665, 6934},
  {"radial equation", 206779, 6937},
  {"bound states", 206889, 6940},
  {"dimensionless radial equation", 207003, 6943},
  {"generic term", 207129, 6946},
  {"pattern matching", 207230, 6949},
  {"recurrence relation", 207362, 6952},
  {"power series method", 207494, 6955},
  {"first-order perturbation theory", 207629, 6958},
  {"energy shift", 207763, 6961},
  {"ME(r cos)", 207969, 6966},
  {"ME(r)", 208069, 6969},
  {"ME(cos)", 208160, 6972},
  {"selection rules", 208261, 6975},
  {"Clebsch-Gordan coefficients", 208388, 6978},
  {"perturbation matrix", 208507, 6981},
  {"helium", 208604, 6984},
  {"first-order perturbation energy", 208715, 6987},
  {"interparticle coordinates", 208856, 6990},
  {"general matrix element", 209016, 6993}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 131, 5, 74, "Title",
  CounterAssignments->{{"Title", 6}}],
Cell[1921, 60, 29, 0, 26, "Author"],
Cell[1953, 62, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2392, 78, 39, 0, 42, "Subsubsection"],
Cell[2434, 80, 215, 5, 26, "Text"],
Cell[2652, 87, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2767, 91, 87, 3, 24, "Text"],
Cell[2857, 96, 117, 2, 24, "Input",
  InitializationCell->True],
Cell[2977, 100, 148, 5, 26, "Text"],
Cell[3128, 107, 142, 4, 24, "Input",
  InitializationCell->True],
Cell[3273, 113, 86, 1, 24, "Text"],
Cell[3362, 116, 307, 5, 42, "Input",
  InitializationCell->True],
Cell[3672, 123, 75, 0, 24, "Text"],
Cell[3750, 125, 1415, 30, 120, "Input",
  InitializationCell->True],
Cell[5168, 157, 125, 4, 24, "Text",
  CellTags->"complex conjugation"],
Cell[5296, 163, 149, 3, 24, "Input",
  InitializationCell->True],
Cell[5448, 168, 112, 4, 26, "Text"],
Cell[5563, 174, 185, 4, 24, "Input",
  InitializationCell->True],
Cell[5751, 180, 152, 4, 24, "Input",
  InitializationCell->True],
Cell[5906, 186, 205, 5, 24, "Input",
  InitializationCell->True],
Cell[6114, 193, 172, 5, 24, "Text"],
Cell[6289, 200, 674, 19, 42, "Input",
  InitializationCell->True],
Cell[6966, 221, 755, 18, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7758, 244, 111, 7, 41, "SectionFirst"],
Cell[7872, 253, 103, 3, 24, "Text"],
Cell[7978, 258, 633, 18, 34, "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],
Cell[8614, 278, 213, 8, 24, "Text"],
Cell[8830, 288, 1057, 37, 56, "Text",
  CellTags->{
  "spherical polar coordinates", "spherically symmetric", 
    "quantum numbers"}],
Cell[9890, 327, 305, 8, 24, "NumberedEquation"],
Cell[10198, 337, 490, 14, 24, "Text"],

Cell[CellGroupData[{
Cell[10713, 355, 154, 8, 54, "Subsection"],
Cell[10870, 365, 570, 16, 40, "Text",
  CellTags->{
  "Laplacian operator", "kinetic energy operator", "atomic units"}],
Cell[11443, 383, 206, 3, 44, "NumberedEquation"],
Cell[11652, 388, 258, 10, 24, "Text"],
Cell[11913, 400, 608, 15, 46, "NumberedEquation"],
Cell[12524, 417, 233, 6, 36, "Text",
  CellTags->"angular momentum operator"],
Cell[12760, 425, 882, 19, 52, "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[13679, 449, 200, 11, 32, "Subsection"],
Cell[13882, 462, 901, 28, 44, "Text"],
Cell[14786, 492, 178, 3, 25, "NumberedEquation"],
Cell[14967, 497, 40, 0, 24, "Text"],
Cell[15010, 499, 274, 5, 38, "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[15321, 509, 147, 7, 32, "Subsection"],

Cell[CellGroupData[{
Cell[15493, 520, 98, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[15594, 524, 226, 6, 24, "Text",
  CellTags->"spherical harmonics"],
Cell[15823, 532, 762, 29, 52, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[16622, 566, 95, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[16720, 570, 221, 7, 26, "Text",
  CellTags->"total angular momentum operator"],
Cell[16944, 579, 896, 21, 54, "Input"],
Cell[17843, 602, 116, 5, 24, "Text"],
Cell[17962, 609, 278, 6, 42, "Input"],
Cell[18243, 617, 114, 1, 24, "Text",
  CellTags->"eigenfunction relation"],
Cell[18360, 620, 213, 5, 25, "NumberedEquation"],
Cell[18576, 627, 182, 3, 23, "NumberedEquation"],
Cell[18761, 632, 601, 21, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[19399, 658, 87, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[19489, 662, 455, 11, 42, "Text",
  CellTags->"complete basis set"],
Cell[19947, 675, 599, 14, 41, "NumberedEquation"],
Cell[20549, 691, 1098, 34, 42, "Text",
  CellTags->{"integration volume element", "complex conjugate"}],
Cell[21650, 727, 618, 22, 50, "BeginEndQuestion"],
Cell[22271, 751, 124, 4, 24, "Text",
  CellTags->"bra-ket notation"],
Cell[22398, 757, 341, 6, 41, "Input"],
Cell[22742, 765, 713, 26, 50, "BeginEndQuestion"],
Cell[23458, 793, 412, 13, 42, "Text",
  CellTags->"representation"]
}, Closed]],

Cell[CellGroupData[{
Cell[23907, 811, 96, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[24006, 815, 405, 12, 26, "Text",
  CellTags->"angular charge density distribution"],
Cell[24414, 829, 202, 3, 30, "DisplayFormula"],
Cell[24619, 834, 229, 6, 24, "Text",
  CellTags->"axial symmetry"],
Cell[24851, 842, 214, 4, 25, "Input",
  InitializationCell->True],
Cell[25068, 848, 142, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[25235, 857, 89, 1, 25, "Input"],
Cell[25327, 860, 142, 2, 42, "Output"]
}, Open  ]],
Cell[25484, 865, 276, 8, 26, "Text"],
Cell[25763, 875, 630, 26, 52, "BeginEndQuestion",
  CellTags->"PolarPlot"],
Cell[26396, 903, 813, 32, 50, "BeginEndQuestion",
  CellTags->"SphericalPlot3D"],
Cell[27212, 937, 730, 24, 42, "Warning"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27991, 967, 146, 7, 32, "Subsection"],
Cell[28140, 976, 239, 8, 28, "Text"],
Cell[28382, 986, 311, 6, 50, "NumberedEquation",
  CellTags->"radial equation"],
Cell[28696, 994, 128, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[28849, 1001, 894, 21, 41, "Input"],
Cell[29746, 1024, 2898, 63, 47, "Output"]
}, Open  ]],
Cell[32659, 1090, 531, 19, 43, "Text",
  CellTags->"bound states"],

Cell[CellGroupData[{
Cell[33215, 1113, 291, 8, 42, "Input"],
Cell[33509, 1123, 2624, 59, 38, "Output"]
}, Open  ]],
Cell[36148, 1185, 229, 4, 40, "Text"],

Cell[CellGroupData[{
Cell[36402, 1193, 105, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[36510, 1197, 739, 16, 22, "Text"],
Cell[37252, 1215, 229, 6, 50, "BeginEndQuestion"],
Cell[37484, 1223, 104, 2, 32, "Answer",
  Evaluatable->False],
Cell[37591, 1227, 600, 21, 50, "BeginEndQuestion"],
Cell[38194, 1250, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[38297, 1257, 101, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[38401, 1261, 322, 6, 40, "Text"],
Cell[38726, 1269, 545, 12, 42, "Input"],
Cell[39274, 1283, 387, 13, 28, "Text"],
Cell[39664, 1298, 1777, 61, 72, "BeginEndQuestion"],
Cell[41444, 1361, 1577, 58, 70, "BeginEndQuestion"],
Cell[43024, 1421, 169, 4, 24, "Text"],
Cell[43196, 1427, 714, 17, 55, "NumberedEquation",
  CellTags->"dimensionless radial equation"],
Cell[43913, 1446, 230, 9, 36, "Text",
  CellTags->"quantum numbers"],
Cell[44146, 1457, 172, 5, 37, "BeginQuestion"],
Cell[44321, 1464, 589, 14, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44947, 1483, 175, 6, 26, "Subsubsection",
  Evaluatable->False],
Cell[45125, 1491, 281, 14, 24, "Text"],
Cell[45409, 1507, 330, 9, 38, "NumberedEquation"],
Cell[45742, 1518, 190, 8, 24, "Text"],
Cell[45935, 1528, 499, 14, 68, "BeginEndQuestion"],
Cell[46437, 1544, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[46540, 1551, 165, 6, 26, "Subsubsection",
  Evaluatable->False],
Cell[46708, 1559, 786, 29, 68, "BeginEndQuestion"],
Cell[47497, 1590, 66, 2, 32, "Answer",
  Evaluatable->False],
Cell[47566, 1594, 626, 19, 44, "Warning"],

Cell[CellGroupData[{
Cell[48217, 1617, 151, 2, 42, "Input"],
Cell[48371, 1621, 55, 1, 38, "Output"]
}, Open  ]],
Cell[48441, 1625, 790, 19, 56, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[49268, 1649, 111, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[49382, 1653, 1655, 47, 92, "Text"],
Cell[51040, 1702, 1106, 35, 78, "BeginEndQuestion"],
Cell[52149, 1739, 739, 21, 26, "Text"],

Cell[CellGroupData[{
Cell[52913, 1764, 658, 15, 24, "Input"],
Cell[53574, 1781, 3823, 89, 25, "Output"]
}, Open  ]],
Cell[57412, 1873, 95, 3, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[57544, 1881, 46, 0, 26, "Subsubsection"],
Cell[57593, 1883, 837, 26, 26, "Text",
  CellTags->"generic term"],

Cell[CellGroupData[{
Cell[58455, 1913, 590, 15, 25, "Input"],
Cell[59048, 1930, 93, 1, 25, "Output"]
}, Open  ]],
Cell[59156, 1934, 286, 9, 26, "Text",
  CellTags->{"pattern matching", "recurrence relation"}],

Cell[CellGroupData[{
Cell[59467, 1947, 150, 3, 25, "Input"],
Cell[59620, 1952, 81, 1, 25, "Output"]
}, Open  ]],
Cell[59716, 1956, 762, 29, 39, "BrightIdea"],
Cell[60481, 1987, 217, 8, 24, "Text"],

Cell[CellGroupData[{
Cell[60723, 1999, 64, 1, 24, "Input"],
Cell[60790, 2002, 97, 2, 36, "Output"]
}, Open  ]],
Cell[60902, 2007, 756, 23, 50, "BeginEndQuestion",
  CellTags->"power series method"],
Cell[61661, 2032, 456, 13, 42, "Text"],
Cell[62120, 2047, 170, 7, 50, "BeginEndQuestion"],
Cell[62293, 2056, 18, 0, 32, "Answer"],
Cell[62314, 2058, 346, 8, 42, "Text"],
Cell[62663, 2068, 940, 31, 70, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[63640, 2104, 88, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[63731, 2108, 314, 9, 28, "Text"],
Cell[64048, 2119, 206, 3, 39, "Input"],
Cell[64257, 2124, 349, 14, 31, "Text"],
Cell[64609, 2140, 566, 13, 42, "NumberedEquation"],
Cell[65178, 2155, 116, 5, 26, "Text"],
Cell[65297, 2162, 554, 12, 43, "Input"],
Cell[65854, 2176, 708, 24, 68, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[66599, 2205, 96, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[66698, 2209, 170, 5, 26, "Text"],
Cell[66871, 2216, 373, 10, 39, "NumberedEquation"],
Cell[67247, 2228, 212, 7, 29, "Text"],
Cell[67462, 2237, 1351, 41, 86, "BeginEndQuestion"],
Cell[68816, 2280, 283, 8, 44, "Text"],
Cell[69102, 2290, 497, 17, 70, "BeginEndQuestion"],
Cell[69602, 2309, 394, 15, 26, "Text",
  Evaluatable->False],
Cell[69999, 2326, 1690, 49, 106, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[71726, 2380, 103, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[71832, 2384, 609, 18, 27, "Text"],
Cell[72444, 2404, 330, 11, 50, "BeginEndQuestion"],
Cell[72777, 2417, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[72880, 2424, 98, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[72981, 2428, 569, 19, 27, "Text"],
Cell[73553, 2449, 546, 16, 64, "BeginEndQuestion"],
Cell[74102, 2467, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[74205, 2474, 96, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[74304, 2478, 533, 21, 51, "BeginEndQuestion"],
Cell[74840, 2501, 170, 5, 26, "Text"],
Cell[75013, 2508, 275, 8, 26, "NumberedEquation"],
Cell[75291, 2518, 114, 3, 24, "Text"],
Cell[75408, 2523, 529, 21, 51, "BeginEndQuestion"],
Cell[75940, 2546, 332, 9, 42, "Text"],
Cell[76275, 2557, 374, 15, 51, "BeginEndQuestion"],
Cell[76652, 2574, 334, 11, 50, "BeginEndQuestion"],
Cell[76989, 2587, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[77116, 2596, 123, 7, 39, "Section"],
Cell[77242, 2605, 847, 25, 42, "Text",
  CellTags->{"first-order perturbation theory", "energy shift"}],
Cell[78092, 2632, 367, 5, 22, "NumberedEquation"],
Cell[78462, 2639, 21, 0, 24, "Text"],
Cell[78486, 2641, 355, 8, 24, "NumberedEquation"],
Cell[78844, 2651, 219, 8, 26, "Text"],
Cell[79066, 2661, 1220, 25, 41, "NumberedEquation",
  CellTags->"ME(r cos)"],
Cell[80289, 2688, 262, 5, 40, "Text"],

Cell[CellGroupData[{
Cell[80576, 2697, 175, 11, 54, "Subsection",
  CellTags->"ME(r)"],
Cell[80754, 2710, 1371, 40, 84, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[82162, 2755, 179, 11, 32, "Subsection",
  CellTags->"ME(cos)"],
Cell[82344, 2768, 1261, 38, 69, "BeginEndQuestion"],
Cell[83608, 2808, 894, 28, 65, "BeginEndQuestion",
  CellTags->"selection rules"],
Cell[84505, 2838, 764, 18, 13, "Input",
  CellOpen->False],

Cell[CellGroupData[{
Cell[85294, 2860, 279, 6, 13, "Input",
  CellOpen->False],
Cell[85576, 2868, 2427, 59, 0, "Output",
  CellOpen->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88052, 2933, 209, 10, 32, "Subsection"],
Cell[88264, 2945, 938, 29, 53, "Text",
  CellTags->"Clebsch-Gordan coefficients"],
Cell[89205, 2976, 562, 13, 37, "NumberedEquation"],
Cell[89770, 2991, 880, 30, 42, "Text"],
Cell[90653, 3023, 1005, 23, 84, "NumberedEquation"],
Cell[91661, 3048, 784, 24, 44, "Text"],
Cell[92448, 3074, 891, 22, 41, "NumberedEquation"],
Cell[93342, 3098, 439, 14, 70, "BeginEndQuestion"],
Cell[93784, 3114, 583, 22, 35, "Text"],
Cell[94370, 3138, 69, 0, 24, "Text"],
Cell[94442, 3140, 329, 8, 49, "Input"],
Cell[94774, 3150, 893, 28, 64, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[95704, 3183, 159, 10, 32, "Subsection"],
Cell[95866, 3195, 1110, 34, 66, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[97001, 3233, 79, 1, 40, "Subsubsection"],
Cell[97083, 3236, 259, 11, 26, "Text"],
Cell[97345, 3249, 406, 12, 85, "Input"],
Cell[97754, 3263, 248, 6, 26, "Text",
  CellTags->"perturbation matrix"],

Cell[CellGroupData[{
Cell[98027, 3273, 84, 1, 36, "Input"],
Cell[98114, 3276, 322, 9, 81, "Output"]
}, Open  ]],
Cell[98451, 3288, 183, 6, 26, "Text",
  CellTags->"energy shift"],

Cell[CellGroupData[{
Cell[98659, 3298, 81, 1, 36, "Input"],
Cell[98743, 3301, 279, 6, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99059, 3312, 59, 1, 36, "Input"],
Cell[99121, 3315, 68, 1, 34, "Output"]
}, Open  ]],
Cell[99204, 3319, 155, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[99384, 3326, 86, 1, 36, "Input"],
Cell[99473, 3329, 644, 21, 81, "Output"]
}, Open  ]],
Cell[100132, 3353, 249, 6, 50, "BeginEndQuestion"],
Cell[100384, 3361, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[100439, 3366, 79, 1, 24, "Subsubsection"],
Cell[100521, 3369, 370, 15, 50, "BeginEndQuestion"],
Cell[100894, 3386, 18, 0, 32, "Answer"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100973, 3393, 123, 5, 39, "Section"],
Cell[101099, 3400, 365, 16, 24, "Text"],
Cell[101467, 3418, 1286, 32, 56, "NumberedEquation"],
Cell[102756, 3452, 676, 23, 26, "Text"],

Cell[CellGroupData[{
Cell[103457, 3479, 371, 8, 19, "Input",
  Evaluatable->False,
  CellOpen->False],
Cell[103831, 3489, 13529, 330, 188, 3991, 208, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[117375, 3822, 210, 7, 24, "Text"],
Cell[117588, 3831, 599, 14, 54, "NumberedEquation"],
Cell[118190, 3847, 189, 5, 24, "Text"],
Cell[118382, 3854, 687, 17, 59, "NumberedEquation"],
Cell[119072, 3873, 21, 0, 24, "Text"],
Cell[119096, 3875, 395, 6, 57, "NumberedEquation"],
Cell[119494, 3883, 19, 0, 24, "Text"],
Cell[119516, 3885, 125, 2, 40, "NumberedEquation"],
Cell[119644, 3889, 546, 15, 42, "Text",
  CellTags->"helium"],
Cell[120193, 3906, 154, 2, 25, "NumberedEquation"],
Cell[120350, 3910, 204, 8, 26, "Text"],
Cell[120557, 3920, 384, 8, 41, "NumberedEquation"],
Cell[120944, 3930, 513, 18, 50, "BeginEndQuestion"],
Cell[121460, 3950, 280, 8, 50, "BeginEndQuestion"],
Cell[121743, 3960, 66, 2, 32, "Answer",
  Evaluatable->False],
Cell[121812, 3964, 352, 10, 24, "Text"],
Cell[122167, 3976, 399, 7, 53, "NumberedEquation",
  CellTags->"first-order perturbation energy"],
Cell[122569, 3985, 279, 10, 26, "Text"],
Cell[122851, 3997, 612, 9, 42, "NumberedEquation",
  CellTags->{"interparticle coordinates", "general matrix element"}],
Cell[123466, 4008, 465, 21, 24, "Text"],

Cell[CellGroupData[{
Cell[123956, 4033, 151, 7, 54, "Subsection"],
Cell[124110, 4042, 52, 0, 24, "Text"],
Cell[124165, 4044, 333, 5, 43, "NumberedEquation"],
Cell[124501, 4051, 21, 0, 24, "Text"],
Cell[124525, 4053, 222, 4, 25, "NumberedEquation"],
Cell[124750, 4059, 688, 16, 58, "Text"],
Cell[125441, 4077, 97, 3, 24, "Warning"],

Cell[CellGroupData[{
Cell[125563, 4084, 135, 3, 40, "Subsubsection",
  Evaluatable->False],
Cell[125701, 4089, 272, 9, 24, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[125998, 4102, 112, 2, 24, "Input"],
Cell[126113, 4106, 153, 3, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126303, 4114, 299, 6, 42, "Input"],
Cell[126605, 4122, 343, 5, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126985, 4132, 141, 3, 39, "Input"],
Cell[127129, 4137, 443, 7, 45, "Output"]
}, Open  ]],
Cell[127587, 4147, 67, 2, 24, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[127679, 4153, 145, 3, 39, "Input"],
Cell[127827, 4158, 199, 3, 43, "Output"]
}, Open  ]],
Cell[128041, 4164, 126, 5, 24, "Text"],
Cell[128170, 4171, 237, 3, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[128444, 4179, 135, 3, 24, "Subsubsection",
  Evaluatable->False],
Cell[128582, 4184, 400, 12, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[129019, 4201, 97, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[129119, 4205, 531, 18, 52, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[129687, 4228, 96, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[129786, 4232, 210, 7, 24, "Text"],
Cell[129999, 4241, 415, 6, 52, "NumberedEquation",
  CellTags->"general matrix element"],
Cell[130417, 4249, 189, 7, 50, "BeginEndQuestion"],
Cell[130609, 4258, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[130712, 4265, 99, 2, 26, "Subsubsection",
  Evaluatable->False],
Cell[130814, 4269, 46, 0, 24, "Text"],
Cell[130863, 4271, 561, 9, 47, "NumberedEquation"],
Cell[131427, 4282, 293, 14, 50, "BeginEndQuestion"],
Cell[131723, 4298, 18, 0, 32, "Answer"],
Cell[131744, 4300, 302, 10, 26, "Text",
  Evaluatable->False],
Cell[132049, 4312, 340, 6, 41, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[132438, 4324, 152, 10, 32, "Subsection"],
Cell[132593, 4336, 836, 23, 66, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[133466, 4364, 159, 7, 32, "Subsection"],
Cell[133628, 4373, 397, 15, 50, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[134062, 4393, 142, 7, 32, "Subsection"],
Cell[134207, 4402, 293, 9, 50, "BeginEndQuestion"],
Cell[134503, 4413, 266, 9, 50, "BeginEndQuestion"],
Cell[134772, 4424, 66, 2, 32, "Answer",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

