(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    183051,       5583]*)
(*NotebookOutlinePosition[    260395,       8226]*)
(*  CellTagsIndexPosition[    258608,       8178]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell["Exam 2000", "Title"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["physics.uwa.edu.au/Physics/Courses/Third_Year/Computational_\
Physics.html",
    ButtonData:>{
      URL[ 
      "http://physics.uwa.edu.au/Courses/Third_Year/Computational_Physics.\
html"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Instructions", "Subsection"],

Cell[TextData[{
  "This exam, worth 40% of the total mark for Computational Physics, is due \
in by 5 pm on Monday May 22. Each student is to do the exam ",
  StyleBox["by themselves",
    FontSlant->"Italic"],
  " and submit their solutions ",
  StyleBox["individually",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "The exam consists of 6 questions of varying difficulty with numerous hints \
as to how to proceed. You should attempt to answer ",
  StyleBox["whole",
    FontSlant->"Italic"],
  " questions whose total value is ",
  StyleBox["at least",
    FontSlant->"Italic"],
  " 110 marks. The marks for each question is clearly indicated in red \
brackets (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["[", "Marks"],
  StyleBox["n", "Marks",
    FontSlant->"Italic"],
  StyleBox["]", "Marks"],
  ") and, obviously, the marks provide a good guide to the question's \
difficulty. Bonus marks will be given for elegant or unconventional \
solutions."
}], "Text"],

Cell[TextData[{
  "I quote from the Departmental ",
  StyleBox["Guidelines on Plagiarism",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell["\<\
Like the scientific process, assessment of students relies on the \
integrity of the participants. The Department expects that any piece of work \
submitted by a student for assessment will be essentially their own work, and \
that contributions of others to that work will be appropriately acknowledged. \
In essence, students are expected to write their own essays and assignments, \
just as they are expected to sit the exams themselves.\
\>", "Quote"],

Cell["\<\
Students should generally avoid verbatim copying of published work, \
even when the work is cited. They are strongly encouraged to express their \
knowledge and thoughts in their own words, rather than those of others, as \
this greatly assists the learning process. It is acknowledged however that in \
some circumstances it is desirable to quote directly from a published work.\
\
\>", "Quote"],

Cell[TextData[{
  "Please do not leave copies of your working Notebooks in public locations, \
such as on the computers in the second- or third-year laboratory. I recommend \
that you backup your solutions to a password-secured area, such as to your \
tartarus account. Note that, when I mark the exam papers, I find it \
particularly easy to spot answers, or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code, that is common to more than one student."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell["Submitting your Solution", "Subsection"],

Cell[TextData[{
  "Please name your exam solution using your initials, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["PCA.nb", "InlineInputTraditionalForm"],
  ", and ",
  "submit to ",
  ButtonBox["ftp://ftp.physics.uwa.edu.au/incoming/Exam",
    ButtonData:>{
      URL[ "ftp://ftp.physics.uwa.edu.au/incoming/Exam"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Thermodynamics ",
  StyleBox["[40]", "Marks"]
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Equation of State",
  " ",
  StyleBox["[1]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Equations of state (EOS) are widely \
used\[ThinSpace]\[LongDash]\[ThinSpace]both in textbooks and in industry\
\[ThinSpace]\[LongDash]\[ThinSpace]for representing the pressure (",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "), volume (",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  "), and temperature (",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ") relationships of real fluids. Many EOS are explicit in ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " and cubic in ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(P = \(R\ T\)\/\(V - b\) - \ 
        a\/\(w\ b\^2 + u\ V\ b + V\^2\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the ",
  ButtonBox["gas constant",
    ButtonData:>{
      FrontEnd`FileName[ {$TopDirectory, "Documentation", "English", 
        "GettingStarted", "Demos", "Palettes", "PhysicalConstants.nb"}], 
      None},
    ButtonStyle->"Hyperlink",
    ButtonNote->None],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are parameters to be determined. In some EOS the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is a function of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a(T)\)]],
  ". The quantities ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " are usually given integer values."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Write a general function for the EOS. ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Polynomial Form",
  " ",
  StyleBox["[3]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The general EOS can be expressed as a cubic polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Express the general EOS as a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", with leading coefficient unity, and simplify the result. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Special Cases ",
  StyleBox["[2]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For suitable parameters, the EOS reduces to that of an ideal gas. Find \
these parameters. ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The van der Waals equation has ",
  Cell[BoxData[
      \(TraditionalForm\`u = \(w = 0\)\)]],
  ". Determine the van der Waals EOS. ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"van der Waals EOS"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Compressibility ",
  StyleBox["[2]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["An important thermodynamical quantity is the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["compressibility",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", defined by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`z = \(P\ V\)\/\(R\ T\)\)]],
  ". "
}], "Text",
  Evaluatable->False],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Using the replacements ",
  Cell[BoxData[
      \(TraditionalForm\`V \[Rule] \(z\ R\ T\)\/P\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \(A\ \((R\ T)\)\^2\)\/P\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \(B\ \((R\ T)\)\)\/P\)]],
  ", obtain and simplify the ",
  StyleBox["compressibility polynomial",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Note that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  StyleBox[" are ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["dimensionless",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" (since ",
    Evaluatable->False,
    AspectRatioFixed->True],
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  StyleBox[" is dimensionless). ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Critical Point ",
  StyleBox["[5]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " (or ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ") may be evaluated by making use of the fact that the ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " relationship has a point of inflection at the ",
  StyleBox["critical point",
    FontSlant->"Italic"],
  ". That is:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        FractionBox[\(\[PartialD]P\), \(\[PartialD]V\),
          MultilineFunction->None], "=", 
        RowBox[{
          RowBox[{"0", Cell[" and "], 
            FractionBox[\(\[PartialD]\^2 P\), \(\[PartialD]V\^2\),
              MultilineFunction->None]}], "=", "0"}]}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"critical point"],

Cell[TextData[{
  "when ",
  Cell[BoxData[
      \(TraditionalForm\`P = P\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T = T\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V = V\_c\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_c = \(\(P\_c\) V\_c\)\/\(R\ T\_c\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`P\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_c\)]],
  " are the critical pressure, temperature, volume, and compressibility \
respectively. These properties have been determined experimentally for a \
large number of fluids and have been estimated for many others."
}], "Text"],

Cell[TextData[{
  "Equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "critical point"],
  ") is equivalent to requiring that the volume or compressibility \
polynomials have three equal real roots:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\((V - V\_c)\)\^3\), "=", 
        RowBox[{"0", "=", 
          RowBox[{Cell[""], \(\(\((z - z\_c)\)\^3\)\(.\)\)}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and the parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", for the van der Waals EOS (see question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "van der Waals EOS"],
  "). ",
  StyleBox["[5]", "Marks"]
}], "BeginEndQuestion",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Redlich-Kwong EOS ",
  StyleBox["[7]", "Marks"]
}], "Subsection"],

Cell["The Redlich-Kwong (RK) EOS reads", "Text",
  CellTags->"Redlich-Kwong EOS"],

Cell[BoxData[
    \(TraditionalForm\`P = \(R\ T\)\/\(V - b\) - \(\(a\/\(\(T\^\(1/2\)\) 
                V\ \((V + b)\)\)\)\(.\)\)\)], "NumberedEquation",
  CellTags->"RK EOS"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", for the RK EOS (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "RK EOS"],
  "). As a check, you should find that ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c = \(R\ T\_c\)\/\(3\ P\_c\)\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Obtain and simplify the ",
  StyleBox["dimensionless form",
    FontSlant->"Italic"],
  " of the RK EOS (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "RK EOS"],
  ") by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`p\ P\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\ V\_c\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`t\ T\_c\)]],
  ", respectively, where the ",
  StyleBox["dimensionless parameters",
    FontSlant->"Italic"],
  " are denoted using ",
  Cell[BoxData[
      \(TraditionalForm\`x = X/X\_c\)]],
  ". ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". \[ThinSpace]Maxwell Construction ",
  StyleBox["[20]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "As you will see, below the critical temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ", loops appear in the ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " diagram. These loops are forbidden for thermodynamical reasons. For ",
  Cell[BoxData[
      \(TraditionalForm\`t < 1\)]],
  ", a phase transition between gas and liquid takes place; at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  " the difference between the liquid and gaseous phases vanishes."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". One one plot, display a set of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " curves with ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0.9, 0.92, \[Ellipsis], 1.02\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Element] \([0.4, 4]\)\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"p-v curves"],

Cell[CellGroupData[{

Cell[TextData[{
  "Over a certain temperature range, three volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v\_2 \[LessEqual] v\_3\)]],
  " correspond to each pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ". For thermodynamic reasons, the transition from the gas with large volume \
",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ", to the liquid, with small volume ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", takes place at the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p\&_\)]],
  " for which "
}], "Text",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(v\_1\)\%\(v\_3\)\(p(
            v)\) \[DifferentialD]v = \((v\_3 - 
            v\_1)\) \(\(p\&_\)\(\[VeryThinSpace]\)\(.\)\)\)], \
"NumberedEquation",
  CellTags->"equal area"],

Cell[TextData[{
  "At ",
  Cell[BoxData[
      \(TraditionalForm\`p\&_\)]],
  ", gas and liquid are simultaneously present for all volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_3\)]],
  "; one observes a two-phase mixture\[ThinSpace]\[LongDash]\[ThinSpace]the \
",
  StyleBox["coexistence region",
    FontSlant->"Italic"],
  ". Geometrically, equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "equal area"],
  ") means that the area between the curve ",
  Cell[BoxData[
      \(TraditionalForm\`p(v)\)]],
  " and the straight line ",
  Cell[BoxData[
      \(TraditionalForm\`p\&_ = constant\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_2\)]],
  " is the same as the corresponding area for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2 \[LessEqual] v \[LessEqual] v\_3\)]],
  ". This is known as the ",
  StyleBox["Maxwell construction",
    FontSlant->"Italic"],
  ". We want to construct the line ",
  Cell[BoxData[
      \(TraditionalForm\`p\&_ = constant\)]],
  "; the two-phase line. For the two-phase line we need two equations in \
order to determine the two unknown volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ":"
}], "Text",
  CellTags->{"two-phase line", "Maxwell construction"}],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(p(v\_1, t) = p(v\_3, t)\)\(,\)\)},
          {\(\[Integral]\_\(v\_1\)\%\(v\_3\)\(p(v, 
                    t)\) \[DifferentialD]v = \((v\_3 - v\_1)\) \(\(p(v\_3, 
                    t)\)\(.\)\)\)}
          }], TraditionalForm]], "NumberedEquation",
  GridBoxOptions->{ColumnAlignments->{"="}},
  CellTags->"two-phase"],

Cell[TextData[{
  "There is no simple analytical solution to equations (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-phase"],
  ")."
}], "Text"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For each temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0.9, 0.92, \[Ellipsis], 0.98\)]],
  ", determine ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  " using ",
  Cell[BoxData[
      FormBox[
        StyleBox["FindRoot",
          "Input"], TraditionalForm]]],
  ". You will need fairly accurate initial guesses; \[VeryThinSpace]these can \
be estimated from the plot in question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "p-v curves"],
  ". ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Visualize the Maxwell construction for the RK EOS as a set of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " curves for ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0.9, 0.92, \[Ellipsis], 1.02\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Element] \([0.4, 4]\)\)]],
  ". Display the boundary of the coexistence region on your plot. ",
  StyleBox["[8]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Visualize the ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " surface",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  " of the RK EOS over ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Element] \([0.9, 1.05]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v \[Element] \([0.4, 5]\)\)]],
  ". ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Solitons ",
  StyleBox["[40]", "Marks"]
}], "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Korteweg de Vries (KdV) equation, describing water waves in \
shallow channels, is given by\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]u\), \(\[PartialD]t\),
              MultilineFunction->None], "-", 
            RowBox[{"6", " ", "u", " ", 
              FractionBox[\(\[PartialD]u\), \(\[PartialD]x\),
                MultilineFunction->None]}], "+", 
            FractionBox[\(\[PartialD]\^3 u\), \(\[PartialD]x\^3\),
              MultilineFunction->None]}], "=", "0"}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"KdV equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is the wave amplitude."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "One-soliton Solution ",
  StyleBox["[9]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Find a solution to the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ") of the form ",
  Cell[BoxData[
      \(TraditionalForm\`a\ \(\(sech\^2\)(x - b\ t)\)\)]],
  " by selecting suitable values for ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". Call your result ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x_, t_)\)]],
  ". Visualize (and animate) the time evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, t)\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([\(-20\), 20]\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t = \(-4\), \(-3\), \[Ellipsis], 4\)]],
  ". What happens to the shape of the wave as a function of time? ",
  StyleBox["[7]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"time evolution"],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". What is the velocity of an arbitrary wave of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f(k\ x - \[Omega]\ t)\)]],
  "? Determine the velocity of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, t)\)]],
  " from its time evolution and compare it with the expected result. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-soliton Solution ",
  StyleBox["[8]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_2\)(x, 
          t) = \(-\(\(12\ \((4\ \(cosh(8\ t - 2\ x)\) + cosh(64\ t - 4\ x) + 
                    3)\)\)\/\((3\ \(cosh(28\ t - x)\) + cosh(36\ t - 3\ x))\)\
\^2\)\)\)]],
  " is a \[OpenCurlyDoubleQuote]two-soliton\[CloseCurlyDoubleQuote] solution \
to the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  "). Visualize the time evolution of this solution over ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([\(-40\), 40]\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t = \(-2\), \(-1.75\), \(-1.5\), \[Ellipsis], 1.75, 
      2\)]],
  ".  The meaning of the name \[OpenCurlyDoubleQuote]two-soliton\
\[CloseCurlyDoubleQuote] solution should become clear. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"two-soliton solution"],

Cell[CellGroupData[{

Cell["\<\
Observe that the smaller slower soliton of the two-soliton solution \
appears identical to the one-soliton solution, but with a small phase \
shift.\
\>", "Text",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(Plot[{\(u\_1\)(x, 2), \(u\_2\)(x, 2)}, {x, 0, 15}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.603319 0.294304 [
[.15079 .59082 -4.5 -12 ]
[.15079 .59082 4.5 0 ]
[.27778 .59082 -4.5 -12 ]
[.27778 .59082 4.5 0 ]
[.40476 .59082 -4.5 -12 ]
[.40476 .59082 4.5 0 ]
[.53175 .59082 -4.5 -12 ]
[.53175 .59082 4.5 0 ]
[.65873 .59082 -7 -12 ]
[.65873 .59082 7 0 ]
[.78571 .59082 -7 -12 ]
[.78571 .59082 7 0 ]
[.9127 .59082 -7 -12 ]
[.9127 .59082 7 0 ]
[.01131 .01471 -15.9375 -6 ]
[.01131 .01471 0 6 ]
[.01131 .16186 -23.4375 -6 ]
[.01131 .16186 0 6 ]
[.01131 .30902 -15.9375 -6 ]
[.01131 .30902 0 6 ]
[.01131 .45617 -23.4375 -6 ]
[.01131 .45617 0 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .60332 m
.15079 .60957 L
s
gsave
.15079 .59082 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.27778 .60332 m
.27778 .60957 L
s
gsave
.27778 .59082 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.40476 .60332 m
.40476 .60957 L
s
gsave
.40476 .59082 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.53175 .60332 m
.53175 .60957 L
s
gsave
.53175 .59082 -65.5 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65873 .60332 m
.65873 .60957 L
s
gsave
.65873 .59082 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.78571 .60332 m
.78571 .60957 L
s
gsave
.78571 .59082 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.9127 .60332 m
.9127 .60957 L
s
gsave
.9127 .59082 -68 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .60332 m
.05556 .60707 L
s
.0873 .60332 m
.0873 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.18254 .60332 m
.18254 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.24603 .60332 m
.24603 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.34127 .60332 m
.34127 .60707 L
s
.37302 .60332 m
.37302 .60707 L
s
.43651 .60332 m
.43651 .60707 L
s
.46825 .60332 m
.46825 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.56349 .60332 m
.56349 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.62698 .60332 m
.62698 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.72222 .60332 m
.72222 .60707 L
s
.75397 .60332 m
.75397 .60707 L
s
.81746 .60332 m
.81746 .60707 L
s
.84921 .60332 m
.84921 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.94444 .60332 m
.94444 .60707 L
s
.97619 .60332 m
.97619 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01471 m
.03006 .01471 L
s
gsave
.01131 .01471 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .16186 m
.03006 .16186 L
s
gsave
.01131 .16186 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -76.9375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .45617 m
.03006 .45617 L
s
gsave
.01131 .45617 -84.4375 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.03279 .60332 L
.04262 .60332 L
.05288 .60332 L
.06244 .60332 L
.0731 .60332 L
.0828 .60332 L
.094 .60332 L
.10458 .60332 L
.11428 .60331 L
.12455 .60331 L
.13333 .60331 L
.14299 .60331 L
.15313 .6033 L
.1624 .6033 L
.17311 .60329 L
.18328 .60328 L
.19287 .60326 L
.20309 .60324 L
.21273 .60322 L
.22147 .60319 L
.2315 .60314 L
.24072 .60307 L
.25085 .60298 L
.26154 .60285 L
.27102 .60268 L
.28118 .60244 L
.29077 .60213 L
.29951 .60175 L
.30943 .60118 L
.3186 .60047 L
.32866 .59941 L
.33936 .59785 L
.34873 .59598 L
.35883 .59326 L
.36837 .58978 L
.37711 .58555 L
.38691 .57925 L
.39603 .57146 L
.40604 .56009 L
.41673 .54367 L
.42698 .52257 L
.43808 .49209 L
.44856 .45442 L
.45823 .41082 L
.47699 .30104 L
.49763 .15657 L
.50761 .0922 L
.51252 .06553 L
.51708 .04503 L
Mistroke
.51982 .03499 L
.5223 .02754 L
.52506 .02119 L
.52657 .0186 L
.528 .01676 L
.52921 .01565 L
.5305 .01494 L
.53159 .01472 L
.53279 .01487 L
.53409 .01551 L
.53481 .01608 L
.53547 .01674 L
.53676 .01836 L
.53797 .02034 L
.54035 .02539 L
.54258 .03151 L
.54765 .05016 L
.5526 .0739 L
.55792 .10443 L
.57636 .23088 L
.59604 .36085 L
.60645 .41665 L
.61755 .46472 L
.62833 .50097 L
.63811 .52626 L
.64795 .54576 L
.65722 .55979 L
.66697 .57098 L
.67728 .57976 L
.68608 .58538 L
.69574 .59003 L
.70593 .59365 L
.71523 .59609 L
.72596 .59815 L
.73613 .59957 L
.74577 .60055 L
.75602 .60131 L
.76477 .60179 L
.77443 .60219 L
.78451 .6025 L
.79375 .60271 L
.80391 .60287 L
.8146 .603 L
.82413 .60308 L
.83432 .60315 L
.84393 .60319 L
.85268 .60322 L
.86264 .60325 L
.87184 .60327 L
.88193 .60328 L
Mistroke
.89263 .60329 L
.90205 .6033 L
.91218 .6033 L
.92174 .60331 L
.93048 .60331 L
.94034 .60331 L
.94948 .60331 L
.95952 .60332 L
.97021 .60332 L
.97619 .60332 L
Mfstroke
.02381 .60332 m
.03279 .60332 L
.04262 .60332 L
.05288 .60332 L
.06244 .60332 L
.0731 .60332 L
.0828 .60331 L
.094 .60331 L
.10458 .60331 L
.11428 .60331 L
.12455 .6033 L
.13333 .60329 L
.14299 .60329 L
.15313 .60327 L
.1624 .60326 L
.17311 .60323 L
.18328 .6032 L
.19287 .60316 L
.20309 .60309 L
.21273 .60301 L
.22147 .60292 L
.2315 .60277 L
.24072 .60258 L
.25085 .60231 L
.26154 .6019 L
.27102 .60141 L
.28118 .60069 L
.29077 .59976 L
.29951 .59864 L
.30943 .59693 L
.3186 .59481 L
.32866 .59167 L
.33936 .58706 L
.34873 .58159 L
.35883 .57365 L
.36837 .56361 L
.37711 .55159 L
.38691 .534 L
.39603 .51277 L
.40604 .48281 L
.41673 .44164 L
.43808 .32727 L
.45823 .18834 L
.46795 .12172 L
.47327 .08909 L
.47824 .06259 L
.48284 .04256 L
.48703 .02862 L
.48942 .02274 L
.49169 .01861 L
Mistroke
.49293 .01697 L
.49409 .01584 L
.49535 .01505 L
.49606 .01481 L
.4967 .01472 L
.4979 .01487 L
.49903 .01539 L
.50026 .01639 L
.50159 .01795 L
.50297 .02012 L
.50429 .02267 L
.50675 .02873 L
.51117 .0436 L
.51598 .06498 L
.52681 .12839 L
.53682 .19763 L
.55711 .33635 L
.56704 .39364 L
.57613 .43782 L
.58483 .47277 L
.59434 .50353 L
.60389 .52773 L
.61394 .54723 L
.62424 .56222 L
.63359 .57242 L
.64438 .58115 L
.65455 .58715 L
.6643 .59138 L
.6746 .59466 L
.6834 .59675 L
.69307 .59847 L
.70326 .59979 L
.71255 .60069 L
.72329 .60144 L
.73346 .60196 L
.7431 .60231 L
.75335 .60259 L
.76209 .60277 L
.77176 .60291 L
.78183 .60302 L
.79108 .6031 L
.80123 .60316 L
.81193 .6032 L
.82146 .60323 L
.83165 .60326 L
.84126 .60327 L
.85 .60328 L
.85997 .60329 L
.86917 .6033 L
.87926 .60331 L
Mistroke
.88995 .60331 L
.89938 .60331 L
.9095 .60331 L
.91907 .60332 L
.92781 .60332 L
.93766 .60332 L
.94681 .60332 L
.95684 .60332 L
.96754 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`008@3oool00`000000oooo0?oo
o`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool001@0oooo1@0000080?oo
o`030000003oool0oooo0?l0ooooA@3oool001@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA@3oool001D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`3o0?ooodD0oooo000<0?ooo`L000000`3oool00`000000oooo0?oo
o`080?ooo`<00000VP3oool2000000X0oooo0P00002L0?ooo`005`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo09T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00002K0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo09T0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000V`3oool001@0oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000V`3oool001@0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0V03oool001D0oooo0`0000090?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0V03oool00240oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2G0?ooo`008@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo09L0oooo000Q0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo09H0oooo000Q0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000090?ooo`030000
003oool0oooo09H0oooo000Q0?ooo`800000U`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000T0oooo00<000000?ooo`3oool0UP3oool00240oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0U@3oool0
0240oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`060?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool0U@3oool00240oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`080?ooo`8000002P3oool00`000000oooo0?ooo`2E0?ooo`008@3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2E0?ooo`008@3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2E0?ooo`008@3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`030000003oool0oooo09D0oooo000Q0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0203oool2000000/0oooo00<000000?oo
o`3oool0U03oool00240oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`080?ooo`80
00002`3oool00`000000oooo0?ooo`2D0?ooo`008@3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo00T0oooo0P00000;0?ooo`030000003oool0oooo09@0oooo000Q0?ooo`800000U@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0U03o
ool00240oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool0U03oool00240oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0U03o
ool00240oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool0T`3oool00240oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`090?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0T`3o
ool00240oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000002`3oool00`000000oooo0?ooo`2C0?ooo`008@3oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09<0oooo000Q0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00240oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`00
8@3oool2000009<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00240oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`2B0?ooo`008@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0980oooo000Q0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0TP3oool00240
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2B0?ooo`008@3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0940oooo000Q0?ooo`030000003oool0oooo0940oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0T@3oool00240oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2A
0?ooo`008@3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0940oooo000Q0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0T@3oool00240oooo0P00002B0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0940oooo000Q0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T@3o
ool00240oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2@0?ooo`008@3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0900oooo000Q0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0T03oool00240oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2@0?ooo`008@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0900oooo000<
0?ooo`<000000`3oool00`000000oooo00000004000000P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2@0?ooo`003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2@0?ooo`003@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2?0?ooo`000`3oool7000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`050?ooo`<00000S`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2?0?ooo`003@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2?0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`D00000203oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo08l0oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08l0oooo000=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo08l0oooo000<0?ooo`8000001`3oool5000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2?0?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo08h0oooo000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0SP3oool0
0240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2>0?ooo`008@3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo08h0oooo000Q0?ooo`800000S`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2>0?ooo`008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08h0oooo000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0SP3oool00240oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`2=0?ooo`008@3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo08d0oooo000Q0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
S@3oool00240oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2=0?ooo`008@3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo08d0oooo000Q0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0S@3oool00240oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2=0?ooo`008@3oool2000008d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0S03oool00240oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2<0?ooo`008@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo08`0oooo000Q0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0S03oool00240oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2<0?ooo`00
8@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08`0oooo000Q0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0S03oool00240oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`2;0?ooo`008@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
08/0oooo000Q0?ooo`800000S03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2;0?ooo`008@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo08/0oooo000Q0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0R`3oool00240oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2;
0?ooo`008@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08X0oooo000Q0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0RP3oool00240oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`2:0?ooo`008@3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo08X0oooo000Q0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0RP3oool0
0240oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2:0?ooo`008@3oool2000008/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0R@3oool00240oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`290?ooo`008@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08T0oooo000Q
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R@3oool00240oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`290?ooo`008@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo08T0oooo000Q0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
R03oool001D0oooo0`0000090?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R03o
ool001H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo08P0oooo000F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`280?ooo`00303oool7000000<0oooo00<000000?ooo`3oool0203oool3000008P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0R03oool001H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo08P0oooo000F0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`280?ooo`005P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q`3oool001H0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08L0oooo000E0?ooo`80
00002P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08L0oooo000Q0?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0Q`3oool00240oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`270?ooo`008@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo08L0oooo000Q0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0QP3oool00240
oooo0P0000270?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo08H0oooo000Q0?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0QP3oool00240oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`260?ooo`008@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08H0oooo000Q0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0QP3oool00240oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`250?ooo`008@3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo08D0oooo000Q0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q@3o
ool00240oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`250?ooo`008@3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo08D0oooo000Q0?ooo`800000QP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`250?ooo`008@3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08@0oooo
000Q0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q03oool00240oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`240?ooo`008@3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo08@0oooo000Q0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0Q03oool00240oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`240?ooo`008@3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08<0oooo000Q0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0P`3oool00240oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`230?ooo`008@3oool2000008@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P`3oool00240oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`230?ooo`008@3oool00`000000oooo0?oo
o`220?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo08<0oooo000Q0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0P`3oool00240oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`220?oo
o`008@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0880oooo000Q0?ooo`030000
003oool0oooo0880oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0PP3oool00240oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`220?ooo`008@3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0880oooo000Q0?ooo`800000PP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`210?ooo`008@3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0840oooo000Q0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0P@3oool00240oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`210?ooo`008@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0800oooo000Q0?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P03oool00240oooo00<000000?ooo`3o
ool0P03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`200?ooo`00303oool4000000<0oooo00<000000?ooo`000000
100000070?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P03oool000/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1o0?ooo`002`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo07l0oooo00030?ooo`L0000000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo0`00001o0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
07l0oooo000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0O`3oool000/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`D000001`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo07h0oooo000;0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0OP3oool000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1n
0?ooo`00303oool4000000H0oooo1@0000060?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0O@3oool00240oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1m0?ooo`00
8@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07d0oooo000Q0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0O03oool00240oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1l0?ooo`008@3oool2000007d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0O03oool00240
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1k0?ooo`008@3oool00`000000oooo
0?ooo`1k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo07/0oooo000Q0?ooo`030000003oool0oooo07/0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0N`3oool00240oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1j
0?ooo`008@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo07X0oooo000Q0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0NP3oool00240oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1i0?ooo`008@3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo07T0oooo000Q0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0N@3oool0
0240oooo0P00001j0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo07P0oooo000Q0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0N03oool00240oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1h0?ooo`008@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo07L0oooo000Q
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M`3oool00240oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1g0?ooo`008@3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo07H0oooo000Q0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
MP3oool00240oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1e0?ooo`008@3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo07D0oooo000Q0?ooo`800000M@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1d0?ooo`008@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07@0
oooo000Q0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0L`3oool00240oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1b0?ooo`008@3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0780oooo000Q0?ooo`030000003oool0oooo02@0oooo1@00000Z0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool4000002H0oooo1000000L0?oo
o`030000003oool0oooo00@0oooo0`0000020?ooo`D000008@3oool300000080oooo1@00000P0?oo
o`<000001P3oool00`000000oooo0?ooo`0H0?ooo`008@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo00H000000?ooo`3oool000000?ooo`00000T0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
603oool00240oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`H000006P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool000000080oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool010000000oooo0?ooo`3oool60000
01T0oooo000Q0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool01@000000
oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool0203oool2000000<0oooo00<000000?oo
o`3oool08`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`<000008@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0240oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo01P0oooo
000Q0?ooo`800000:03oool00`000000oooo0?ooo`0V0?ooo`040000003oool0oooo000001P0oooo
0P00000:0?ooo`<000000`3oool00`000000oooo0?ooo`0T0?ooo`8000008@3oool200000080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000006P3oool00240oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0000001L0oooo00<000000?ooo`3oool02@3oool010000000oooo0000003oool30000
02H0oooo00@000000?ooo`3oool000008P3oool00`000000oooo000000030?ooo`030000003oool0
oooo0080oooo0P00000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0000001X0oooo000Q0?ooo`030000003oool0oooo
02@0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`8000005P3oool00`000000oooo0?ooo`08
0?ooo`8000000`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0803oool2000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000
000N0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00@0oooo0P00000J0?ooo`008@3oool00`000000oooo0?ooo`0T0?ooo`050000003o
ool0oooo0?ooo`000000:@3oool2000001@0oooo0P00000:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo
0P0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000M0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00@0oooo0P00000J0?ooo`008@3oool00`000000oooo0?ooo`0U0?ooo`<00000:`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`<000009@3oool4000002<0
oooo0P000000103oool000000?ooo`3oool4000000D0oooo0P00000J0?ooo`800000103oool30000
0240oooo0P0000070?ooo`030000003oool0oooo01P0oooo000Q0?ooo`030000003oool0oooo06D0
oooo0P00000:0?ooo`030000003oool0oooo05/0oooo0`00000:0?ooo`030000003oool0oooo06D0
oooo000Q0?ooo`030000003oool0oooo0640oooo1000000:0?ooo`800000H@3oool4000000L0oooo
0`00001T0?ooo`008@3oool00`000000oooo0?ooo`1N0?ooo`<000002P3oool4000006L0oooo0`00
00070?ooo`<00000H@3oool00240oooo00<000000?ooo`3oool0F`3oool3000000L0oooo1P00001^
0?ooo`<000001`3oool4000005d0oooo000Q0?ooo`030000003oool0oooo0540oooo2P0000030?oo
o`L00000M`3oool:000000030?ooo`000000000000P00000D`3oool001T0ooooo`00001@00000000
8@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`008@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`008@3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo000Q0?ooo`030000003oool0oooo0?l0ooooA@3oool00240
oooo00<000000?ooo`3oool0o`3ooom50?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.58065, -2.14105, \
0.059038, 0.0127367}}]
}, Open  ]],

Cell["\<\
From your visualization of the two-soliton solution, you should \
find that the velocity of the smaller slower soliton is\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(v\_1 = \(+4\);\)\)], "Input"],

Cell[TextData[{
  "In a frame of reference moving with this velocity (",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] x + \(v\_1\) t\)]],
  "), the shape of the slow soliton as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  " is given as follows. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(u\_\(2, slow\)\)(x_, \[Infinity]) = 
      lim\+\(t \[Rule] \[Infinity]\)\(u\_2\)(x + \(v\_1\) t\ , t)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-\(\(24\ \[ExponentialE]\^\(2\ x\)\)\/\((1 + 3\ \
\[ExponentialE]\^\(2\ x\))\)\^2\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_\(2, slow\)\)(x, \[Infinity])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, 0)\)]],
  " together for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([\(-5\), 5]\)\)]],
  ". Determine the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " phase-shift by solving ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x + \[Phi], 0) = \(u\_\(2, slow\)\)(
          x, \[Infinity])\)]],
  ". Verify that your result agrees with the plot. You may find ",
  StyleBox["TrigToExp", "InlineInputTraditionalForm"],
  " useful. ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine the velocity of the taller faster soliton, ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ", and use this to find the shape of the fast soliton as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Conservation Laws ",
  StyleBox["[10]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "A ",
  StyleBox["continuity equation",
    FontSlant->"Italic"],
  ", relating a general density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " and its corresponding current ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  ", of the form"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]\_t \[Rho] + \[PartialD]\_x J = 
      0\)\(,\)\)\)], "NumberedEquation",
  CellTags->"continuity equation"],

Cell[TextData[{
  "leads to a related ",
  StyleBox["conservation law",
    FontSlant->"Italic"],
  ". If both ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  " depend on ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]u/\[PartialD]x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 u/\[PartialD]x\^2\)]],
  ", \[Ellipsis] but not on ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]u/\[PartialD]t\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  " vanishes as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(\[PlusMinus]\[Infinity]\)\)]],
  ", integrating equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "continuity equation"],
  ") over ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \((\(-\[Infinity]\), \
\[Infinity])\)\)]],
  ", leads to"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[PartialD]\_t\(\[Integral]\_\(-\[Infinity]\)\%\
\[Infinity] \[Rho] \[DifferentialD]x\) = \(0 \[Implies] \[Integral]\_\(-\
\[Infinity]\)\%\[Infinity] \[Rho] \[DifferentialD]x = \(\(constant\)\(.\)\)\)\
\)], "NumberedEquation",
  CellTags->"mass conservation"],

Cell[TextData[{
  "For example, the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ") is already in the form of the continuity equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "continuity equation"],
  ") with the density"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Rho] = u(x, t);\)\)], "Input"],

Cell[TextData[{
  "if the corresponding current ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  ", is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"J", "=", 
        RowBox[{"\[Integral]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                
                FractionBox[\(\[PartialD]\^3\( u(x, 
                      t)\)\), \(\[PartialD]x\^3\),
                  MultilineFunction->None], "-", 
                RowBox[{"6", " ", \(u(x, t)\), " ", 
                  FractionBox[\(\[PartialD]\(u(x, t)\)\), \(\[PartialD]x\),
                    MultilineFunction->None]}]}], 
              ")"}], \(\[DifferentialD]x\)}]}]}], TraditionalForm]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SuperscriptBox["u", 
            TagBox[\((2, 0)\),
              Derivative],
            MultilineFunction->None], "(", \(x, t\), ")"}], 
        "-", \(3\ \(u(x, t)\)\^2\)}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "because the continuity equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "continuity equation"],
  ") yields the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[PartialD]\_t \[Rho] + \[PartialD]\_x J \[Equal] 
      0\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["u", 
              TagBox[\((0, 1)\),
                Derivative],
              MultilineFunction->None], "(", \(x, t\), ")"}], "-", 
          RowBox[{"6", " ", \(u(x, t)\), " ", 
            RowBox[{
              SuperscriptBox["u", 
                TagBox[\((1, 0)\),
                  Derivative],
                MultilineFunction->None], "(", \(x, t\), ")"}]}], "+", 
          RowBox[{
            SuperscriptBox["u", 
              TagBox[\((3, 0)\),
                Derivative],
              MultilineFunction->None], "(", \(x, t\), ")"}]}], "==", "0"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Hence, we conclude from the conservation equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "mass conservation"],
  ") that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( u(x, 
              t)\) \[DifferentialD]x = constant\)]],
  " for solutions to the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ") satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`u(\(\[PlusMinus]\[Infinity]\), t) = 0\)]],
  ". Physically, this conservation law expresses ",
  StyleBox["conservation of mass",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"conservation of mass"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, t)\)]],
  " satisfies the conservation law, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( u(x, 
              t)\) \[DifferentialD]x = constant\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Integral]\(u(x, 
              t)\) \[PartialD]\_t\( u(x, t)\) \[DifferentialD]t\)]],
  ", find the corresponding current, ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  ", and determine the associated (momentum) conservation law. Verify that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, t)\)]],
  " satisfies this conservation law. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For the (energy) density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "=", 
          RowBox[{\(\(u(x, t)\)\^3\), "+", 
            RowBox[{\(1\/2\), " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["u", 
                    TagBox[\((1, 0)\),
                      Derivative],
                    MultilineFunction->None], "(", \(x, t\), ")"}], 
                "2"]}]}]}], TraditionalForm]]],
  ", obtain and simplify the corresponding current (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you will need to use the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ") and its time derivative to eliminate the terms in ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t \[Rho]\)]],
  " involving time derivatives). Determine the associated conservation law, \
and verify that it is satisfied by ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x, t)\)]],
  ". ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution ",
  StyleBox["[13]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "There is an interesting relationship between the soliton solutions of the \
KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  ") and the Schr\[ODoubleDot]dinger equation. Using this relationship, the \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution can be generated in an exact way. "
}], "Text"],

Cell[TextData[{
  "Initial values (",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ") of the one- and two-soliton solutions read."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(u\_1\)(x, 0)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-2\)\ \(\(sech\^2\)(x)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(u\_2\)(x, 0) // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-6\)\ \(\(sech\^2\)(x)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "It turns out that the initial value of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution is ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_n\)(x, 
          0) = \(\(-\(n\[VeryThinSpace](n + 1)\)\) \(\(sech\^2\)(x)\) = 
          2 \(\( \[ScriptCapitalV]\_n\)(x)\)\)\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalV]\_n\)(x)\)]],
  " is interpreted as the ",
  StyleBox["potential",
    FontSlant->"Italic"],
  " of the Schr\[ODoubleDot]dinger equation, that is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\(-1\)\/2\) \[PartialD]\^2\( \[Psi](x)\)\/\
\[PartialD]x\^2 - \(1\/2\) \(n\[VeryThinSpace](n + 1)\) \(\(sech\^2\)(
            x)\) \(\[Psi](x)\) = \[ScriptCapitalE]\ \(\[Psi](
          x)\)\)\(,\)\)\)], "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],

Cell["the (unnormalized) solution is", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\[Psi]\_\(n_, m_\)\)(x_)\), "=", 
          FormBox[
            RowBox[{
              SubsuperscriptBox[
                TagBox["P",
                  LegendreP], "n", "m"], "(", \(tanh(x)\), ")"}],
            "TraditionalForm"]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox[
            TagBox["P",
              LegendreP], "n", "m"], "(", "z", ")"}], TraditionalForm]]],
  " is the associated Legendre function, and the energy is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\_m = \(-m\^2\)/2\)]],
  ". For each ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", there exists ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " bound states with ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] m \[LessEqual] n\)]],
  "."
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Verify that each ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(n, m\)\)(x)\)]],
  " satisfies the Schr\[ODoubleDot]dinger equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Schr\[ODoubleDot]dinger equation"],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] m \[LessEqual] n \[LessEqual] 4\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Use dynamic programming (",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\_\(n_, m_\) := \(\[ScriptCapitalN]\
\_\(n, m\) = \[Ellipsis]\)\)]],
  "), to compute and save the normalization constants determined by requiring \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[ScriptCapitalN]\_\(n, m\)\%2\), 
            RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
              RowBox[{
                SuperscriptBox[
                  FormBox[\(\(\[Psi]\_\(n, m\)\)(x)\),
                    "TraditionalForm"], "2"], \(\[DifferentialD]x\)}]}]}], 
          "=", "1"}], TraditionalForm]]],
  ". Determine the normalization constants for ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] m \[LessEqual] n \[LessEqual] 4\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". On one plot, display the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\(V\_n\)(x)\)]],
  " together with the normalized eigenfunctions, shifted downwards by the \
associated energy, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalN]\_\(n, 
              m\)\) \(\(\[Psi]\_\(n, m\)\)(x)\) + \[ScriptCapitalE]\_m\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] m \[LessEqual] n\)]],
  ". You should obtain a familiar looking plot. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
  "The next step in determining the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution (much theory omitted here) is to form the ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  " matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\_n\)]],
  ", whose coefficients are"
}], "Text",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalA]\_\(n_, m_, k_\) := \[Delta]\_\(m, \
k\) + \(c\_\(n, m\)\%2\/\(m + 
                k\)\) \[ExponentialE]\^\(8 \( m\^3\) t - \((m + k)\) x\)\)], \
"Input"],

Cell["where", "Text"],

Cell[BoxData[
    \(TraditionalForm\`c\_\(n_, m_\) := \(c\_\(n, m\) = 
        lim\+\(x \[Rule] \[Infinity]\)Expand[\(\[ScriptCapitalN]\_\(n, 
                  m\)\) \(\(\[Psi]\_\(n, m\)\)(
                x)\)\ \[ExponentialE]\^\(m\ x\)]\)\)], "Input"],

Cell["and", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[Delta]\_\(m_, k_\) := 
      KroneckerDelta[m, k]\)], "Input"],

Cell[TextData[{
  "Finally, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution is given by"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(u\_n\)(x, t)\), "=", 
          RowBox[{\(-2\), " ", 
            FractionBox[
              RowBox[{\(\[PartialD]\^2\), 
                RowBox[{"log", "(", 
                  
                  TagBox[\(\[LeftBracketingBar]\[ScriptCapitalA]\_n\
\[RightBracketingBar]\),
                    {Det}], ")"}]}], \(\[PartialD]x\^2\),
              MultilineFunction->None]}]}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\[ScriptCapitalA]\_n\
\[RightBracketingBar]\)]],
  " is the determinant of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\_n\)]],
  ". For example, the two-soliton matrix is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalA]\_2 = 
      Table[\[ScriptCapitalA]\_\(2, m, k\), {m, 2}, {k, 2}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1 + 
                3\ \[ExponentialE]\^\(8\ t - 2\ x\)\), \(2\ \[ExponentialE]\^\
\(8\ t - 3\ x\)\)},
            {\(4\ \[ExponentialE]\^\(64\ t - 3\ x\)\), \(1 + 
                3\ \[ExponentialE]\^\(64\ t - 4\ x\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-soliton solution is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{\(-2\), " ", 
        FractionBox[
          RowBox[{\(\[PartialD]\^2\), 
            RowBox[{"log", "(", 
              FormBox[
                
                TagBox[\(\[LeftBracketingBar]\[ScriptCapitalA]\_2\
\[RightBracketingBar]\),
                  {Det}],
                "TraditionalForm"], ")"}]}], \(\[PartialD]x\^2\),
          MultilineFunction->None]}], TraditionalForm]], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(-2\)\ \((\(36\ \[ExponentialE]\^\(72\ t - 6\ x\) + \
48\ \[ExponentialE]\^\(64\ t - 4\ x\) + 12\ \[ExponentialE]\^\(8\ t - 2\ \
x\)\)\/\(1 + \[ExponentialE]\^\(72\ t - 6\ x\) + 3\ \[ExponentialE]\^\(64\ t \
- 4\ x\) + 3\ \[ExponentialE]\^\(8\ t - 2\ x\)\) - \((\(-6\)\ \[ExponentialE]\
\^\(72\ t - 6\ x\) - 12\ \[ExponentialE]\^\(64\ t - 4\ x\) - 6\ \
\[ExponentialE]\^\(8\ t - 2\ x\))\)\^2\/\((1 + \[ExponentialE]\^\(72\ t - 6\ \
x\) + 3\ \[ExponentialE]\^\(64\ t - 4\ x\) + 3\ \[ExponentialE]\^\(8\ t - 2\ \
x\))\)\^2)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We compare this result with ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_2\)(x, t)\)]],
  " given above in question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "two-soliton solution"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Simplify[% \[Equal] \(u\_2\)(x, t)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compute the three-soliton solution, ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_3\)(x, t)\)]],
  " to the KdV equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "KdV equation"],
  "). Visualize the time evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_3\)(x, t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Element] \([\(-1\), 1]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([\(-20\), 20]\)\)]],
  " using ",
  StyleBox["ContourPlot", "InlineInputTraditionalForm"],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " phase-shift of the slowest soliton by comparing it with ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(x + \[Phi], 0)\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine the velocity of the fastest soliton and use this to find its \
shape as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \[Infinity]\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Hydrogen Molecular Ion ",
  StyleBox["[15]", "Marks"]
}], "Section"],

Cell[TextData[{
  "In this problem you will examine the bound states of a system comprising a \
single electron moving in the field of two fixed nuclei of arbitrary charge \
(commonly known as the ",
  StyleBox["generalized hydrogen molecular ion problem",
    FontSlant->"Italic"],
  " or ",
  StyleBox["reduced two-centre problem",
    FontSlant->"Italic"],
  "). This configuration is the simplest conceivable molecule, and yet is the \
most complex exactly solvable system."
}], "Text"],

Cell[TextData[{
  "An important special case is the hydrogen molecular ion, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["H",
            FontSlant->"Plain"], "2", "+"], TraditionalForm]]],
  ", which is composed of two (fixed) protons and one electron. In ",
  ButtonBox["atomic units",
    ButtonData:>{
      URL[ 
      "http://www.calvin.edu/academic/chemistry/homedocs/compchem/primer/\
intro2e.htm"], None},
    ButtonStyle->"Hyperlink"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`m\_e = e\)],
    CellTags->"atomic units"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(\[HBar]\)\)\)]],
  "\[VeryThinSpace]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(a\_0\)\)\)]],
  "\[VeryThinSpace]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(=\)\(1\)\)\)]],
  "), the Schr\[ODoubleDot]dinger equation for the motion of the electron",
  StyleBox[" ",
    FontSize->7],
  "reads"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalH]\ \(\[CapitalPhi](r)\)\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->4], 
                RowBox[{
                  UnderscriptBox[\(\(-\(1\/2\)\) \[CapitalDelta]\_r\), 
                    UnderscriptBox["\[UnderBrace]", 
                      StyleBox["\[ScriptCapitalT]",
                        FontSize->12]]], "+", 
                  UnderscriptBox[\((\(-\(1\/r\_A\)\) - 1\/r\_B + 1\/R)\), 
                    UnderscriptBox["\[UnderBrace]", 
                      StyleBox["\[ScriptCapitalV]",
                        FontSize->12]]]}], 
                StyleBox[
                  FormBox[
                    StyleBox["}",
                      SpanMaxSize->4],
                    "TraditionalForm"],
                  SpanMaxSize->Infinity]}], 
              RowBox[{"\[CapitalPhi]", "(", 
                StyleBox["r",
                  FontWeight->"Bold"], ")"}]}], "=", 
            RowBox[{"\[ScriptCapitalE]", " ", 
              RowBox[{"\[CapitalPhi]", "(", 
                StyleBox["r",
                  FontWeight->"Bold"], ")"}]}]}]}], ","}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the internuclear separation, and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold"], "A"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold"], "B"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold"], TraditionalForm]]],
  " are the position vectors of the electron with respect to the protons ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ", and to the midpoint of the internuclear line, respectively."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.41421 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.707107 0.476191 [
[1.025 .70711 0 -6.03125 ]
[1.025 .70711 18.375 6.03125 ]
[.5 1.43921 -3.96875 0 ]
[.5 1.43921 3.96875 12 ]
[ 0 0 0 0 ]
[ 1 1.41421 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .70711 m
1 .70711 L
s
gsave
1.025 .70711 -61 -10.0312 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.0625 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.250 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
67.688 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
72.938 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
77.375 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 1.41421 L
s
gsave
.5 1.43921 -64.9688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.062 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.41421 L
0 1.41421 L
closepath
clip
newpath
.5 Mabswid
.02381 .70738 m
.02499 .7544 L
.02605 .77243 L
.02846 .80096 L
.03279 .83725 L
.03784 .86937 L
.04262 .8945 L
.06244 .97282 L
.08265 1.03138 L
.10458 1.08234 L
.14545 1.15666 L
.1848 1.21189 L
.22263 1.25451 L
.26292 1.29115 L
.30169 1.31937 L
.34292 1.34285 L
.36351 1.35228 L
.38262 1.35976 L
.40229 1.36621 L
.42082 1.37117 L
.44134 1.37541 L
.45995 1.37816 L
.46971 1.37918 L
.47505 1.37962 L
.48003 1.37995 L
.48428 1.38017 L
.48883 1.38036 L
.49143 1.38043 L
.49271 1.38046 L
.49389 1.38049 L
.49494 1.3805 L
.4961 1.38052 L
.49726 1.38053 L
.4985 1.38054 L
.49971 1.38054 L
.50085 1.38054 L
.50209 1.38054 L
.50278 1.38053 L
.50341 1.38052 L
.50469 1.38051 L
.50608 1.38049 L
.50859 1.38043 L
.51093 1.38036 L
.51341 1.38028 L
.51785 1.38007 L
.52298 1.37976 L
.52778 1.3794 L
.5387 1.37831 L
.54911 1.37695 L
.55899 1.37535 L
Mistroke
.57753 1.37156 L
.59737 1.36631 L
.61577 1.36034 L
.65495 1.34389 L
.69659 1.32048 L
.73671 1.29145 L
.77531 1.25658 L
.81636 1.21044 L
.8559 1.15452 L
.89393 1.08547 L
.91511 1.03707 L
.9344 .98297 L
.944 .95051 L
.95442 .90838 L
.9592 .88539 L
.96427 .85685 L
.9686 .82691 L
.97089 .80729 L
.97336 .78036 L
.97408 .77038 L
.97484 .75779 L
.97549 .74374 L
.97619 .70738 L
Mfstroke
.02381 .70683 m
.02499 .65981 L
.02605 .64179 L
.02846 .61325 L
.03279 .57697 L
.03784 .54484 L
.04262 .51971 L
.06244 .44139 L
.08265 .38284 L
.10458 .33187 L
.14545 .25755 L
.1848 .20232 L
.22263 .1597 L
.26292 .12307 L
.30169 .09485 L
.34292 .07137 L
.36351 .06193 L
.38262 .05445 L
.40229 .048 L
.42082 .04305 L
.44134 .0388 L
.45995 .03606 L
.46971 .03504 L
.47505 .0346 L
.48003 .03426 L
.48428 .03404 L
.48883 .03386 L
.49143 .03378 L
.49271 .03375 L
.49389 .03373 L
.49494 .03371 L
.4961 .03369 L
.49726 .03368 L
.4985 .03367 L
.49971 .03367 L
.50085 .03367 L
.50209 .03368 L
.50278 .03368 L
.50341 .03369 L
.50469 .0337 L
.50608 .03373 L
.50859 .03378 L
.51093 .03385 L
.51341 .03394 L
.51785 .03414 L
.52298 .03446 L
.52778 .03482 L
.5387 .0359 L
.54911 .03726 L
.55899 .03886 L
Mistroke
.57753 .04266 L
.59737 .0479 L
.61577 .05388 L
.65495 .07032 L
.69659 .09374 L
.73671 .12276 L
.77531 .15763 L
.81636 .20378 L
.8559 .25969 L
.89393 .32875 L
.91511 .37714 L
.9344 .43124 L
.944 .46371 L
.95442 .50583 L
.9592 .52883 L
.96427 .55736 L
.9686 .58731 L
.97089 .60693 L
.97336 .63385 L
.97408 .64383 L
.97484 .65642 L
.97549 .67047 L
.97619 .70683 L
Mfstroke
.03 w
.5 .23092 Mdot
.5 1.1833 Mdot
.95238 .49683 Mdot
gsave
.44286 .23092 -66.1562 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.250 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.44286 1.1833 -66.0938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.125 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.75238 .32615 -67.6875 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.062 14.562 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.77143 .85949 -67.6562 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
67.000 14.562 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.44286 .9452 -68.6562 -15.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 30.5625 translate 1 -1 scale
65.688 11.500 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.438 18.688 moveto
(\\200\\200\\200\\200) show
69.938 18.688 moveto
(\\200) show
71.250 18.688 moveto
(\\200) show
66.125 25.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.44286 .46901 -68.6562 -15.2812 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 30.5625 translate 1 -1 scale
65.688 11.500 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
64.438 18.688 moveto
(\\200\\200\\200\\200) show
69.938 18.688 moveto
(\\200) show
71.250 18.688 moveto
(\\200) show
66.125 25.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
1.00952 .47854 -68 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
67.438 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
1.000 setlinewidth
grestore
.5 Mabswid
.5 .23092 m
.95238 .49683 L
.5 1.1833 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{188.75, 255},
  ImageMargins->{{144, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {-0.0193097, 1.02703}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[0001?R000`400?l00000o`00003oj`3oool0
0>/0oooo003[0?ooo`00j`3oool006L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<00000
0?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3o
ool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3o
ool006H0oooo0`0000220?ooo`00G@3ooolF000007P0oooo001E0?ooo`P000002P3oool00`000000
oooo0?ooo`090?ooo`L00000L@3oool00580oooo0`00000B0?ooo`030000003oool0oooo0100oooo
0`00001^0?ooo`00D03oool2000001D0oooo00<000000?ooo`3oool04`3oool2000006`0oooo001=
0?ooo`<000005`3oool00`000000oooo0?ooo`0E0?ooo`800000JP3oool004X0oooo0`00000J0?oo
o`030000003oool0oooo01L0oooo0`00001W0?ooo`00A`3oool3000001d0oooo00<000000?ooo`3o
ool06P3oool3000006@0oooo00150?ooo`800000803oool00`000000oooo0?ooo`0M0?ooo`800000
HP3oool004@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`800000H03o
ool00480oooo0P00000S0?ooo`030000003oool0oooo0240oooo0P00001N0?ooo`00@03oool20000
02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1K0?ooo`00?`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo0P00001K0?ooo`00?@3oool2000002P0oooo
00<000000?ooo`3oool09P3oool2000005T0oooo000l0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`1F0?ooo`00>`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0E@3oool003T0oooo0P00000/0?oo
o`030000003oool0oooo02X0oooo0P00001E0?ooo`00>03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0DP3oool003L0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0540oooo000f0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0;P3oool200000540oooo000e0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1>0?ooo`00=03oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0C@3oool003<0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo04`0
oooo000b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1;0?ooo`00<@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0BP3oool00300oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo04T0oooo000_0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`180?ooo`00;P3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0B03oool002d0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04L0oooo000/0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`160?ooo`00:`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0A@3oool0
02X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
04@0oooo000Y0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`140?ooo`00:03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0@`3oool002L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo0480oooo000V0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`110?ooo`009P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0@03oool002D0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0400oooo000T0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0o0?ooo`00903o
ool00`000000oooo0?ooo`0`0?ooo`8000000`3oool3000000H0oooo100000110?ooo`030000003o
ool0oooo03h0oooo000S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`H00000@@3oool00`000000oooo0?ooo`0m0?ooo`008P3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool60000
0480oooo00<000000?ooo`3oool0?03oool00280oooo00<000000?ooo`3oool0=03oool5000000H0
oooo1`0000120?ooo`030000003oool0oooo03/0oooo000Q0?ooo`030000003oool0oooo03H0oooo
00@000000?ooo`3oool000001P3oool6000000030?ooo`000000oooo0400oooo00<000000?ooo`3o
ool0>`3oool00200oooo00<000000?ooo`3oool0=`3oool010000000oooo0?ooo`0000070?ooo`@0
00000`3oool200000400oooo00<000000?ooo`3oool0>P3oool00200oooo00<000000?ooo`3oool0
>03oool2000000X0oooo00<000000?ooo`3oool0103oool2000003l0oooo00<000000?ooo`3oool0
>@3oool001l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0h0?ooo`007P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool2
000003h0oooo00<000000?ooo`3oool0=`3oool001h0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`090?ooo`800000?03oool00`000000oooo0?ooo`0g0?ooo`007@3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0f0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00`0oooo
0P00000j0?ooo`030000003oool0oooo03H0oooo000L0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03P3oool2000003T0oooo00<000000?ooo`3oool0=@3oool001/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0=@3oool001/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0A0?oo
o`800000=`3oool00`000000oooo0?ooo`0d0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo01<0oooo0P00000e0?ooo`030000003oool0oooo03@0oooo000I0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool05@3oool2000003@0oooo00<000000?ooo`3oool0
<`3oool001T0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01H0oooo0P000000103oool0000000000000000E0?ooo`030000003oool0oooo03<0oooo
000H0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0603oool2000001L0oooo00@0
00000?ooo`3oool000005P3oool00`000000oooo0?ooo`0c0?ooo`00603oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo01X0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo0`00
000G0?ooo`030000003oool0oooo0380oooo000G0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000005`3oool00`000000oooo0?ooo`0b0?ooo`005P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo01d0oooo0P00000=0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0a0?ooo`005P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo01l0oooo0P00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0a0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0300oooo000E0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool08P3o
ool2000000P0oooo1000000N0?ooo`030000003oool0oooo0300oooo000D0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool0903oool2000002T0oooo00<000000?ooo`3oool0;`3oool0
01@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0;`3oool001@0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0W0?ooo`8000009`3oool00`000000oooo0?ooo`0^0?ooo`004`3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo02T0oooo0P00000U0?ooo`030000003oool0oooo02h0oooo
000C0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0:`3oool2000002@0oooo00<0
00000?ooo`3oool0;@3oool001<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool00180oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0^0?ooo`8000008P3oool00`000000oooo0?ooo`0/0?oo
o`004P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0300oooo0P00000P0?ooo`03
0000003oool0oooo02`0oooo000B0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02/0oooo000A0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0<`3oool2000001h0oooo00<000000?ooo`3oool0:`3o
ool00140oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0e0?ooo`8000007@3oool0
0`000000oooo0?ooo`0Z0?ooo`00403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Z0?ooo`00403oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo03P0oooo0P00000J0?ooo`030000003oool0oooo02X0
oooo000@0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0>P3oool2000001T0oooo
00<000000?ooo`3oool0:@3oool000l0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:@3oool000l0oooo00<00000
0?ooo`3oool0AP3oool5000000X0oooo00<000000?ooo`3oool0?@3oool2000001H0oooo00<00000
0?ooo`3oool0:@3oool000h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?`3oool2000001D0oooo00<000000?oo
o`3oool0:03oool000h0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`00
3@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
@P3oool200000180oooo00<000000?ooo`3oool0:03oool000d0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04@0oooo0P00000A0?ooo`030000003o
ool0oooo02L0oooo000=0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`160?ooo`8000003`3oool00`000000oooo0?ooo`0W0?ooo`00303oool00`00
0000oooo0?ooo`190?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool000`0oooo00<000000?oo
o`3oool0B@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0B@3oool2
000000d0oooo00<000000?ooo`3oool09P3oool000`0oooo00<000000?ooo`3oool0BP3oool30000
00/0oooo00<000000?ooo`3oool0B`3oool2000000/0oooo00<000000?ooo`3oool09P3oool000/0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool09@3oool000/0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`1>0?ooo`8000002@3oool00`000000oooo0?ooo`0U0?ooo`002`3oool00`000000oooo0?oo
o`180?ooo`X000001`3oool00`000000oooo0?ooo`1@0?ooo`8000001`3oool00`000000oooo0?oo
o`040?ooo`<000007P3oool000/0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
000M0?ooo`002P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05<0oooo0P000005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07P3oool000X0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`1E0?ooo`8000000`3oool00`000000oooo0?ooo`030?oo
o`@000007@3oool000X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0000000<00000103oool010000000oooo0?ooo`00000L0?ooo`002P3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo05P0oooo1P0000040?ooo`<00000703oool000T0oooo
00<000000?ooo`3oool0B`3oool3000000<0oooo0P0000080?ooo`030000003oool0oooo05P0oooo
1P00000S0?ooo`002@3oool00`000000oooo0?ooo`1<0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`1H0?ooo`H000002@3oool4000001H0oooo00090?ooo`030000003o
ool0oooo04d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1H0?ooo`H00000
8`3oool000T0oooo00<000000?ooo`3oool0C@3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo05P0oooo1@00000T0?ooo`00203oool00`000000oooo0?ooo`1?0?ooo`@000002@3o
ool00`000000oooo0?ooo`1H0?ooo`040000003oool0oooo000002D0oooo00080?ooo`030000003o
ool0oooo04l0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooo`00203oool00`000000oooo0?oo
o`1?0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool000P0oooo00<000000?ooo`3oool0C`3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0280oooo00070?ooo`030000003oool0oooo04l0oooo1@00
00090?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0R0?ooo`001`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`001`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?oo
o`001`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool00`000000oooo0?ooo`1M0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`001`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0Q0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`001P3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0Q0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`001P3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0P0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0P0?ooo`001P3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P
0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`00
1@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`001@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?oo
o`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O0?ooo`001@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`8000001`3oool000D0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`00103oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000@0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02P3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool00`000000oooo0?ooo`03
0?ooo`00103oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`<0000000<0oooo0000003oool01`3oool00`00
0000oooo000000040?ooo`00103oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`000000103oool00<l000002P3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo000000<0oooo00040?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo0P0000080?ooo`800000
0P3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0;0?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`010?ooo`00103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0O0?ooo`00103oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0O0?ooo`00103oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?oo
o`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0O0?ooo`001@3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0O0?ooo`001@3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0P
0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0P0?ooo`00
1@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0P0?ooo`001@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0P0?ooo`001@3oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0P0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`001P3oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0P0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`001P3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool5000002D0oooo00<0
00000?ooo`3oool0803oool000H0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000T0?ooo`030000003o
ool0oooo0200oooo00060?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0:`3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`3oool000008`3oool00`000000oooo
0?ooo`0Q0?ooo`001P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`<00000903oool00`000000oooo0?oo
o`0Q0?ooo`001`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0000002<0oooo00<00000
0?ooo`3oool08@3oool000L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool4000002<0oooo00<000000?oo
o`3oool08@3oool000L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Q0?ooo`00
1`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
1P3oool4000002T0oooo00<000000?ooo`3oool08@3oool000L0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08P3o
ool000L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool08P3oool000P0oooo00<000000?ooo`3oool0C@3oool50000
00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0280oooo00080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0R0?ooo`00203oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0280oooo
00080?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08`3oool000P0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0S0?ooo`002@3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo02<0oooo00090?ooo`030000003oool0oooo04`0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0S0?ooo`002@3oool00`000000oooo0?ooo`1<0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0903oool000T0oooo00<000000?ooo`3oool0C@3oool3000000/0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02@0oooo000:0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo02@0oooo000:0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02@0oooo000:0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo02@0oooo000:0?ooo`030000003oool0oooo04T0oooo2P0000070?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0U0?ooo`002`3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0U0?ooo`002`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0U0?ooo`002`3oool00`000000oooo0?oo
o`1I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0U0?ooo`002`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`0V0?ooo`00303oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0V0?oo
o`00303oool00`000000oooo0?ooo`180?ooo`<000000`3oool2000000P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02H0oooo000<0?ooo`030000
003oool0oooo04T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0W0?ooo`003@3oool00`000000oooo
0?ooo`190?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo02L0oooo000=0?ooo`030000003oool0oooo04T0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool09`3oool000d0oooo00<000000?ooo`3oool0BP3oool4000000T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02P0oooo
000>0?ooo`030000003oool0oooo04T0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0X0?ooo`003P3o
ool00`000000oooo0?ooo`190?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0:03oool000l0oooo00<0
00000?ooo`3oool0B03oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02T0oooo000?0?ooo`030000003o
ool0oooo04L0oooo1@0000090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0Y0?ooo`00403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Y0?ooo`00403oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0Z0?ooo`00403oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Z0?ooo`004@3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0Z0?ooo`004@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0[0?ooo`004P3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0[
0?ooo`004P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0/0?ooo`004P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0/0?ooo`00
4`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0]0?ooo`004`3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0]0?ooo`00503oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0^0?ooo`00503oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0^0?ooo`00503oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0_0?ooo`005@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`005@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0`0?ooo`005P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0`0?ooo`005P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0a0?oo
o`005`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0a0?ooo`00603oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0b0?ooo`00603o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0b0?ooo`006@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0c0?ooo`006@3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0c0?ooo`006P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0d0?ooo`006P3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0d0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0e0?ooo`006`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0e
0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0f0?ooo`007@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0f0?ooo`00
7@3oool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0?ooo`000000A@3oool00`000000
oooo0?ooo`0g0?ooo`007P3oool00`000000oooo0?ooo`160?ooo`050000003oool0oooo0?ooo`00
0000A@3oool00`000000oooo0?ooo`0g0?ooo`007P3oool00`000000oooo0?ooo`160?ooo`040000
003oool0oooo000004D0oooo00<000000?ooo`3oool0>03oool001l0oooo00<000000?ooo`3oool0
=@3oool6000000X0oooo00<000000?ooo`000000A@3oool00`000000oooo0?ooo`0i0?ooo`00803o
ool00`000000oooo0?ooo`0e0?ooo`040000003oool0oooo0?ooo`8000001`3oool5000004@0oooo
00<000000?ooo`3oool0>P3oool00240oooo00<000000?ooo`3oool0=@3oool01@000000oooo0?oo
o`3oool0000000H0oooo1P0000140?ooo`030000003oool0oooo03X0oooo000Q0?ooo`030000003o
ool0oooo03D0oooo00D000000?ooo`3oool0oooo000000060?ooo`H00000@`3oool00`000000oooo
0?ooo`0k0?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`<000001`3oool600000480oooo00<0
00000?ooo`3oool0?03oool002<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`02
000000D0oooo1P0000110?ooo`030000003oool0oooo03d0oooo000S0?ooo`030000003oool0oooo
03@0oooo00D000000?ooo`3oool0oooo000000060?ooo`@00000@P3oool00`000000oooo0?ooo`0m
0?ooo`00903oool00`000000oooo0?ooo`0c0?ooo`050000003oool0oooo0?ooo`000000203oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03h0oooo000U0?ooo`030000003oool0oooo
0340oooo1@0000090?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool002H0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0400
oooo000V0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`100?ooo`009`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool0@@3oool002P0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo0480oooo000Y0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`130?ooo`00:P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0A03oool002/0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo04D0oooo000/0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`160?ooo`00;@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0A`3oool0
02h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
04P0oooo000_0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`190?ooo`00<03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0BP3oool00340oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo04/0oooo000b0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`1<0?ooo`00<`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0C@3oool003@0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo04h0oooo000e0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1?0?ooo`00=P3o
ool2000002l0oooo00<000000?ooo`3oool0;@3oool200000580oooo000h0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1B0?ooo`00>@3oool20000
02`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1C0?ooo`00>`3oool2000002X0
oooo00<000000?ooo`3oool0:@3oool2000005H0oooo000m0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1F0?ooo`00?P3oool2000002L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1G0?ooo`00@03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02D0oooo0P00001J0?ooo`00@@3oool2000002@0oooo00<000000?oo
o`3oool08`3oool2000005`0oooo00130?ooo`8000008P3oool00`000000oooo0?ooo`0P0?ooo`<0
0000GP3oool004D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`800000
H@3oool004H0oooo0P00000O0?ooo`030000003oool0oooo01`0oooo0P00001S0?ooo`00B03oool3
000001`0oooo00<000000?ooo`3oool06P3oool2000006D0oooo001;0?ooo`8000006P3oool00`00
0000oooo0?ooo`0H0?ooo`800000I`3oool004d0oooo0P00000H0?ooo`030000003oool0oooo01H0
oooo0P00001Y0?ooo`00C`3oool3000001D0oooo00<000000?ooo`3oool04`3oool3000006/0oooo
001B0?ooo`@000004@3oool00`000000oooo0?ooo`0?0?ooo`@00000KP3oool005H0oooo1000000=
0?ooo`030000003oool0oooo00/0oooo1000001b0?ooo`00FP3oool4000000T0oooo00<000000?oo
o`3oool01P3oool5000007H0oooo001N0?oooa800000N`3oool006L0oooo00<000000?ooo`3oool0
P@3oool006L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool0
06L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool006L0oooo
00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool00>/0oooo003[0?oo
o`00j`3oool00>/0oooo003[0?ooo`00j`3oool00>/0oooo003[0?ooo`00J03oool200000840oooo
001U0?ooo`<0000000<0oooo0000003oool0P03oool006H0oooo00<000000?ooo`3oool0PP3oool0
06L0oooo00<000000?ooo`3oool0P@3oool006L0oooo00<000000?ooo`3oool0P@3oool006H0oooo
00<000000?ooo`000000PP3oool006L0oooo0`0000210?ooo`00j`3oool00>/0oooo003[0?ooo`00
j`3oool00>/0oooo003[0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 234.938}, {323.875, -8.5625}} -> {-1.05001, \
-1.67248, 0.0126936, 0.0126936}}],

Cell["Diagram for the two-centre problem.", "NumberedFigureCaption"],

Cell[TextData[{
  "The vectors ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold"], "A"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold"], "B"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold"], TraditionalForm]]],
  " are not independent since ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold"], "A"], "=", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold"], "+", 
            RowBox[{\(1\/2\), 
              StyleBox["R",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold"], "B"], "=", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold"], "-", 
            RowBox[{\(1\/2\), 
              StyleBox["R",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["LCAO Method", "Subsection"],

Cell[TextData[{
  "Although it is possible to solve the Schr\[ODoubleDot]dinger equation for \
",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["H",
            FontSlant->"Plain"], "2", "+"], TraditionalForm]]],
  StyleBox[" ",
    FontSize->7],
  "exactly, it is more convenient to solve the equation approximately. When \
",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is large, the electron will be attached to one of the protons. If the \
system is in the ground state, and the electron is attached to proton ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  ", the solution will be of the form"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", "(", 
            RowBox[{
              StyleBox["R",
                FontWeight->"Bold"], ";", 
              StyleBox["r",
                FontWeight->"Bold"]}], ")"}], 
          "=", \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\)}], ","}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
          r) = \[Pi]\^\(\(-1\)/2\)\ \[ExponentialE]\^\(-r\)\)]],
  " is the normalized ground state wave function for atomic hydrogen. Clearly \
such a wave function does not have the required symmetry about the midpoint \
of the internuclear line. The linear combination of atomic orbitals (LCAO) \
method constructs an ",
  StyleBox["approximate",
    FontSlant->"Italic"],
  " solution by forming the even (",
  Cell[BoxData[
      \(TraditionalForm\`+\)]],
  ") and odd (",
  Cell[BoxData[
      \(TraditionalForm\`-\)]],
  ") linear combinations,"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
          RowBox[{
            StyleBox["R",
              FontWeight->"Bold"], ";", 
            StyleBox["r",
              FontWeight->"Bold"]}], ")"}], 
        "=", \(\(1\/\@2\) \(\((\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                  r\_A) \[PlusMinus] \(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                  r\_B))\)\(.\)\)\)}], TraditionalForm]], "NumberedEquation"],

Cell["\<\
We will use these combinations as trial functions in a variational \
calculation of the energy,\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalE]\_\[PlusMinus]\), "(", 
          StyleBox["R",
            FontWeight->"Bold"], ")"}], "=", 
        RowBox[{
          FractionBox[
            RowBox[{"\[Integral]", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                    RowBox[{
                      StyleBox["R",
                        FontWeight->"Bold"], ";", 
                      StyleBox["r",
                        FontWeight->"Bold"]}], ")"}], "*"], 
                "\[ScriptCapitalH]", " ", 
                RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                  RowBox[{
                    StyleBox["R",
                      FontWeight->"Bold"], ";", 
                    StyleBox["r",
                      FontWeight->"Bold"]}], ")"}], \(\[DifferentialD]r\)}]}],
             
            RowBox[{"\[Integral]", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                    RowBox[{
                      StyleBox["R",
                        FontWeight->"Bold"], ";", 
                      StyleBox["r",
                        FontWeight->"Bold"]}], ")"}], "*"], " ", 
                RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                  RowBox[{
                    StyleBox["R",
                      FontWeight->"Bold"], ";", 
                    StyleBox["r",
                      FontWeight->"Bold"]}], 
                  ")"}], \(\[DifferentialD]r\)}]}]], "."}]}], 
      TraditionalForm]], "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Probability Densities ",
  StyleBox["[4]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "The electron probability density in the states ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_+\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_-\)\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(\[CapitalPhi]\_+\)\
\[RightBracketingBar]\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(\[CapitalPhi]\_-\)\
\[RightBracketingBar]\^2\)]],
  ", respectively, so that the corresponding charge densities are ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_+\) = \(-e\) \[LeftBracketingBar]\(\
\[CapitalPhi]\_+\)\[RightBracketingBar]\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_-\) = \(-e\) \[LeftBracketingBar]\(\
\[CapitalPhi]\_-\)\[RightBracketingBar]\^2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Along the internuclear line (arbitrarily chosen to be the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis) the states ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_+\)(R, z)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_-\)(R, z)\)]],
  " can be defined by"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
          r_) = \[Pi]\^\(\(-1\)/2\)\ \[ExponentialE]\^\(-r\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\[CapitalPhi]\_\[Sigma]_\)(R_, 
        z_) = \(\(\[Psi]\_\(1, s\)\)(r\_A) + \[Sigma]\ \(\(\[Psi]\_\(1, \
s\)\)(r\_B)\)\)\/\@2 /. \[InvisibleSpace]{r\_A \[Rule] \[LeftBracketingBar]z \
+ R\/2\[RightBracketingBar], 
          r\_B \[Rule] \[LeftBracketingBar]z - 
                R\/2\[RightBracketingBar]}\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ExponentialE]\^\(-\[LeftBracketingBar]z - R\/2\
\[RightBracketingBar]\)\ \[Sigma]\)\/\@\[Pi] + \[ExponentialE]\^\(-\
\[LeftBracketingBar]R\/2 + z\[RightBracketingBar]\)\/\@\[Pi]\)\/\@2\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = \(+1\)\)]],
  " corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_+\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = \(-1\)\)]],
  " corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_-\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Visualize ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{\(\[CapitalPhi]\_+\), "(", 
              StyleBox[\(R, z\),
                FontWeight->"Bold"], ")"}], "\[RightBracketingBar]"}], "2"], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{\(\[CapitalPhi]\_-\), "(", 
              StyleBox[\(R, z\),
                FontWeight->"Bold"], ")"}], "\[RightBracketingBar]"}], "2"], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`R = 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Element] \([\(-4\), 4]\)\)]],
  ". Interpret the charge density in the region between the two protons. ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{

Cell["Confocal Elliptic Coordinates", "Subsection"],

Cell[TextData[{
  "Integrals which arise in two-centre problems are called two-centre \
integrals and are most easily evaluated by using ",
  StyleBox["confocal elliptic coordinates",
    FontSlant->"Italic"],
  ", defined by"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[Xi] = 
              1\/R\ \((r\_A + 
                    r\_B)\)\)\(,\)\), \(1 \[LessEqual] \[Xi] < \
\[Infinity]\)},
          {\(\(\[Eta] = 
              1\/R\ \((r\_A - 
                    r\_B)\)\)\(,\)\), \(\(-1\) \[LessEqual] \[Eta] \
\[LessEqual] 1\)},
          {\(\(\[Phi]\)\(,\)\), \(0 \[LessEqual] \[Phi] < 2  \[Pi]\)}
          }], TraditionalForm]], "NumberedEquation",
  GridBoxOptions->{ColumnsEqual->False}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is the usual azimuthal angle about the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis. The volume element ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[DifferentialD]", 
          StyleBox["r",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", expressed in ",
  "confocal elliptic coordinates (",
  Cell[BoxData[
      \(TraditionalForm\`\[Xi], \[Eta], \[Phi]\)]],
  ") is given by"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]r = \(R\^3\/8\) \((\[Xi]\^2 - \
\[Eta]\^2)\)\ \[DifferentialD]\[Xi] \[DifferentialD]\[Eta] \(\(\
\[DifferentialD]\[Phi]\)\(.\)\)\)], "NumberedEquation",
  CellTags->"Equation: prolate coordinate ranges"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Denominator of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_\[PlusMinus]\)(R)\)]],
  "\[ThinSpace]\[LongDash]\[ThinSpace]Normalization ",
  StyleBox["[3]", "Marks"]
}], "Subsection"],

Cell["\<\
The normalization integral, for the even and odd cases, reads\
\>", \
"Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Integral]", 
          RowBox[{
            SuperscriptBox[
              RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                RowBox[{
                  StyleBox["R",
                    FontWeight->"Bold"], ";", 
                  StyleBox["r",
                    FontWeight->"Bold"]}], ")"}], "*"], " ", 
            RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
              RowBox[{
                StyleBox["R",
                  FontWeight->"Bold"], ";", 
                StyleBox["r",
                  FontWeight->"Bold"]}], ")"}], 
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold"]}]}]}], "=", 
        RowBox[{\(1\/2\), 
          RowBox[{"\[Integral]", 
            
            RowBox[{\((\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\)\^2 + \
\(\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_B)\)\^2 \[PlusMinus] 
                    2 \(\( \[Psi]\_\(1\[InvisibleComma]s\)\)(
                        r\_A)\) \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                        r\_B)\)\))\), 
              RowBox[{
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold"]}], 
                StyleBox[".",
                  FontWeight->"Plain"]}]}]}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell["Introducing the change of variables,", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(change = {r\_A \[Rule] \(R\/2\) \((\[Xi] + \
\[Eta])\), \ r\_B \[Rule] \(R\/2\) \((\[Xi] - \[Eta])\)};\)\)], "Input"],

Cell["and defining", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]a_ \[VerticalSeparator] 
          b_\[RightAngleBracket] := \(\(\ \)\(R\^3\)\)\/8\ \
\(\[Integral]\_\(-1\)\%1\(\[Integral]\_1\%\[Infinity]\(\[Integral]\_0\%\(2  \
\[Pi]\)\((a\ b /. 
                      change)\) \((\[Xi]\^2 - \[Eta]\^2)\) \[DifferentialD]\
\[Phi] \[DifferentialD]\[Xi] \[DifferentialD]\[Eta]\)\)\) // 
        Simplify\)], "Input"],

Cell[TextData[{
  "we can evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{\(\(\(\[Psi]\_\(1\[VeryThinSpace]s\)\)(r\_A)\)\^2\), 
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  " as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[LeftAngleBracket]\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
          r\_A) \[VerticalSeparator] \(\[Psi]\_\(1\[InvisibleComma]s\)\)(
          r\_A)\[RightAngleBracket]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Show that the normalization integral is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Integral]", 
            RowBox[{
              SuperscriptBox[
                RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                  RowBox[{
                    StyleBox["R",
                      FontWeight->"Bold"], ";", 
                    StyleBox["r",
                      FontWeight->"Bold"]}], ")"}], "*"], " ", 
              RowBox[{\(\[CapitalPhi]\_\[PlusMinus]\), "(", 
                RowBox[{
                  StyleBox["R",
                    FontWeight->"Bold"], ";", 
                  StyleBox["r",
                    FontWeight->"Bold"]}], ")"}], 
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold"]}]}]}], "=", 
          RowBox[{"1", "\[PlusMinus]", 
            FormBox[\(1\/3\ \[ExponentialE]\^\(-R\)\ \((R\^2 + 3\ R + 3)\)\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Numerator of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_\[PlusMinus]\)(R)\)]],
  " ",
  StyleBox["[2]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "From the Schr\[ODoubleDot]dinger equation for hydrogen (noting that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_r \[Congruent] \[CapitalDelta]\_\(r\
\_A\) \[Congruent] \[CapitalDelta]\_\(r\_B\)\)]],
  "),"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["{",
                SpanMaxSize->4], \(\(-\(1\/2\)\) \[CapitalDelta]\_r - 1\/r\), 
              
              StyleBox[
                FormBox[
                  StyleBox["}",
                    SpanMaxSize->4],
                  "TraditionalForm"],
                
                SpanMaxSize->
                  Infinity]}], \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r)\)}], 
          "=", \(\[ScriptCapitalE]\_\(1\[InvisibleComma]s\)\ \(\(\[Psi]\_\(1\
\[InvisibleComma]s\)\)(r)\)\)}], ",", 
        " ", \(\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) = \(-1\)/2\), ","}],
       TraditionalForm]], "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],

Cell[TextData[{
  "the Schr\[ODoubleDot]dinger equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Schr\[ODoubleDot]dinger equation"],
  ") for ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["H",
            FontSlant->"Plain"], "2", "+"], TraditionalForm]]],
  StyleBox[" ",
    FontSize->7],
  "yields"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptCapitalH]\ \
\(\(\[Psi]\_\(1\[VeryThinSpace]s\)\)(
          r\_A)\) = \((\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) - 1\/r\_B + 
            1\/R\ )\) \(\(\[Psi]\_\(1\[VeryThinSpace]s\)\)(
          r\_A)\)\)\(,\)\)\)], "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],

Cell["so", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[ScriptCapitalH]\_\(A\[InvisibleComma]A\)\), "=", 
          RowBox[{
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\), 
                "\[ScriptCapitalH]", 
                " ", \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\), 
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold"]}]}]}], "=", 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                  r\_A)\), \((\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) - 
                    1\/r\_B + 
                    1\/R\ )\), \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\), 
                
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold"]}]}]}]}]}], 
        StyleBox[",",
          FontWeight->"Plain"]}], TraditionalForm]], "NumberedEquation"],

Cell["and", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalH]\_\(A\[InvisibleComma]B\)\), "=", 
        RowBox[{
          RowBox[{"\[Integral]", 
            
            RowBox[{\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_A)\), 
              "\[ScriptCapitalH]", 
              " ", \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(r\_B)\), 
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold"]}]}]}], "=", 
          RowBox[{"\[Integral]", 
            
            RowBox[{\(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                r\_A)\), \((\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) - 
                  1\/r\_A + 1\/R\ )\), \(\(\[Psi]\_\(1\[InvisibleComma]s\)\)(
                r\_B)\), 
              RowBox[{
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold"]}], "."}]}]}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_\(A\[InvisibleComma]A\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH]\_\(A\[InvisibleComma]B\)\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_\[PlusMinus]\)(R)\)]],
  " ",
  StyleBox["[6]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Now compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_\[PlusMinus]\)(R)\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_+\)(
          R) - \[ScriptCapitalE]\_\(1\[InvisibleComma]s\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_-\)(
          R) - \[ScriptCapitalE]\_\(1\[InvisibleComma]s\)\)]],
  " together on one graph. Use ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) = \(-1\)/
          2\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Determine numerically the location of the minima of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalE]\_+\)(
          R) - \[ScriptCapitalE]\_\(1\[InvisibleComma]s\)\)]],
  " and call it ",
  Cell[BoxData[
      \(TraditionalForm\`R\_0\)]],
  ". Determine the corresponding (approximate) binding energy, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\_\(1\[InvisibleComma]s\) - \(\
\[ScriptCapitalE]\_+\)(R\_0)\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Series ",
  StyleBox["[15]", "Marks"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Ideal Fermi Gas ",
  StyleBox["[9]", "Marks"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["equation of state",
    FontSlant->"Italic"],
  " is a functional relationship between the thermodynamic parameters, say ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f(P, V, T) = 0\)]],
  ". The ",
  StyleBox["parametric form",
    FontSlant->"Italic"],
  " of the equation of state for a spinless ideal Fermi gas is (see Huang, K, \
",
  StyleBox["Statistical Mechanics",
    FontSlant->"Italic"],
  ", pp187-8, 1987)"
}], "Text",
  CellTags->{
  "equation of state", "thermodynamic parameters", "ideal Fermi gas"}],

Cell[BoxData[
    \(TraditionalForm\`P\/\(k\ T\) = \(1\/\[Lambda]\^3\) \(\(f\_\(5/2\)\)(
          z)\), \ \n
    1\/v = \(1\/\[Lambda]\^3\) \(\(f\_\(3/2\)\)(z)\), \)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`v = V/N\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \[HBar] \@\(\( 2  \[Pi]\)\/\(m\ k\ T\)\)\
\)]],
  " is the ",
  StyleBox["thermal wavelength",
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_n\)(
          z) = \[Sum]\+\(l = 1\)\%\[Infinity]\(\(\((\(-1\))\)\^\(l + 1\)\) \
z\^l\)\/l\^n\)]],
  "."
}], "Text",
  CellTags->"thermal wavelength"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Find a closed form expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_n\)(z)\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The ",
  StyleBox["virial expansion",
    FontSlant->"Italic"],
  " of the equation of state is defined to be ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\ v\)\/\(k\ T\) = \[Sum]\+\(l = 1\)\%\[Infinity] \
a\_l\ \((\[Lambda]\^3\/v)\)\^\(l - 1\)\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_l\)]],
  " is called the ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  "-th ",
  StyleBox["virial coefficient",
    FontSlant->"Italic"],
  ". For high temperatures and low densities ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\[Lambda]\^3/v \[LessLess] 1)\)\(,\)\)\)]],
  " apply series methods (up to sufficiently high order) to equation ",
  Cell[TextData[{
    "(",
    
    CounterBox["Section"],
    ".",
    
    CounterBox["Equation"],
    ")"
  }]],
  " so as to correctly determine the first four virial coefficients. ",
  StyleBox["[8]", "Marks"]
}], "BeginEndQuestion",
  CellTags->{"virial expansion", "virial coefficient", "series methods"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Cumulant Expansion ",
  StyleBox["[6]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "The cumulant expansion plays a central role in statistical physics. Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " be a real parameter and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n, b\_n \[Element] \[DoubleStruckCapitalR]\)]],
  ". Assume that"
}], "Text",
  CellTags->"cumulant expansion"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ExponentialE]\^\(\[Sum]\+\(n = \
1\)\%\[Infinity]\( b\_n\ \[Lambda]\^n\)\/\(n!\)\) = \[Sum]\+\(n = 0\)\%\
\[Infinity]\(\( a\_n\) \[Lambda]\^n\)\/\(n!\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0 = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Using series expansion, determine the forward and inverse relationship \
between ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] n \[LessEqual] 7\)]],
  ". For example, ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2 \[Rule] b\_1\%2 + b\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_2 \[Rule] a\_2 - a\_1\%2\)]],
  ". Verify that each relationship is self-consistent by substituting one \
into the other. ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Convergence Acceleration ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Shank's Transform ",
  StyleBox["[14]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "One can improve the convergence of the summation of a series by removing \
its transient behaviour. Suppose that the sum to ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " terms of a given series satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(s\_n = S + \[Alpha]\ q\^n\), ",", " ", 
          RowBox[{"(", 
            FormBox[\(\[LeftBracketingBar]q\[RightBracketingBar] < 1\),
              "TraditionalForm"], ")"}]}], TraditionalForm]]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\(\[LongRightArrow]\+\(n \[Rule] \
\[Infinity]\)\)S\)]],
  ".  To determine ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " one requires three equations. These can be provided by computing, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(n - 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(n + 1\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Solve for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(n - 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_\(n + 1\)\)]],
  "by eliminating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ". The new series generated by computing ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " for different values of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is called the Shank's transformed series. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"Shank's transformed series"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Apply the Shank's transform to the partial sums of the series ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(s\_n = 1 - 1\/2 + 1\/3 - 1\/4 + 1\/5\),
            "TraditionalForm"], "+", "\[CenterEllipsis]", 
          "+", \(\((\(-1\))\)\^\(n - 1\)\/n\)}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 35\)]],
  ".  (",
  StyleBox["NB",
    FontSlant->"Italic"],
  ": you will need to use high-precision arithmetic). Compute the exact value \
of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " and compare it with the last value of the Shank's transformed series. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Iterate the Shank's transform four times on ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", consider the series generated by the Shank's transform as a new series \
and apply the Shank's transform to it) for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis], 35\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Display a linear-log plot showing the convergence rate of each iteration \
by comparing it with the exact value. What happens to the convergence of the \
partial sums as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "? Determine from your plot how many terms of the original series are \
required to achieve 8 decimal place accuracy for the second, third, and \
fourth iterates. ",
  StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Richardson Extrapolation ",
  StyleBox["[6]", "Marks"]
}], "Subsection"],

Cell[TextData[{
  "One can improve the convergence of the summation of a series by removing \
its asymptotic behaviour. Suppose that the sum to ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " terms of a given series satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`s\_n = S + q\_1\/n + q\_2\/n\^2 + \[Ellipsis]\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] \[Infinity]\)]],
  ". Richardson extrapolation consists of truncating at ",
  Cell[BoxData[
      \(TraditionalForm\`q\_p/n\^p\)]],
  " and solving the ",
  Cell[BoxData[
      \(TraditionalForm\`p + 1\)]],
  " equations"
}], "Text",
  CellTags->"Richardson extrapolation"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(s\_n\), 
            "=", \(\(S + q\_1\/n + q\_2\/n\^2 + \[Ellipsis] + 
              q\_p\/n\^p\)\(,\)\)},
          {\(s\_\(n + 1\)\), 
            "=", \(\(S + q\_1\/\(n + 1\) + 
              q\_2\/\((n + 1)\)\^2 + \[Ellipsis] + 
              q\_p\/\((n + 1)\)\^p\)\(,\)\)},
          {\(s\_\(n + 2\)\), 
            "=", \(\(S + q\_1\/\(n + 2\) + 
              q\_2\/\((n + 2)\)\^2 + \[Ellipsis] + 
              q\_p\/\((n + 2)\)\^p\)\(,\)\)},
          {"\[VerticalEllipsis]", " ", "\[VerticalEllipsis]"},
          {\(s\_\(n + p\)\), 
            "=", \(S + q\_1\/\(n + p\) + 
              q\_2\/\((n + p)\)\^2 + \[Ellipsis] + \(\(q\_p\/\((n + p)\)\^p\)\
\(.\)\)\)}
          }], TraditionalForm]], "NumberedEquation"],

Cell["The solution is", "Text"],

Cell[BoxData[
    \(TraditionalForm\`S\^\([n, p]\) = \[Sum]\+\(k = 0\)\%p\(\(\(\(\(\( 
                          s\_\(n + k\)\)(
                      n + k)\)\^p\) \((\(-1\))\)\^\(k + p\)\)\/\(\(k!\)\ \
\(\((p - k)\)!\)\)\)\(\[CenterDot]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Apply Richardson extrapolation to partial sums of the series ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(S = 1 + 1\/4 + 1\/9 + 1\/25 + 1\/36\),
              "TraditionalForm"], "+", "\[CenterEllipsis]"}]}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " ranging from 0 to 6 and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " ranging from 1 to 25. Compute the exact value of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " and compare it with your results. ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Display a linear-log plot showing the convergence rate as a function of \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " ranging from 0 to 6. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Green Function Solution to an Inverse Problem ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "A powerful and general method for solving inhomogenous differential \
equations such as ",
  Cell[BoxData[
      \(TraditionalForm\`L[f(x)] = g(x)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is a differential operator with homogenous boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`f(a) = 0, \ f(b) = 0\)]],
  ", is provided by the ",
  StyleBox["Green function",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`G(x, y)\)]],
  ", which formally satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(x, y)] = \[Delta](x - y)\)]],
  ", where \[Delta] is the ",
  StyleBox["Dirac delta function",
    FontSlant->"Italic"],
  " (distribution), and the (homogenous) boundary conditions"
}], "Text",
  CellTags->{"Green function", "Dirac delta function", "distribution"}],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(G(a, y) = 0, \ G(b, y) = 0, \ G(x, a) = 0, \ 
    G(x, b) = 0. \)\)\)], "NumberedEquation",
  CellTags->"homogenous boundary conditions"],

Cell["\<\
Green functions are due to George Green (1793-1841), an English \
mathematician whose work was not appreciated during his lifetime\[ThinSpace]\
\[LongDash]\[ThinSpace]largely due to his unusual methodology.\
\>", "Text"],

Cell[TextData[{
  "The strength of the method is that ",
  Cell[BoxData[
      \(TraditionalForm\`G(x, y)\)]],
  " is ",
  StyleBox["independent",
    FontSlant->"Italic"],
  " of the inhomogenous part of the differential equation, ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  ". The solution to the differential equation is"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`f(
        x) = \[Integral]\_a\%b\ \(G(x, y)\) \(g(
            y)\) \(\(\[DifferentialD]y\)\(.\)\)\)], "NumberedEquation",
  CellTags->"solution"],

Cell["\<\
Consider the differential equation describing a forced simple \
harmonic oscillator:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(x\^\[DoublePrime]\)(t) + x(t) = 
      g(t)\)\(,\)\)\)], "NumberedEquation",
  CellTags->"forced simple harmonic oscillator"],

Cell["along with the boundary conditions", "Text"],

Cell[BoxData[
    \(TraditionalForm\`x(0) = \(x(\[Pi]\/2) = 0. \)\)], "NumberedEquation",
  CellTags->"boundary conditions"],

Cell[TextData[{
  "The (region-dependent) Green function, independent of ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", is"
}], "Text",
  CellTags->"region-dependent function"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{\(G(t, \[Tau])\), "=", 
          RowBox[{
            RowBox[{
              StyleBox["{",
                SpanMaxSize->Infinity], GridBox[{
                  {\(\(-\(cos(\[Tau])\)\)\ \(sin(t)\), \ 
                    0 \[LessEqual] 
                      t \[LessEqual] \[Tau] \[LessEqual] \[Pi]\/2\)},
                  {\(\(-\(cos(t)\)\)\ \(sin(\[Tau])\), \ 
                    0 \[LessEqual] \[Tau] \[LessEqual] 
                      t \[LessEqual] \[Pi]\/2\)}
                  }], "\[AutoRightMatch]"}], "\[CenterDot]"}]}]}], 
      TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Implement the Green function. Show that it is continuous. ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". ",
  "Verify that the Green function satisfies the homogenous boundary \
conditions (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "homogenous boundary conditions"],
  ") and the homogenous differential equation, ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(t, \[Tau])] \[Equal] 0\)]],
  ", in each region (",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t < \[Tau] \[LessEqual] \[Pi]\/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \[Tau] < t \[LessEqual] \[Pi]\/2\)]],
  "). ",
  StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Visualize the Green function to reveal its behaviour on the boundaries \
and determine its symmetry about the diagonal line ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau]\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". The Green function has a discontinuous derivative along the line ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau]\)]],
  ". Compute the difference in the derivative across this line. \
Differentiation of this step-function discontinuity leads to the Dirac delta \
function (distribution), ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L[G(t, \[Tau])] = \[Delta](t - \[Tau])\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"discontinuous derivative"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". For the forcing term ",
  Cell[BoxData[
      \(TraditionalForm\`g(t) = \[ExponentialE]\^t\ \(sin(10\ t)\)\)]],
  " compute the ",
  StyleBox["exact",
    FontSlant->"Italic"],
  " solution, ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", to the differential equation using the Green function and equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "solution"],
  "). Verify that your solution ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " is correct (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", it satisfies (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "forced simple harmonic oscillator"],
  ") and takes into account the boundary conditions). ",
  StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
  CellTags->"exact solution"],

Cell[CellGroupData[{

Cell[TextData[{
  "Consider the ",
  StyleBox["inverse problem",
    FontSlant->"Italic"],
  " of determining the inhomogenous part, ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", of the differential equation by measuring ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " at a finite number of times. Discretizing the equation, we obtain the \
following matrix equation:"
}], "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{"discretizing equations", "inverse problem"}],

Cell[BoxData[
    \(TraditionalForm\`\(\(x(
        t) = \(\[Integral]\_0\%\(\[Pi]/2\)\ \(G(
              t, \[Tau])\) \(g(\[Tau])\) \[DifferentialD]\[Tau]\
\[LongRightArrow]\(x(t\_i)\) = \(\[Sum]\+\(j = 0\)\%m\ \(G(
                t\_i, \[Tau]\_j)\) \(g(\[Tau]\_j)\) \[Delta]\[Tau]\_j\
\[LongRightArrow]x\_i = \[Sum]\+j\( G\_\(i\[InvisibleComma]j\)\) 
              g\_j\)\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\) = \(G(
            t\_i, \[Tau]\_j)\) \[Delta]\[Tau]\_j\)]],
  ". The discretized forcing term ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j \[Congruent] g(\[Tau]\_j)\)]],
  " can be computed from the inverse of the (discretized) Green function,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`x\_i = \(\[Sum]\+j\( G\_\(i\[InvisibleComma]j\)\) 
              g\_j \[Implies] 
          g\_j = \[Sum]\+i\( G\_\(i\[InvisibleComma]j\)\^\(-1\)\) \
\(\(x\_i\)\(\[CenterDot]\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "For a list of",
  StyleBox[" equally-spaced",
    FontSlant->"Italic"],
  " data points, this discretization corresponds to the ",
  StyleBox["trapezoid approximation",
    FontSlant->"Italic"],
  " because the Green function vanishes along the boundaries. "
}], "Warning",
  CellTags->{"equally spaced data points", "trapezoid approximation"}],

Cell[TextData[{
  "Note that, in general, the matrix ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\)\)]],
  " is ",
  StyleBox["rectangular",
    FontSlant->"Italic"],
  " because there can be a ",
  StyleBox["different",
    FontSlant->"Italic"],
  " number of ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_j\)]],
  " samples. Hence no inverse matrix exists in the usual sense. However, \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j = g(\[Tau]\_j)\)]],
  " can be computed using the pseudo or Moore-Penrose inverse (",
  Cell[BoxData[
      FormBox[
        StyleBox["PseudoInverse",
          "Input"], TraditionalForm]]],
  ")."
}], "Text",
  CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Suppose that, at the times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i = 
        0, \[Pi]\/30, \(2  \[Pi]\)\/30, \[Ellipsis], \[Pi]\/2\)]],
  ", we make measurements of the displacements ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i = x(t\_i)\)]],
  ". Using the exact solution found in question ",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise", "exact solution"],
  ", the displacements at these times can be computed. Compute the driving \
term, ",
  Cell[BoxData[
      \(TraditionalForm\`g\_j = g(\[Tau]\_j)\)]],
  ", at the times ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_j = 
        0, \[Pi]\/40, \(2  \[Pi]\)\/40, \[Ellipsis], \[Pi]\/2\)]],
  ", by (matrix) multiplying the pseudo-inverse of the discretized product ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(i\[InvisibleComma]j\)\)]],
  " with the ",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  ". ",
  StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Exercise"],
  ". Compare the forcing term, ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", and the discretized (inverse) solution, ",
  Cell[BoxData[
      \(TraditionalForm\`g(\[Tau]\_j)\)]],
  ", and comment. ",
  StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell["", "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, None}, {
    None, Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"], 
    "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title \
resets all cell CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading \
in a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"Equation", 0}, {"Exercise", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. \
Sets counter values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "Equation", 0}, {"Exercise", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to \
zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published \
frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after \
a section cell. Used if the question is a single text paragraph.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want \
to number sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered \
list sequence with two digits. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). \
Author name(s) may be preced by \"Edited by \" for certain columns. Text in \
author cell to be used as the left page header. Usually followed by an \
Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with \
the Help Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Marks"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    FontFamily->"Times",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Marks", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Marks", "Printout"]]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed \
tabular material. Can be followed by NumberedTableCaption cell.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other \
cells.  If the FormatType of a cell style matches the name of one of the \
styles defined below, then that style is applied along with the local cell \
style definitions. This is particularly true of Input and Output.\
\>", 
    "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, \
FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, \
FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`On3ohP==`Tf0fL5N`?P0080004/0B`000000`d26P01
0000I00000400@410?l00BL?00400@JLnR0000000000060801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "van der Waals EOS"->{
    Cell[8666, 323, 303, 12, 53, "BeginEndQuestion",
      CellTags->"van der Waals EOS"]},
  "critical point"->{
    Cell[11613, 457, 394, 10, 51, "NumberedEquation",
      CellTags->"critical point"]},
  "Redlich-Kwong EOS"->{
    Cell[13927, 556, 81, 1, 31, "Text",
      CellTags->"Redlich-Kwong EOS"]},
  "RK EOS"->{
    Cell[14011, 559, 175, 3, 49, "NumberedEquation",
      CellTags->"RK EOS"]},
  "p-v curves"->{
    Cell[16403, 667, 487, 21, 59, "BeginEndQuestion",
      CellTags->"p-v curves"]},
  "equal area"->{
    Cell[17544, 713, 230, 5, 51, "NumberedEquation",
      CellTags->"equal area"]},
  "two-phase line"->{
    Cell[17777, 720, 1450, 47, 115, "Text",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "Maxwell construction"->{
    Cell[17777, 720, 1450, 47, 115, "Text",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "two-phase"->{
    Cell[19230, 769, 371, 8, 56, "NumberedEquation",
      CellTags->"two-phase"]},
  "KdV equation"->{
    Cell[21848, 883, 538, 13, 51, "NumberedEquation",
      CellTags->"KdV equation"]},
  "time evolution"->{
    Cell[22619, 912, 1013, 37, 95, "BeginEndQuestion",
      CellTags->"time evolution"]},
  "two-soliton solution"->{
    Cell[24356, 982, 1005, 31, 103, "BeginEndQuestion",
      CellTags->"two-soliton solution"]},
  "continuity equation"->{
    Cell[75410, 2340, 160, 3, 28, "NumberedEquation",
      CellTags->"continuity equation"]},
  "mass conservation"->{
    Cell[76609, 2389, 296, 5, 47, "NumberedEquation",
      CellTags->"mass conservation"]},
  "conservation of mass"->{
    Cell[79447, 2496, 707, 25, 52, "Text",
      CellTags->"conservation of mass"]},
  "Schr\[ODoubleDot]dinger equation"->{
    Cell[83997, 2670, 315, 5, 51, "NumberedEquation",
      CellTags->"Schr\[ODoubleDot]dinger equation"],
    Cell[94556, 3050, 1325, 32, 75, "NumberedEquation",
      CellTags->"Schr\[ODoubleDot]dinger equation"],
    Cell[155440, 4567, 791, 21, 47, "NumberedEquation",
      CellTags->"Schr\[ODoubleDot]dinger equation"],
    Cell[156611, 4608, 337, 6, 50, "NumberedEquation",
      CellTags->"Schr\[ODoubleDot]dinger equation"]},
  "Equation: prolate coordinate ranges"->{
    Cell[150537, 4414, 256, 4, 51, "NumberedEquation",
      CellTags->"Equation: prolate coordinate ranges"]},
  "equation of state"->{
    Cell[161283, 4777, 737, 26, 73, "Text",
      CellTags->{
      "equation of state", "thermodynamic parameters", "ideal Fermi gas"}]},
  "thermodynamic parameters"->{
    Cell[161283, 4777, 737, 26, 73, "Text",
      CellTags->{
      "equation of state", "thermodynamic parameters", "ideal Fermi gas"}]},
  "ideal Fermi gas"->{
    Cell[161283, 4777, 737, 26, 73, "Text",
      CellTags->{
      "equation of state", "thermodynamic parameters", "ideal Fermi gas"}]},
  "thermal wavelength"->{
    Cell[162214, 4810, 473, 18, 55, "Text",
      CellTags->"thermal wavelength"]},
  "virial expansion"->{
    Cell[162931, 4843, 1063, 38, 109, "BeginEndQuestion",
      CellTags->{
      "virial expansion", "virial coefficient", "series methods"}]},
  "virial coefficient"->{
    Cell[162931, 4843, 1063, 38, 109, "BeginEndQuestion",
      CellTags->{
      "virial expansion", "virial coefficient", "series methods"}]},
  "series methods"->{
    Cell[162931, 4843, 1063, 38, 109, "BeginEndQuestion",
      CellTags->{
      "virial expansion", "virial coefficient", "series methods"}]},
  "cumulant expansion"->{
    Cell[164187, 4896, 336, 9, 31, "Text",
      CellTags->"cumulant expansion"]},
  "Shank's transformed series"->{
    Cell[167029, 5009, 803, 33, 76, "BeginEndQuestion",
      CellTags->"Shank's transformed series"]},
  "Richardson extrapolation"->{
    Cell[169918, 5124, 662, 19, 77, "Text",
      CellTags->"Richardson extrapolation"]},
  "Green function"->{
    Cell[172917, 5228, 859, 25, 73, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "Dirac delta function"->{
    Cell[172917, 5228, 859, 25, 73, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "distribution"->{
    Cell[172917, 5228, 859, 25, 73, "Text",
      CellTags->{"Green function", "Dirac delta function", "distribution"}]},
  "homogenous boundary conditions"->{
    Cell[173779, 5255, 184, 3, 28, "NumberedEquation",
      CellTags->"homogenous boundary conditions"]},
  "solution"->{
    Cell[174550, 5279, 184, 4, 50, "NumberedEquation",
      CellTags->"solution"]},
  "forced simple harmonic oscillator"->{
    Cell[174848, 5290, 168, 3, 30, "NumberedEquation",
      CellTags->"forced simple harmonic oscillator"]},
  "boundary conditions"->{
    Cell[175072, 5297, 124, 2, 44, "NumberedEquation",
      CellTags->"boundary conditions"]},
  "region-dependent function"->{
    Cell[175199, 5301, 188, 6, 31, "Text",
      CellTags->"region-dependent function"]},
  "discontinuous derivative"->{
    Cell[177312, 5380, 619, 20, 76, "BeginEndQuestion",
      CellTags->"discontinuous derivative"]},
  "exact solution"->{
    Cell[177934, 5402, 892, 36, 94, "BeginEndQuestion",
      CellTags->"exact solution"]},
  "discretizing equations"->{
    Cell[178851, 5442, 508, 14, 52, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{"discretizing equations", "inverse problem"}]},
  "inverse problem"->{
    Cell[178851, 5442, 508, 14, 52, "Text",
      CellGroupingRules->{"SectionGrouping", 55},
      CellTags->{"discretizing equations", "inverse problem"}]},
  "equally spaced data points"->{
    Cell[180379, 5484, 363, 9, 52, "Warning",
      CellTags->{"equally spaced data points", "trapezoid approximation"}]},
  "trapezoid approximation"->{
    Cell[180379, 5484, 363, 9, 52, "Warning",
      CellTags->{"equally spaced data points", "trapezoid approximation"}]},
  "Moore-Penrose inverse"->{
    Cell[180745, 5495, 805, 27, 73, "Text",
      CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]},
  "PseudoInverse"->{
    Cell[180745, 5495, 805, 27, 73, "Text",
      CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"van der Waals EOS", 252527, 8031},
  {"critical point", 252641, 8034},
  {"Redlich-Kwong EOS", 252756, 8037},
  {"RK EOS", 252849, 8040},
  {"p-v curves", 252948, 8043},
  {"equal area", 253052, 8046},
  {"two-phase line", 253159, 8049},
  {"Maxwell construction", 253293, 8052},
  {"two-phase", 253416, 8055},
  {"KdV equation", 253520, 8058},
  {"time evolution", 253630, 8061},
  {"two-soliton solution", 253749, 8064},
  {"continuity equation", 253874, 8067},
  {"mass conservation", 253994, 8070},
  {"conservation of mass", 254115, 8073},
  {"Schr\[ODoubleDot]dinger equation", 254240, 8076},
  {"Equation: prolate coordinate ranges", 254717, 8085},
  {"equation of state", 254854, 8088},
  {"thermodynamic parameters", 255025, 8092},
  {"ideal Fermi gas", 255187, 8096},
  {"thermal wavelength", 255352, 8100},
  {"virial expansion", 255460, 8103},
  {"virial coefficient", 255631, 8107},
  {"series methods", 255798, 8111},
  {"cumulant expansion", 255969, 8115},
  {"Shank's transformed series", 256086, 8118},
  {"Richardson extrapolation", 256222, 8121},
  {"Green function", 256334, 8124},
  {"Dirac delta function", 256484, 8127},
  {"distribution", 256626, 8130},
  {"homogenous boundary conditions", 256786, 8133},
  {"solution", 256909, 8136},
  {"forced simple harmonic oscillator", 257035, 8139},
  {"boundary conditions", 257172, 8142},
  {"region-dependent function", 257301, 8145},
  {"discontinuous derivative", 257423, 8148},
  {"exact solution", 257547, 8151},
  {"discretizing equations", 257669, 8154},
  {"inverse problem", 257851, 8158},
  {"equally spaced data points", 258044, 8162},
  {"trapezoid approximation", 258198, 8165},
  {"Moore-Penrose inverse", 258350, 8168},
  {"PseudoInverse", 258477, 8171}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 29, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 26, 0, 91, "Title"],
Cell[1816, 55, 364, 10, 78, "Address"],

Cell[CellGroupData[{
Cell[2205, 69, 34, 0, 68, "Subsection"],
Cell[2242, 71, 316, 9, 52, "Text"],
Cell[2561, 82, 690, 20, 94, "Text"],
Cell[3254, 104, 134, 5, 31, "Text"],
Cell[3391, 111, 465, 7, 86, "Quote"],
Cell[3859, 120, 406, 7, 67, "Quote"],
Cell[4268, 129, 481, 9, 94, "Warning"]
}, Closed]],

Cell[CellGroupData[{
Cell[4786, 143, 46, 0, 39, "Subsection"],
Cell[4835, 145, 396, 13, 31, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5268, 163, 157, 7, 45, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5450, 174, 206, 11, 68, "Subsection",
  Evaluatable->False],
Cell[5659, 187, 583, 19, 52, "Text"],
Cell[6245, 208, 142, 2, 47, "NumberedEquation"],
Cell[6390, 212, 943, 37, 52, "Text"],
Cell[7336, 251, 176, 8, 59, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[7549, 264, 204, 11, 39, "Subsection",
  Evaluatable->False],
Cell[7756, 277, 145, 5, 31, "Text"],
Cell[7904, 284, 294, 11, 59, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[8235, 300, 196, 10, 39, "Subsection",
  Evaluatable->False],
Cell[8434, 312, 229, 9, 59, "BeginEndQuestion"],
Cell[8666, 323, 303, 12, 53, "BeginEndQuestion",
  CellTags->"van der Waals EOS"]
}, Closed]],

Cell[CellGroupData[{
Cell[9006, 340, 198, 10, 39, "Subsection",
  Evaluatable->False],
Cell[9207, 352, 427, 15, 35, "Text",
  Evaluatable->False],
Cell[9637, 369, 1177, 46, 89, "BeginEndQuestion",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[10851, 420, 197, 10, 39, "Subsection",
  Evaluatable->False],
Cell[11051, 432, 559, 23, 52, "Text"],
Cell[11613, 457, 394, 10, 51, "NumberedEquation",
  CellTags->"critical point"],
Cell[12010, 469, 775, 28, 81, "Text"],
Cell[12788, 499, 236, 9, 31, "Text"],
Cell[13027, 510, 208, 5, 34, "NumberedEquation"],
Cell[13238, 517, 497, 24, 59, "BeginEndQuestion",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[13772, 546, 152, 8, 39, "Subsection"],
Cell[13927, 556, 81, 1, 31, "Text",
  CellTags->"Redlich-Kwong EOS"],
Cell[14011, 559, 175, 3, 49, "NumberedEquation",
  CellTags->"RK EOS"],
Cell[14189, 564, 541, 26, 71, "BeginEndQuestion"],
Cell[14733, 592, 881, 41, 76, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[15651, 638, 168, 8, 39, "Subsection"],
Cell[15822, 648, 578, 17, 73, "Text"],
Cell[16403, 667, 487, 21, 59, "BeginEndQuestion",
  CellTags->"p-v curves"],

Cell[CellGroupData[{
Cell[16915, 692, 626, 19, 52, "Text",
  CellGroupingRules->{"SectionGrouping", 55}],
Cell[17544, 713, 230, 5, 51, "NumberedEquation",
  CellTags->"equal area"],
Cell[17777, 720, 1450, 47, 115, "Text",
  CellTags->{"two-phase line", "Maxwell construction"}],
Cell[19230, 769, 371, 8, 56, "NumberedEquation",
  CellTags->"two-phase"],
Cell[19604, 779, 170, 8, 31, "Text"]
}, Open  ]],
Cell[19789, 790, 691, 29, 76, "BeginEndQuestion"],
Cell[20483, 821, 553, 20, 76, "BeginEndQuestion"],
Cell[21039, 843, 466, 20, 61, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21554, 869, 136, 6, 45, "Section"],
Cell[21693, 877, 152, 4, 31, "Text"],
Cell[21848, 883, 538, 13, 51, "NumberedEquation",
  CellTags->"KdV equation"],
Cell[22389, 898, 115, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[22529, 907, 87, 3, 68, "Subsection"],
Cell[22619, 912, 1013, 37, 95, "BeginEndQuestion",
  CellTags->"time evolution"],
Cell[23635, 951, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}],
Cell[23702, 954, 460, 15, 76, "BeginEndQuestion"],
Cell[24165, 971, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{
Cell[24266, 977, 87, 3, 39, "Subsection"],
Cell[24356, 982, 1005, 31, 103, "BeginEndQuestion",
  CellTags->"two-soliton solution"],

Cell[CellGroupData[{
Cell[25386, 1017, 218, 5, 52, "Text",
  CellGroupingRules->{"SectionGrouping", 55}],

Cell[CellGroupData[{
Cell[25629, 1026, 137, 2, 28, "Input"],
Cell[25769, 1030, 47161, 1210, 235, 13897, 795, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[72945, 2243, 145, 3, 31, "Text"],
Cell[73093, 2248, 68, 1, 28, "Input"],
Cell[73164, 2251, 292, 8, 31, "Text"],

Cell[CellGroupData[{
Cell[73481, 2263, 154, 2, 36, "Input"],
Cell[73638, 2267, 138, 2, 54, "Output"]
}, Open  ]]
}, Open  ]],
Cell[73803, 2273, 777, 27, 78, "BeginEndQuestion"],
Cell[74583, 2302, 413, 15, 59, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[75033, 2322, 85, 3, 39, "Subsection"],
Cell[75121, 2327, 286, 11, 31, "Text"],
Cell[75410, 2340, 160, 3, 28, "NumberedEquation",
  CellTags->"continuity equation"],
Cell[75573, 2345, 1033, 42, 52, "Text"],
Cell[76609, 2389, 296, 5, 47, "NumberedEquation",
  CellTags->"mass conservation"],
Cell[76908, 2396, 313, 14, 31, "Text"],
Cell[77224, 2412, 71, 1, 28, "Input"],
Cell[77298, 2415, 119, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[77442, 2424, 580, 14, 60, "Input"],
Cell[78025, 2440, 275, 8, 32, "Output"]
}, Open  ]],
Cell[78315, 2451, 273, 14, 31, "Text"],

Cell[CellGroupData[{
Cell[78613, 2469, 108, 2, 28, "Input"],
Cell[78724, 2473, 708, 20, 32, "Output"]
}, Open  ]],
Cell[79447, 2496, 707, 25, 52, "Text",
  CellTags->"conservation of mass"],
Cell[80157, 2523, 436, 16, 61, "BeginEndQuestion"],
Cell[80596, 2541, 592, 19, 78, "BeginEndQuestion"],
Cell[81191, 2562, 1162, 38, 101, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[82390, 2605, 133, 5, 39, "Subsection"],
Cell[82526, 2612, 389, 13, 52, "Text"],
Cell[82918, 2627, 151, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[83094, 2636, 64, 1, 28, "Input"],
Cell[83161, 2639, 77, 1, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83275, 2645, 76, 1, 28, "Input"],
Cell[83354, 2648, 77, 1, 32, "Output"]
}, Open  ]],
Cell[83446, 2652, 548, 16, 52, "Text"],
Cell[83997, 2670, 315, 5, 51, "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],
Cell[84315, 2677, 46, 0, 31, "Text"],
Cell[84364, 2679, 331, 9, 31, "Input"],
Cell[84698, 2690, 600, 21, 52, "Text"],
Cell[85301, 2713, 493, 20, 59, "BeginEndQuestion"],
Cell[85797, 2735, 924, 27, 79, "BeginEndQuestion"],
Cell[86724, 2764, 677, 22, 76, "BeginEndQuestion"],

Cell[CellGroupData[{
Cell[87426, 2790, 394, 12, 52, "Text",
  CellGroupingRules->{"SectionGrouping", 55}],
Cell[87823, 2804, 209, 4, 61, "Input"],
Cell[88035, 2810, 21, 0, 31, "Text"],
Cell[88059, 2812, 254, 4, 38, "Input"],
Cell[88316, 2818, 19, 0, 31, "Text"],
Cell[88338, 2820, 101, 2, 29, "Input"],
Cell[88442, 2824, 128, 5, 31, "Text"],
Cell[88573, 2831, 488, 13, 51, "NumberedEquation"],
Cell[89064, 2846, 290, 9, 31, "Text"],

Cell[CellGroupData[{
Cell[89379, 2859, 133, 2, 29, "Input"],
Cell[89515, 2863, 372, 8, 54, "Output"]
}, Open  ]],
Cell[89902, 2874, 114, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[90041, 2883, 437, 12, 58, "Input"],
Cell[90481, 2897, 575, 8, 57, "Output"]
}, Open  ]],
Cell[91071, 2908, 247, 11, 31, "Text"],

Cell[CellGroupData[{
Cell[91343, 2923, 85, 1, 28, "Input"],
Cell[91431, 2926, 55, 1, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[91513, 2931, 730, 29, 78, "BeginEndQuestion"],
Cell[92246, 2962, 372, 15, 59, "BeginEndQuestion"],
Cell[92621, 2979, 329, 13, 59, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[92999, 2998, 117, 5, 45, "Section"],
Cell[93119, 3005, 490, 11, 73, "Text"],
Cell[93612, 3018, 941, 30, 52, "Text"],
Cell[94556, 3050, 1325, 32, 75, "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],
Cell[95884, 3084, 775, 28, 52, "Text"],
Cell[96662, 3114, 43747, 962, 331, 11133, 555, "GraphicsData", "PostScript", \
"Graphics"],
Cell[140412, 4078, 68, 0, 35, "NumberedFigureCaption"],
Cell[140483, 4080, 1197, 45, 35, "Text"],

Cell[CellGroupData[{
Cell[141705, 4129, 33, 0, 68, "Subsection"],
Cell[141741, 4131, 654, 19, 73, "Text"],
Cell[142398, 4152, 383, 11, 28, "NumberedEquation"],
Cell[142784, 4165, 670, 18, 73, "Text"],
Cell[143457, 4185, 473, 11, 50, "NumberedEquation"],
Cell[143933, 4198, 119, 3, 31, "Text"],
Cell[144055, 4203, 1657, 41, 56, "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[145749, 4249, 88, 3, 39, "Subsection"],
Cell[145840, 4254, 840, 24, 52, "Text"],
Cell[146683, 4280, 343, 11, 31, "Text"],
Cell[147029, 4293, 152, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[147206, 4299, 357, 6, 61, "Input"],
Cell[147566, 4307, 243, 4, 76, "Output"]
}, Open  ]],
Cell[147824, 4314, 363, 14, 31, "Text"],
Cell[148190, 4330, 954, 32, 78, "BeginEndQuestion"],
Cell[149147, 4364, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{
Cell[149248, 4370, 51, 0, 39, "Subsection"],
Cell[149302, 4372, 238, 6, 52, "Text"],
Cell[149543, 4380, 479, 12, 88, "NumberedEquation"],
Cell[150025, 4394, 509, 18, 52, "Text"],
Cell[150537, 4414, 256, 4, 51, "NumberedEquation",
  CellTags->"Equation: prolate coordinate ranges"]
}, Closed]],

Cell[CellGroupData[{
Cell[150830, 4423, 221, 6, 39, "Subsection"],
Cell[151054, 4431, 87, 3, 31, "Text"],
Cell[151144, 4436, 1390, 35, 47, "NumberedEquation"],
Cell[152537, 4473, 52, 0, 31, "Text"],
Cell[152592, 4475, 156, 2, 54, "Input"],
Cell[152751, 4479, 28, 0, 31, "Text"],
Cell[152782, 4481, 407, 7, 58, "Input"],
Cell[153192, 4490, 333, 10, 31, "Text"],

Cell[CellGroupData[{
Cell[153550, 4504, 215, 3, 28, "Input"],
Cell[153768, 4509, 52, 1, 28, "Output"]
}, Open  ]],
Cell[153835, 4513, 1138, 33, 67, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[155010, 4551, 171, 6, 39, "Subsection"],
Cell[155184, 4559, 253, 6, 31, "Text"],
Cell[155440, 4567, 791, 21, 47, "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],
Cell[156234, 4590, 374, 16, 31, "Text"],
Cell[156611, 4608, 337, 6, 50, "NumberedEquation",
  CellTags->"Schr\[ODoubleDot]dinger equation"],
Cell[156951, 4616, 18, 0, 31, "Text"],
Cell[156972, 4618, 1027, 24, 50, "NumberedEquation"],
Cell[158002, 4644, 19, 0, 31, "Text"],
Cell[158024, 4646, 941, 22, 50, "NumberedEquation"],
Cell[158968, 4670, 343, 14, 59, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[159348, 4689, 152, 5, 39, "Subsection"],
Cell[159503, 4696, 243, 11, 59, "BeginEndQuestion"],
Cell[159749, 4709, 567, 20, 59, "BeginEndQuestion"],
Cell[160319, 4731, 588, 19, 76, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[160956, 4756, 101, 5, 45, "Section"],

Cell[CellGroupData[{
Cell[161082, 4765, 198, 10, 68, "Subsection",
  Evaluatable->False],
Cell[161283, 4777, 737, 26, 73, "Text",
  CellTags->{
  "equation of state", "thermodynamic parameters", "ideal Fermi gas"}],
Cell[162023, 4805, 188, 3, 88, "NumberedEquation"],
Cell[162214, 4810, 473, 18, 55, "Text",
  CellTags->"thermal wavelength"],
Cell[162690, 4830, 238, 11, 59, "BeginEndQuestion"],
Cell[162931, 4843, 1063, 38, 109, "BeginEndQuestion",
  CellTags->{"virial expansion", "virial coefficient", "series methods"}]
}, Closed]],

Cell[CellGroupData[{
Cell[164031, 4886, 153, 8, 39, "Subsection"],
Cell[164187, 4896, 336, 9, 31, "Text",
  CellTags->"cumulant expansion"],
Cell[164526, 4907, 227, 3, 61, "NumberedEquation"],
Cell[164756, 4912, 101, 5, 31, "Text"],
Cell[164860, 4919, 696, 25, 80, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[165605, 4950, 119, 5, 45, "Section"],

Cell[CellGroupData[{
Cell[165749, 4959, 153, 8, 68, "Subsection"],
Cell[165905, 4969, 1121, 38, 78, "Text"],
Cell[167029, 5009, 803, 33, 76, "BeginEndQuestion",
  CellTags->"Shank's transformed series"],
Cell[167835, 5044, 783, 25, 106, "BeginEndQuestion"],
Cell[168621, 5071, 490, 18, 76, "BeginEndQuestion"],
Cell[169114, 5091, 538, 15, 93, "BeginEndQuestion"],
Cell[169655, 5108, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]],

Cell[CellGroupData[{
Cell[169756, 5114, 159, 8, 39, "Subsection"],
Cell[169918, 5124, 662, 19, 77, "Text",
  CellTags->"Richardson extrapolation"],
Cell[170583, 5145, 778, 18, 166, "NumberedEquation"],
Cell[171364, 5165, 31, 0, 31, "Text"],
Cell[171398, 5167, 266, 4, 61, "NumberedEquation"],
Cell[171667, 5173, 708, 25, 84, "BeginEndQuestion"],
Cell[172378, 5200, 347, 15, 59, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[172774, 5221, 140, 5, 45, "Section"],
Cell[172917, 5228, 859, 25, 73, "Text",
  CellTags->{"Green function", "Dirac delta function", "distribution"}],
Cell[173779, 5255, 184, 3, 28, "NumberedEquation",
  CellTags->"homogenous boundary conditions"],
Cell[173966, 5260, 230, 4, 52, "Text"],
Cell[174199, 5266, 348, 11, 52, "Text"],
Cell[174550, 5279, 184, 4, 50, "NumberedEquation",
  CellTags->"solution"],
Cell[174737, 5285, 108, 3, 31, "Text"],
Cell[174848, 5290, 168, 3, 30, "NumberedEquation",
  CellTags->"forced simple harmonic oscillator"],
Cell[175019, 5295, 50, 0, 31, "Text"],
Cell[175072, 5297, 124, 2, 44, "NumberedEquation",
  CellTags->"boundary conditions"],
Cell[175199, 5301, 188, 6, 31, "Text",
  CellTags->"region-dependent function"],
Cell[175390, 5309, 644, 15, 64, "NumberedEquation"],
Cell[176037, 5326, 196, 8, 59, "BeginEndQuestion"],
Cell[176236, 5336, 676, 25, 82, "BeginEndQuestion"],
Cell[176915, 5363, 327, 12, 76, "BeginEndQuestion"],
Cell[177245, 5377, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}],
Cell[177312, 5380, 619, 20, 76, "BeginEndQuestion",
  CellTags->"discontinuous derivative"],
Cell[177934, 5402, 892, 36, 94, "BeginEndQuestion",
  CellTags->"exact solution"],

Cell[CellGroupData[{
Cell[178851, 5442, 508, 14, 52, "Text",
  CellGroupingRules->{"SectionGrouping", 55},
  CellTags->{"discretizing equations", "inverse problem"}],
Cell[179362, 5458, 410, 7, 62, "NumberedEquation"],
Cell[179775, 5467, 357, 9, 52, "Text"],
Cell[180135, 5478, 241, 4, 52, "NumberedEquation"],
Cell[180379, 5484, 363, 9, 52, "Warning",
  CellTags->{"equally spaced data points", "trapezoid approximation"}],
Cell[180745, 5495, 805, 27, 73, "Text",
  CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]],
Cell[181565, 5525, 1045, 35, 117, "BeginEndQuestion"],
Cell[182613, 5562, 343, 14, 59, "BeginEndQuestion"],
Cell[182959, 5578, 64, 1, 41, "Answer",
  CellGroupingRules->{"SectionGrouping", 55}]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

