(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     81401,       2820]*)
(*NotebookOutlinePosition[    125746,       4316]*)
(*  CellTagsIndexPosition[    123978,       4267]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1999 Computational Physics Exam", "Title"],

Cell[CellGroupData[{

Cell["Instructions", "Subsection"],

Cell[TextData[{
  "This exam, worth 40% of the total mark for Computational Physics, is due \
in by 4 pm on Thursday May 13.  Each student is to do the exam ",
  StyleBox["by themselves",
    FontSlant->"Italic"],
  " and submit their solutions ",
  StyleBox["individually",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  "The exam consists of 6 questions of approximately equal difficulty and \
several hints as to how to proceed. You should attempt to answer  ",
  StyleBox["whole",
    FontSlant->"Italic"],
  " questions whose total value is 100 marks.  The marks for each question is \
clearly indicated in red brackets (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  StyleBox["[", "Marks"],
  StyleBox["n", "Marks",
    FontSlant->"Italic"],
  StyleBox["]", "Marks"],
  ") and, obviously, the marks provide a good guide to the question's \
difficulty.  Bonus marks will be given for elegant or unconventional \
solutions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Convergence Acceleration ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell["\<\
It is very common in mathematical physics and engineering to expand \
functions or solve differential equations by expansion into a Fourier basis \
or into a system of orthogonal polynomials.  However, because these basis \
functions are well-behaved, convergence near singular points or \
discontinuities is slow \[LongDash] a famous example being the Gibbs' \
phenomena for Fourier series. If the form of the singularity is known then \
one can explicitly take this into account using series re-arrangement to \
dramatically improve the convergence of series expansions. \
\>", "Text",
  CellTags->{
  "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
    "series re-arrangement"}],

Cell[TextData[{
  "As a specific example, consider the generating function for the Legendre \
polynomials, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            TagBox["P",
              LegendreP], "n"], "(", "x", ")"}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(1\/\@\(1 - 2  x\ t + t\^2\)\), "=", " ", 
          RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"], "(", "x", ")"}], \(t\^n\)}]}]}], ",", 
        " ", \(\(-1\) < x < 1\), ",", 
        RowBox[{
          FormBox[\(\[LeftBracketingBar]t\[RightBracketingBar]\),
            "TraditionalForm"], "<", "1."}]}], TraditionalForm]], 
  "NumberedEquation",
  CellTags->"generating function"],

Cell[TextData[{
  "Expand the left hand side of equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "generating function"],
  ") into a series in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and verify that it generates the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            TagBox["P",
              LegendreP], "n"], "(", "x", ")"}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, \[Ellipsis], 5\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`R = \@\(1 - 2  x\ t + t\^2\)\)]],
  ", show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t R == \((t - x)\)/R\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - 2  x\ t + t\^2)\)/R == R\)]],
  ".  By hand, or using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", formally conclude that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\_t\), 
            RowBox[{"(", 
              RowBox[{\((1 - 2  x\ t + t\^2)\), 
                RowBox[{
                  SubscriptBox[
                    TagBox["P",
                      LegendreP], "n"], "(", "x", ")"}], \(t\^n\)}], ")"}]}], 
          "==", 
          RowBox[{\((t - x)\), 
            RowBox[{
              SubscriptBox[
                TagBox["P",
                  LegendreP], "n"], "(", "x", ")"}], \(t\^n\)}]}], 
        TraditionalForm]]],
  " where there is an ",
  StyleBox["implied summation",
    FontSlant->"Italic"],
  " over the index ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart"],

Cell[CellGroupData[{

Cell[TextData[{
  "From [b] and, by considering a ",
  StyleBox["generic term",
    FontSlant->"Italic"],
  " on the right hand side of equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "generating function"],
  "), ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              TagBox["P",
                LegendreP], "n"], "(", "x", ")"}], \(t\^n\)}], TraditionalForm
        ]]],
  ", using ",
  StyleBox["pattern-matching",
    FontSlant->"Italic"],
  " and ",
  StyleBox["replacement rules",
    FontSlant->"Italic"],
  " (or by hand),",
  " show that the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            TagBox["P",
              LegendreP], "n"], "(", "x", ")"}], TraditionalForm]]],
  " satisfy the following recurrence relation:"
}], "LetteredPart"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"x", " ", 
          RowBox[{
            SubscriptBox[
              TagBox["P",
                LegendreP], "n"], "(", "x", ")"}]}], "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"n", " ", 
                RowBox[{
                  SubscriptBox[
                    TagBox["P",
                      LegendreP], \(n - 1\)], "(", "x", ")"}]}], "+", 
              RowBox[{\((n + 1)\), " ", 
                RowBox[{
                  SubscriptBox[
                    TagBox["P",
                      LegendreP], \(n + 1\)], "(", "x", ")"}]}]}], 
            \(2\ n + 1\)], "\[CenterDot]"}]}], TraditionalForm]], 
  "NumberedEquation",
  CellTags->"recurrence relation"],

Cell[TextData[{
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": You may find the replacement rule, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          \(anything_\ t\^\(n + k_. \) \[RuleDelayed] 
            \((anything /. n \[Rule] n - k)\) t\^n\),
          "Input"], TraditionalForm]]],
  ", useful. ",
  StyleBox["[4]", "Marks"]
}], "SubPart"]
}, Open  ]],

Cell[TextData[{
  "Check that recurrence relation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "recurrence relation"],
  ") holds for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, \[Ellipsis], 5\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "Make repetitive use of the recurrence relation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "recurrence relation"],
  ") to reduce ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x\^3\), " ", 
          RowBox[{
            SubscriptBox[
              TagBox["P",
                LegendreP], "n"], "(", "x", ")"}]}], TraditionalForm]]],
  " to an expansion only  involving Legendre polynomials. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["//.",
          "Input"], TraditionalForm]]],
  " to repeatedly execute a replacement rule until the expression no longer \
changes. Also, you can use ",
  Cell[BoxData[
      FormBox[
        StyleBox["Collect",
          "Input"], TraditionalForm]]],
  " to group together all terms multiplying the same Legendre polynomial \
(which has the generic pattern",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              TagBox["P",
                LegendreP], "n_"],
            "Input"], "(", 
          StyleBox["x",
            "Input"], 
          StyleBox[")",
            "Input"]}], TraditionalForm]]],
  "). ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart"],

Cell[CellGroupData[{

Cell[TextData[{
  "Consider the ",
  StyleBox["generic term",
    FontSlant->"Italic"],
  " of the expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((1 - x)\), " ", 
          RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
            RowBox[{\(a\_n\), " ", 
              RowBox[{
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"], "(", "x", ")"}]}]}]}], TraditionalForm]
        ]],
  ", (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_n\), " ", \((1 - x)\), " ", 
          RowBox[{
            SubscriptBox[
              TagBox["P",
                LegendreP], "n"], "(", "x", ")"}]}], TraditionalForm]]],
  "). Use the recurrence relation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "recurrence relation"],
  ") to show that "
}], "LetteredPart",
  CellTags->"generic term"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\((1 - x)\), 
          RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
            RowBox[{\(a\_n\), " ", 
              RowBox[{
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"], "(", "x", ")"}]}]}]}], "\[Congruent]", 
        "  ", 
        RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
          RowBox[{
          \((\(-\(\(n\ a\_\(n - 1\)\)\/\(2\ n - 1\)\)\) + a\_n - 
                \(\((n + 1)\)\ a\_\(n + 1\)\)\/\(2\ n + 3\))\), " ", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"], "(", "x", ")"}], "."}]}]}]}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"Legendre expansion:acceleration"],

Cell[TextData[{
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": You may find the replacement rule, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["anything_",
              "Input"], 
            StyleBox[" ",
              "Input"], 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  TagBox["P",
                    LegendreP], \(n + k_. \)],
                "Input"], "(", 
              StyleBox["x",
                "Input"], 
              StyleBox[")",
                "Input"]}]}], 
          StyleBox["\[RuleDelayed]",
            "Input"], 
          RowBox[{
            StyleBox[\((anything /. n \[Rule] n - k)\),
              "Input"], 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"],
                "Input"], "(", 
              StyleBox["x",
                "Input"], 
              StyleBox[")",
                "Input"]}]}]}], TraditionalForm]]],
  ", useful. ",
  StyleBox["[2]", "Marks"]
}], "SubPart"],

Cell[TextData[{
  "Such a re-arrangement can be used to accelerate the convergence of \
expansions which have a singularity at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  "."
}], "SubPart"],

Cell[CellGroupData[{

Cell[TextData[{
  "Formally, when ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ", equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "generating function"],
  ") becomes"
}], "SubPart"],

Cell[BoxData[
    FormBox[
      RowBox[{\(1\/\@\(1 - x\)\), "=", 
        RowBox[{\(\@2\), " ", 
          RowBox[{\(\[Sum]\+\(n = 0\)\%\[Infinity]\), 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  TagBox["P",
                    LegendreP], "n"], "(", "x", ")"}], "."}]}]}]}], 
      TraditionalForm]], "NumberedEquation",
  CellTags->"Legendre expansion"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Make a plot which compares the left hand side of equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Legendre expansion"],
  ") with a partial sum of the right hand side of equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Legendre expansion"],
  "). Comment on the convergence of the partial sum. ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "Use equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Legendre expansion:acceleration"],
  ") to accelerate the convergence of equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Legendre expansion"],
  "). Make a plot of a partial sum of the accelerated series to demonstrate \
how much the convergence has improved ",
  StyleBox["[4]", "Marks"]
}], "LetteredPart"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Maxwell Construction ",
  StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
  "The equation of state of an ideal gas of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalN]\)]],
  " noninteracting classical particles reads"
}], "Text",
  CellTags->{"equation of state", "ideal gas"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(p\ V \[Equal] \[ScriptCapitalN]\ \(k\_B\) T, \)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  " is the Boltzmann constant. A simple approximation, taking into account \
the interaction between particles, is the van der Waals equation of state,"
}], "Text",
  CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\((p + a\/V\^2)\) \((V - b)\) \[Equal] 
      \[ScriptCapitalN]\ \(k\_B\) T\)\(,\)\)\)], "NumberedEquation",
  CellTags->"van der Waals"],

Cell[TextData[{
  "with parameters ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ".  As you will see, there exists a critical temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  " below which loops appear in the ",
  Cell[BoxData[
      \(TraditionalForm\`p - V\)]],
  " diagram.  These loops are forbidden for thermodynamical reasons. For ",
  Cell[BoxData[
      \(TraditionalForm\`T < T\_c\)]],
  ", a phase transition between gas and liquid takes place; at ",
  Cell[BoxData[
      \(TraditionalForm\`T = T\_c\)]],
  " the difference between the liquid and gaseous phases vanishes."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  " are determined by the condition that the first and second derivatives of \
",
  Cell[BoxData[
      \(TraditionalForm\`p(V, T)\)]],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " vanish, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\(p(V, T)\)\), \(\[PartialD]V\),
            MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( p(V, T)\)\), \(\[PartialD]V\^2\),
            MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
  ". "
}], "Text"]
}, Open  ]],

Cell[TextData[{
  "Determine ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and the corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c = p(V\_c, T\_c)\)]],
  " for the van der Waals equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "van der Waals"],
  "). ",
  "As a check, you should find that ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c = a\/\(27\ b\^2\)\)]],
  ". ",
  StyleBox["[5]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "Rescale ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`p\_c\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_c\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_c\)]],
  ", respectively, to obtain a dimensionless form of the van der Waals \
equation. In the following, the dimensionless parameters are denoted using ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~ = x/x\_c\)]],
  ". ",
  StyleBox["[4]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "Plot a set of ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~ - V\&~\)]],
  " curves for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", 
          "1.05"}], TraditionalForm]]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`0.5 \[LessEqual] V\&~ \[LessEqual] 5\)]],
  " to visualise the unphysical van der Waals loops which arise for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\&~\), "<", 
          StyleBox["1",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], TraditionalForm]]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart"],

Cell[CellGroupData[{

Cell[TextData[{
  "Over a certain temperature range, three volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v\_2 \[LessEqual] v\_3\)]],
  " correspond to each pressure ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\&~\)\)]],
  ".  For thermodynamic reasons, the transition from the gas with large \
volume ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ", to the liquid, with small volume ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", takes place at the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p\_t\)\&~\)\)]],
  " for which "
}], "SubPart",
  CellGroupingRules->{"SectionGrouping", 45}],

Cell[BoxData[
    \(TraditionalForm
    \`\[Integral]\_v\_1\%v\_3\(\( p\&~\)(v)\) \[DifferentialD]v = 
      \((v\_3 - v\_1)\) \(\(\(p\_t\)\&~\)\(\[CenterDot]\)\)\)], 
  "NumberedEquation",
  CellTags->"equal area"],

Cell[CellGroupData[{

Cell[TextData[{
  "At ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~\)]],
  ", gas and liquid are simultaneously present for all volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_3\)]],
  "; one observes a two-phase mixture.  Geometrically, equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "equal area"],
  ") means that the area between the curve ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\&~\)(v)\)]],
  " and the straight line ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~ = constant\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1 \[LessEqual] v \[LessEqual] v\_2\)]],
  " is the same as the corresponding area for ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2 \[LessEqual] v \[LessEqual] v\_3\)]],
  ". This is known as the ",
  StyleBox["Maxwell construction",
    FontSlant->"Italic"],
  ". We want to construct the line ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_t\)\&~ = constant\)]],
  ", the two-phase line. For the two-phase line we need two equations in \
order to determine the two unknown volumes ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  ":"
}], "SubPart",
  CellTags->{"two-phase line", "Maxwell construction"}],

Cell[BoxData[
    FormBox[GridBox[{
          
          {\(\(p\&~\) \((v\_1, t)\)\), "\[Equal]", \(\(\(p\&~\)(v\_3, t)\)\(,
            \)\)},
          
          {\(\[Integral]\_v\_1\%v\_3\(\( p\&~\)(v, t)\) \[DifferentialD]v\), 
            "\[Equal]", \(\((v\_3 - v\_1)\) \(\(\(p\&~\)(v\_1, t)\)\(.\)\)\)}
          }], TraditionalForm]], "NumberedEquation",
  CellTags->"two-phase"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "There is no simple analytical solution to equations (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "two-phase"],
  ") so, for each temperature, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], 
        TraditionalForm]]],
  ", determine ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_3\)]],
  " using ",
  Cell[BoxData[
      FormBox[
        StyleBox["FindRoot",
          "Input"], TraditionalForm]]],
  ". You will need fairly accurate initial guesses \[LongDash] these can be \
obtained from the plots of the unphysical van der Waals ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~ - V\&~\)]],
  " equation in part [c]. ",
  StyleBox["[6]", "Marks"]
}], "LetteredPart"],

Cell[TextData[{
  "Display the Maxwell construction for the van der Waals equation for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", 
          "1.05"}], TraditionalForm]]],
  ". Physically interpret the lowest three curves (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "=", 
            StyleBox["0.85`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], 
        TraditionalForm]]],
  ") and the two-phase lines.",
  " ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Normal Modes of a Circular Membrane ",
  StyleBox["[20]", "Marks"]
}], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell["\<\
If there is no external force, the (wave) equation for free \
vibrations of a uniform isotropic membrane reads\
\>", "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2 u\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "\[Equal]", 
          \(c\^2\ \[CapitalDelta]\ u\)}], ","}], TraditionalForm]], 
  "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"wave equation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  " is the two-dimensional Laplacian. For a circular membrane of radius ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " fixed at its edge, polar coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta])\)\)]],
  " are convenient; the boundary condition is ",
  Cell[BoxData[
      \(TraditionalForm\`u(1, \[Theta], t) \[Equal] 0\)]],
  " and the Laplacian reads"
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->{"Laplacian", "polar coordinates", "boundary condition"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[CapitalDelta][f_] := 
      \(1\/r\) \[PartialD]\((r \[PartialD]f\/\[PartialD]r)\)\/\[PartialD]r + 
        \(1\/r\^2\) \[PartialD]\^2 f\/\[PartialD]\[Theta]\^2\)], "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[TextData[{
  "By hand, or using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", apply separation of variables, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`u(r, \[Theta], t) = 
        \(R(r)\)\ \(\[CapitalTheta](
            \[Theta])\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\)]],
  ", and introduce a ",
  StyleBox["separation constant",
    FontSlant->"Italic"],
  ", to reduce equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "wave equation"],
  ") to a pair of ordinary differential equations. ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"separation of variables"],

Cell[TextData[{
  "Solve the differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\)]],
  ". What condition does this solution place on the separation constant? ",
  " ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": a physical solution must be single-valued, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalTheta](\[Theta] + 2  m\ \[Pi]) \[Equal] 
        \[CapitalTheta](\[Theta])\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"m", "\[Element]", 
          FormBox[
            TagBox["\[DoubleStruckCapitalZ]",
              (Integers&)],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Hence, c",
  "hoose the separation constant so that you will get trigonometric solutions \
to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\)]],
  "-equation.",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Determine the differential equation for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", eliminating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " using ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2 = \[Omega]\^2/c\^2\)]],
  ", and solve this equation. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you should obtain a solution involving a pair of Bessel functions.  ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "With the condition on the separation constant found in [b], the pair of \
Bessel functions obtained in [c] become ",
  StyleBox["dependent",
    FontSlant->"Italic"],
  ". Verify this by simplifying the solution obtained in [c] (using ",
  Cell[BoxData[
      FormBox[
        StyleBox["Simplify",
          "Input"], TraditionalForm]]],
  ") for a few allowed values of the separation constant. ",
  StyleBox["[1]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "For integral ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", the linearly independent solutions to Bessel's equation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(z\^2\), 
              RowBox[{
                SuperscriptBox["w", "\[Prime]\[Prime]",
                  MultilineFunction->None], "(", "z", ")"}]}], "+", 
            RowBox[{"z", " ", 
              RowBox[{
                SuperscriptBox["w", "\[Prime]",
                  MultilineFunction->None], "(", "r", ")"}]}], "+", 
            \(\((z\^2 - n\^2)\)\ \(w(r)\)\)}], "\[Equal]", "0"}], 
        TraditionalForm]]],
  ", are ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_n\)(z)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_n\)(z)\)]],
  ". Produce plots of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_n\)(z)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_n\)(z)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, \[Ellipsis]4\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] z \[LessEqual] 10\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Considering the nature of the solution at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ", explain why terms involving ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_n\)]],
  " are excluded. Combining the results of [b]-[e], write down the general \
solution to equation (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "wave equation"],
  ").  ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Apply the boundary condition, ",
  Cell[BoxData[
      \(TraditionalForm\`u(1, \[Theta], t) = 0\)]],
  ", to write down an expression which implicitly determines the allowed \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Determine the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-values corresponding to the 10 lowest frequencies and, in one plot, \
display the corresponding (unnormalised) radial functions ",
  Cell[BoxData[
      \(TraditionalForm\`R(r)\)]],
  ". ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(\[Omega]/c = 2  \[Pi]\ \[Nu]/\ c\)\)]],
  ". You should find the ",
  Cell[BoxData[
      FormBox[
        StyleBox["NumericalMath`BesselZeros`",
          "Input"], TraditionalForm]]],
  " package useful. Note that the lowest frequency terms arise from ",
  StyleBox["different",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`J\_n\)]],
  ". ",
  StyleBox["[6]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Produce an animation of one period (",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]/\[Omega]\)]],
  ") of ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta], t)\)]],
  " for the third lowest frequency. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you may find ",
  Cell[BoxData[
      FormBox[
        StyleBox["CylindricalPlot3D",
          "Input"], TraditionalForm]]],
  " useful. ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Ground State Energy of Helium ",
  StyleBox["[20]", "Marks"]
}], "Section",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "In atomic units, the Hamiltonian for a two-electron atom with nuclear \
charge ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          FormBox["\[ScriptCapitalZ]",
            "TraditionalForm"], "+"], TraditionalForm]]],
  " reads"
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->"helium"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[ScriptCapitalH] = 
      \(-\(1\/2\)\) \((\[CapitalDelta]\_1 + \[CapitalDelta]\_2)\) - 
        \[ScriptCapitalZ]\/r\_1 - \[ScriptCapitalZ]\/r\_2 + 1\/r\_12\)\(,
    \)\)\)], "NumberedEquation",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "where the ",
  StyleBox["interparticle coordinates",
    FontSlant->"Italic"],
  " \[LongDash] ",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_12\)]],
  "\[LongDash] are defined in Figure 1."
}], "Text",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  ShowCellBracket->False,
  CellMargins->{{Inherited, Inherited}, {0, 0}},
  CellElementSpacings->{"CellMinHeight"->0.0625,
  "ClosedCellHeight"->0.0625},
  CellOpen->False,
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  ShowCellBracket->False,
  CellMargins->{{Inherited, Inherited}, {0, 0}},
  CellElementSpacings->{"CellMinHeight"->0.0625,
  "ClosedCellHeight"->0.0625},
  CellOpen->False,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(Show[Graphics[
          {Arrow[{0, 0}, \ {1, 0.1}]\ , Arrow[{0, 0}, \ {0.7, 1}], 
            Arrow[{0.7, 1}, {1, 0.1}], AbsolutePointSize[40], \ 
            Point[{0, 0}], AbsolutePointSize[20], Point[{1, 0.1}], 
            Point[{0.7, 1}], Text[r\_1, \ {0.3, 0.55}], 
            Text[r\_2, \ {0.5, 0}], Text[r\_12, \ {0.9, 0.55}], GrayLevel[1], 
            Text[1, \ {0.7, 1}], Text[2, \ {1, 0.1}], 
            Text[\(\[ScriptCapitalZ]\^+\), \ {0, 0}]}], 
        AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-0.1\), 1.1}}];\)\)], "Input",
  ShowCellBracket->False,
  CellMargins->{{Inherited, Inherited}, {0, 0}},
  CellElementSpacings->{"CellMinHeight"->0.0625,
  "ClosedCellHeight"->0.0625},
  CellOpen->False,
  PageBreakBelow->Automatic],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.833333 0.0833333 0.833333 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.08333 .08333 m
.91667 .16667 L
s
% Start of user PostScript
0 0 1. 0.1 MAarrowhead1
% End of user PostScript
.08333 .08333 m
.66667 .91667 L
s
% Start of user PostScript
0 0 0.7 1. MAarrowhead1
% End of user PostScript
.66667 .91667 m
.91667 .16667 L
s
% Start of user PostScript
0.7 1. 1. 0.1 MAarrowhead1
% End of user PostScript
40 Mabswid
.08333 .08333 Mdot
20 Mabswid
.91667 .16667 Mdot
.66667 .91667 Mdot
gsave
.33333 .54167 -67.2188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.5 .08333 -67.2188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.83333 .54167 -68.9688 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Italic
%%IncludeFont: Times-Italic
/Times-Italic findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
66.875 14.562 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
1 g
gsave
.66667 .91667 -65.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
gsave
.91667 .16667 -65.5 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
gsave
.08333 .08333 -70.0938 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math5
%%IncludeFont: Math5
/Math5 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(Z) show
71.625 9.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(+) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageBreakBelow->Automatic,
  ImageSize->{172, 170.812},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0.0741279, 1}, {0.0673253, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002/0000ZQ000`40O003h00O[7oo002/Ool00:ao
o`00[7oo002/Ool001Ioo`P008ioo`004Woo4000RWoo000@OolD0028Ool000mooaH008Moo`003Goo
6P00QGoo000<OolL0024Ool000]ooah008=oo`002Woo8000PWoo000:OolP0022Ool000Uoob80085o
o`0027oo9000P7oo0008OolT0020Ool000MoobH007moo`001goo9P00Ogoo0007OolV001oOol000Mo
obH007moo`001Woo3`0017oo5@00;Goo1000CGoo0006Ool<0003Ool400000goo0000000B000YOol0
0`00Oomoo`02Ool00`00Oomoo`1=Ool000Ioo`h00003Ool0000001L002Uoo`03001oogoo00=oo`03
001oogoo04aoo`001Woo3`0000=oo`0000005P00:Woo00@007ooOol0009oo`03001oogoo04]oo`00
1Woo400000=oo`000000100000=oo`0000003P00:Woo0P000Woo0P00CWoo0006OolA00000goo0000
000300000goo0000000B000UOol200000goo001oo`1@Ool000Ioo`d00003Ool0000000800003Ool0
000000Eoo`h000Aoo`T0075oo`001Woo3P001goo0P0000=oo`0000003P003Goo2@00Egoo1P002goo
0007OolF00000goo0000000=000GOol:001;Ool:0009Ool000MoobH0025oo`T0041oo`h000Moo`00
1goo9P00:Woo2P00=Goo40001Woo0007OolV000dOol9000/Ool@0006Ool000Qoob@003ioo`X0025o
oa8000Eoo`0027oo9000B7oo2@0067oo4P001Goo0009OolR001BOol9000>OolD0004Ool000Yoob00
05aoo`X000Aoo`L000Aoo`T000Aoo`002Woo8000IWoo2`0000Aoo`00001oo`T000Aoo`002goo7P00
Jgoo200000=oo`0000002@0017oo000<OolL001/Ool900000goo000000080004Ool000eooaX006eo
o`X00003Ool0000000L000Aoo`003goo5`00Kgoo1P0000Aoo`00001oo`P000Eoo`0047oo500000=o
o`00Ool0KWoo1`000Woo2@001Goo000BOol@0004Ool00`00Oomoo`1]Ool@0006Ool001Ioo`P000Uo
o`03001oogoo06aooa0000Ioo`009goo00<007ooOol0KGoo3P001goo000XOol00`00Oomoo`1^Ool:
0009Ool002Uoo`03001oogoo06ioo`L000]oo`00:Woo00<007ooOol0KGoo00<007ooOol03goo000Z
Ool00`00Oomoo`1]Ool00`00Oomoo`0?Ool002]oo`03001oogoo06]oo`03001oogoo011oo`00;7oo
00<007ooOol0JWoo00<007ooOol047oo000/Ool00`00Oomoo`1ZOol00`00Oomoo`0@Ool002eoo`03
001oogoo06Qoo`03001oogoo015oo`00;Woo00<007ooOol0Igoo00<007ooOol04Goo000^Ool00`00
Oomoo`1WOol00`00Oomoo`0AOol002moo`03001oogoo06Eoo`03001oogoo019oo`00<7oo00<007oo
Ool0I7oo00<007ooOol04Woo000aOol00`00Oomoo`1SOol00`00Oomoo`0BOol0035oo`03001oogoo
069oo`03001oogoo01=oo`00<Woo00<007ooOol0HGoo00<007ooOol04goo000cOol00`00Oomoo`1P
Ool00`00Oomoo`0COol003=oo`03001oogoo05moo`03001oogoo01Aoo`00=7oo00<007ooOol0GWoo
00<007ooOol057oo000eOol00`00Oomoo`1MOol00`00Oomoo`0DOol003Ioo`03001oogoo05]oo`03
001oogoo01Eoo`00=Woo00<007ooOol0Fgoo00<007ooOol05Goo000gOol00`00Oomoo`1JOol00`00
Oomoo`0EOol003Qoo`03001oogoo05Qoo`03001oogoo01Ioo`00>7oo00<007ooOol0F7oo00<007oo
Ool05Woo000iOol00`00Oomoo`1GOol00`00Oomoo`0FOol003Yoo`03001oogoo05Eoo`03001oogoo
01Moo`00>Woo00<007ooOol0EGoo00<007ooOol05goo000kOol00`00Oomoo`1DOol00`00Oomoo`0G
Ool003aoo`03001oogoo059oo`03001oogoo01Qoo`00?Goo00<007ooOol0DGoo00<007ooOol067oo
000mOol00`00Oomoo`1AOol00`00Oomoo`0HOol003ioo`03001oogoo04moo`03001oogoo01Uoo`00
?goo00<007ooOol0CWoo00<007ooOol06Goo000oOol00`00Oomoo`1>Ool00`00Oomoo`0IOol0041o
o`03001oogoo04aoo`03001oogoo01Yoo`00@Goo00<007ooOol0Bgoo00<007ooOol06Woo0012Ool0
0`00Oomoo`1:Ool00`00Oomoo`0JOol0049oo`03001oogoo04Uoo`03001oogoo01]oo`00@goo00<0
07ooOol0B7oo00<007ooOol06goo0014Ool00`00Oomoo`17Ool00`00Oomoo`0KOol004Aoo`03001o
ogoo04Ioo`03001oogoo01aoo`00AGoo00<007ooOol0AGoo00<007ooOol077oo0016Ool00`00Oomo
o`14Ool00`00Oomoo`0LOol004Ioo`03001oogoo04=oo`03001oogoo01eoo`00Agoo00<007ooOol0
@Woo00<007ooOol07Goo0018Ool00`00Oomoo`11Ool00`00Oomoo`0MOol004Uoo`03001oogoo03mo
o`03001oogoo01ioo`00@Goo0`001Goo00<007ooOol0?goo00<007ooOol00`0000=oo`0000000P00
5Woo0012Ool00`00Oomoo`05Ool00`00Oomoo`0nOol01@00Oomoogoo00000goo00<007ooOol05Woo
000mOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0EOol003eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03aoo`03
001oogoo009oo`04001oogoo0002Ool00`00Oomoo`0DOol003ioo`03001oogoo008000Uoo`03001o
ogoo03]oo`80009oo`8000=oo`8001Moo`00?Woo0P003Goo00<007ooOol0>Goo00@007oo000001mo
o`00?Goo0P0000=oo`00Ool02goo00<007ooOol0>Goo0`0000=oo`00Ool07Goo001>Ool00`00Oomo
o`0hOol00`00Oomoo`0POol004moo`03001oogoo03Ioo`03001oogoo025oo`00D7oo00<007ooOol0
=Goo00<007ooOol08Goo001@Ool00`00Oomoo`0eOol00`00Oomoo`0QOol0055oo`03001oogoo03=o
o`03001oogoo029oo`00DWoo00<007ooOol0<Woo00<007ooOol08Woo001BOol00`00Oomoo`0bOol0
0`00Oomoo`0ROol005=oo`03001oogoo031oo`03001oogoo02=oo`00E7oo00<007ooOol0;goo00<0
07ooOol08goo001EOol00`00Oomoo`0^Ool00`00Oomoo`0SOol005Eoo`03001oogoo02eoo`03001o
ogoo02Aoo`00EWoo00<007ooOol0;7oo00<007ooOol097oo001GOol00`00Oomoo`0[Ool00`00Oomo
o`0TOol005Moo`03001oogoo02Yoo`03001oogoo02Eoo`00F7oo00<007ooOol0:Goo00<007ooOol0
9Goo001IOol00`00Oomoo`0XOol00`00Oomoo`0UOol005Uoo`03001oogoo02Moo`03001oogoo02Io
o`00FWoo00<007ooOol09Woo00<007ooOol09Woo001KOol00`00Oomoo`0UOol00`00Oomoo`0VOol0
05aoo`03001oogoo02=oo`03001oogoo02Moo`00G7oo00<007ooOol08goo00<007ooOol09goo001M
Ool00`00Oomoo`0ROol00`00Oomoo`0WOol005ioo`03001oogoo021oo`03001oogoo02Qoo`00GWoo
00<007ooOol087oo00<007ooOol0:7oo001OOol00`00Oomoo`0OOol00`00Oomoo`0XOol0061oo`03
001oogoo01eoo`03001oogoo02Uoo`00HGoo00<007ooOol077oo00<007ooOol0:Goo001QOol00`00
Oomoo`0LOol00`00Oomoo`0YOol0069oo`03001oogoo01Yoo`03001oogoo02Yoo`00Hgoo00<007oo
Ool06Goo00<007ooOol0:Woo001SOol00`00Oomoo`0IOol00`00Oomoo`0ZOol006Aoo`03001oogoo
01Moo`03001oogoo02]oo`00IGoo00<007ooOol05Woo00<007ooOol0:goo001UOol00`00Oomoo`0F
Ool00`00Oomoo`0[Ool006Ioo`03001oogoo01Aoo`03001oogoo02aoo`00Igoo00<007ooOol04goo
00<007ooOol0;7oo001XOol00`00Oomoo`0BOol00`00Oomoo`0/Ool006Qoo`03001oogoo015oo`03
001oogoo02eoo`00JGoo00<007ooOol047oo00<007ooOol0;Goo001ZOol00`00Oomoo`0?Ool00`00
Oomoo`0]Ool006Yoo`03001oogoo00ioo`03001oogoo02ioo`00Jgoo00<007ooOol03Goo00<007oo
Ool0;Woo001/Ool00`00Oomoo`0<Ool00`00Oomoo`0^Ool006aoo`03001oogoo00]oo`03001oogoo
02moo`00KGoo00<007ooOol02Woo00<007ooOol0;goo001^Ool00`00Oomoo`09Ool00`00Oomoo`0_
Ool006moo`03001oogoo00Moo`03001oogoo031oo`00Kgoo00@007ooOomoo`L0039oo`00L7oo2`00
<Goo001_Ool>000_Ool006iooa0002ioo`00KWoo4000;Woo001]OolB000]Ool006eooa8002eoo`00
K7oo20000goo2@00;7oo001/Ool900000goo00000008000/Ool006aoo`T00003Ool0000000P002ao
o`00K7oo2@0000=oo`0000002000;7oo001/Ool900000goo00000008000/Ool006aoo`P0009oo`X0
02aoo`00KGoo200000=oo`0000001`00;Goo001]OolB000]Ool006iooa0002ioo`00KWoo4000;Woo
001_Ool>000_Ool0075oo`X0035oo`00Lgoo1P00<goo002/Ool00:aoo`00[7oo0000\
\>"],
  ImageRangeCache->{{{12.75, 171}, {158.312, 0}} -> {-0.196689, -0.100243, 
  0.00758302, 0.00758302}}]
}, Open  ]],

Cell["Interparticle coordinates.", "NumberedFigure",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "In interparticle coordinates, the matrix element of a ",
  StyleBox["general",
    FontSlant->"Italic"],
  " operator, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  ", is defined by the following integral:"
}], "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\[Phi] 
          \[LeftBracketingBar]\[ScriptCapitalL]\[RightBracketingBar] 
          \[Phi]\[RightAngleBracket] = 
      8 \( \[Pi]\^2\) 
        \(\[Integral]\_0\%\[Infinity]\( r\_1\) \[DifferentialD]r\_1 
            \(\[Integral]\_0\%\[Infinity]\( r\_2\) \[DifferentialD]r\_2 
                \(\[Integral]\_\[LeftBracketingBar]r\_1 - r\_2\
\[RightBracketingBar]\%\(r\_1 + r\_2\)\(r\_12\) \(\[Phi]\^*\) 
                    \[ScriptCapitalL]\ \[Phi] 
                    \(\(\[DifferentialD]r\_12\)\(\[CenterDot]\)\)\)\)\)\)], 
  "NumberedEquation",
  PageBreakBelow->Automatic],

Cell["In assignment 6 you showed that for ", "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[\(\[Phi](r\_1, r\_2, r\_12)\),
            "TraditionalForm"], "=", 
          \(\[ExponentialE]\^\(\(-\[Lambda]\_1\) r\_1 - \(\[Lambda]\_2\) r\_2 
                - \(\[Lambda]\_12\) r\_12\)\)}], ","}], TraditionalForm]], 
  "NumberedEquation",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "the matrix element of an arbitrary monomial, ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\_1\%i\) \(r\_2\%j\) r\_12\%k\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`i, j, k \[GreaterEqual] \ \(-1\)\)]],
  ", can be computed by differentiating a particular matrix element, ",
  StyleBox["viz",
    FontSlant->"Italic"],
  ","
}], "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\(\[PartialD]\^\(i + j + k + 3\)\/\(\[PartialD]\[Lambda]\_1\%\(i + \
1\) \[PartialD]\[Lambda]\_2\%\(j + 1\) 
              \[PartialD]\[Lambda]\_12\%\(k + 1\)\)\) 
        \[LeftAngleBracket]\[Phi] 
            \[LeftBracketingBar]1\/\(\(r\_1\) \(r\_2\) r\_12\)\
\[RightBracketingBar] \[Phi]\[RightAngleBracket] = 
      \(\((\(-2\))\)\^\(i + j + k + 3\)\) 
        \[LeftAngleBracket]\[Phi] 
            \[LeftBracketingBar]\(r\_1\%i\) \(r\_2\%j\) 
                r\_12\%k\[RightBracketingBar] \[Phi]\[RightAngleBracket]\)\(,
    \)\)\)], "NumberedEquation",
  PageBreakBelow->Automatic],

Cell["where", "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\[Phi] 
          \[LeftBracketingBar]1\/\(\(r\_1\) \(r\_2\) r\_12\)\
\[RightBracketingBar] \[Phi]\[RightAngleBracket] = 
      \(\(\(2  \[Pi]\^2\)\/\(\((\[Lambda]\_1 + \[Lambda]\_2)\) 
              \((\[Lambda]\_1 + \[Lambda]\_12)\) 
              \((\[Lambda]\_2 + \[Lambda]\_12)\)\)\)\(\[CenterDot]\)\)\)], 
  "NumberedEquation",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "The importance of this result is that matrix elements of ",
  StyleBox["any",
    FontSlant->"Italic"],
  " combination of integral powers (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GreaterEqual]\)\(-1\)\)\)]],
  ") of the interparticle coordinates can be obtained by ",
  StyleBox["differentiation",
    FontSlant->"Italic"],
  " with respect to the parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_i\)]],
  "."
}], "Text",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "In interparticle coordinates the (",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "-state) ",
  StyleBox["kinetic energy operator",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalT] = 
        \(-\(1\/2\)\) \((\[CapitalDelta]\_1 + \[CapitalDelta]\_2)\)\)]],
  ", reads"
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->"kinetic energy operator"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ScriptCapitalT](\[Psi]_)\), ":=", 
        RowBox[{\(-\(1\/2\)\), " ", 
          RowBox[{"(", 
            RowBox[{
              FractionBox[\(\[PartialD]\^2 \[Psi]\), \(\[PartialD]r\_1\^2\),
                MultilineFunction->None], "+", 
              FractionBox[\(\[PartialD]\^2 \[Psi]\), \(\[PartialD]r\_2\^2\),
                MultilineFunction->None], "+", 
              RowBox[{"2", 
                
                FractionBox[\(\[PartialD]\^2 \[Psi]\), 
                  \(\[PartialD]r\_12\^2\),
                  MultilineFunction->None]}], "+", 
              RowBox[{\(2\/r\_1\), 
                FormBox[
                  FractionBox[\(\[PartialD]\[Psi]\), \(\[PartialD]r\_1\),
                    MultilineFunction->None],
                  "TraditionalForm"]}], "+", 
              RowBox[{\(2\/r\_2\), 
                FormBox[
                  FractionBox[\(\[PartialD]\[Psi]\), \(\[PartialD]r\_2\),
                    MultilineFunction->None],
                  "TraditionalForm"]}], "+", 
              RowBox[{\(4\/r\_12\), 
                FractionBox[\(\[PartialD]\[Psi]\), \(\[PartialD]r\_12\),
                  MultilineFunction->None]}], "+", 
              RowBox[{
              \(\((r\_1\%2 - r\_2\%2 + r\_12\%2)\)\/\(r\_1\ r\_12\)\), 
                
                FractionBox[\(\[PartialD]\^2 \[Psi]\), 
                  \(\[PartialD]r\_1\[ThinSpace]\[PartialD]r\_12\),
                  MultilineFunction->None]}], "+", 
              RowBox[{
              \(\((r\_2\%2 - r\_1\%2 + r\_12\%2)\)\/\(r\_2\ r\_12\)\), 
                
                FractionBox[\(\[PartialD]\^2 \[Psi]\), 
                  \(\[PartialD]r\_2\[ThinSpace]\[PartialD]r\_12\),
                  MultilineFunction->None]}]}], ")"}]}]}], TraditionalForm]], 
  "Input",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "the ",
  StyleBox["potential energy operator",
    FontSlant->"Italic"],
  ", \[ScriptCapitalV], is"
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->"potential energy operator"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[ScriptCapitalV] = 
        \(-\(\[ScriptCapitalZ]\/r\_1\)\) - \[ScriptCapitalZ]\/r\_2 + 1\/r\_12;
      \)\)], "Input",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "and the ",
  StyleBox["Hamiltonian",
    FontSlant->"Italic"],
  ", \[ScriptCapitalH], is"
}], "Text",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm
    \`\[ScriptCapitalH](\[Psi]_) := 
      \[ScriptCapitalT](\[Psi]) + \[ScriptCapitalV]\ \[Psi]\)], "Input",
  PageBreakBelow->Automatic],

Cell[TextData[{
  StyleBox["In ",
    FontSlant->"Plain"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" notation, the",
    FontSlant->"Plain"],
  StyleBox[" matrix element",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]i, j, k\[RightAngleBracket] \[Congruent] 
        \[LeftAngleBracket]\[Phi] 
            \[LeftBracketingBar]\(r\_1\%i\) \(r\_2\%j\) 
                r\_12\%k\[RightBracketingBar] \[Phi]\[RightAngleBracket]\)]],
  StyleBox[" can be computed and saved using the following code:",
    FontSlant->"Plain"]
}], "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]i_, j_, k_\[RightAngleBracket] := 
      \(\[LeftAngleBracket]i, j, k\[RightAngleBracket] = 
        \(1\/\((\(-2\))\)\^\(i + j + k + 3\)\) 
          \[PartialD]\_\({\[Lambda]\_1, i + 1}, {\[Lambda]\_2, j + 1}, {\
\[Lambda]\_12, k + 1}\)\(\(2  \[Pi]\^2\)\/\(\((\[Lambda]\_1 + \[Lambda]\_2)\) 
                  \((\[Lambda]\_1 + \[Lambda]\_12)\) 
                  \((\[Lambda]\_2 + \[Lambda]\_12)\)\)\)\)\)], "Input",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Using this result we can compute matrix elements of any zeroth order \
approximation consisting of a ",
  StyleBox["linear combination",
    FontSlant->"Italic"],
  " of terms of the form  ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(P(r\_1, r\_2, r\_12)\) 
        \[ExponentialE]\^\(\(-\[Lambda]\_1\) r\_1 - \(\[Lambda]\_2\) r\_2 - \
\(\[Lambda]\_12\) r\_12\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`P(r\_1, r\_2, r\_12)\)]],
  " is a polynomial in the interparticle coordinates."
}], "Text",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Consider the ",
  StyleBox["trial wavefunction",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Psi]\_0 = 
        \[ExponentialE]\^\(\(-\[ScriptCapitalZ]\)\ r\_1 - \[ScriptCapitalZ]\ \
r\_2 + r\_12/2\)\)]],
  ". "
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->"trial wavefunction"]
}, Open  ]],

Cell[TextData[{
  "Use ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]i, j, k\[RightAngleBracket]\)]],
  " to compute the normalisation integral ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\[Psi]\_0 | \[Psi]\_0\[RightAngleBracket]\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute the matrix element ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalE][\[ScriptCapitalZ]] = 
        \[LeftAngleBracket]\(\[Psi]\_0\) \
\[LeftBracketingBar]\[ScriptCapitalH]\[RightBracketingBar] \[Psi]\_0\
\[RightAngleBracket]\/\[LeftAngleBracket]\[Psi]\_0 | \[Psi]\_0\
\[RightAngleBracket]\)]],
  " and determine the approximation to the helium ground-state energy, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", \[ScriptCapitalE][2], for this trial wavefunction.  Compare your result \
with the non-relativistic ground-state energy for helium, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2.903724377034\)\)]],
  " a.u. ",
  StyleBox["[6]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->{"ground-state energy", "local energy"}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you may find it advantageous to compute the ",
  StyleBox["local energy",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH][\[Psi]\_0]/\[Psi]\_0\)]],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Psi]\_0\) 
            \[LeftBracketingBar]\[ScriptCapitalH]\[RightBracketingBar] 
            \[Psi]\_0\[RightAngleBracket] \[Congruent] 
        \[LeftAngleBracket]\(\[Psi]\_0\) 
            \[LeftBracketingBar]\[ScriptCapitalH][\[Psi]\_0]\/\[Psi]\_0\
\[RightBracketingBar] \[Psi]\_0\[RightAngleBracket]\)]],
  ". (",
  StyleBox["Aside",
    FontSlant->"Italic"],
  ": the quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH][\[Psi]]/\[Psi]\)]],
  " is known as the local energy because, if  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " were an exact solution to the Schr\[ODoubleDot]dinger equation, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalH][\[Psi]]/\[Psi] = \[ScriptCapitalE]\)]],
  ".  However, for approximate wavefunctions such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalH][\[Psi]\_0]/\[Psi]\_0\)]],
  " is a function of the interparticle coordinates.) You can then use ",
  StyleBox["pattern-matching",
    FontSlant->"Italic"],
  " to identify all the matrix elements you need to compute. There is a trick \
you can use to help here: suppose you would like to determine the powers of ",
  
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " in each term of the following expression,"
}], "SubPart",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm
    \`\(p = 1 + 2\/\(\(a\)\(\ \)\) + 3\/b + 4  a + 5  a\ b;\)\)], "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "and replace ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^m\) b\^n\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]m, n\[RightAngleBracket]\)]],
  ". The difficulty is that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not recognise ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^0\) b\^0\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`2/a\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \(a\^\(-1\)\) b\^0\)]],
  ".  This can be overcome by multiplying throughout by ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^i\) b\^j\)]],
  " (where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  ") and then using pattern-matching to replace ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^\(m + i\)\) b\^\(n + j\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]m, n\[RightAngleBracket]\)]],
  ", ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ","
}], "SubPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Expand[\(a\^i\) b\^j\ p]\)], "Input",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm
    \`2\ b\^j\ a\^\(i - 1\) + 3\ b\^\(j - 1\)\ a\^i + b\^j\ a\^i + 
      4\ b\^j\ a\^\(i + 1\) + 5\ b\^\(j + 1\)\ a\^\(i + 1\)\)], "Output",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`% /. \(a\^\(i + m_. \)\) b\^\(j + n_. \) \[Rule] 
        \[LeftAngleBracket]m, n\[RightAngleBracket]\)], "Input",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm
    \`2\ \[LeftAngleBracket]\(-1\), 0\[RightAngleBracket] + 
      3\ \[LeftAngleBracket]0, \(-1\)\[RightAngleBracket] + 
      \[LeftAngleBracket]0, 0\[RightAngleBracket] + 
      4\ \[LeftAngleBracket]1, 0\[RightAngleBracket] + 
      5\ \[LeftAngleBracket]1, 1\[RightAngleBracket]\)], "Output",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the pattern ",
  Cell[BoxData[
      FormBox[
        StyleBox["m_.",
          "Input"], TraditionalForm]]],
  " in ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(i + m_. \),
          "Input"], TraditionalForm]]],
  " indicates ",
  Cell[BoxData[
      FormBox[
        StyleBox["i",
          "Input"], TraditionalForm]]],
  " plus anything ",
  StyleBox["including",
    FontSlant->"Italic"],
  " 0."
}], "SubPart",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[TextData[{
  "Can you conclude whether ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\^-\)\)]],
  " is bound? ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE][1]\)]],
  " less than the ionization energy of hydrogen? ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"ionization energy"],

Cell[TextData[{
  "Using [b], produce a plot of energy versus \[ScriptCapitalZ] for \
two-electron atoms with nuclear charge ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \[ScriptCapitalZ] \[LessEqual] 5\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"helium iso-electronic sequence"],

Cell[TextData[{
  "Now consider the more general trial wavefunction ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Psi]\_0 = 
        \[ExponentialE]\^\(\(-\[Mu]\)\ r\_1 - \[Mu]\ r\_2 - \[Lambda]\ \
r\_12\)\)]],
  "."
}], "SubPart",
  CellGroupingRules->{"SectionGrouping", 45},
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Compute the matrix element ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[ScriptCapitalE]\_\(\[Lambda], \[Mu]\)[\[ScriptCapitalZ]] = 
        \[LeftAngleBracket]\(\[Psi]\_0\) \
\[LeftBracketingBar]\[ScriptCapitalH]\[RightBracketingBar] \[Psi]\_0\
\[RightAngleBracket]\/\[LeftAngleBracket]\[Psi]\_0 | \[Psi]\_0\
\[RightAngleBracket]\)]],
  ".  Use the ",
  StyleBox["variational method",
    FontSlant->"Italic"],
  " to ",
  StyleBox["numerically",
    FontSlant->"Italic"],
  " determine the values of \[Lambda] and \[Mu] that give the lowest \
ground-state energy for helium. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": use ",
  Cell[BoxData[
      FormBox[
        StyleBox["FindMinimum",
          "Input"], TraditionalForm]]],
  " to find values of \[Lambda] and \[Mu] such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalE]\_\(\[Lambda], \[Mu]\)[2]\)]],
  " is a minimum.  Do you expect this minimum energy to be lower than that \
obtained in [b]? If so, why? ",
  StyleBox["[7]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->{"variational method", "FindRoot"}],

Cell[TextData[{
  "Can you now conclude whether ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\^-\)\)]],
  " is bound? ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"ionization energy"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  "Pauli spin matrices",
  " and Dirac gamma matrices ",
  StyleBox["[20]", "Marks"]
}], "Section",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "The ",
  StyleBox["Pauli spin matrices",
    FontSlant->"Italic"],
  ", "
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->"Pauli spin matrices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_1\), "=", 
          RowBox[{"(", GridBox[{
                {"0", "1"},
                {"1", "0"}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], TraditionalForm]
      ], "Input",
  PageBreakBelow->Automatic],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_2\), "=", 
          RowBox[{"(", GridBox[{
                {"0", \(-\[ImaginaryI]\)},
                {"\[ImaginaryI]", "0"}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], TraditionalForm]
      ], "Input",
  PageBreakBelow->Automatic],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Sigma]", "/:", \(\[Sigma]\_3\), "=", 
          RowBox[{"(", GridBox[{
                {"1", "0"},
                {"0", \(-1\)}
                },
              ColumnAlignments->{Decimal}], ")"}]}], ";"}], TraditionalForm]
      ], "Input",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "along with the ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Cross]2\)]],
  " identity matrix:"
}], "Text",
  PageBreakBelow->Automatic],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalI]\_n_ := IdentityMatrix[n]\)], "Input",\

  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalI]\_2\)], "Input",
  PageBreakBelow->Automatic],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {"0", "1"}
            },
          ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}], TraditionalForm]
      ], "Output",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell["\<\
are used in a matrix representation of spin operators in quantum \
mechanics.\
\>", "Text",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Verify that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sigma]\_i . \[Sigma]\_i \[Equal] \[ScriptCapitalI]\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3\)]],
  ". ",
  StyleBox["[1]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Verify that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\([\[Sigma]\_i, \[Sigma]\_j]\) \[Congruent] \ 
        \[Sigma]\_i\[CenterDot]\[Sigma]\_j - 
          \[Sigma]\_j\[CenterDot]\[Sigma]\_i \[Equal] 
        2  \[ImaginaryI]\ \(\[Epsilon]\_\(i, j, k\)\) \[Sigma]\_k\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_\(i, j, k\)\)]],
  " is the (3-component) Levi-Civita tensor which is ",
  Cell[BoxData[
      \(TraditionalForm\`\(+1\)\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j, k)\)\)]],
  " is a cyclic permutation of the indices, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j, k)\)\)]],
  " is an anti-cyclic permutation, and ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " otherwise. ",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": there is a very simple and general ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation of this tensor, ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Epsilon]\_i__ := Signature[{i}]\),
          "Input"], TraditionalForm]]],
  ".  Also, you might find ",
  Cell[BoxData[
      FormBox[
        StyleBox["Permutations",
          "Input"], TraditionalForm]]],
  " useful. ",
  StyleBox["[4]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"Levi-Civita tensor"],

Cell[TextData[{
  "Show that the three matrices, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_i\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3\)]],
  ", along with unit ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalI]\_2\)]],
  " form a complete set of ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrices in the sense that an ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " complex ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " matrix can be expressed in terms of them. ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[TextData[{
  "Show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["A",
                  FontWeight->"Bold"]}], ")"}], 
            RowBox[{"(", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["B",
                  FontWeight->"Bold"]}], ")"}]}], "\[Equal]", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontWeight->"Bold"], "\[CenterDot]", 
              StyleBox["B",
                FontWeight->"Bold"]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
                StyleBox["\[Sigma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["A",
                      FontWeight->"Bold"], "\[Cross]", 
                    StyleBox["B",
                      FontWeight->"Bold"]}], ")"}]}]}]}]}], TraditionalForm]]]
  ,
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Sigma]",
            FontWeight->"Bold"], 
          StyleBox["\[Congruent]",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{
              TagBox[\(\[Sigma]\_1\),
                HoldForm], ",", 
              TagBox[\(\[Sigma]\_2\),
                HoldForm], ",", 
              TagBox[\(\[Sigma]\_3\),
                HoldForm]}], ")"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["A",
          FontWeight->"Bold"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["B",
          FontWeight->"Bold"], TraditionalForm]]],
  " are any two vectors. ",
  StyleBox["NB",
    FontSlant->"Italic"],
  ": this identity, as stated, is a typical abuse of notation widely used in \
quantum mechanics texts.  Explicitly, what you are trying to show is that "
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\((\(a\_1\) \[Sigma]\_1 + \(a\_2\) \[Sigma]\_2 + 
              \(a\_3\) \[Sigma]\_3)\) . 
          \((\(b\_1\) \[Sigma]\_1 + \(b\_2\) \[Sigma]\_2 + 
              \(b\_3\) \[Sigma]\_3)\)\), "\[Equal]", 
        RowBox[{
        \({a\_1, a\_2, a\_3} . {b\_1, b\_2, b\_3} \[ScriptCapitalI]\_2\), 
          "+", 
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
            \(({a\_1, a\_2, a\_3}\[Cross]{b\_1, b\_2, b\_3})\), ".", 
              \({\[Sigma]\_1, \[Sigma]\_2, \[Sigma]\_3}\), ".", " ", 
              StyleBox[\([3]\),
                "Marks"]}]}]}]}], TraditionalForm]], "NumberedEquation",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[TextData[{
  "The following set of 5, ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Times]4\)]],
  ", ",
  StyleBox["Dirac gamma matrices",
    FontSlant->"Italic"],
  " arise in relativistic quantum mechanics:"
}], "SubPart",
  PageBreakBelow->Automatic,
  CellTags->"Dirac gamma matrices"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Gamma]\_k\), "=", 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"\[ScriptCapitalO]", \(\(-\[ImaginaryI]\)\ \[Sigma]\_k\)},
                {\(\[ImaginaryI]\ \[Sigma]\_k\), "\[ScriptCapitalO]"}
                }], "\[NoBreak]", ")"}]}], ",", " ", \(k = 1\), ",", "2", 
        ",", "3", ",", "\[IndentingNewLine]", 
        RowBox[{\(\[Gamma]\_4\), "=", 
          RowBox[{"(", GridBox[{
                {\(\[ScriptCapitalI]\_2\), "\[ScriptCapitalO]"},
                {"\[ScriptCapitalO]", \(-\[ScriptCapitalI]\_2\)}
                }], ")"}]}], ",", "\[IndentingNewLine]", 
        \(\[Gamma]\_5 = \ 
          \[Gamma]\_1 . \[Gamma]\_2 . \[Gamma]\_3 . \[Gamma]\_4\), ","}], 
      TraditionalForm]], "NumberedEquation",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalO]\)]],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " zero matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalI]\_2\)]],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`2\[Times]2\)]],
  " unit matrix, and the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\_k\)]],
  " are the Pauli spin matrices."
}], "SubPart",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[TextData[{
  "Implement these matrices and show that they satisfy the following ",
  StyleBox["anti-commutation",
    FontSlant->"Italic"],
  " relation,",
  " ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Gamma]\_\[Mu] . \[Gamma]\_\[Nu] + \[Gamma]\_\[Nu] . \[Gamma]\_\[Mu] 
        \[Equal] 2  \[Delta]\_\(\[Mu], \[Nu]\)\ \[ScriptCapitalI]\_4\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu], \[Nu] = 1, 2, 3, 4\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_\(\[Mu], \[Nu]\)\)]],
  " is the Kronecker delta function. ",
  StyleBox["[4]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Introducing the commutator bracket, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\([\[ScriptCapitalA], \[ScriptCapitalB]]\) = 
        \[ScriptCapitalA] . \[ScriptCapitalB] - 
          \[ScriptCapitalB] . \[ScriptCapitalA]\)]],
  ", show that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sigma]\_\(\[Mu], \[Nu]\) = 
        \(\(1\/\(2\ \[ImaginaryI]\)\)[\[Gamma]\_\[Mu], \[Gamma]\_\[Nu]] = \ 
          \(-\[ImaginaryI]\)\ \[Gamma]\_\[Mu] . \[Gamma]\_\[Nu]\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu] \[NotEqual] \[Nu] = 1, 2, 3, 4\)]],
  ". ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Show that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sum]\+\(\[Mu] = 1\)\%4 \[Gamma]\_\[Mu] . 
            \((\[Gamma] . \[ScriptCapitalA])\) . 
            \((\[Gamma] . \[ScriptCapitalB])\) . 
            \((\[Gamma] . \[ScriptCapitalC])\) . \[Gamma]\_\[Mu] \[Equal] 
        \(-2\) \((\[Gamma] . \[ScriptCapitalC])\) . 
            \((\[Gamma] . \[ScriptCapitalB])\) . 
            \((\[Gamma] . \[ScriptCapitalA])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm
      \`Tr(\[Gamma]\_5 . \((\[Gamma] . \[ScriptCapitalA])\) . 
            \((\[Gamma] . \[ScriptCapitalB])\)) \[Equal] 0\)]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Gamma]", "=", 
          RowBox[{"(", 
            RowBox[{
              TagBox[\(\[Gamma]\_1\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_2\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_3\),
                HoldForm], ",", 
              TagBox[\(\[Gamma]\_4\),
                HoldForm]}], ")"}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\)]],
  " are ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " 4-vectors, ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] = {a\_1, a\_2, a\_3, a\_4}\)]],
  ", ",
  StyleBox["etc",
    FontSlant->"Italic"],
  "., and ",
  Cell[BoxData[
      \(TraditionalForm\`Tr\)]],
  " denotes the trace of a square matrix (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the sum of the diagonal entries in the matrix).",
  " ",
  " ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". Series ",
  StyleBox["[20]", "Marks"]
}], "Section",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Discrete nonlinear transform ",
  StyleBox["[12]", "Marks"]
}], "Subsection",
  PageBreakBelow->Automatic],

Cell["Consider the formal Taylor series", "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Sum]\+\(n = 0\)\%\[Infinity]\(\((\(-1\))\)\^n\) \(a\_n\) x\^n\)\(,
    \)\)\)], "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"Taylor series"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0 = 1\)]],
  "and the continued fraction"
}], "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(1\/\(1 + 
            \(\(b\_1\) x\)\/\(1 + \(\(b\_2\) x\)\/\(1 + \(\(b\_3\) x\)\/\(1 + \
\[Ellipsis]\)\)\)\)\)\(\[CenterDot]\)\)\)], "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"continued fraction"],

Cell[TextData[{
  "Assuming that the expressions in (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "Taylor series"],
  ") and (",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Equation", "continued fraction"],
  ") represent the same function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", use series expansion to determine the forward and inverse relationship \
between ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] n \[LessEqual] 5\)]],
  ".  For example, ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2 \[Rule] b\_1\%2 + \(b\_1\) b\_2\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(b\_2\), "\[Rule]", 
          RowBox[{
            FormBox[\(a\_2\/a\_1\),
              "TraditionalForm"], "-", \(a\_1\)}]}], TraditionalForm]]],
  ".  Verify that each relationship is self-consistent by substituting one \
into the other. ",
  StyleBox["[6]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\_n\), "=", 
          RowBox[{\(\((\(-1\))\)\^n\), " ", 
            SubscriptBox[
              TagBox["E",
                EulerE], \(2\ n\)]}]}], TraditionalForm]]],
  ", where the ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(2  n\)\)]],
  " are the (even) Euler numbers, compute the associated ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] n \[LessEqual] 5\)]],
  " and comment. Use this result to obtain a simple continued fraction \
expansion whose Maclaurin series generates the Euler numbers. ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "Compute the Maclaurin series of ",
  Cell[BoxData[
      \(TraditionalForm\`sec(x)\)]],
  " and relate the coefficients to the ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(2  n\)\)]],
  ". ",
  StyleBox["[3]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  ". Kepler equation ",
  StyleBox["[8]", "Marks"]
}], "Subsection",
  PageBreakBelow->Automatic],

Cell[TextData[{
  "The ",
  StyleBox["Kepler equation",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s = u + e\ sin\ s\)]],
  ", arises in celestial mechanics. Defining ",
  Cell[BoxData[
      \(TraditionalForm\`s = u + a\)]],
  " reduces the equation to ",
  Cell[BoxData[
      \(TraditionalForm\`a = e\ \(sin(u + a)\)\)]],
  " which can be formally solved by introducing the recurrence relation ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k = e\ \(sin(u + a\_\(k - 1\))\)\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is a small parameter, as ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Rule] \[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(k - 1\) \[Rule] \(a\_k \[Rule] a\)\)]],
  ", and hence the Kepler equation is formally satisfied."
}], "Text",
  PageBreakBelow->Automatic,
  CellTags->{
  "Kepler equation", "celestial mechanics", "power series solution", 
    "formal solution"}],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " a small quantity, this equation can be solved using power series. Use \
series expansion and dynamic programming (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(k  _\) := \(a\_k = \[Ellipsis]\)\)]],
  ") to solve the Kepler equation recursively up to sixth order.  Use ",
  Cell[BoxData[
      FormBox[
        StyleBox["TrigReduce",
          "Input"], TraditionalForm]]],
  " to express the result as a Fourier series expansion. Note that you need \
to define a suitable initial condition (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  "). ",
  StyleBox["[6]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"dynamic programming"],

Cell[TextData[{
  "Check the ",
  StyleBox["self-consistency ",
    FontSlant->"Italic"],
  "of your solution to the Kepler equation (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", substitute your series solution back into the Kepler equation). ",
  StyleBox["[2]", "Marks"]
}], "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"self-consistency "]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 580}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{732, 553},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, None}, {
    None, Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", 
          " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"]
        , "]"}], "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{
      {"Section", 0}, {"Equation", 0}, {"Figure", 0}, {"Subtitle", 0}, {
        "Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{
      {"Section", 0}, {"Equation", 0}, {"Figure", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{
      {"Equation", 0}, {"NumberedEquation", 0}, {"NumberedBullet", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Equation", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LetteredPart"],
    CellDingbat->None,
    CellMargins->{{14, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 45},
    PageBreakBelow->False,
    CellFrameLabels->{{Cell[ 
            TextData[ {"[", 
              CounterBox[ "Subsubsection", CounterFunction -> (Part[ 
                  CharacterRange[ "a", "z"], #]&)], "]"}]], None}, {
        None, None}},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["LetteredPart", "Presentation"],
    CellDingbat->None,
    CellMargins->{{14, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["LetteredPart", "Printout"],
    CellDingbat->None,
    CellMargins->{{14, 0}, {4, 20}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubPart"],
    CellDingbat->None,
    CellMargins->{{34, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabels->{{None, None}, {None, None}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["SubPart", "Presentation"],
    CellDingbat->None,
    CellMargins->{{42, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["SubPart", "Printout"],
    CellDingbat->None,
    CellMargins->{{35, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Marks"],
    FontFamily->"Times",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Marks", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Marks", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Marks", "Printout"],
    CellMargins->{{9, 0}, {72, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    FontFamily->"Chicago",
    FontSize->10],
  
  Cell[StyleData["Menu", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Menu", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Menu", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedBullet"],
    CellMargins->{{23, Inherited}, {4, 18}},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "NumberedBullet"], ". "}]], None}, {None, None}},
    CounterIncrements->"NumberedBullet"],
  
  Cell[StyleData["NumberedBullet", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["NumberedBullet", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["NumberedBullet", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedExercise"],
    CellMargins->{{23, Inherited}, {4, 18}},
    PageBreakBelow->False,
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "NumberedExercise"], ". "}]], None}, {None, None}},
    CounterIncrements->"NumberedExercise",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["NumberedExercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["NumberedExercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["NumberedExercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedAnswer"],
    CellMargins->{{23, Inherited}, {4, 18}},
    PageBreakBelow->False,
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "NumberedExercise"], ". Answer:"}]], None}, {
        None, None}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["NumberedAnswer", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["NumberedAnswer", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["NumberedAnswer", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellGroupingRules->{"SectionGrouping", 55},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"], "."}]], None}, {None, None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    FormatType->InputForm,
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    FormatType->InputForm,
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`On3ohP==`Tf0fL5N`?P0080004/0B`000000`d26P01
0000I00000400@410?l00BL?00400@IfTc0000000000060801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Gibbs' phenomena"->{
    Cell[2956, 95, 708, 12, 74, "Text",
      CellTags->{
      "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
        "series re-arrangement"}]},
  "Fourier series"->{
    Cell[2956, 95, 708, 12, 74, "Text",
      CellTags->{
      "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
        "series re-arrangement"}]},
  "orthogonal polynomials"->{
    Cell[2956, 95, 708, 12, 74, "Text",
      CellTags->{
      "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
        "series re-arrangement"}]},
  "series re-arrangement"->{
    Cell[2956, 95, 708, 12, 74, "Text",
      CellTags->{
      "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
        "series re-arrangement"}]},
  "generating function"->{
    Cell[3963, 121, 583, 15, 45, "NumberedEquation",
      CellTags->"generating function"]},
  "recurrence relation"->{
    Cell[7222, 244, 774, 23, 38, "NumberedEquation",
      CellTags->"recurrence relation"]},
  "generic term"->{
    Cell[9963, 348, 922, 34, 36, "LetteredPart",
      CellTags->"generic term"]},
  "Legendre expansion:acceleration"->{
    Cell[10888, 384, 811, 21, 45, "NumberedEquation",
      CellTags->"Legendre expansion:acceleration"]},
  "Legendre expansion"->{
    Cell[13263, 471, 404, 11, 45, "NumberedEquation",
      CellTags->"Legendre expansion"]},
  "equation of state"->{
    Cell[14707, 531, 232, 6, 21, "Text",
      CellTags->{"equation of state", "ideal gas"}]},
  "ideal gas"->{
    Cell[14707, 531, 232, 6, 21, "Text",
      CellTags->{"equation of state", "ideal gas"}]},
  "Boltzmann constant"->{
    Cell[15080, 545, 305, 7, 34, "Text",
      CellTags->{"Boltzmann constant", "van der Waals equation"}]},
  "van der Waals equation"->{
    Cell[15080, 545, 305, 7, 34, "Text",
      CellTags->{"Boltzmann constant", "van der Waals equation"}]},
  "van der Waals"->{
    Cell[15422, 557, 183, 4, 28, "NumberedEquation",
      CellTags->"van der Waals"]},
  "equal area"->{
    Cell[19764, 718, 215, 5, 35, "NumberedEquation",
      CellTags->"equal area"]},
  "two-phase line"->{
    Cell[20004, 727, 1376, 43, 96, "SubPart",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "Maxwell construction"->{
    Cell[20004, 727, 1376, 43, 96, "SubPart",
      CellTags->{"two-phase line", "Maxwell construction"}]},
  "two-phase"->{
    Cell[21383, 772, 388, 9, 40, "NumberedEquation",
      CellTags->"two-phase"]},
  "wave equation"->{
    Cell[24006, 870, 323, 9, 32, "NumberedEquation",
      PageBreakBelow->Automatic,
      CellTags->"wave equation"]},
  "Laplacian"->{
    Cell[24332, 881, 584, 16, 34, "Text",
      PageBreakBelow->Automatic,
      CellTags->{"Laplacian", "polar coordinates", "boundary condition"}]},
  "polar coordinates"->{
    Cell[24332, 881, 584, 16, 34, "Text",
      PageBreakBelow->Automatic,
      CellTags->{"Laplacian", "polar coordinates", "boundary condition"}]},
  "boundary condition"->{
    Cell[24332, 881, 584, 16, 34, "Text",
      PageBreakBelow->Automatic,
      CellTags->{"Laplacian", "polar coordinates", "boundary condition"}]},
  "separation of variables"->{
    Cell[25180, 907, 729, 26, 48, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"separation of variables"]},
  "helium"->{
    Cell[31335, 1131, 326, 11, 26, "Text",
      PageBreakBelow->Automatic,
      CellTags->"helium"]},
  "kinetic energy operator"->{
    Cell[49808, 1720, 423, 15, 30, "Text",
      PageBreakBelow->Automatic,
      CellTags->"kinetic energy operator"]},
  "potential energy operator"->{
    Cell[52101, 1780, 201, 7, 28, "Text",
      PageBreakBelow->Automatic,
      CellTags->"potential energy operator"]},
  "trial wavefunction"->{
    Cell[54640, 1863, 344, 13, 28, "Text",
      PageBreakBelow->Automatic,
      CellTags->"trial wavefunction"]},
  "ground-state energy"->{
    Cell[55385, 1894, 858, 23, 60, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->{"ground-state energy", "local energy"}]},
  "local energy"->{
    Cell[55385, 1894, 858, 23, 60, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->{"ground-state energy", "local energy"}]},
  "ionization energy"->{
    Cell[60870, 2084, 402, 14, 36, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"ionization energy"],
    Cell[63090, 2157, 231, 8, 34, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"ionization energy"]},
  "helium iso-electronic sequence"->{
    Cell[61275, 2100, 351, 9, 34, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"helium iso-electronic sequence"]},
  "variational method"->{
    Cell[61945, 2123, 1142, 32, 74, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->{"variational method", "FindRoot"}]},
  "FindRoot"->{
    Cell[61945, 2123, 1142, 32, 74, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->{"variational method", "FindRoot"}]},
  "Pauli spin matrices"->{
    Cell[63541, 2180, 168, 7, 21, "Text",
      PageBreakBelow->Automatic,
      CellTags->"Pauli spin matrices"]},
  "Levi-Civita tensor"->{
    Cell[65847, 2274, 1404, 46, 72, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"Levi-Civita tensor"]},
  "Dirac gamma matrices"->{
    Cell[70871, 2440, 297, 10, 36, "SubPart",
      PageBreakBelow->Automatic,
      CellTags->"Dirac gamma matrices"]},
  "Taylor series"->{
    Cell[76186, 2628, 205, 5, 39, "NumberedEquation",
      PageBreakBelow->Automatic,
      CellTags->"Taylor series"]},
  "continued fraction"->{
    Cell[76563, 2644, 262, 6, 53, "NumberedEquation",
      PageBreakBelow->Automatic,
      CellTags->"continued fraction"]},
  "Kepler equation"->{
    Cell[79176, 2744, 977, 30, 60, "Text",
      PageBreakBelow->Automatic,
      CellTags->{
      "Kepler equation", "celestial mechanics", "power series solution", 
        "formal solution"}]},
  "celestial mechanics"->{
    Cell[79176, 2744, 977, 30, 60, "Text",
      PageBreakBelow->Automatic,
      CellTags->{
      "Kepler equation", "celestial mechanics", "power series solution", 
        "formal solution"}]},
  "power series solution"->{
    Cell[79176, 2744, 977, 30, 60, "Text",
      PageBreakBelow->Automatic,
      CellTags->{
      "Kepler equation", "celestial mechanics", "power series solution", 
        "formal solution"}]},
  "formal solution"->{
    Cell[79176, 2744, 977, 30, 60, "Text",
      PageBreakBelow->Automatic,
      CellTags->{
      "Kepler equation", "celestial mechanics", "power series solution", 
        "formal solution"}]},
  "dynamic programming"->{
    Cell[80156, 2776, 852, 27, 67, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"dynamic programming"]},
  "self-consistency "->{
    Cell[81011, 2805, 362, 11, 36, "LetteredPart",
      PageBreakBelow->Automatic,
      CellTags->"self-consistency "]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Gibbs' phenomena", 117099, 4086},
  {"Fourier series", 117286, 4091},
  {"orthogonal polynomials", 117481, 4096},
  {"series re-arrangement", 117675, 4101},
  {"generating function", 117867, 4106},
  {"recurrence relation", 117988, 4109},
  {"generic term", 118102, 4112},
  {"Legendre expansion:acceleration", 118224, 4115},
  {"Legendre expansion", 118357, 4118},
  {"equation of state", 118476, 4121},
  {"ideal gas", 118588, 4124},
  {"Boltzmann constant", 118709, 4127},
  {"van der Waals equation", 118848, 4130},
  {"van der Waals", 118978, 4133},
  {"equal area", 119084, 4136},
  {"two-phase line", 119191, 4139},
  {"Maxwell construction", 119327, 4142},
  {"two-phase", 119452, 4145},
  {"wave equation", 119557, 4148},
  {"Laplacian", 119695, 4152},
  {"polar coordinates", 119871, 4156},
  {"boundary condition", 120048, 4160},
  {"separation of variables", 120230, 4164},
  {"helium", 120372, 4168},
  {"kinetic energy operator", 120507, 4172},
  {"potential energy operator", 120661, 4176},
  {"trial wavefunction", 120809, 4180},
  {"ground-state energy", 120952, 4184},
  {"local energy", 121115, 4188},
  {"ionization energy", 121283, 4192},
  {"helium iso-electronic sequence", 121565, 4199},
  {"variational method", 121726, 4203},
  {"FindRoot", 121881, 4207},
  {"Pauli spin matrices", 122047, 4211},
  {"Levi-Civita tensor", 122189, 4215},
  {"Dirac gamma matrices", 122342, 4219},
  {"Taylor series", 122484, 4223},
  {"continued fraction", 122632, 4227},
  {"Kepler equation", 122782, 4231},
  {"celestial mechanics", 123007, 4237},
  {"power series solution", 123234, 4243},
  {"formal solution", 123455, 4249},
  {"dynamic programming", 123680, 4255},
  {"self-consistency ", 123830, 4259}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 48, 0, 50, "Title"],

Cell[CellGroupData[{
Cell[1790, 53, 34, 0, 43, "Subsection"],
Cell[1827, 55, 320, 9, 34, "Text"],
Cell[2150, 66, 647, 17, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2834, 88, 119, 5, 33, "Section"],
Cell[2956, 95, 708, 12, 74, "Text",
  CellTags->{
  "Gibbs' phenomena", "Fourier series", "orthogonal polynomials", 
    "series re-arrangement"}],
Cell[3667, 109, 293, 10, 26, "Text"],
Cell[3963, 121, 583, 15, 45, "NumberedEquation",
  CellTags->"generating function"],
Cell[4549, 138, 562, 22, 34, "LetteredPart"],
Cell[5114, 162, 1158, 39, 54, "LetteredPart"],

Cell[CellGroupData[{
Cell[6297, 205, 922, 37, 52, "LetteredPart"],
Cell[7222, 244, 774, 23, 38, "NumberedEquation",
  CellTags->"recurrence relation"],
Cell[7999, 269, 359, 12, 36, "SubPart"]
}, Open  ]],
Cell[8373, 284, 284, 12, 34, "LetteredPart"],
Cell[8660, 298, 1278, 46, 65, "LetteredPart"],

Cell[CellGroupData[{
Cell[9963, 348, 922, 34, 36, "LetteredPart",
  CellTags->"generic term"],
Cell[10888, 384, 811, 21, 45, "NumberedEquation",
  CellTags->"Legendre expansion:acceleration"],
Cell[11702, 407, 1106, 39, 36, "SubPart"],
Cell[12811, 448, 202, 6, 34, "SubPart"],

Cell[CellGroupData[{
Cell[13038, 458, 222, 11, 34, "SubPart"],
Cell[13263, 471, 404, 11, 45, "NumberedEquation",
  CellTags->"Legendre expansion"]
}, Open  ]]
}, Open  ]],
Cell[13694, 486, 418, 15, 48, "LetteredPart"],
Cell[14115, 503, 437, 16, 48, "LetteredPart"]
}, Closed]],

Cell[CellGroupData[{
Cell[14589, 524, 115, 5, 33, "Section"],
Cell[14707, 531, 232, 6, 21, "Text",
  CellTags->{"equation of state", "ideal gas"}],

Cell[CellGroupData[{
Cell[14964, 541, 113, 2, 20, "NumberedEquation"],
Cell[15080, 545, 305, 7, 34, "Text",
  CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[15422, 557, 183, 4, 28, "NumberedEquation",
  CellTags->"van der Waals"],
Cell[15608, 563, 680, 20, 47, "Text"],
Cell[16291, 585, 826, 29, 39, "Text"]
}, Open  ]],
Cell[17132, 617, 530, 22, 49, "LetteredPart"],
Cell[17665, 641, 642, 25, 48, "LetteredPart"],
Cell[18310, 668, 778, 25, 51, "LetteredPart"],

Cell[CellGroupData[{
Cell[19113, 697, 648, 19, 60, "SubPart",
  CellGroupingRules->{"SectionGrouping", 45}],
Cell[19764, 718, 215, 5, 35, "NumberedEquation",
  CellTags->"equal area"],

Cell[CellGroupData[{
Cell[20004, 727, 1376, 43, 96, "SubPart",
  CellTags->{"two-phase line", "Maxwell construction"}],
Cell[21383, 772, 388, 9, 40, "NumberedEquation",
  CellTags->"two-phase"]
}, Open  ]]
}, Open  ]],
Cell[21798, 785, 945, 33, 63, "LetteredPart"],
Cell[22746, 820, 801, 26, 51, "LetteredPart"]
}, Closed]],

Cell[CellGroupData[{
Cell[23584, 851, 231, 9, 33, "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  PageBreakBelow->Automatic],
Cell[23818, 862, 163, 4, 21, "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[24006, 870, 323, 9, 32, "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"wave equation"],
Cell[24332, 881, 584, 16, 34, "Text",
  PageBreakBelow->Automatic,
  CellTags->{"Laplacian", "polar coordinates", "boundary condition"}],
Cell[24919, 899, 246, 5, 41, "Input",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[25180, 907, 729, 26, 48, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"separation of variables"],
Cell[25912, 935, 973, 32, 60, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[26888, 969, 497, 16, 48, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[27388, 987, 493, 13, 60, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[27884, 1002, 1205, 40, 61, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[29092, 1044, 471, 17, 48, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[29566, 1063, 1068, 35, 84, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[30637, 1100, 505, 18, 48, "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[31179, 1123, 153, 6, 33, "Section",
  PageBreakBelow->Automatic],
Cell[31335, 1131, 326, 11, 26, "Text",
  PageBreakBelow->Automatic,
  CellTags->"helium"],

Cell[CellGroupData[{
Cell[31686, 1146, 271, 6, 40, "NumberedEquation",
  PageBreakBelow->Automatic],
Cell[31960, 1154, 375, 16, 28, "Text",
  PageBreakBelow->Automatic],
Cell[32338, 1172, 287, 7, 0, "Input",
  CellOpen->False,
  PageBreakBelow->Automatic],
Cell[32628, 1181, 292, 7, 0, "Input",
  CellOpen->False,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[32945, 1192, 828, 17, 0, "Input",
  CellOpen->False,
  PageBreakBelow->Automatic],
Cell[33776, 1211, 12399, 391, 179, 6041, 308, "GraphicsData", 
"PostScript", "Graphics",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[46190, 1605, 81, 1, 22, "NumberedFigure",
  PageBreakBelow->Automatic],
Cell[46274, 1608, 289, 9, 28, "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[46600, 1622, 645, 13, 42, "NumberedEquation",
  PageBreakBelow->Automatic],
Cell[47248, 1637, 81, 1, 26, "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[47366, 1643, 351, 9, 25, "NumberedEquation",
  PageBreakBelow->Automatic],
Cell[47720, 1654, 399, 12, 28, "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[48156, 1671, 635, 13, 47, "NumberedEquation",
  PageBreakBelow->Automatic],
Cell[48794, 1686, 50, 1, 26, "Text",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[48881, 1692, 423, 9, 43, "NumberedEquation",
  PageBreakBelow->Automatic],
Cell[49307, 1703, 498, 15, 46, "Text",
  PageBreakBelow->Automatic],
Cell[49808, 1720, 423, 15, 30, "Text",
  PageBreakBelow->Automatic,
  CellTags->"kinetic energy operator"],
Cell[50234, 1737, 1864, 41, 89, "Input",
  PageBreakBelow->Automatic],
Cell[52101, 1780, 201, 7, 28, "Text",
  PageBreakBelow->Automatic,
  CellTags->"potential energy operator"],
Cell[52305, 1789, 194, 5, 46, "Input",
  PageBreakBelow->Automatic],
Cell[52502, 1796, 150, 6, 28, "Text",
  PageBreakBelow->Automatic],
Cell[52655, 1804, 174, 4, 28, "Input",
  PageBreakBelow->Automatic],
Cell[52832, 1810, 720, 22, 28, "Text",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[53555, 1834, 509, 9, 48, "Input",
  PageBreakBelow->Automatic],
Cell[54067, 1845, 570, 16, 44, "Text",
  PageBreakBelow->Automatic],
Cell[54640, 1863, 344, 13, 28, "Text",
  PageBreakBelow->Automatic,
  CellTags->"trial wavefunction"]
}, Open  ]],
Cell[54999, 1879, 361, 11, 34, "LetteredPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[55385, 1894, 858, 23, 60, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->{"ground-state energy", "local energy"}],

Cell[CellGroupData[{
Cell[56268, 1921, 1783, 50, 102, "SubPart",
  PageBreakBelow->Automatic],
Cell[58054, 1973, 139, 3, 43, "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[58230, 1981, 1191, 45, 68, "SubPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[59446, 2030, 103, 2, 29, "Input",
  PageBreakBelow->Automatic],
Cell[59552, 2034, 206, 4, 29, "Output",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[59795, 2043, 185, 4, 29, "Input",
  PageBreakBelow->Automatic],
Cell[59983, 2049, 362, 7, 26, "Output",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],
Cell[60372, 2060, 483, 21, 36, "SubPart",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[60870, 2084, 402, 14, 36, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"ionization energy"],
Cell[61275, 2100, 351, 9, 34, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"helium iso-electronic sequence"],
Cell[61629, 2111, 313, 10, 35, "SubPart",
  CellGroupingRules->{"SectionGrouping", 45},
  PageBreakBelow->Automatic],
Cell[61945, 2123, 1142, 32, 74, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->{"variational method", "FindRoot"}],
Cell[63090, 2157, 231, 8, 34, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"ionization energy"]
}, Closed]],

Cell[CellGroupData[{
Cell[63358, 2170, 180, 8, 33, "Section",
  PageBreakBelow->Automatic],
Cell[63541, 2180, 168, 7, 21, "Text",
  PageBreakBelow->Automatic,
  CellTags->"Pauli spin matrices"],
Cell[63712, 2189, 329, 10, 34, "Input",
  PageBreakBelow->Automatic],
Cell[64044, 2201, 356, 10, 34, "Input",
  PageBreakBelow->Automatic],
Cell[64403, 2213, 332, 10, 34, "Input",
  PageBreakBelow->Automatic],
Cell[64738, 2225, 156, 6, 21, "Text",
  PageBreakBelow->Automatic],
Cell[64897, 2233, 123, 3, 22, "Input",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[65045, 2240, 99, 2, 22, "Input",
  PageBreakBelow->Automatic],
Cell[65147, 2244, 257, 8, 34, "Output",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[65419, 2255, 130, 4, 21, "Text",
  PageBreakBelow->Automatic],
Cell[65552, 2261, 292, 11, 36, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[65847, 2274, 1404, 46, 72, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"Levi-Civita tensor"],
Cell[67254, 2322, 711, 25, 52, "LetteredPart",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[67990, 2351, 2155, 67, 50, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[70148, 2420, 698, 16, 37, "NumberedEquation",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[70871, 2440, 297, 10, 36, "SubPart",
  PageBreakBelow->Automatic,
  CellTags->"Dirac gamma matrices"],
Cell[71171, 2452, 831, 17, 86, "NumberedEquation",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[72017, 2472, 480, 18, 34, "SubPart",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[72512, 2493, 647, 19, 51, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[73162, 2514, 675, 19, 40, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[73840, 2535, 1855, 62, 67, "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[75732, 2602, 130, 6, 33, "Section",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[75887, 2612, 193, 9, 43, "Subsection",
  PageBreakBelow->Automatic],
Cell[76083, 2623, 78, 1, 21, "Text",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[76186, 2628, 205, 5, 39, "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"Taylor series"],
Cell[76394, 2635, 154, 6, 21, "Text",
  PageBreakBelow->Automatic]
}, Open  ]],
Cell[76563, 2644, 262, 6, 53, "NumberedEquation",
  PageBreakBelow->Automatic,
  CellTags->"continued fraction"],
Cell[76828, 2652, 1098, 40, 77, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[77929, 2694, 735, 22, 48, "LetteredPart",
  PageBreakBelow->Automatic],
Cell[78667, 2718, 290, 10, 34, "LetteredPart",
  PageBreakBelow->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[78994, 2733, 179, 9, 27, "Subsection",
  PageBreakBelow->Automatic],
Cell[79176, 2744, 977, 30, 60, "Text",
  PageBreakBelow->Automatic,
  CellTags->{
  "Kepler equation", "celestial mechanics", "power series solution", 
    "formal solution"}],
Cell[80156, 2776, 852, 27, 67, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"dynamic programming"],
Cell[81011, 2805, 362, 11, 36, "LetteredPart",
  PageBreakBelow->Automatic,
  CellTags->"self-consistency "]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

